(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1256608,      20666]*)
(*NotebookOutlinePosition[   1257236,      20688]*)
(*  CellTagsIndexPosition[   1257192,      20684]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Zweidimensionales Ising-Modell", "Subtitle",
  FontSize->26],

Cell["\[Copyright] Apl. Prof. Dr. J\[UDoubleDot]rgen Schnack, Probestudium \
2005", "Subsubtitle",
  FontSize->16],

Cell["\<\
Ising-Modell auf einem Quadratgitter der Gr\[ODoubleDot]\[SZ]e NMax \
* NMax.
Die Temperatur kann vorgegeben werden.
Die Wechselwirkung der Spins ist 1.
\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Einstellungen", "Section"],

Cell[BoxData[{
    \(\(NMax = 10;\)\), "\[IndentingNewLine]", 
    \(\(T = 2.6;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wechselwirkungsmatrix", "Section"],

Cell[BoxData[
    \(\(NMaxSq = NMax\^2;\)\)], "Input"],

Cell[TextData[{
  "Spins sind wie folgt abgez\[ADoubleDot]hlt:\n",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"1", "2", "3"},
            {"4", "5", "6"},
            {"7", "8", "9"}
            }], ")"}]]]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Hilfsfeld, in dem die Spinnummer in den Platz umgerechnet \
wird\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Platz = 
      Table[{IntegerPart[\(k - 1\)\/NMax] + 1, Mod[k - 1, NMax] + 1}, {k, 1, 
          NMaxSq}]\)], "Input"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 
        9}, {1, 10}, {2, 1}, {2, 2}, {2, 3}, {2, 4}, {2, 5}, {2, 6}, {2, 
        7}, {2, 8}, {2, 9}, {2, 10}, {3, 1}, {3, 2}, {3, 3}, {3, 4}, {3, 
        5}, {3, 6}, {3, 7}, {3, 8}, {3, 9}, {3, 10}, {4, 1}, {4, 2}, {4, 
        3}, {4, 4}, {4, 5}, {4, 6}, {4, 7}, {4, 8}, {4, 9}, {4, 10}, {5, 
        1}, {5, 2}, {5, 3}, {5, 4}, {5, 5}, {5, 6}, {5, 7}, {5, 8}, {5, 
        9}, {5, 10}, {6, 1}, {6, 2}, {6, 3}, {6, 4}, {6, 5}, {6, 6}, {6, 
        7}, {6, 8}, {6, 9}, {6, 10}, {7, 1}, {7, 2}, {7, 3}, {7, 4}, {7, 
        5}, {7, 6}, {7, 7}, {7, 8}, {7, 9}, {7, 10}, {8, 1}, {8, 2}, {8, 
        3}, {8, 4}, {8, 5}, {8, 6}, {8, 7}, {8, 8}, {8, 9}, {8, 10}, {9, 
        1}, {9, 2}, {9, 3}, {9, 4}, {9, 5}, {9, 6}, {9, 7}, {9, 8}, {9, 
        9}, {9, 10}, {10, 1}, {10, 2}, {10, 3}, {10, 4}, {10, 5}, {10, 
        6}, {10, 7}, {10, 8}, {10, 9}, {10, 10}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wechselwirkungsmatrix JMat", "Subsection"],

Cell[BoxData[{
    \(\(JMat = 
        Table[0, {i, 1, NMaxSq}, {j, 1, 
            NMaxSq}];\)\), "\[IndentingNewLine]", 
    \(\(For[i1 = 1, 
        i1 < NMax + 1, \(i1++\), \[IndentingNewLine]For[j1 = 1, 
          j1 < NMax + 1, \(j1++\), \[IndentingNewLine]For[i2 = 1, 
            i2 < NMax + 1, \(i2++\), \[IndentingNewLine]For[j2 = 1, 
              j2 < NMax + 
                  1, \(j2++\), \[IndentingNewLine] (*\ \(Print[i1, "\< \>", 
                    i2, "\< \>", j1, "\< \>", 
                    j2, "\< \>", \((i1 - 1)\)*NMax + 
                      j1, "\< \>", \((i2 - 1)\)*NMax + 
                      j2];\)\ *) \[IndentingNewLine]If[
                Mod[Abs[i1 - i2], NMax] \[Equal] 1 && j1 \[Equal] j2, 
                JMat[\([\((i1 - 1)\)*NMax + j1, \((i2 - 1)\)*NMax + j2]\)] = 
                  1]; \[IndentingNewLine]If[
                Mod[Abs[i1 - i2], NMax] \[Equal] NMax - 1 && j1 \[Equal] j2, 
                JMat[\([\((i1 - 1)\)*NMax + j1, \((i2 - 1)\)*NMax + j2]\)] = 
                  1]; \[IndentingNewLine]If[
                Mod[Abs[j1 - j2], NMax] \[Equal] 1 && i1 \[Equal] i2, 
                JMat[\([\((i1 - 1)\)*NMax + j1, \((i2 - 1)\)*NMax + j2]\)] = 
                  1]; \[IndentingNewLine]If[
                Mod[Abs[j1 - j2], NMax] \[Equal] NMax - 1 && i1 \[Equal] i2, 
                JMat[\([\((i1 - 1)\)*NMax + j1, \((i2 - 1)\)*NMax + j2]\)] = 
                  1]\[IndentingNewLine]]\[IndentingNewLine]]\
\[IndentingNewLine]]\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(MatrixForm[JMat];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ausgangszustand", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Spins = 
        Table[2*Random[Integer] - 1, {i, 1, NMax}, {j, 1, 
            NMax}];\)\), "\[IndentingNewLine]", 
    \(\(Spins0 = Spins;\)\), "\[IndentingNewLine]", 
    \(MatrixForm[Spins]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "1", \(-1\), \(-1\), \(-1\), \(-1\), \(-1\), 
              "1", \(-1\), \(-1\)},
            {\(-1\), \(-1\), \(-1\), \(-1\), \(-1\), \(-1\), "1", \(-1\), "1",
               "1"},
            {"1", "1", \(-1\), \(-1\), \(-1\), \(-1\), "1", \(-1\), 
              "1", \(-1\)},
            {\(-1\), \(-1\), \(-1\), "1", \(-1\), \(-1\), 
              "1", \(-1\), \(-1\), \(-1\)},
            {\(-1\), \(-1\), "1", "1", "1", "1", \(-1\), "1", "1", "1"},
            {"1", "1", \(-1\), "1", \(-1\), "1", \(-1\), \(-1\), \(-1\), 
              "1"},
            {"1", "1", "1", "1", "1", "1", "1", "1", \(-1\), \(-1\)},
            {\(-1\), "1", "1", "1", "1", "1", \(-1\), "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "1", \(-1\), "1", \(-1\)},
            {"1", "1", "1", \(-1\), "1", \(-1\), "1", \(-1\), "1", \(-1\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"I1", "=", 
        RowBox[{"Show", "[", 
          RowBox[{"Graphics", "[", 
            
            StyleBox[\(RasterArray[
                  Spins] /. {1 -> RGBColor[1, 0, 0], \(-1\) -> 
                    RGBColor[0, 0, 1]}, AspectRatio -> 1\),
              PageBreakAbove->False,
              AspectRatioFixed->True,
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF00000000FF
0000FF0000FF0000FFFF00000000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o
1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o6`3o0029
0000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0
oooo70000?lK0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00
=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK
0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?oo
o`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o
703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL
0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000
o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00
R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000o`L0oooo0006
0?oooa`0003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l0
03L0003o1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o
6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3o
ool000H0oooo70000?lK0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000
oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0oooo
70000?lK0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`00
0?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0ooooY@000?lK0?l0
01`0003o=`3o00070?ooo`001P3ooonU0000oa/0o`0070000?lg0?l000L0oooo00060?ooojD0003o
6`3o000L0000ocL0o`001`3oool000H0ooooY@000?lK0?l001`0003o=`3o00070?ooo`001P3ooonU
0000oa/0o`0070000?lg0?l000L0oooo00060?ooojD0003o6`3o000L0000ocL0o`001`3oool000H0
ooooY@000?lK0?l001`0003o=`3o00070?ooo`001P3ooonU0000oa/0o`0070000?lg0?l000L0oooo
00060?ooojD0003o6`3o000L0000ocL0o`001`3oool000H0ooooY@000?lK0?l001`0003o=`3o0007
0?ooo`001P3ooonU0000oa/0o`0070000?lg0?l000L0oooo00060?ooojD0003o6`3o000L0000ocL0
o`001`3oool000H0ooooY@000?lK0?l001`0003o=`3o00070?ooo`001P3ooonU0000oa/0o`007000
0?lg0?l000L0oooo00060?ooojD0003o6`3o000L0000ocL0o`001`3oool000H0ooooY@000?lK0?l0
01`0003o=`3o00070?ooo`001P3ooonU0000oa/0o`0070000?lg0?l000L0oooo00060?ooojD0003o
6`3o000L0000ocL0o`001`3oool000H0ooooY@000?lK0?l001`0003o=`3o00070?ooo`001P3ooonU
0000oa/0o`0070000?lg0?l000L0oooo00060?ooojD0003o6`3o000L0000ocL0o`001`3oool000H0
ooooY@000?lK0?l001`0003o=`3o00070?ooo`001P3ooonU0000oa/0o`0070000?lg0?l000L0oooo
00060?ooojD0003o6`3o000L0000ocL0o`001`3oool000H0ooooY@000?lK0?l001`0003o=`3o0007
0?ooo`001P3ooonU0000oa/0o`0070000?lg0?l000L0oooo00060?ooojD0003o6`3o000L0000ocL0
o`001`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o
001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK
0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0
oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`00
70000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3o
ool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000
oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0
003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o
001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK
0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0
oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`00
70000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3o
ool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000
oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0
003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o
001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK
0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0
oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`00
70000?lK0?l001`0003o1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lK0?l001`0003o1`3o
ool000H0ooooD`000?lK0?l003L0003o6`3o001C0000o`L0oooo00060?oooe<0003o6`3o000g0000
oa/0o`00D`000?l70?ooo`001P3ooomC0000oa/0o`00=`000?lK0?l005<0003o1`3oool000H0oooo
D`000?lK0?l003L0003o6`3o001C0000o`L0oooo00060?oooe<0003o6`3o000g0000oa/0o`00D`00
0?l70?ooo`001P3ooomC0000oa/0o`00=`000?lK0?l005<0003o1`3oool000H0ooooD`000?lK0?l0
03L0003o6`3o001C0000o`L0oooo00060?oooe<0003o6`3o000g0000oa/0o`00D`000?l70?ooo`00
1P3ooomC0000oa/0o`00=`000?lK0?l005<0003o1`3oool000H0ooooD`000?lK0?l003L0003o6`3o
001C0000o`L0oooo00060?oooe<0003o6`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooomC0000
oa/0o`00=`000?lK0?l005<0003o1`3oool000H0ooooD`000?lK0?l003L0003o6`3o001C0000o`L0
oooo00060?oooe<0003o6`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooomC0000oa/0o`00=`00
0?lK0?l005<0003o1`3oool000H0ooooD`000?lK0?l003L0003o6`3o001C0000o`L0oooo00060?oo
oe<0003o6`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooomC0000oa/0o`00=`000?lK0?l005<0
003o1`3oool000H0ooooD`000?lK0?l003L0003o6`3o001C0000o`L0oooo00060?oooe<0003o6`3o
000g0000oa/0o`00D`000?l70?ooo`001P3ooomC0000oa/0o`00=`000?lK0?l005<0003o1`3oool0
00H0ooooD`000?lK0?l003L0003o6`3o001C0000o`L0oooo00060?oooe<0003o6`3o000g0000oa/0
o`00D`000?l70?ooo`001P3ooomC0000oa/0o`00=`000?lK0?l005<0003o1`3oool000H0ooooD`00
0?lK0?l003L0003o6`3o001C0000o`L0oooo00060?oooe<0003o6`3o000g0000oa/0o`00D`000?l7
0?ooo`001P3ooomC0000oa/0o`00=`000?lK0?l005<0003o1`3oool000H0oooo=`000?m^0?l001/0
003oD`3o00070?ooo`001P3ooolg0000ofh0o`006`000?mC0?l000L0oooo00060?ooocL0003oKP3o
000K0000oe<0o`001`3oool000H0oooo=`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolg0000
ofh0o`006`000?mC0?l000L0oooo00060?ooocL0003oKP3o000K0000oe<0o`001`3oool000H0oooo
=`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolg0000ofh0o`006`000?mC0?l000L0oooo0006
0?ooocL0003oKP3o000K0000oe<0o`001`3oool000H0oooo=`000?m^0?l001/0003oD`3o00070?oo
o`001P3ooolg0000ofh0o`006`000?mC0?l000L0oooo00060?ooocL0003oKP3o000K0000oe<0o`00
1`3oool000H0oooo=`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolg0000ofh0o`006`000?mC
0?l000L0oooo00060?ooocL0003oKP3o000K0000oe<0o`001`3oool000H0oooo=`000?m^0?l001/0
003oD`3o00070?ooo`001P3ooolg0000ofh0o`006`000?mC0?l000L0oooo00060?ooocL0003oKP3o
000K0000oe<0o`001`3oool000H0oooo=`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolg0000
ofh0o`006`000?mC0?l000L0oooo00060?ooocL0003oKP3o000K0000oe<0o`001`3oool000H0oooo
=`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolg0000ofh0o`006`000?mC0?l000L0oooo0006
0?ooocL0003oKP3o000K0000oe<0o`001`3oool000H0oooo=`000?m^0?l001/0003oD`3o00070?oo
o`001P3ooolg0000ofh0o`006`000?mC0?l000L0oooo00060?ooocL0003oKP3o000K0000oe<0o`00
1`3oool000H0oooo=`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolg0?l001`0003o6`3o000K
0000oa`0o`00DP000?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003o703o001B0000
oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?lL0?l00580003o703o00070?ooo`00
1P3ooolg0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l000L0oooo00060?ooocL0o`007000
0?lK0?l001/0003o703o001B0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?lL
0?l00580003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l0
00L0oooo00060?ooocL0o`0070000?lK0?l001/0003o703o001B0000oa`0o`001`3oool000H0oooo
=`3o000L0000oa/0o`006`000?lL0?l00580003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o
000K0000oa`0o`00DP000?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003o703o001B
0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?lL0?l00580003o703o00070?oo
o`001P3ooolg0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l000L0oooo00060?ooocL0o`00
70000?lK0?l001/0003o703o001B0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`00
0?lL0?l00580003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000oa`0o`00DP000?lL
0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003o703o001B0000oa`0o`001`3oool000H0
oooo=`3o000L0000oa/0o`006`000?lL0?l00580003o703o00070?ooo`001P3ooolg0?l001`0003o
6`3o000K0000oa`0o`00DP000?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003o703o
001B0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?lL0?l00580003o703o0007
0?ooo`001P3ooolg0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l000L0oooo00060?ooocL0
o`0070000?lK0?l001/0003o703o001B0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`00
6`000?lL0?l00580003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000oa`0o`00DP00
0?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003o703o001B0000oa`0o`001`3oool0
00H0oooo=`3o000L0000oa/0o`006`000?lL0?l00580003o703o00070?ooo`001P3ooooL0?l003L0
003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL
0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`00
1P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l7
0?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00
=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?oo
om`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo
00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000
o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o
000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0
oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooolL0000ohT0o`006`00
0?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l0
01/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003o
R@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL
0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0
oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo
00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o0007
0?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0
o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`00
0?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l0
01/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003o
R@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL
0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0
oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo
00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o0007
0?ooo`001P3oooo00?l001`0003o6`3o000L0000o`L0oooo00060?oool00o`0070000?lK0?l001`0
003o1`3oool000H0oooo`03o000L0000oa/0o`0070000?l70?ooo`001P3oooo00?l001`0003o6`3o
000L0000o`L0oooo00060?oool00o`0070000?lK0?l001`0003o1`3oool000H0oooo`03o000L0000
oa/0o`0070000?l70?ooo`001P3oooo00?l001`0003o6`3o000L0000o`L0oooo00060?oool00o`00
70000?lK0?l001`0003o1`3oool000H0oooo`03o000L0000oa/0o`0070000?l70?ooo`001P3oooo0
0?l001`0003o6`3o000L0000o`L0oooo00060?oool00o`0070000?lK0?l001`0003o1`3oool000H0
oooo`03o000L0000oa/0o`0070000?l70?ooo`001P3oooo00?l001`0003o6`3o000L0000o`L0oooo
00060?oool00o`0070000?lK0?l001`0003o1`3oool000H0oooo`03o000L0000oa/0o`0070000?l7
0?ooo`001P3oooo00?l001`0003o6`3o000L0000o`L0oooo00060?oool00o`0070000?lK0?l001`0
003o1`3oool000H0oooo`03o000L0000oa/0o`0070000?l70?ooo`001P3oooo00?l001`0003o6`3o
000L0000o`L0oooo00060?oool00o`0070000?lK0?l001`0003o1`3oool000H0oooo`03o000L0000
oa/0o`0070000?l70?ooo`001P3oooo00?l001`0003o6`3o000L0000o`L0oooo00060?oool00o`00
70000?lK0?l001`0003o1`3oool000H0oooo`03o000L0000oa/0o`0070000?l70?ooo`001P3oooo0
0?l001`0003o6`3o000L0000o`L0oooo00060?oool00o`0070000?lK0?l001`0003o1`3oool000H0
oooo`03o000L0000oa/0o`0070000?l70?ooo`001P3ooomC0?l001/0003o6`3o000L0000oa/0o`00
70000?lK0?l001`0003o1`3oool000H0ooooD`3o000K0000oa/0o`0070000?lK0?l001`0003o6`3o
000L0000o`L0oooo00060?oooe<0o`006`000?lK0?l001`0003o6`3o000L0000oa/0o`0070000?l7
0?ooo`001P3ooomC0?l001/0003o6`3o000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0
ooooD`3o000K0000oa/0o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0o`00
6`000?lK0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC0?l001/0003o6`3o
000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooD`3o000K0000oa/0o`0070000?lK
0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0o`006`000?lK0?l001`0003o6`3o000L0000
oa/0o`0070000?l70?ooo`001P3ooomC0?l001/0003o6`3o000L0000oa/0o`0070000?lK0?l001`0
003o1`3oool000H0ooooD`3o000K0000oa/0o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo
00060?oooe<0o`006`000?lK0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC
0?l001/0003o6`3o000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooD`3o000K0000
oa/0o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0o`006`000?lK0?l001`0
003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC0?l001/0003o6`3o000L0000oa/0o`00
70000?lK0?l001`0003o1`3oool000H0ooooD`3o000K0000oa/0o`0070000?lK0?l001`0003o6`3o
000L0000o`L0oooo00060?oooe<0o`006`000?lK0?l001`0003o6`3o000L0000oa/0o`0070000?l7
0?ooo`001P3ooomC0?l001/0003o6`3o000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0
ooooD`3o000K0000oa/0o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0o`00
6`000?lK0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC0?l001/0003o6`3o
000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooD`3o000K0000oa/0o`0070000?lK
0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0o`006`000?lK0?l001`0003o6`3o000L0000
oa/0o`0070000?l70?ooo`001P3ooomC0?l001/0003o6`3o000L0000oa/0o`0070000?lK0?l001`0
003o1`3oool000H0ooooD`3o000K0000oa/0o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo
00060?oooe<0o`006`000?lK0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC
0?l001/0003o6`3o000L0000oa/0o`0070000?lK0?l001`0003o1`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}]
}, Open  ]],

Cell[BoxData[
    \(\(Export["\<I1.jpg\>", I1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Metropolis", "Section"],

Cell[BoxData[
    \(\(MaxSweeps = 100;\)\)], "Input"],

Cell["\<\
DeltaE=(ENeu-EAlt) ist zweimal die Summe, weil man \
-s_i*Summe-s_i*Summe hat.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{\(Spins = Spins0;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"For", "[", 
        RowBox[{\(Sweeps = 1\), ",", \(Sweeps < MaxSweeps + 1\), 
          ",", \(Sweeps++\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(For[i = 1, 
              i < NMaxSq + 1, \(i++\), \ \ \  (*\ 
                Spinnummer\ *) \[IndentingNewLine]DeltaE\  = \ \ 2*
                  Spins[\([Platz[\([i, 1]\)], 
                      Platz[\([i, 2]\)]]\)]*\[IndentingNewLine]Sum[
                    JMat[\([i, k]\)]*
                      Spins[\([Platz[\([k, 1]\)], Platz[\([k, 2]\)]]\)], {k, 
                      1, NMaxSq}]; \[IndentingNewLine]If[
                DeltaE \[LessEqual] 0\ , 
                Spins[\([Platz[\([i, 1]\)], 
                      Platz[\([i, 2]\)]]\)] = \(-Spins[\([Platz[\([i, 1]\)], 
                        Platz[\([i, 2]\)]]\)]\), \[IndentingNewLine]If[
                  Random[] \[LessEqual] \[ExponentialE]\^\(\(-DeltaE\)/T\), 
                  Spins[\([Platz[\([i, 1]\)], 
                        Platz[\([i, 
                            2]\)]]\)] = \(-Spins[\([Platz[\([i, 1]\)], 
                          Platz[\([i, 2]\)]]\)]\)]]\[IndentingNewLine]]\), 
            ";", "\[IndentingNewLine]", 
            RowBox[{"Show", "[", 
              RowBox[{"Graphics", "[", 
                RowBox[{
                  
                  StyleBox[\(RasterArray[
                        Spins] /. {1 -> RGBColor[1, 0, 0], \(-1\) -> 
                          RGBColor[0, 0, 1]}\),
                    PageBreakAbove->False,
                    AspectRatioFixed->True,
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain",
                    FontTracking->"Plain",
                    FontVariations->{"Underline"->False,
                    "Outline"->False,
                    "Shadow"->False}], ",", \(AspectRatio -> 1\)}], "]"}], 
              "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`00
1`3oool000H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK
0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0
oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o
=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0oooo703o0029
0000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o=`3o00070?oo
o`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0oooo703o00290000oa/0o`00
70000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o=`3o00070?ooo`001P3ooolL
0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0oooo703o00290000oa/0o`0070000?lg0?l0
00L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o
6`3o000L0000ocL0o`001`3oool000H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo0006
0?oooa`0o`00R@000?lK0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000
ocL0o`001`3oool000H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00
R@000?lK0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3o
ool000H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l0
01`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0oooo
703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o=`3o
00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0oooo=`3o002U0000
oa/0o`0070000?l70?ooo`001P3ooolg0?l00:D0003o6`3o000L0000o`L0oooo00060?ooocL0o`00
Y@000?lK0?l001`0003o1`3oool000H0oooo=`3o002U0000oa/0o`0070000?l70?ooo`001P3ooolg
0?l00:D0003o6`3o000L0000o`L0oooo00060?ooocL0o`00Y@000?lK0?l001`0003o1`3oool000H0
oooo=`3o002U0000oa/0o`0070000?l70?ooo`001P3ooolg0?l00:D0003o6`3o000L0000o`L0oooo
00060?ooocL0o`00Y@000?lK0?l001`0003o1`3oool000H0oooo=`3o002U0000oa/0o`0070000?l7
0?ooo`001P3ooolg0?l00:D0003o6`3o000L0000o`L0oooo00060?ooocL0o`00Y@000?lK0?l001`0
003o1`3oool000H0oooo=`3o002U0000oa/0o`0070000?l70?ooo`001P3ooolg0?l00:D0003o6`3o
000L0000o`L0oooo00060?ooocL0o`00Y@000?lK0?l001`0003o1`3oool000H0oooo=`3o002U0000
oa/0o`0070000?l70?ooo`001P3ooolg0?l00:D0003o6`3o000L0000o`L0oooo00060?ooocL0o`00
Y@000?lK0?l001`0003o1`3oool000H0oooo=`3o002U0000oa/0o`0070000?l70?ooo`001P3ooolg
0?l00:D0003o6`3o000L0000o`L0oooo00060?ooocL0o`00Y@000?lK0?l001`0003o1`3oool000H0
oooo=`3o002U0000oa/0o`0070000?l70?ooo`001P3ooolg0?l00:D0003o6`3o000L0000o`L0oooo
00060?ooocL0o`00Y@000?lK0?l001`0003o1`3oool000H0oooo=`3o002U0000oa/0o`0070000?l7
0?ooo`001P3ooolg0?l00:D0003o6`3o000L0000o`L0oooo00060?ooocL0o`00Y@000?lK0?l001`0
003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3o
ool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0
ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`00
0?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l0
0:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o
1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool0
00H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0oooo
D`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK
0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0
003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3o
ool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0
ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`000?lK0?l00:D0003o1`3oool000H0ooooD`00
0?lK0?l00:D0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?oo
ocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0
003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o
000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool0
00H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0
o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`00
0?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l7
0?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0
003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3o
oolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^
0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0
o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo
00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg
0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0
003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o
1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K
0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0
ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3o
ool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0
003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^
0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`00
1P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l7
0?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00
Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?oo
ofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo
00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000
o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o
002U0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0
ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3o
ool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0
003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon9
0?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`00
1P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l7
0?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00
RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?oo
ohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo
00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000
o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo
00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oo
oa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003o
R@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^
0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0
oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo0006
0?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0
003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o
001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000
o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo
00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oo
oa`0003oR@3o001^0000o`L0oooo00060?oooa`0003oR@3o001^0000o`L0oooo00060?oooa`0003o
R@3o001^0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool0
00H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o
1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l0
05<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3o
ooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?oo
o`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`00
0?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00
o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo0006
0?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0
oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C
0000o`L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0
oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo0006
0?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0
o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`00
0?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l0
00L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo
00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?oo
om`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`00
6`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL
0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0
oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo0006
0?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0
o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oD`3o000K0000oa`0o`00
1`3oool000H0oooo=`3o000L0000oa/0o`006`000?mC0?l001/0003o703o00070?ooo`001P3ooolg
0?l001`0003o6`3o000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l0
01/0003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?mC0?l001/0
003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000oe<0o`006`000?lL0?l000L0oooo
00060?ooocL0o`0070000?lK0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o000L
0000oa/0o`006`000?mC0?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000
oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oD`3o000K0000oa`0
o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?mC0?l001/0003o703o00070?ooo`001P3o
oolg0?l001`0003o6`3o000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?lK
0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?mC0?l0
01/0003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000oe<0o`006`000?lL0?l000L0
oooo00060?ooocL0o`0070000?lK0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o
000L0000oa/0o`006`000?mC0?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o000K
0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oD`3o000K0000
oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?mC0?l001/0003o703o00070?ooo`00
1P3ooolg0?l001`0003o6`3o000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`007000
0?lK0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?mC
0?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000oe<0o`006`000?lL0?l0
00L0oooo00060?ooocL0o`0070000?lK0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0oooo
=`3o000L0000oa/0o`006`000?mC0?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003o6`3o
000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oD`3o000K
0000oa`0o`001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0?l00580003o703o000K0000oe<0o`00
1`3oool000H0oooo=`3o001B0000oa`0o`006`000?mC0?l000L0oooo00060?ooocL0o`00DP000?lL
0?l001/0003oD`3o00070?ooo`001P3ooolg0?l00580003o703o000K0000oe<0o`001`3oool000H0
oooo=`3o001B0000oa`0o`006`000?mC0?l000L0oooo00060?ooocL0o`00DP000?lL0?l001/0003o
D`3o00070?ooo`001P3ooolg0?l00580003o703o000K0000oe<0o`001`3oool000H0oooo=`3o001B
0000oa`0o`006`000?mC0?l000L0oooo00060?ooocL0o`00DP000?lL0?l001/0003oD`3o00070?oo
o`001P3ooolg0?l00580003o703o000K0000oe<0o`001`3oool000H0oooo=`3o001B0000oa`0o`00
6`000?mC0?l000L0oooo00060?ooocL0o`00DP000?lL0?l001/0003oD`3o00070?ooo`001P3ooolg
0?l00580003o703o000K0000oe<0o`001`3oool000H0oooo=`3o001B0000oa`0o`006`000?mC0?l0
00L0oooo00060?ooocL0o`00DP000?lL0?l001/0003oD`3o00070?ooo`001P3ooolg0?l00580003o
703o000K0000oe<0o`001`3oool000H0oooo=`3o001B0000oa`0o`006`000?mC0?l000L0oooo0006
0?ooocL0o`00DP000?lL0?l001/0003oD`3o00070?ooo`001P3ooolg0?l00580003o703o000K0000
oe<0o`001`3oool000H0oooo=`3o001B0000oa`0o`006`000?mC0?l000L0oooo00060?ooocL0o`00
DP000?lL0?l001/0003oD`3o00070?ooo`001P3ooolg0?l00580003o703o000K0000oe<0o`001`3o
ool000H0oooo=`3o001B0000oa`0o`006`000?mC0?l000L0oooo00060?ooocL0o`00DP000?lL0?l0
01/0003oD`3o00070?ooo`001P3ooolg0?l00580003o703o000K0000oe<0o`001`3oool000H0oooo
=`3o001B0000oa`0o`006`000?mC0?l000L0oooo00060?ooocL0o`00DP000?lL0?l001/0003oD`3o
00070?ooo`001P3ooolg0?l00580003o703o000K0000oe<0o`001`3oool000H0oooo`0000?lL0?l0
03L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o
1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool0
00H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo
`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL
0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0
003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3o
ool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0
oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`000
0?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l0
03L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o
1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool0
00H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo
=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP00
0?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l0
01/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`00
1P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o
001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000
oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0
oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`00
0?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?oo
ocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0
003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o
000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool0
00H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0
o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`00
0?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l7
0?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0
003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3o
oolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0ooooR@3o001C0000ocL0o`001`3oool0
00H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0oooo
R@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C
0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0
o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3o
ool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0
ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o
001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000
ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`00
1`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool0
00H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0oooo
R@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C
0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL0000
ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo
70000?n90?l00580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo0006
0?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l00580003o703o00070?oo
o`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`00
1`3oool000H0oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP000?lL
0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l00580
003o703o00070?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003oR@3o
001B0000oa`0o`001`3oool000H0oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL0000
ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo
70000?n90?l00580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo0006
0?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l00580003o703o00070?oo
o`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`00
1`3oool000H0oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP000?lL
0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0
o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3o
ool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0
ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o
001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000
oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`00
1`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool0
00H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0oooo
R@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^
0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0
o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3o
ool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0
ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo
Y@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B
0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0
o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3o
ool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0
ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0ooooD`3o000K0000oe80o`0070000?lg0?l000L0oooo00060?oooe<0o`006`00
0?mB0?l001`0003o=`3o00070?ooo`001P3ooomC0?l001/0003oDP3o000L0000ocL0o`001`3oool0
00H0ooooD`3o000K0000oe80o`0070000?lg0?l000L0oooo00060?oooe<0o`006`000?mB0?l001`0
003o=`3o00070?ooo`001P3ooomC0?l001/0003oDP3o000L0000ocL0o`001`3oool000H0ooooD`3o
000K0000oe80o`0070000?lg0?l000L0oooo00060?oooe<0o`006`000?mB0?l001`0003o=`3o0007
0?ooo`001P3ooomC0?l001/0003oDP3o000L0000ocL0o`001`3oool000H0ooooD`3o000K0000oe80
o`0070000?lg0?l000L0oooo00060?oooe<0o`006`000?mB0?l001`0003o=`3o00070?ooo`001P3o
oomC0?l001/0003oDP3o000L0000ocL0o`001`3oool000H0ooooD`3o000K0000oe80o`0070000?lg
0?l000L0oooo00060?oooe<0o`006`000?mB0?l001`0003o=`3o00070?ooo`001P3ooomC0?l001/0
003oDP3o000L0000ocL0o`001`3oool000H0ooooD`3o000K0000oe80o`0070000?lg0?l000L0oooo
00060?oooe<0o`006`000?mB0?l001`0003o=`3o00070?ooo`001P3ooomC0?l001/0003oDP3o000L
0000ocL0o`001`3oool000H0ooooD`3o000K0000oe80o`0070000?lg0?l000L0oooo00060?oooe<0
o`006`000?mB0?l001`0003o=`3o00070?ooo`001P3ooomC0?l001/0003oDP3o000L0000ocL0o`00
1`3oool000H0ooooD`3o000K0000oe80o`0070000?lg0?l000L0oooo00060?oooe<0o`006`000?mB
0?l001`0003o=`3o00070?ooo`001P3ooomC0?l001/0003oDP3o000L0000ocL0o`001`3oool000H0
ooooD`3o000K0000oe80o`0070000?lg0?l000L0oooo00060?oooe<0o`006`000?mB0?l001`0003o
=`3o00070?ooo`001P3ooomC0?l001/0003oDP3o000L0000ocL0o`001`3oool000H0ooooD`3o000K
0000oe80o`0070000?lg0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FFFF00000000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF00000000FF0000FFFF0000FF00000000FF0000FFFF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o
1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L
0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0
ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00
D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?lK
0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?oo
o`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0003o
6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^
0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C0000
o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`00
70000?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo0006
0?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l0
05<0003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o
6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3o
ool000H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L0000
oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0oooo
KP000?lK0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`00
0?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?mB0?l0
05<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o
1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool0
00H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0oooo
KP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB
0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0
003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3o
ool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0
ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP00
0?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l0
05<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o
1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool0
00H0ooooKP000?mB0?l005<0003o1`3oool000H0ooooKP000?mB0?l005<0003o1`3oool000H0oooo
=`3o000L0000ocH0o`00KP000?lL0?l000L0oooo00060?ooocL0o`0070000?lf0?l006h0003o703o
00070?ooo`001P3ooolg0?l001`0003o=P3o001^0000oa`0o`001`3oool000H0oooo=`3o000L0000
ocH0o`00KP000?lL0?l000L0oooo00060?ooocL0o`0070000?lf0?l006h0003o703o00070?ooo`00
1P3ooolg0?l001`0003o=P3o001^0000oa`0o`001`3oool000H0oooo=`3o000L0000ocH0o`00KP00
0?lL0?l000L0oooo00060?ooocL0o`0070000?lf0?l006h0003o703o00070?ooo`001P3ooolg0?l0
01`0003o=P3o001^0000oa`0o`001`3oool000H0oooo=`3o000L0000ocH0o`00KP000?lL0?l000L0
oooo00060?ooocL0o`0070000?lf0?l006h0003o703o00070?ooo`001P3ooolg0?l001`0003o=P3o
001^0000oa`0o`001`3oool000H0oooo=`3o000L0000ocH0o`00KP000?lL0?l000L0oooo00060?oo
ocL0o`0070000?lf0?l006h0003o703o00070?ooo`001P3ooolg0?l001`0003o=P3o001^0000oa`0
o`001`3oool000H0oooo=`3o000L0000ocH0o`00KP000?lL0?l000L0oooo00060?ooocL0o`007000
0?lf0?l006h0003o703o00070?ooo`001P3ooolg0?l001`0003o=P3o001^0000oa`0o`001`3oool0
00H0oooo=`3o000L0000ocH0o`00KP000?lL0?l000L0oooo00060?ooocL0o`0070000?lf0?l006h0
003o703o00070?ooo`001P3ooolg0?l001`0003o=P3o001^0000oa`0o`001`3oool000H0oooo=`3o
000L0000ocH0o`00KP000?lL0?l000L0oooo00060?ooocL0o`0070000?lf0?l006h0003o703o0007
0?ooo`001P3ooolg0?l001`0003o=P3o001^0000oa`0o`001`3oool000H0oooo=`3o000L0000ocH0
o`00KP000?lL0?l000L0oooo00060?ooocL0o`0070000?lf0?l006h0003o703o00070?ooo`001P3o
oolg0?l001`0003o=P3o001^0000oa`0o`001`3oool000H0ooooKP3o002U0000o`L0oooo00060?oo
ofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo
00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000
o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o
002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0
ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3o
ool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0
003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^
0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`00
1P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l7
0?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`00
1P3ooon90?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3o
ool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0003o703o000g0000
o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0ooooR@3o000g0000oa`0o`00
=`000?l70?ooo`001P3ooon90?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL
0?l003L0003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0
003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0ooooR@3o
000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0003o703o000g0000o`L0oooo00060?oo
ohT0o`00=`000?lL0?l003L0003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`00
1P3ooon90?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3o
ool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0003o703o000g0000
o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0ooooR@3o000g0000oa`0o`00
=`000?l70?ooo`001P3ooon90?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL
0?l003L0003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0
003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0ooooR@3o
000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l0
05<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o
=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o0007
0?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`00
1P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon9
0?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0
003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o
00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?oo
o`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3o
oon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l0
05<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o
=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o0007
0?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`00
1P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU
0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0
003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o
00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?oo
o`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3o
oonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l0
03L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o
=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o0007
0?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`00
1P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU
0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0
003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooon90?l001`0003oKP3o
00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?oo
o`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`00
1P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon9
0?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0
003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o
00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?oo
o`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooonU0?l0
01/0003o703o000K0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0
oooo00060?ooojD0o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o
000K0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?oo
ojD0o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0
o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`00
0?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0o`001`3oool0
00H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`000?lL0?l001/0
003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooY@3o
000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`000?lL0?l001/0003o703o0007
0?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0
o`006`000?lL0?l000L0oooo00060?ooojD0o`006`000?lL0?l001/0003o703o00070?ooo`001P3o
oonU0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL
0?l000L0oooo00060?ooojD0o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0
003o703o000K0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo
00060?ooojD0o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K
0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0
o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00
=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL
0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000
oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`00
1P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o
000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l7
0?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0
003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00
=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL
0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000
oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`00
1P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o
000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l7
0?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0
003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00
=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL
0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000
oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`00
1P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o
000g0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l003L0003o=P3o000g0000oa`0o`00=`000?l7
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF00000000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o
1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L
0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0
oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00
KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK
0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?oo
o`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003o
DP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL
0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000
o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00
70000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo0006
0?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l0
06h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o
6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3o
ool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000
oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo
70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP00
0?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?n90?l0
06h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o
1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool0
00H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo
70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n9
0?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0
003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3o
ool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0
oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo7000
0?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l0
06h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o
1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool0
00H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo
KP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool0
00H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o
1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l0
0:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3o
oom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?oo
o`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@00
0?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0
o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo0006
0?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0
oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooR@3o002:
0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0oooo
R@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool0
00H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o
1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l0
08X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3o
oon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?oo
o`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP00
0?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0
o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo0006
0?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o001^0000oa`0
o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3o
ool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0
ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o
001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000
oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`00
1`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool0
00H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0oooo
R@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^
0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0
o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3o
ool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0
ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o
001^0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo
Y@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B
0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0
o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3o
ool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0
ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0
oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`007000
0?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oo
oa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0
003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o
000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool0
00H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80
o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo7000
0?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l7
0?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0
003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3o
oolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L
0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0
o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo
00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB
0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0
003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo7000
0?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l0
05<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o
1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool0
00H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo
70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT
0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0
003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3o
ool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0
oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo7000
0?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l0
05<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o
1`3oool000H0oooo70000?nT0?l005<0003o1`3oool000H0oooo70000?nT0?l005<0003o1`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3o
oon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l0
06h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o
703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o0007
0?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`00
1P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon9
0?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0
003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o
00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?oo
o`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3o
oon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l0
06h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o
703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o0007
0?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`00
1P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon9
0?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0
003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o
00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?oo
o`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3o
oon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l0
06h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o
703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o0007
0?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`00
1P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon9
0?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0
003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o
00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?oo
o`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3o
oonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l0
0580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o
703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o0007
0?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`00
1P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU
0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580
003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o
00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?oo
o`001P3ooonU0?l00580003o703o00070?ooo`001P3ooonU0?l00580003o703o00070?ooo`001P3o
oonU0?l00580003o703o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l0
03L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o
=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o0007
0?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`00
1P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU
0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0
003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o
00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?oo
o`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3o
oonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l0
03L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o
=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o0007
0?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooom^0?l001/0003o703o000g0000ocL0
o`001`3oool000H0ooooKP3o000K0000oa`0o`00=`000?lg0?l000L0oooo00060?ooofh0o`006`00
0?lL0?l003L0003o=`3o00070?ooo`001P3ooom^0?l001/0003o703o000g0000ocL0o`001`3oool0
00H0ooooKP3o000K0000oa`0o`00=`000?lg0?l000L0oooo00060?ooofh0o`006`000?lL0?l003L0
003o=`3o00070?ooo`001P3ooom^0?l001/0003o703o000g0000ocL0o`001`3oool000H0ooooKP3o
000K0000oa`0o`00=`000?lg0?l000L0oooo00060?ooofh0o`006`000?lL0?l003L0003o=`3o0007
0?ooo`001P3ooom^0?l001/0003o703o000g0000ocL0o`001`3oool000H0ooooKP3o000K0000oa`0
o`00=`000?lg0?l000L0oooo00060?ooofh0o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3o
oom^0?l001/0003o703o000g0000ocL0o`001`3oool000H0ooooKP3o000K0000oa`0o`00=`000?lg
0?l000L0oooo00060?ooofh0o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooom^0?l001/0
003o703o000g0000ocL0o`001`3oool000H0ooooKP3o000K0000oa`0o`00=`000?lg0?l000L0oooo
00060?ooofh0o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooom^0?l001/0003o703o000g
0000ocL0o`001`3oool000H0ooooKP3o000K0000oa`0o`00=`000?lg0?l000L0oooo00060?ooofh0
o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooom^0?l001/0003o703o000g0000ocL0o`00
1`3oool000H0ooooKP3o000K0000oa`0o`00=`000?lg0?l000L0oooo00060?ooofh0o`006`000?lL
0?l003L0003o=`3o00070?ooo`001P3ooom^0?l001/0003o703o000g0000ocL0o`001`3oool000H0
ooooKP3o000K0000oa`0o`00=`000?lg0?l000L0oooo00060?ooofh0o`006`000?lL0?l003L0003o
=`3o00070?ooo`001P3ooom^0?l001/0003o703o000g0000ocL0o`001`3oool000H0ooooR@3o000g
0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0
o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3o
oon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool0
00H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0
oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`007000
0?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l0
01`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o
=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g
0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0
o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3o
oon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool0
00H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0
oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`007000
0?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l0
01`0003o1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`00
1P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l7
0?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00
=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?oo
om`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo
00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000
o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o
000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0
oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3o
ool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0
003o1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3o
ool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0
ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo
Y@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B
0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0
o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3o
ool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0
ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`00
1`3oool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB
0?l003L0003o=`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0
oooo=`3o000L0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l003L0003o
=`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L
0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o00070?oo
o`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00
=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg
0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l0
00L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg0?l001`0003o
DP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l000L0oooo0006
0?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000
ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`00
70000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3o
ool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l0
03L0003o=`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo
=`3o000L0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o
00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`00
1`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool0
00H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0oooo
R@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g
0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0
o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3o
ool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0
ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o
000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000
oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`00
1`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool0
00H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0oooo
R@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooKP3o000g
0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o
000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000
ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`00
1`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool0
00H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0oooo
KP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g
0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o
000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000
ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`00
1`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool0
00H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0oooo
KP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g
0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o
000g0000ofh0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000
o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`00
70000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP000?mB
0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0
003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o
001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?oo
ocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`00
1P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o1`3o
ool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000
o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`00
70000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP000?mB
0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0
003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o
001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?oo
ocL0o`00KP000?mB0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`00
1P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3o
ool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000
o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`00
70000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^
0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0
003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o
000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oo
oe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`00
1P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3o
ool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000
o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`00
70000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^
0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0
003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o
000f0000ofh0o`0070000?l70?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0
003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o
000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000
ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`00
6`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC
0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0
ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo
00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l7
0?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0
003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o
000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000
ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`00
6`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC
0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0
ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0
003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o
00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF00000000FF
FF00000000FFFF00000000FF0000FFFF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
D`3o001B0000oe80o`0070000?l70?ooo`001P3ooomC0?l00580003oDP3o000L0000o`L0oooo0006
0?oooe<0o`00DP000?mB0?l001`0003o1`3oool000H0ooooD`3o001B0000oe80o`0070000?l70?oo
o`001P3ooomC0?l00580003oDP3o000L0000o`L0oooo00060?oooe<0o`00DP000?mB0?l001`0003o
1`3oool000H0ooooD`3o001B0000oe80o`0070000?l70?ooo`001P3ooomC0?l00580003oDP3o000L
0000o`L0oooo00060?oooe<0o`00DP000?mB0?l001`0003o1`3oool000H0ooooD`3o001B0000oe80
o`0070000?l70?ooo`001P3ooomC0?l00580003oDP3o000L0000o`L0oooo00060?oooe<0o`00DP00
0?mB0?l001`0003o1`3oool000H0ooooD`3o001B0000oe80o`0070000?l70?ooo`001P3ooomC0?l0
0580003oDP3o000L0000o`L0oooo00060?oooe<0o`00DP000?mB0?l001`0003o1`3oool000H0oooo
D`3o001B0000oe80o`0070000?l70?ooo`001P3ooomC0?l00580003oDP3o000L0000o`L0oooo0006
0?oooe<0o`00DP000?mB0?l001`0003o1`3oool000H0ooooD`3o001B0000oe80o`0070000?l70?oo
o`001P3ooomC0?l00580003oDP3o000L0000o`L0oooo00060?oooe<0o`00DP000?mB0?l001`0003o
1`3oool000H0ooooD`3o001B0000oe80o`0070000?l70?ooo`001P3ooomC0?l00580003oDP3o000L
0000o`L0oooo00060?oooe<0o`00DP000?mB0?l001`0003o1`3oool000H0ooooD`3o001B0000oe80
o`0070000?l70?ooo`001P3ooomC0?l00580003oDP3o000L0000o`L0oooo00060?oooe<0o`00DP00
0?mB0?l001`0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool0
00H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0
o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o
1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K
0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l0
03L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo
703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P00
0?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool0
00H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0
o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o
1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K
0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l0
03L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo
703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P00
0?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool0
00H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0
o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o
1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K
0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo703o000K0000oa`0o`00=P000?mC0?l0
03L0003o1`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`00
6`000?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0o`001`3o
ool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`000?lL0?l0
01/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0o`001`3oool000H0oooo
Y@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`000?lL0?l001/0003o703o
00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooY@3o000K0000
oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`000?lL0?l001/0003o703o00070?ooo`00
1P3ooonU0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0o`006`00
0?lL0?l000L0oooo00060?ooojD0o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l0
01/0003o703o000K0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0
oooo00060?ooojD0o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o
000K0000oa`0o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?oo
ojD0o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0
o`001`3oool000H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`00
0?lL0?l001/0003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0o`001`3oool0
00H0ooooY@3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`000?lL0?l001/0
003o703o00070?ooo`001P3ooonU0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooY@3o
000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?oo
ojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`00
6`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC
0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0
oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo0006
0?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0
o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`00
0?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l0
00L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo
00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?oo
ojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`00
6`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC
0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oooe<0o`006`000?lg0?l001/0003oD`3o
00070?ooo`001P3ooomC0?l001/0003o=`3o000K0000oe<0o`001`3oool000H0ooooD`3o000K0000
ocL0o`006`000?mC0?l000L0oooo00060?oooe<0o`006`000?lg0?l001/0003oD`3o00070?ooo`00
1P3ooomC0?l001/0003o=`3o000K0000oe<0o`001`3oool000H0ooooD`3o000K0000ocL0o`006`00
0?mC0?l000L0oooo00060?oooe<0o`006`000?lg0?l001/0003oD`3o00070?ooo`001P3ooomC0?l0
01/0003o=`3o000K0000oe<0o`001`3oool000H0ooooD`3o000K0000ocL0o`006`000?mC0?l000L0
oooo00060?oooe<0o`006`000?lg0?l001/0003oD`3o00070?ooo`001P3ooomC0?l001/0003o=`3o
000K0000oe<0o`001`3oool000H0ooooD`3o000K0000ocL0o`006`000?mC0?l000L0oooo00060?oo
oe<0o`006`000?lg0?l001/0003oD`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000K0000oe<0
o`001`3oool000H0ooooD`3o000K0000ocL0o`006`000?mC0?l000L0oooo00060?oooe<0o`006`00
0?lg0?l001/0003oD`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000K0000oe<0o`001`3oool0
00H0ooooD`3o000K0000ocL0o`006`000?mC0?l000L0oooo00060?oooe<0o`006`000?lg0?l001/0
003oD`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000K0000oe<0o`001`3oool000H0ooooD`3o
000K0000ocL0o`006`000?mC0?l000L0oooo00060?oooe<0o`006`000?lg0?l001/0003oD`3o0007
0?ooo`001P3ooomC0?l001/0003o=`3o000K0000oe<0o`001`3oool000H0ooooD`3o000K0000ocL0
o`006`000?mC0?l000L0oooo00060?oooe<0o`006`000?lg0?l001/0003oD`3o00070?ooo`001P3o
oomC0?l001/0003o=`3o000K0000oe<0o`001`3oool000H0ooooD`3o000K0000ocL0o`006`000?mC
0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0
oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo0006
0?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0
o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`00
0?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l0
00L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo
00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?oo
ojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`00
6`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC
0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0
oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo0006
0?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0
o`006`000?mC0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3o
oolg0?l001`0003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC
0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0
003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo
00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g
0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo00060?ooocL0
o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g0000oe<0o`00
1`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo00060?ooocL0o`0070000?lf
0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g0000oe<0o`001`3oool000H0
oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0003o
D`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L
0000ocH0o`00=`000?mC0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?oo
o`001P3ooolg0?l001`0003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00
=`000?mC0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg
0?l001`0003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l0
00L0oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o
=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo0006
0?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
R@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC
0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0
003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3o
ool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0
ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@00
0?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l0
03L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o
1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool0
00H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0oooo
R@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC
0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0
003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3oool000H0ooooR@000?mC0?l003L0003o1`3o
ool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l0
00L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003o
Y@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g
0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0
o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo7000
0?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oo
oa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`00
1P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3o
ool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l0
00L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003o
Y@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g
0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0
o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo7000
0?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oo
oa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o
000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000
oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`00
1`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool0
00H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooo
g03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K
0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0
o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3o
ool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0
oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o
000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000
oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0
oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`007000
0?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l0
01`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003o
DP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L
0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0
o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3o
oon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool0
00H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0
oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`007000
0?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l0
01`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003o
DP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L
0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0
o`0070000?mB0?l001`0003o1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FF0000FF0000FFFF00000000FF
0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0ooooD`000?lK0?l0
01/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`00
1P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0003oKP3o
000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooomC0000
oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0003oKP3o000L0000o`L0
oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooomC0000oa/0o`006`00
0?m^0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oo
oe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0
003o1`3oool000H0ooooD`000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o
000K0000ofh0o`0070000?l70?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool0
00H0ooooD`000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0
o`0070000?l70?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`00
0?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l7
0?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0
003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3o
oomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0003oKP3o000L
0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooomC0000oa/0
o`006`000?m^0?l001`0003o1`3oool000H0ooooKP000?mB0?l001`0003o=`3o00070?ooo`001P3o
oom^0000oe80o`0070000?lg0?l000L0oooo00060?ooofh0003oDP3o000L0000ocL0o`001`3oool0
00H0ooooKP000?mB0?l001`0003o=`3o00070?ooo`001P3ooom^0000oe80o`0070000?lg0?l000L0
oooo00060?ooofh0003oDP3o000L0000ocL0o`001`3oool000H0ooooKP000?mB0?l001`0003o=`3o
00070?ooo`001P3ooom^0000oe80o`0070000?lg0?l000L0oooo00060?ooofh0003oDP3o000L0000
ocL0o`001`3oool000H0ooooKP000?mB0?l001`0003o=`3o00070?ooo`001P3ooom^0000oe80o`00
70000?lg0?l000L0oooo00060?ooofh0003oDP3o000L0000ocL0o`001`3oool000H0ooooKP000?mB
0?l001`0003o=`3o00070?ooo`001P3ooom^0000oe80o`0070000?lg0?l000L0oooo00060?ooofh0
003oDP3o000L0000ocL0o`001`3oool000H0ooooKP000?mB0?l001`0003o=`3o00070?ooo`001P3o
oom^0000oe80o`0070000?lg0?l000L0oooo00060?ooofh0003oDP3o000L0000ocL0o`001`3oool0
00H0ooooKP000?mB0?l001`0003o=`3o00070?ooo`001P3ooom^0000oe80o`0070000?lg0?l000L0
oooo00060?ooofh0003oDP3o000L0000ocL0o`001`3oool000H0ooooKP000?mB0?l001`0003o=`3o
00070?ooo`001P3ooom^0000oe80o`0070000?lg0?l000L0oooo00060?ooofh0003oDP3o000L0000
ocL0o`001`3oool000H0ooooKP000?mB0?l001`0003o=`3o00070?ooo`001P3ooom^0000oe80o`00
70000?lg0?l000L0oooo00060?ooofh0003oDP3o000L0000ocL0o`001`3oool000H0oooo703o000g
0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o00070?oo
o`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00
=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL
0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00=`000?lL0?l0
00L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL0?l003L0003o
K@3o000g0000oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00=`000?lL0?l000L0oooo0006
0?oooa`0o`00=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000
oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00
=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3o
ool000H0oooo703o000g0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l0
03L0003o703o00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo
703o000g0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o
00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo703o000g0000
ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o00070?ooo`00
1P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00=`00
0?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL0?l0
03L0003oK@3o000g0000oa`0o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000
ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0
003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o
000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg
0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0
oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00
=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3o
ool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000
ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0
003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o
000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg
0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0
oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00
=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3o
ool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000
ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0
003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o
000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg
0?l001`0003o1`3oool000H0oooo703o000g0000ocH0o`00=`000?lg0?l001`0003o1`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0oooo70000?lK0?l001`0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL
0000oa/0o`0070000?lf0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000
ocH0o`00D`000?lK0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o001C0000oa/0
o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lf0?l005<0003o6`3o000L0000o`L0oooo
00060?oooa`0003o6`3o000L0000ocH0o`00D`000?lK0?l001`0003o1`3oool000H0oooo70000?lK
0?l001`0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lf0?l0
05<0003o6`3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`00D`000?lK0?l001`0
003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3o
oolL0000oa/0o`0070000?lf0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003o6`3o000L
0000ocH0o`00D`000?lK0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o001C0000
oa/0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lf0?l005<0003o6`3o000L0000o`L0
oooo00060?oooa`0003o6`3o000L0000ocH0o`00D`000?lK0?l001`0003o1`3oool000H0oooo7000
0?lK0?l001`0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lf
0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`00D`000?lK0?l0
01`0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o001C0000oa/0o`0070000?l70?ooo`00
1P3ooolL0000oa/0o`0070000?lf0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003o6`3o
000L0000ocH0o`00D`000?lK0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o001C
0000oa/0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lf0?l005<0003o6`3o000L0000
o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`00D`000?lK0?l001`0003o1`3oool000H0oooo
70000?lK0?l001`0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0000oa/0o`007000
0?lf0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`00D`000?lK
0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003oK@3o001C0000o`L0oooo00060?oooa`0
003o6`3o000L0000ofd0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?m]0?l005<0003o
1`3oool000H0oooo70000?lK0?l001`0003oK@3o001C0000o`L0oooo00060?oooa`0003o6`3o000L
0000ofd0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?m]0?l005<0003o1`3oool000H0
oooo70000?lK0?l001`0003oK@3o001C0000o`L0oooo00060?oooa`0003o6`3o000L0000ofd0o`00
D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?m]0?l005<0003o1`3oool000H0oooo70000?lK
0?l001`0003oK@3o001C0000o`L0oooo00060?oooa`0003o6`3o000L0000ofd0o`00D`000?l70?oo
o`001P3ooolL0000oa/0o`0070000?m]0?l005<0003o1`3oool000H0oooo70000?lK0?l001`0003o
K@3o001C0000o`L0oooo00060?oooa`0003o6`3o000L0000ofd0o`00D`000?l70?ooo`001P3ooolL
0000oa/0o`0070000?m]0?l005<0003o1`3oool000H0oooo70000?lK0?l001`0003oK@3o001C0000
o`L0oooo00060?oooa`0003o6`3o000L0000ofd0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`00
70000?m]0?l005<0003o1`3oool000H0oooo70000?lK0?l001`0003oK@3o001C0000o`L0oooo0006
0?oooa`0003o6`3o000L0000ofd0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?m]0?l0
05<0003o1`3oool000H0oooo70000?lK0?l001`0003oK@3o001C0000o`L0oooo00060?oooa`0003o
6`3o000L0000ofd0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?m]0?l005<0003o1`3o
ool000H0oooo70000?lK0?l001`0003oK@3o001C0000o`L0oooo00060?oooa`0003o6`3o000L0000
ofd0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?m]0?l005<0003o1`3oool000H0oooo
D`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT
0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0
003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3o
ool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0
ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`00
0?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l0
01`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o
1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool0
00H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0oooo
D`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT
0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0
003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3o
ool000H0ooooD`000?nT0?l001`0003o1`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FFFF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF00000000FFFF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l006d0003oKP3o000L0000o`L0oooo
00060?oooa`0o`00K@000?m^0?l001`0003o1`3oool000H0oooo703o001]0000ofh0o`0070000?l7
0?ooo`001P3ooolL0?l006d0003oKP3o000L0000o`L0oooo00060?oooa`0o`00K@000?m^0?l001`0
003o1`3oool000H0oooo703o001]0000ofh0o`0070000?l70?ooo`001P3ooolL0?l006d0003oKP3o
000L0000o`L0oooo00060?oooa`0o`00K@000?m^0?l001`0003o1`3oool000H0oooo703o001]0000
ofh0o`0070000?l70?ooo`001P3ooolL0?l006d0003oKP3o000L0000o`L0oooo00060?oooa`0o`00
K@000?m^0?l001`0003o1`3oool000H0oooo703o001]0000ofh0o`0070000?l70?ooo`001P3ooolL
0?l006d0003oKP3o000L0000o`L0oooo00060?oooa`0o`00K@000?m^0?l001`0003o1`3oool000H0
oooo703o001]0000ofh0o`0070000?l70?ooo`001P3ooolL0?l006d0003oKP3o000L0000o`L0oooo
00060?oooa`0o`00K@000?m^0?l001`0003o1`3oool000H0oooo703o001]0000ofh0o`0070000?l7
0?ooo`001P3ooolL0?l006d0003oKP3o000L0000o`L0oooo00060?oooa`0o`00K@000?m^0?l001`0
003o1`3oool000H0oooo703o001]0000ofh0o`0070000?l70?ooo`001P3ooolL0?l006d0003oKP3o
000L0000o`L0oooo00060?oooa`0o`00K@000?m^0?l001`0003o1`3oool000H0oooo703o001]0000
ofh0o`0070000?l70?ooo`001P3ooolL0?l006d0003oKP3o000L0000o`L0oooo00060?oooa`0o`00
K@000?m^0?l001`0003o1`3oool000H0oooo703o001]0000ofh0o`0070000?l70?ooo`001P3ooolL
0?l006d0003oKP3o000L0000o`L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0
o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^
0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`00
1P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o0007
0?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003o
Y@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?oo
ofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo
00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l0
00L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP00
0?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0
ooooKP000?nU0?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`00
0?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l0
00L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo
00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oo
oa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00
=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o0
0?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0
oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo0006
0?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0
o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`00
0?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l0
00L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo
00060?oooa`0o`00=`000?o00?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?oo
ojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`00
6`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC
0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0
oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo0006
0?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0
o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`00
0?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l0
00L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo
00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?oo
ojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`00
6`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC
0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?mB0?l005<0
003o=`3o00070?ooo`001P3ooolL0?l001/0003oDP3o001C0000ocL0o`001`3oool000H0oooo703o
000K0000oe80o`00D`000?lg0?l000L0oooo00060?oooa`0o`006`000?mB0?l005<0003o=`3o0007
0?ooo`001P3ooolL0?l001/0003oDP3o001C0000ocL0o`001`3oool000H0oooo703o000K0000oe80
o`00D`000?lg0?l000L0oooo00060?oooa`0o`006`000?mB0?l005<0003o=`3o00070?ooo`001P3o
oolL0?l001/0003oDP3o001C0000ocL0o`001`3oool000H0oooo703o000K0000oe80o`00D`000?lg
0?l000L0oooo00060?oooa`0o`006`000?mB0?l005<0003o=`3o00070?ooo`001P3ooolL0?l001/0
003oDP3o001C0000ocL0o`001`3oool000H0oooo703o000K0000oe80o`00D`000?lg0?l000L0oooo
00060?oooa`0o`006`000?mB0?l005<0003o=`3o00070?ooo`001P3ooolL0?l001/0003oDP3o001C
0000ocL0o`001`3oool000H0oooo703o000K0000oe80o`00D`000?lg0?l000L0oooo00060?oooa`0
o`006`000?mB0?l005<0003o=`3o00070?ooo`001P3ooolL0?l001/0003oDP3o001C0000ocL0o`00
1`3oool000H0oooo703o000K0000oe80o`00D`000?lg0?l000L0oooo00060?oooa`0o`006`000?mB
0?l005<0003o=`3o00070?ooo`001P3ooolL0?l001/0003oDP3o001C0000ocL0o`001`3oool000H0
oooo703o000K0000oe80o`00D`000?lg0?l000L0oooo00060?oooa`0o`006`000?mB0?l005<0003o
=`3o00070?ooo`001P3ooolL0?l001/0003oDP3o001C0000ocL0o`001`3oool000H0oooo703o000K
0000oe80o`00D`000?lg0?l000L0oooo00060?oooa`0o`006`000?mB0?l005<0003o=`3o00070?oo
o`001P3ooolL0?l001/0003oDP3o001C0000ocL0o`001`3oool000H0oooo703o000K0000oe80o`00
D`000?lg0?l000L0oooo00060?oooa`0o`006`000?mB0?l005<0003o=`3o00070?ooo`001P3ooolg
0000ohT0o`00=`000?lL0?l000L0oooo00060?ooocL0003oR@3o000g0000oa`0o`001`3oool000H0
oooo=`000?n90?l003L0003o703o00070?ooo`001P3ooolg0000ohT0o`00=`000?lL0?l000L0oooo
00060?ooocL0003oR@3o000g0000oa`0o`001`3oool000H0oooo=`000?n90?l003L0003o703o0007
0?ooo`001P3ooolg0000ohT0o`00=`000?lL0?l000L0oooo00060?ooocL0003oR@3o000g0000oa`0
o`001`3oool000H0oooo=`000?n90?l003L0003o703o00070?ooo`001P3ooolg0000ohT0o`00=`00
0?lL0?l000L0oooo00060?ooocL0003oR@3o000g0000oa`0o`001`3oool000H0oooo=`000?n90?l0
03L0003o703o00070?ooo`001P3ooolg0000ohT0o`00=`000?lL0?l000L0oooo00060?ooocL0003o
R@3o000g0000oa`0o`001`3oool000H0oooo=`000?n90?l003L0003o703o00070?ooo`001P3ooolg
0000ohT0o`00=`000?lL0?l000L0oooo00060?ooocL0003oR@3o000g0000oa`0o`001`3oool000H0
oooo=`000?n90?l003L0003o703o00070?ooo`001P3ooolg0000ohT0o`00=`000?lL0?l000L0oooo
00060?ooocL0003oR@3o000g0000oa`0o`001`3oool000H0oooo=`000?n90?l003L0003o703o0007
0?ooo`001P3ooolg0000ohT0o`00=`000?lL0?l000L0oooo00060?ooocL0003oR@3o000g0000oa`0
o`001`3oool000H0oooo=`000?n90?l003L0003o703o00070?ooo`001P3ooolg0000ohT0o`00=`00
0?lL0?l000L0oooo00060?ooocL0003oR@3o000g0000oa`0o`001`3oool000H0oooo=`000?n90?l0
03L0003o703o00070?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00
RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l7
0?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`00
1P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC
0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0
o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP00
0?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?oo
o`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3o
oomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000
ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00
RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l7
0?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`00
1P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg
0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0
o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`00
0?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?oo
o`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3o
oolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000
ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00
=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l7
0?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`00
1P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg
0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0
o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`00
0?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolL0?l001/0003o=`3o001B0000
oe<0o`001`3oool000H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`00
6`000?lg0?l00580003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3o
ool000H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l0
0580003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0oooo
703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o
00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0oooo703o000K0000
ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o00070?ooo`00
1P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0oooo703o000K0000ocL0o`00DP00
0?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o00070?ooo`001P3ooolL0?l0
01/0003o=`3o001B0000oe<0o`001`3oool000H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0
oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o
001B0000oe<0o`001`3oool000H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oo
oa`0o`006`000?lg0?l00580003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0
o`001`3oool000H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`00
0?lg0?l00580003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool0
00H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580
003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0oooo703o
000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o0007
0?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0oooo703o000K0000ocL0
o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o00070?ooo`001P3o
oolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0oooo703o000K0000ocL0o`00DP000?mC
0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o00070?ooo`001P3ooolL0?l001/0
003o=`3o001B0000oe<0o`001`3oool000H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo
00060?oooa`0o`006`000?lg0?l00580003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B
0000oe<0o`001`3oool000H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0
o`006`000?lg0?l00580003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`00
1`3oool000H0oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg
0?l00580003oD`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0
oooo703o000K0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003o
D`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0oooo703o000K
0000ocL0o`00DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o00070?oo
o`001P3ooolL0?l001/0003o=`3o001B0000oe<0o`001`3oool000H0oooo703o000K0000ocL0o`00
DP000?mC0?l000L0oooo00060?oooa`0o`006`000?lg0?l00580003oD`3o00070?ooo`001P3ooolL
0?l001/0003o=`3o001B0000oe<0o`001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP00
0?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0
ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3o
ool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0
o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^
0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`00
1P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o0007
0?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003o
Y@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?oo
ofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo
00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0oooo703o000g0000
ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`00
1`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool0
00H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo
703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g
0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00
o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3o
ool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0
oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o
000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000
ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`00
1`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool0
00H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
oooo70000?lg0?l003H0003oRP3o00070?ooo`001P3ooolL0000ocL0o`00=P000?n:0?l000L0oooo
00060?oooa`0003o=`3o000f0000ohX0o`001`3oool000H0oooo70000?lg0?l003H0003oRP3o0007
0?ooo`001P3ooolL0000ocL0o`00=P000?n:0?l000L0oooo00060?oooa`0003o=`3o000f0000ohX0
o`001`3oool000H0oooo70000?lg0?l003H0003oRP3o00070?ooo`001P3ooolL0000ocL0o`00=P00
0?n:0?l000L0oooo00060?oooa`0003o=`3o000f0000ohX0o`001`3oool000H0oooo70000?lg0?l0
03H0003oRP3o00070?ooo`001P3ooolL0000ocL0o`00=P000?n:0?l000L0oooo00060?oooa`0003o
=`3o000f0000ohX0o`001`3oool000H0oooo70000?lg0?l003H0003oRP3o00070?ooo`001P3ooolL
0000ocL0o`00=P000?n:0?l000L0oooo00060?oooa`0003o=`3o000f0000ohX0o`001`3oool000H0
oooo70000?lg0?l003H0003oRP3o00070?ooo`001P3ooolL0000ocL0o`00=P000?n:0?l000L0oooo
00060?oooa`0003o=`3o000f0000ohX0o`001`3oool000H0oooo70000?lg0?l003H0003oRP3o0007
0?ooo`001P3ooolL0000ocL0o`00=P000?n:0?l000L0oooo00060?oooa`0003o=`3o000f0000ohX0
o`001`3oool000H0oooo70000?lg0?l003H0003oRP3o00070?ooo`001P3ooolL0000ocL0o`00=P00
0?n:0?l000L0oooo00060?oooa`0003o=`3o000f0000ohX0o`001`3oool000H0oooo70000?lg0?l0
03H0003oRP3o00070?ooo`001P3ooolL0000ocL0o`00=P000?n:0?l000L0oooo00060?oooa`0003o
=`3o000f0000ohX0o`001`3oool000H0oooo70000?lg0?l003H0003oRP3o00070?ooo`001P3ooolL
0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000
o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`00
6`000?lg0?l001`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo0006
0?oooa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l0
01`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003o
R@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3o
ool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K0000
ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo
70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`007000
0?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?n90?l0
01/0003o=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`00
1P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o
000L0000o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000
ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0
oooo00060?oooa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`006`00
0?lg0?l001`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oo
oa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`00
1P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg
0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00
o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`007000
0?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?oo
o`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3o
oolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000
ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`00
70000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l7
0?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`00
1P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg
0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00
o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo
00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o0007
0?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0
o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`00
0?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l0
01/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o
=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL
0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0
oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo
00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o0007
0?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0
o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`00
0?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l0
01/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o
=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL
0000ocL0o`006`000?nU0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooD`3o000f
0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0
o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3o
ool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0
ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o
000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000
ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`00
1`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool0
00H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0oooo
D`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f
0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0
o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3o
ool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0
oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o
000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000
ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`00
1`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool0
00H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo
=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g
0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0
o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3o
ool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0
oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o
000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000
ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`00
1`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`007000
0?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0
o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo0006
0?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0
oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L
0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooo
m`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool0
00H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o
1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l0
01`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3o
ooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo=`3o000L
0000ohT0o`00=`000?l70?ooo`001P3ooolg0?l001`0003oR@3o000g0000o`L0oooo00060?ooocL0
o`0070000?n90?l003L0003o1`3oool000H0oooo=`3o000L0000ohT0o`00=`000?l70?ooo`001P3o
oolg0?l001`0003oR@3o000g0000o`L0oooo00060?ooocL0o`0070000?n90?l003L0003o1`3oool0
00H0oooo=`3o000L0000ohT0o`00=`000?l70?ooo`001P3ooolg0?l001`0003oR@3o000g0000o`L0
oooo00060?ooocL0o`0070000?n90?l003L0003o1`3oool000H0oooo=`3o000L0000ohT0o`00=`00
0?l70?ooo`001P3ooolg0?l001`0003oR@3o000g0000o`L0oooo00060?ooocL0o`0070000?n90?l0
03L0003o1`3oool000H0oooo=`3o000L0000ohT0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o
R@3o000g0000o`L0oooo00060?ooocL0o`0070000?n90?l003L0003o1`3oool000H0oooo=`3o000L
0000ohT0o`00=`000?l70?ooo`001P3ooolg0?l001`0003oR@3o000g0000o`L0oooo00060?ooocL0
o`0070000?n90?l003L0003o1`3oool000H0oooo=`3o000L0000ohT0o`00=`000?l70?ooo`001P3o
oolg0?l001`0003oR@3o000g0000o`L0oooo00060?ooocL0o`0070000?n90?l003L0003o1`3oool0
00H0oooo=`3o000L0000ohT0o`00=`000?l70?ooo`001P3ooolg0?l001`0003oR@3o000g0000o`L0
oooo00060?ooocL0o`0070000?n90?l003L0003o1`3oool000H0oooo=`3o000L0000ohT0o`00=`00
0?l70?ooo`001P3ooolg0?l001`0003oR@3o000g0000o`L0oooo00060?ooocL0o`0070000?n90?l0
03L0003o1`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`00
1`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool0
00H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo
703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g
0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00
o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3o
ool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0
oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o
000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000
ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`00
1`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool0
00H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo
703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0ooooD`000?nT
0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0
003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3o
ool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0
ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`00
0?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l0
01`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o
1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool0
00H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0oooo
D`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT
0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0
003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3o
ool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooo=`000?oL0?l000L0oooo00060?oo
ocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo
00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l0
00L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`00
0?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0
oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3o
ool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0
o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg
0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`00
1P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o0007
0?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0
oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`00
0?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?oo
ocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0
003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o
000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool0
00H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0
o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`00
0?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l7
0?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0
003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3o
oolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L
0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0
o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo
00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg
0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0
003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o
1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooofh0o`006`000?n:
0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0
oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo0006
0?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0
o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`00
0?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l0
00L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo
00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?oo
ofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`00
6`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:
0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0
oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo0006
0?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo=`000?oL0?l000L0oooo
00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l0
00L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`00
0?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0
oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3o
ool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0
o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg
0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`00
1P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o0007
0?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003o
g03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?nU0?l003L0003o1`3oool0
00H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo
=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU
0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0
003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3o
ool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0
oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`00
0?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l0
03L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o
1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool0
00H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo
=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU
0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0ooooKP3o000g0000ocL0
o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3o
oom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL
0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0
003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo
00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K
0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0
o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`00
1`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg
0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0
ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o
703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g
0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?oo
o`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`00
6`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^
0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l0
00L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o
=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo
00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oo
oa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`00
6`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL
0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0
oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo0006
0?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0
o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`00
0?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l0
00L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo
00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oo
oa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`00
6`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL
0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`00
1`3oool000H0oooo703o000K0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU
0?l001/0003o703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0
oooo703o000K0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o
703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000K
0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o00070?oo
o`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000K0000ojD0o`00
6`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o00070?ooo`001P3ooolL
0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000K0000ojD0o`006`000?lL0?l0
00L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o00070?ooo`001P3ooolL0?l001/0003o
Y@3o000K0000oa`0o`001`3oool000H0oooo703o000K0000ojD0o`006`000?lL0?l000L0oooo0006
0?oooa`0o`006`000?nU0?l001/0003o703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000
oa`0o`001`3oool000H0oooo703o000K0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`00
6`000?nU0?l001/0003o703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3o
ool000H0oooo703o000K0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l0
01/0003o703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo
703o000K0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o
00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000g0000
ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`00
1`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool0
00H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo
703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g
0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00
o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3o
ool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0
oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o
000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000
ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`00
1`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool0
00H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooD`3o001B
0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0
o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3o
ool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0
ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o
001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000
ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`00
1`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool0
00H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0oooo
D`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B
0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0
o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3o
ool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0
oooo703o000K0000oa`0o`00=P000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003o
703o000f0000ocL0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o=`3o
000L0000ocL0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lg0?l001`0003o=`3o0007
0?ooo`001P3ooolL0?l001/0003o703o000f0000ocL0o`0070000?lg0?l000L0oooo00060?oooa`0
o`006`000?lL0?l003H0003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000oa`0o`00
=P000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000ocL0o`007000
0?lg0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o=`3o000L0000ocL0o`001`3oool0
00H0oooo703o000K0000oa`0o`00=P000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0
003o703o000f0000ocL0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o
=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lg0?l001`0003o=`3o
00070?ooo`001P3ooolL0?l001/0003o703o000f0000ocL0o`0070000?lg0?l000L0oooo00060?oo
oa`0o`006`000?lL0?l003H0003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000oa`0
o`00=P000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000ocL0o`00
70000?lg0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o=`3o000L0000ocL0o`001`3o
ool000H0oooo703o000K0000oa`0o`00=P000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l0
01/0003o703o000f0000ocL0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0
003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lg0?l001`0003o
=`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000ocL0o`0070000?lg0?l000L0oooo0006
0?oooa`0o`006`000?lL0?l003H0003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000
oa`0o`00=P000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000ocL0
o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o=`3o000L0000ocL0o`00
1`3oool000H0oooo703o000K0000oa`0o`00=P000?lg0?l001`0003o=`3o00070?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo
00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o0007
0?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0
o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`007000
0?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l0
01`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003o
Y03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL
0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0
oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo
00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o0007
0?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0
o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`007000
0?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l0
01`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003o
Y03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL
0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?oo
o`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003o
KP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL
0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000
o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`00
6`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo0006
0?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l0
01`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o
DP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3o
ool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000
ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo
70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`007000
0?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l0
01/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`00
1P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o
000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000
oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0
oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo0006
0?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0
o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`00
0?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l0
00L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo
00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?oo
ofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00
=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^
0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0
oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo0006
0?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0
o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`00
0?m^0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l0
00L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo
00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?oo
ocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00
DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:
0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0
oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo0006
0?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0
o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP00
0?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l0
00L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo
00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?oo
ocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00
=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU
0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0
oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo0006
0?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0
o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`00
0?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l0
00L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo
00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?oo
ocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00
=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU
0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0
oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo
00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?oo
ojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00
=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg
0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0
oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo0006
0?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0
o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`00
0?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l0
00L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo
00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?oo
ojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00
=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg
0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3o
oonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l0
01/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003o
D`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o0007
0?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`00
1P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU
0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0
003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o
00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?oo
o`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3o
oonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l0
01/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003o
D`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o0007
0?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`00
1P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU
0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0
003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o
00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?oo
o`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3o
oonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l0
01/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003o
D`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o0007
0?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`00
1P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU
0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0
003oD`3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o
00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?oo
o`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3o
oomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l0
03H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003o
RP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o0007
0?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`00
1P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC
0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0
003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o
00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?oo
o`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3o
oomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0
003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o
00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooolL0?l001/0003oR@3o000L0000ocL0
o`001`3oool000H0oooo703o000K0000ohT0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`00
0?n90?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003oR@3o000L0000ocL0o`001`3oool0
00H0oooo703o000K0000ohT0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?n90?l001`0
003o=`3o00070?ooo`001P3ooolL0?l001/0003oR@3o000L0000ocL0o`001`3oool000H0oooo703o
000K0000ohT0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?n90?l001`0003o=`3o0007
0?ooo`001P3ooolL0?l001/0003oR@3o000L0000ocL0o`001`3oool000H0oooo703o000K0000ohT0
o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?n90?l001`0003o=`3o00070?ooo`001P3o
oolL0?l001/0003oR@3o000L0000ocL0o`001`3oool000H0oooo703o000K0000ohT0o`0070000?lg
0?l000L0oooo00060?oooa`0o`006`000?n90?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0
003oR@3o000L0000ocL0o`001`3oool000H0oooo703o000K0000ohT0o`0070000?lg0?l000L0oooo
00060?oooa`0o`006`000?n90?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003oR@3o000L
0000ocL0o`001`3oool000H0oooo703o000K0000ohT0o`0070000?lg0?l000L0oooo00060?oooa`0
o`006`000?n90?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003oR@3o000L0000ocL0o`00
1`3oool000H0oooo703o000K0000ohT0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?n9
0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003oR@3o000L0000ocL0o`001`3oool000H0
oooo703o000K0000ohT0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?n90?l001`0003o
=`3o00070?ooo`001P3ooolL0?l001/0003oR@3o000L0000ocL0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o
000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000
oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`00
1`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool0
00H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K
0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo
Y@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B
0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0
o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3o
ool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0
ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K
0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o
000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000
oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`00
1`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool0
00H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K
0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3o
oon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l0
03L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003o
D`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o0007
0?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`00
1P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon9
0?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0
003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o
00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?oo
o`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3o
oon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l0
03L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003o
D`3o00070?ooo`001P3ooon90?l003L0003oD`3o00070?ooo`001P3ooon90?l003L0003oD`3o0007
0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`00
1P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon9
0?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0
003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o
00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?oo
o`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`00
1P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon9
0?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0
003oKP3o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0
003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o
00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooon90?l005<0003o=`3o0007
0?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`00
1P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon9
0?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0
003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o
00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?oo
o`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3o
oon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l0
05<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o
=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o0007
0?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`00
1P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon9
0?l005<0003o=`3o00070?ooo`001P3ooon90?l005<0003o=`3o00070?ooo`001P3ooon90?l001`0
003o6`3o000L0000ocL0o`001`3oool000H0ooooR@3o000L0000oa/0o`0070000?lg0?l000L0oooo
00060?ooohT0o`0070000?lK0?l001`0003o=`3o00070?ooo`001P3ooon90?l001`0003o6`3o000L
0000ocL0o`001`3oool000H0ooooR@3o000L0000oa/0o`0070000?lg0?l000L0oooo00060?ooohT0
o`0070000?lK0?l001`0003o=`3o00070?ooo`001P3ooon90?l001`0003o6`3o000L0000ocL0o`00
1`3oool000H0ooooR@3o000L0000oa/0o`0070000?lg0?l000L0oooo00060?ooohT0o`0070000?lK
0?l001`0003o=`3o00070?ooo`001P3ooon90?l001`0003o6`3o000L0000ocL0o`001`3oool000H0
ooooR@3o000L0000oa/0o`0070000?lg0?l000L0oooo00060?ooohT0o`0070000?lK0?l001`0003o
=`3o00070?ooo`001P3ooon90?l001`0003o6`3o000L0000ocL0o`001`3oool000H0ooooR@3o000L
0000oa/0o`0070000?lg0?l000L0oooo00060?ooohT0o`0070000?lK0?l001`0003o=`3o00070?oo
o`001P3ooon90?l001`0003o6`3o000L0000ocL0o`001`3oool000H0ooooR@3o000L0000oa/0o`00
70000?lg0?l000L0oooo00060?ooohT0o`0070000?lK0?l001`0003o=`3o00070?ooo`001P3ooon9
0?l001`0003o6`3o000L0000ocL0o`001`3oool000H0ooooR@3o000L0000oa/0o`0070000?lg0?l0
00L0oooo00060?ooohT0o`0070000?lK0?l001`0003o=`3o00070?ooo`001P3ooon90?l001`0003o
6`3o000L0000ocL0o`001`3oool000H0ooooR@3o000L0000oa/0o`0070000?lg0?l000L0oooo0006
0?ooohT0o`0070000?lK0?l001`0003o=`3o00070?ooo`001P3ooon90?l001`0003o6`3o000L0000
ocL0o`001`3oool000H0ooooR@3o000L0000oa/0o`0070000?lg0?l000L0oooo00060?ooohT0o`00
70000?lK0?l001`0003o=`3o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon9
0?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0
003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o
00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?oo
o`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3o
oon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l0
06h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o
703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o0007
0?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`00
1P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon9
0?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0
003o703o00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l006h0003o703o
00070?ooo`001P3ooon90?l006h0003o703o00070?ooo`001P3ooon90?l003L0003o=`3o000L0000
o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`00
70000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg
0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0
003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o
000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?oo
ohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`00
1P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3o
ool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000
o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`00
70000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg
0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0
003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o
000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?oo
ohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`00
1P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3o
ool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000
o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`00
70000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg
0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0
003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o
000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?oo
ohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`00
1P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3o
ool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000
o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`00
70000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg
0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0
003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o
000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`00
1P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon9
0?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0
003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o
00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?oo
o`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0
o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3o
oolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`006`000?mC
0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0
003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`006`000?mC0?l000L0oooo
00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000K
0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`006`000?mC0?l000L0oooo00060?oooa`0
o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`00
1`3oool000H0oooo703o000K0000ofh0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^
0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0
oooo703o000K0000ofh0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003o
D`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K
0000ofh0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?oo
o`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`00
6`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolL
0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`006`000?mC0?l0
00L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o
KP3o001B0000oa`0o`001`3oool000H0oooo703o000K0000ofh0o`00DP000?lL0?l000L0oooo0006
0?oooa`0o`006`000?m^0?l00580003o703o00070?ooo`001P3ooolL0?l001/0003oKP3o001B0000
oa`0o`001`3oool000H0oooo703o000K0000ofh0o`00DP000?lL0?l000L0oooo00060?oooa`0o`00
6`000?m^0?l00580003o703o00070?ooo`001P3ooolL0?l001/0003oKP3o001B0000oa`0o`001`3o
ool000H0oooo703o000K0000ofh0o`00DP000?lL0?l000L0oooo00060?oooa`0o`006`000?m^0?l0
0580003o703o00070?ooo`001P3ooolL0?l001/0003oKP3o001B0000oa`0o`001`3oool000H0oooo
703o000K0000ofh0o`00DP000?lL0?l000L0oooo00060?oooa`0o`006`000?m^0?l00580003o703o
00070?ooo`001P3ooolL0?l001/0003oKP3o001B0000oa`0o`001`3oool000H0oooo703o000K0000
ofh0o`00DP000?lL0?l000L0oooo00060?oooa`0o`006`000?m^0?l00580003o703o00070?ooo`00
1P3ooolL0?l001/0003oKP3o001B0000oa`0o`001`3oool000H0oooo703o000K0000ofh0o`00DP00
0?lL0?l000L0oooo00060?oooa`0o`006`000?m^0?l00580003o703o00070?ooo`001P3ooolL0?l0
01/0003oKP3o001B0000oa`0o`001`3oool000H0oooo703o000K0000ofh0o`00DP000?lL0?l000L0
oooo00060?oooa`0o`006`000?m^0?l00580003o703o00070?ooo`001P3ooolL0?l001/0003oKP3o
001B0000oa`0o`001`3oool000H0oooo703o000K0000ofh0o`00DP000?lL0?l000L0oooo00060?oo
oa`0o`006`000?m^0?l00580003o703o00070?ooo`001P3ooolL0?l001/0003oKP3o001B0000oa`0
o`001`3oool000H0oooo703o000K0000ofh0o`00DP000?lL0?l000L0oooo00060?oooa`0o`006`00
0?m^0?l00580003o703o00070?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3ooolg0?l001`0003o=P3o001C0000ocL0o`001`3oool000H0oooo
=`3o000L0000ocH0o`00D`000?lg0?l000L0oooo00060?ooocL0o`0070000?lf0?l005<0003o=`3o
00070?ooo`001P3ooolg0?l001`0003o=P3o001C0000ocL0o`001`3oool000H0oooo=`3o000L0000
ocH0o`00D`000?lg0?l000L0oooo00060?ooocL0o`0070000?lf0?l005<0003o=`3o00070?ooo`00
1P3ooolg0?l001`0003o=P3o001C0000ocL0o`001`3oool000H0oooo=`3o000L0000ocH0o`00D`00
0?lg0?l000L0oooo00060?ooocL0o`0070000?lf0?l005<0003o=`3o00070?ooo`001P3ooolg0?l0
01`0003o=P3o001C0000ocL0o`001`3oool000H0oooo=`3o000L0000ocH0o`00D`000?lg0?l000L0
oooo00060?ooocL0o`0070000?lf0?l005<0003o=`3o00070?ooo`001P3ooolg0?l001`0003o=P3o
001C0000ocL0o`001`3oool000H0oooo=`3o000L0000ocH0o`00D`000?lg0?l000L0oooo00060?oo
ocL0o`0070000?lf0?l005<0003o=`3o00070?ooo`001P3ooolg0?l001`0003o=P3o001C0000ocL0
o`001`3oool000H0oooo=`3o000L0000ocH0o`00D`000?lg0?l000L0oooo00060?ooocL0o`007000
0?lf0?l005<0003o=`3o00070?ooo`001P3ooolg0?l001`0003o=P3o001C0000ocL0o`001`3oool0
00H0oooo=`3o000L0000ocH0o`00D`000?lg0?l000L0oooo00060?ooocL0o`0070000?lf0?l005<0
003o=`3o00070?ooo`001P3ooolg0?l001`0003o=P3o001C0000ocL0o`001`3oool000H0oooo=`3o
000L0000ocH0o`00D`000?lg0?l000L0oooo00060?ooocL0o`0070000?lf0?l005<0003o=`3o0007
0?ooo`001P3ooolg0?l001`0003o=P3o001C0000ocL0o`001`3oool000H0oooo=`3o000L0000ocH0
o`00D`000?lg0?l000L0oooo00060?ooocL0o`0070000?lf0?l005<0003o=`3o00070?ooo`001P3o
oolg0?l001`0003o=P3o001C0000ocL0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o
000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000
oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`00
1`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool0
00H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K
0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooKP3o
001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000
oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`00
1`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool0
00H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0oooo
KP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B
0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0
o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3o
ool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0
ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o
001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000
oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`00
1`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool0
00H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0oooo
KP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B
0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0
o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3o
ool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0
ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o
001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000
oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`00
1`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool0
00H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0oooo
KP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B
0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o
1`3oool000H0oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K
0000ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0
oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`00
70000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0oooo=`000?lg
0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`0070000?l70?oo
o`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0oooo=`000?lg0?l001/0003o
KP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolg
0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0oooo=`000?lg0?l001/0003oKP3o000L0000
o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`00
6`000?m^0?l001`0003o1`3oool000H0oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo0006
0?ooocL0003o=`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l0
01`0003o1`3oool000H0oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o
=`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3o
ool000H0oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000
ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0oooo
=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`007000
0?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?n90?l0
03L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o
1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool0
00H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0oooo
D`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n9
0?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0
003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3o
ool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0
ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`00
0?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l0
03L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o
1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool0
00H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0oooo
70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK
0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0
003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3o
ool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0
oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo7000
0?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l0
01`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o
1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool0
00H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo
70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK
0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0
003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3o
ool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0
oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo7000
0?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l0
06h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o
1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool0
00H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo
70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n9
0?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0
003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3o
ool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0
oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo7000
0?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l0
06h0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o
1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool0
00H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo
=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o0
0?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0
003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3o
ool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0
oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`00
0?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l0
01`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o
1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool0
00H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo
=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo703o000K
0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?oo
o`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`00
6`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL
0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l0
00L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o
=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo0006
0?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000
ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`00
6`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3o
ool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l0
01/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo
703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o
00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000
ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`00
1P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`00
0?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l0
01/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0
oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o
000g0000ofh0o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oo
oa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0
o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`00
0?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool0
00H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0
003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo703o
000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o0007
0?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo703o000g0000oa/0
o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3o
oolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^
0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0
003o6`3o000g0000ofh0o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0oooo
00060?oooa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000g
0000ofh0o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0
o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`00
1`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool0
00H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo
703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o0029
0000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0
o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3o
ool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0
oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o
00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000
ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`00
1`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool0
00H0oooo703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo
703o00290000ofh0o`001`3oool000H0oooo703o00290000ofh0o`001`3oool000H0oooo703o0029
0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0
o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3o
ool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0
ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o
001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000
ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`00
1`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool0
00H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0oooo
D`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B
0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0
o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3o
ool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0
ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000ocL0o`006`000?m^0?l003L0003o
1`3oool000H0oooo70000?lg0?l001/0003oKP3o000g0000o`L0oooo00060?oooa`0003o=`3o000K
0000ofh0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`006`000?m^0?l003L0003o1`3oool000H0
oooo70000?lg0?l001/0003oKP3o000g0000o`L0oooo00060?oooa`0003o=`3o000K0000ofh0o`00
=`000?l70?ooo`001P3ooolL0000ocL0o`006`000?m^0?l003L0003o1`3oool000H0oooo70000?lg
0?l001/0003oKP3o000g0000o`L0oooo00060?oooa`0003o=`3o000K0000ofh0o`00=`000?l70?oo
o`001P3ooolL0000ocL0o`006`000?m^0?l003L0003o1`3oool000H0oooo70000?lg0?l001/0003o
KP3o000g0000o`L0oooo00060?oooa`0003o=`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooolL
0000ocL0o`006`000?m^0?l003L0003o1`3oool000H0oooo70000?lg0?l001/0003oKP3o000g0000
o`L0oooo00060?oooa`0003o=`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`00
6`000?m^0?l003L0003o1`3oool000H0oooo70000?lg0?l001/0003oKP3o000g0000o`L0oooo0006
0?oooa`0003o=`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`006`000?m^0?l0
03L0003o1`3oool000H0oooo70000?lg0?l001/0003oKP3o000g0000o`L0oooo00060?oooa`0003o
=`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`006`000?m^0?l003L0003o1`3o
ool000H0oooo70000?lg0?l001/0003oKP3o000g0000o`L0oooo00060?oooa`0003o=`3o000K0000
ofh0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`006`000?m^0?l003L0003o1`3oool000H0oooo
70000?lg0?l001/0003oKP3o000g0000o`L0oooo00060?oooa`0003o=`3o000K0000ofh0o`00=`00
0?l70?ooo`001P3ooolL0000ocL0o`006`000?m^0?l003L0003o1`3oool000H0oooo70000?lg0?l0
01/0003oR@3o000L0000o`L0oooo00060?oooa`0003o=`3o000K0000ohT0o`0070000?l70?ooo`00
1P3ooolL0000ocL0o`006`000?n90?l001`0003o1`3oool000H0oooo70000?lg0?l001/0003oR@3o
000L0000o`L0oooo00060?oooa`0003o=`3o000K0000ohT0o`0070000?l70?ooo`001P3ooolL0000
ocL0o`006`000?n90?l001`0003o1`3oool000H0oooo70000?lg0?l001/0003oR@3o000L0000o`L0
oooo00060?oooa`0003o=`3o000K0000ohT0o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`00
0?n90?l001`0003o1`3oool000H0oooo70000?lg0?l001/0003oR@3o000L0000o`L0oooo00060?oo
oa`0003o=`3o000K0000ohT0o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`000?n90?l001`0
003o1`3oool000H0oooo70000?lg0?l001/0003oR@3o000L0000o`L0oooo00060?oooa`0003o=`3o
000K0000ohT0o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`000?n90?l001`0003o1`3oool0
00H0oooo70000?lg0?l001/0003oR@3o000L0000o`L0oooo00060?oooa`0003o=`3o000K0000ohT0
o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`000?n90?l001`0003o1`3oool000H0oooo7000
0?lg0?l001/0003oR@3o000L0000o`L0oooo00060?oooa`0003o=`3o000K0000ohT0o`0070000?l7
0?ooo`001P3ooolL0000ocL0o`006`000?n90?l001`0003o1`3oool000H0oooo70000?lg0?l001/0
003oR@3o000L0000o`L0oooo00060?oooa`0003o=`3o000K0000ohT0o`0070000?l70?ooo`001P3o
oolL0000ocL0o`006`000?n90?l001`0003o1`3oool000H0oooo70000?lg0?l001/0003oR@3o000L
0000o`L0oooo00060?oooa`0003o=`3o000K0000ohT0o`0070000?l70?ooo`001P3ooolL0000ocL0
o`006`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000ocL0o`00KP000?l70?ooo`001P3o
oomC0?l001/0003o=`3o001^0000o`L0oooo00060?oooe<0o`006`000?lg0?l006h0003o1`3oool0
00H0ooooD`3o000K0000ocL0o`00KP000?l70?ooo`001P3ooomC0?l001/0003o=`3o001^0000o`L0
oooo00060?oooe<0o`006`000?lg0?l006h0003o1`3oool000H0ooooD`3o000K0000ocL0o`00KP00
0?l70?ooo`001P3ooomC0?l001/0003o=`3o001^0000o`L0oooo00060?oooe<0o`006`000?lg0?l0
06h0003o1`3oool000H0ooooD`3o000K0000ocL0o`00KP000?l70?ooo`001P3ooomC0?l001/0003o
=`3o001^0000o`L0oooo00060?oooe<0o`006`000?lg0?l006h0003o1`3oool000H0ooooD`3o000K
0000ocL0o`00KP000?l70?ooo`001P3ooomC0?l001/0003o=`3o001^0000o`L0oooo00060?oooe<0
o`006`000?lg0?l006h0003o1`3oool000H0ooooD`3o000K0000ocL0o`00KP000?l70?ooo`001P3o
oomC0?l001/0003o=`3o001^0000o`L0oooo00060?oooe<0o`006`000?lg0?l006h0003o1`3oool0
00H0ooooD`3o000K0000ocL0o`00KP000?l70?ooo`001P3ooomC0?l001/0003o=`3o001^0000o`L0
oooo00060?oooe<0o`006`000?lg0?l006h0003o1`3oool000H0ooooD`3o000K0000ocL0o`00KP00
0?l70?ooo`001P3ooomC0?l001/0003o=`3o001^0000o`L0oooo00060?oooe<0o`006`000?lg0?l0
06h0003o1`3oool000H0ooooD`3o000K0000ocL0o`00KP000?l70?ooo`001P3ooomC0?l001/0003o
=`3o001^0000o`L0oooo00060?oooe<0o`006`000?lg0?l006h0003o1`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oooe<0
o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P00
0?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l0
00L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo
00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oo
oe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00
=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:
0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0
oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo0006
0?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0
o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P00
0?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l0
00L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo
00060?oooe<0o`00=P000?mC0?l001/0003o703o00070?ooo`001P3ooomC0?l003H0003oD`3o000K
0000oa`0o`001`3oool000H0ooooD`3o000f0000oe<0o`006`000?lL0?l000L0oooo00060?oooe<0
o`00=P000?mC0?l001/0003o703o00070?ooo`001P3ooomC0?l003H0003oD`3o000K0000oa`0o`00
1`3oool000H0ooooD`3o000f0000oe<0o`006`000?lL0?l000L0oooo00060?oooe<0o`00=P000?mC
0?l001/0003o703o00070?ooo`001P3ooomC0?l003H0003oD`3o000K0000oa`0o`001`3oool000H0
ooooD`3o000f0000oe<0o`006`000?lL0?l000L0oooo00060?oooe<0o`00=P000?mC0?l001/0003o
703o00070?ooo`001P3ooomC0?l003H0003oD`3o000K0000oa`0o`001`3oool000H0ooooD`3o000f
0000oe<0o`006`000?lL0?l000L0oooo00060?oooe<0o`00=P000?mC0?l001/0003o703o00070?oo
o`001P3ooomC0?l003H0003oD`3o000K0000oa`0o`001`3oool000H0ooooD`3o000f0000oe<0o`00
6`000?lL0?l000L0oooo00060?oooe<0o`00=P000?mC0?l001/0003o703o00070?ooo`001P3ooomC
0?l003H0003oD`3o000K0000oa`0o`001`3oool000H0ooooD`3o000f0000oe<0o`006`000?lL0?l0
00L0oooo00060?oooe<0o`00=P000?mC0?l001/0003o703o00070?ooo`001P3ooomC0?l003H0003o
D`3o000K0000oa`0o`001`3oool000H0ooooD`3o000f0000oe<0o`006`000?lL0?l000L0oooo0006
0?oooe<0o`00=P000?mC0?l001/0003o703o00070?ooo`001P3ooomC0?l003H0003oD`3o000K0000
oa`0o`001`3oool000H0ooooD`3o000f0000oe<0o`006`000?lL0?l000L0oooo00060?oooe<0o`00
=P000?mC0?l001/0003o703o00070?ooo`001P3ooomC0?l003H0003oD`3o000K0000oa`0o`001`3o
ool000H0ooooD`3o000f0000oe<0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?mB0?l0
03L0003o703o00070?ooo`001P3ooomC0?l001/0003oDP3o000g0000oa`0o`001`3oool000H0oooo
D`3o000K0000oe80o`00=`000?lL0?l000L0oooo00060?oooe<0o`006`000?mB0?l003L0003o703o
00070?ooo`001P3ooomC0?l001/0003oDP3o000g0000oa`0o`001`3oool000H0ooooD`3o000K0000
oe80o`00=`000?lL0?l000L0oooo00060?oooe<0o`006`000?mB0?l003L0003o703o00070?ooo`00
1P3ooomC0?l001/0003oDP3o000g0000oa`0o`001`3oool000H0ooooD`3o000K0000oe80o`00=`00
0?lL0?l000L0oooo00060?oooe<0o`006`000?mB0?l003L0003o703o00070?ooo`001P3ooomC0?l0
01/0003oDP3o000g0000oa`0o`001`3oool000H0ooooD`3o000K0000oe80o`00=`000?lL0?l000L0
oooo00060?oooe<0o`006`000?mB0?l003L0003o703o00070?ooo`001P3ooomC0?l001/0003oDP3o
000g0000oa`0o`001`3oool000H0ooooD`3o000K0000oe80o`00=`000?lL0?l000L0oooo00060?oo
oe<0o`006`000?mB0?l003L0003o703o00070?ooo`001P3ooomC0?l001/0003oDP3o000g0000oa`0
o`001`3oool000H0ooooD`3o000K0000oe80o`00=`000?lL0?l000L0oooo00060?oooe<0o`006`00
0?mB0?l003L0003o703o00070?ooo`001P3ooomC0?l001/0003oDP3o000g0000oa`0o`001`3oool0
00H0ooooD`3o000K0000oe80o`00=`000?lL0?l000L0oooo00060?oooe<0o`006`000?mB0?l003L0
003o703o00070?ooo`001P3ooomC0?l001/0003oDP3o000g0000oa`0o`001`3oool000H0ooooD`3o
000K0000oe80o`00=`000?lL0?l000L0oooo00060?oooe<0o`006`000?mB0?l003L0003o703o0007
0?ooo`001P3ooomC0?l001/0003oDP3o000g0000oa`0o`001`3oool000H0ooooD`3o000K0000oe80
o`00=`000?lL0?l000L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3o
ool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0
003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL
0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`00
1P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l7
0?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00
=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?oo
om`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo
00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000
o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o
000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003oK@3o000g0000oa`0o`001`3oool000H0oooo=`3o000L0000ofd0
o`00=`000?lL0?l000L0oooo00060?ooocL0o`0070000?m]0?l003L0003o703o00070?ooo`001P3o
oolg0?l001`0003oK@3o000g0000oa`0o`001`3oool000H0oooo=`3o000L0000ofd0o`00=`000?lL
0?l000L0oooo00060?ooocL0o`0070000?m]0?l003L0003o703o00070?ooo`001P3ooolg0?l001`0
003oK@3o000g0000oa`0o`001`3oool000H0oooo=`3o000L0000ofd0o`00=`000?lL0?l000L0oooo
00060?ooocL0o`0070000?m]0?l003L0003o703o00070?ooo`001P3ooolg0?l001`0003oK@3o000g
0000oa`0o`001`3oool000H0oooo=`3o000L0000ofd0o`00=`000?lL0?l000L0oooo00060?ooocL0
o`0070000?m]0?l003L0003o703o00070?ooo`001P3ooolg0?l001`0003oK@3o000g0000oa`0o`00
1`3oool000H0oooo=`3o000L0000ofd0o`00=`000?lL0?l000L0oooo00060?ooocL0o`0070000?m]
0?l003L0003o703o00070?ooo`001P3ooolg0?l001`0003oK@3o000g0000oa`0o`001`3oool000H0
oooo=`3o000L0000ofd0o`00=`000?lL0?l000L0oooo00060?ooocL0o`0070000?m]0?l003L0003o
703o00070?ooo`001P3ooolg0?l001`0003oK@3o000g0000oa`0o`001`3oool000H0oooo=`3o000L
0000ofd0o`00=`000?lL0?l000L0oooo00060?ooocL0o`0070000?m]0?l003L0003o703o00070?oo
o`001P3ooolg0?l001`0003oK@3o000g0000oa`0o`001`3oool000H0oooo=`3o000L0000ofd0o`00
=`000?lL0?l000L0oooo00060?ooocL0o`0070000?m]0?l003L0003o703o00070?ooo`001P3ooolg
0?l001`0003oK@3o000g0000oa`0o`001`3oool000H0oooo=`3o000L0000ofd0o`00=`000?lL0?l0
00L0oooo00060?ooocL0o`0070000?m]0?l003L0003o703o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0
oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`007000
0?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l0
01`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003o
Y03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L
0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0
o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3o
oolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool0
00H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0
oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`007000
0?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l0
01`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003o
Y03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L
0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0
o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l0
01/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o
703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o0007
0?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`00
1P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL
0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0
003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o
00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?oo
o`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l0
01/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o
703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo0
0?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0
003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o
00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?oo
o`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3o
ooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l0
03L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o
703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o0007
0?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`00
1P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo0
0?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0
003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o
00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0
003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o
00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
00H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo
703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
00H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo
703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000L0000
oa/0o`00=`000?lL0?l000L0oooo00060?ooohT0o`0070000?lK0?l003L0003o703o00070?ooo`00
1P3ooon90?l001`0003o6`3o000g0000oa`0o`001`3oool000H0ooooR@3o000L0000oa/0o`00=`00
0?lL0?l000L0oooo00060?ooohT0o`0070000?lK0?l003L0003o703o00070?ooo`001P3ooon90?l0
01`0003o6`3o000g0000oa`0o`001`3oool000H0ooooR@3o000L0000oa/0o`00=`000?lL0?l000L0
oooo00060?ooohT0o`0070000?lK0?l003L0003o703o00070?ooo`001P3ooon90?l001`0003o6`3o
000g0000oa`0o`001`3oool000H0ooooR@3o000L0000oa/0o`00=`000?lL0?l000L0oooo00060?oo
ohT0o`0070000?lK0?l003L0003o703o00070?ooo`001P3ooon90?l001`0003o6`3o000g0000oa`0
o`001`3oool000H0ooooR@3o000L0000oa/0o`00=`000?lL0?l000L0oooo00060?ooohT0o`007000
0?lK0?l003L0003o703o00070?ooo`001P3ooon90?l001`0003o6`3o000g0000oa`0o`001`3oool0
00H0ooooR@3o000L0000oa/0o`00=`000?lL0?l000L0oooo00060?ooohT0o`0070000?lK0?l003L0
003o703o00070?ooo`001P3ooon90?l001`0003o6`3o000g0000oa`0o`001`3oool000H0ooooR@3o
000L0000oa/0o`00=`000?lL0?l000L0oooo00060?ooohT0o`0070000?lK0?l003L0003o703o0007
0?ooo`001P3ooon90?l001`0003o6`3o000g0000oa`0o`001`3oool000H0ooooR@3o000L0000oa/0
o`00=`000?lL0?l000L0oooo00060?ooohT0o`0070000?lK0?l003L0003o703o00070?ooo`001P3o
oon90?l001`0003o6`3o000g0000oa`0o`001`3oool000H0ooooR@3o000L0000oa/0o`00=`000?lL
0?l000L0oooo00060?ooohT0o`0070000?lK0?l003L0003o703o00070?ooo`001P3ooon90?l001`0
003o6`3o000g0000oa`0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo0006
0?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0
o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`00
0?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l0
00L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo
00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oo
oa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`00
6`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL
0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0
oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo0006
0?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0
o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`00
0?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oooa`0003of`3o000L0000o`L0oooo
00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oo
oa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003o
f`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L
0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0
oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo0006
0?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0
003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o
000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000
o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo
00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oo
oa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003o
f`3o000L0000o`L0oooo00060?oooa`0003of`3o000L0000o`L0oooo00060?oooa`0003of`3o000L
0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3o
oolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000
om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`00
70000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l7
0?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`00
1P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL
0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0
o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`007000
0?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?oo
o`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3o
oolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000
om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`00
70000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l7
0?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`00
1P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC
0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0
003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o
00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?oo
o`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3o
oomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l0
03H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003o
RP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o0007
0?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`00
1P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC
0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0
003oRP3o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0
o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo0006
0?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0
oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L
0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooo
m`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool0
00H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o
1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l0
01`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3o
ooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?oo
o`001P3ooolg0?l001`0003oDP3o000K0000oe<0o`001`3oool000H0oooo=`3o000L0000oe80o`00
6`000?mC0?l000L0oooo00060?ooocL0o`0070000?mB0?l001/0003oD`3o00070?ooo`001P3ooolg
0?l001`0003oDP3o000K0000oe<0o`001`3oool000H0oooo=`3o000L0000oe80o`006`000?mC0?l0
00L0oooo00060?ooocL0o`0070000?mB0?l001/0003oD`3o00070?ooo`001P3ooolg0?l001`0003o
DP3o000K0000oe<0o`001`3oool000H0oooo=`3o000L0000oe80o`006`000?mC0?l000L0oooo0006
0?ooocL0o`0070000?mB0?l001/0003oD`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000
oe<0o`001`3oool000H0oooo=`3o000L0000oe80o`006`000?mC0?l000L0oooo00060?ooocL0o`00
70000?mB0?l001/0003oD`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000oe<0o`001`3o
ool000H0oooo=`3o000L0000oe80o`006`000?mC0?l000L0oooo00060?ooocL0o`0070000?mB0?l0
01/0003oD`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000oe<0o`001`3oool000H0oooo
=`3o000L0000oe80o`006`000?mC0?l000L0oooo00060?ooocL0o`0070000?mB0?l001/0003oD`3o
00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000oe<0o`001`3oool000H0oooo=`3o000L0000
oe80o`006`000?mC0?l000L0oooo00060?ooocL0o`0070000?mB0?l001/0003oD`3o00070?ooo`00
1P3ooolg0?l001`0003oDP3o000K0000oe<0o`001`3oool000H0oooo=`3o000L0000oe80o`006`00
0?mC0?l000L0oooo00060?ooocL0o`0070000?mB0?l001/0003oD`3o00070?ooo`001P3ooolg0?l0
01`0003oDP3o000K0000oe<0o`001`3oool000H0oooo=`3o000L0000oe80o`006`000?mC0?l000L0
oooo00060?ooocL0o`0070000?mB0?l001/0003oD`3o00070?ooo`001P3ooolg0?l001`0003oDP3o
000K0000oe<0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`00
1`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool0
00H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo
703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B
0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0
o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3o
ool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0
oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o
001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000
ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`00
1`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool0
00H0oooo703o001B0000ojD0o`001`3oool000H0oooo703o001B0000ojD0o`001`3oool000H0oooo
703o001B0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo0006
0?oooa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l0
01`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0003o
6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3o
ool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0003o6`3o000g0000
ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3oool000H0oooo
70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0003o6`3o000g0000ohT0o`007000
0?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3oool000H0oooo70000?lK0?l0
03L0003oR@3o000L0000o`L0oooo00060?oooa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`00
1P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o
000L0000o`L0oooo00060?oooa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000
oa/0o`00=`000?n90?l001`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0
oooo00060?oooa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`00
0?n90?l001`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oo
oa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0
003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0003o6`3o
000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3oool0
00H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo
70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK
0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0
003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3o
ool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0
oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo7000
0?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l0
01`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o
1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool0
00H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo
70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK
0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0
003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo0
0?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`00
1P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l7
0?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00
D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oo
ol00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo
00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000
o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o
001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0
oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3o
ool000H0oooo`03o001C0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3o
ooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l0
03L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o
703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o0007
0?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`00
1P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo0
0?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0
003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o
00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?oo
o`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3o
ooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l0
03L0003o703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o
703o00070?ooo`001P3oooo00?l003L0003o703o00070?ooo`001P3oooo00?l003L0003o703o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000
o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`00
70000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n9
0?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0
003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o
000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?oo
ocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`00
1P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3o
ool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000
o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`00
70000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n9
0?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0
003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o
000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?oo
ocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0
oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`00
0?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oo
oa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0
003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o
000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool0
00H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0
o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo7000
0?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l7
0?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0
003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3o
oolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L
0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80
o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo
00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^
0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0
003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o
1`3oool000H0oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K
0000ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0
oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`00
70000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0oooo=`000?lg
0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`0070000?l70?oo
o`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0oooo=`000?lg0?l001/0003o
KP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolg
0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0oooo=`000?lg0?l001/0003oKP3o000L0000
o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`00
6`000?m^0?l001`0003o1`3oool000H0oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo0006
0?ooocL0003o=`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l0
01`0003o1`3oool000H0oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o
=`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3o
ool000H0oooo=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000
ofh0o`0070000?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0oooo
=`000?lg0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0003o=`3o000K0000ofh0o`007000
0?l70?ooo`001P3ooolg0000ocL0o`006`000?m^0?l001`0003o1`3oool000H0ooooKP3o000K0000
oe<0o`00=`000?l70?ooo`001P3ooom^0?l001/0003oD`3o000g0000o`L0oooo00060?ooofh0o`00
6`000?mC0?l003L0003o1`3oool000H0ooooKP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooom^
0?l001/0003oD`3o000g0000o`L0oooo00060?ooofh0o`006`000?mC0?l003L0003o1`3oool000H0
ooooKP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooom^0?l001/0003oD`3o000g0000o`L0oooo
00060?ooofh0o`006`000?mC0?l003L0003o1`3oool000H0ooooKP3o000K0000oe<0o`00=`000?l7
0?ooo`001P3ooom^0?l001/0003oD`3o000g0000o`L0oooo00060?ooofh0o`006`000?mC0?l003L0
003o1`3oool000H0ooooKP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooom^0?l001/0003oD`3o
000g0000o`L0oooo00060?ooofh0o`006`000?mC0?l003L0003o1`3oool000H0ooooKP3o000K0000
oe<0o`00=`000?l70?ooo`001P3ooom^0?l001/0003oD`3o000g0000o`L0oooo00060?ooofh0o`00
6`000?mC0?l003L0003o1`3oool000H0ooooKP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooom^
0?l001/0003oD`3o000g0000o`L0oooo00060?ooofh0o`006`000?mC0?l003L0003o1`3oool000H0
ooooKP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooom^0?l001/0003oD`3o000g0000o`L0oooo
00060?ooofh0o`006`000?mC0?l003L0003o1`3oool000H0ooooKP3o000K0000oe<0o`00=`000?l7
0?ooo`001P3ooom^0?l001/0003oD`3o000g0000o`L0oooo00060?ooofh0o`006`000?mC0?l003L0
003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o
000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool0
00H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0
o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo7000
0?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l7
0?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0
003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3o
oolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g
0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80
o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo
00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC
0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0
003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o
1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K
0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0
oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00
=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB
0?l001/0003oD`3o000g0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003o
KP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0003o1`3o
ool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000
oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0
o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0o`00
70000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo0006
0?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l0
01`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0
003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0003o
1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL
0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000
oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0
o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo
00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK
0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l0
01/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0
003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3o
oolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L
0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000
ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0
oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo7000
0?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK
0?l001/0003oKP3o000L0000o`L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0
o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP00
0?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l0
00L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo
00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?oo
ocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00
DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:
0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0
oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo0006
0?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0
o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP00
0?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooocL0o`00DP000?n:0?l0
00L0oooo00060?ooocL0o`00DP000?n:0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`00
6`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU
0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0
oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo0006
0?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0
o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`00
0?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l0
00L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo
00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oo
oe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`00
6`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU
0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0
oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo0006
0?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0
oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL
0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo
=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool0
00H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`00
1`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000
om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3o
oolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?oo
o`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o
00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0
003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo0006
0?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0
oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL
0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo
=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool0
00H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`00
1`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000
om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3o
oolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?oo
o`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?oooa`0003o`03o
000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000
o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo
00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oo
oa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o
`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g
0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0
oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo0006
0?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0
003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o
000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000
o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo
00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oo
ofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003o
KP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g
0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0
oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo0006
0?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0
003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o
000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000
o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo
00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?oo
ofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003o
KP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g
0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0
oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo0006
0?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0
o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`00
0?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l0
00L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo
00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?oo
ocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00
=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU
0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0
oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo0006
0?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0
o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`00
0?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`00
1`3oool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^
0?l001/0003o703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0
ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l001/0003o
703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K
0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l001/0003o703o00070?oo
o`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K0000ofh0o`00
6`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l001/0003o703o00070?ooo`001P3ooomC
0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l0
00L0oooo00060?oooe<0o`006`000?m^0?l001/0003o703o00070?ooo`001P3ooomC0?l001/0003o
KP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo0006
0?oooe<0o`006`000?m^0?l001/0003o703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000
oa`0o`001`3oool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`00
6`000?m^0?l001/0003o703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3o
ool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l0
01/0003o703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo
D`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l001/0003o703o
00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo703o000g0000ohT0o`006`000?lL0?l000L0
oooo00060?oooa`0o`00=`000?n90?l001/0003o703o00070?ooo`001P3ooolL0?l003L0003oR@3o
000K0000oa`0o`001`3oool000H0oooo703o000g0000ohT0o`006`000?lL0?l000L0oooo00060?oo
oa`0o`00=`000?n90?l001/0003o703o00070?ooo`001P3ooolL0?l003L0003oR@3o000K0000oa`0
o`001`3oool000H0oooo703o000g0000ohT0o`006`000?lL0?l000L0oooo00060?oooa`0o`00=`00
0?n90?l001/0003o703o00070?ooo`001P3ooolL0?l003L0003oR@3o000K0000oa`0o`001`3oool0
00H0oooo703o000g0000ohT0o`006`000?lL0?l000L0oooo00060?oooa`0o`00=`000?n90?l001/0
003o703o00070?ooo`001P3ooolL0?l003L0003oR@3o000K0000oa`0o`001`3oool000H0oooo703o
000g0000ohT0o`006`000?lL0?l000L0oooo00060?oooa`0o`00=`000?n90?l001/0003o703o0007
0?ooo`001P3ooolL0?l003L0003oR@3o000K0000oa`0o`001`3oool000H0oooo703o000g0000ohT0
o`006`000?lL0?l000L0oooo00060?oooa`0o`00=`000?n90?l001/0003o703o00070?ooo`001P3o
oolL0?l003L0003oR@3o000K0000oa`0o`001`3oool000H0oooo703o000g0000ohT0o`006`000?lL
0?l000L0oooo00060?oooa`0o`00=`000?n90?l001/0003o703o00070?ooo`001P3ooolL0?l003L0
003oR@3o000K0000oa`0o`001`3oool000H0oooo703o000g0000ohT0o`006`000?lL0?l000L0oooo
00060?oooa`0o`00=`000?n90?l001/0003o703o00070?ooo`001P3ooolL0?l003L0003oR@3o000K
0000oa`0o`001`3oool000H0oooo703o000g0000ohT0o`006`000?lL0?l000L0oooo00060?oooa`0
o`00=`000?n90?l001/0003o703o00070?ooo`001P3ooolL0?l003L0003oR@3o000K0000oa`0o`00
1`3oool000H0oooo703o000g0000ohT0o`006`000?lL0?l000L0oooo00060?ooom`0o`00=`000?l7
0?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00
=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?oo
om`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo
00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000
o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o
000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0
oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3o
ool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0
003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL
0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`00
1P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l7
0?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00
=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?oo
om`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo
00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000
o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o
000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0
oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3o
ool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0
003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL
0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`00
1P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l7
0?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00
=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?oo
om`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo
00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000
o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o
000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0
oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3o
ool000H0oooog03o000g0000o`L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00
o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`00
0?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l0
00L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo
00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oo
ol00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00
=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL
0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0
oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo0006
0?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00
o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`00
0?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l0
00L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o
703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000K
0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o00070?oo
o`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000K0000ojD0o`00
6`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o00070?ooo`001P3ooolL
0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000K0000ojD0o`006`000?lL0?l0
00L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o00070?ooo`001P3ooolL0?l001/0003o
Y@3o000K0000oa`0o`001`3oool000H0oooo703o000K0000ojD0o`006`000?lL0?l000L0oooo0006
0?oooa`0o`006`000?nU0?l001/0003o703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000
oa`0o`001`3oool000H0oooo703o000K0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`00
6`000?nU0?l001/0003o703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3o
ool000H0oooo703o000K0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l0
01/0003o703o00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo
703o000K0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o
00070?ooo`001P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000K0000
ojD0o`006`000?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o00070?ooo`00
1P3ooolL0?l001/0003oY@3o000K0000oa`0o`001`3oool000H0oooo703o000K0000ojD0o`006`00
0?lL0?l000L0oooo00060?oooa`0o`006`000?nU0?l001/0003o703o00070?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
g03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K
0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0
o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3o
ool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0
oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o
000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000
oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`00
1`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool0
00H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooo
g03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K
0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0
o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3o
ool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0
003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL
0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`00
1P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l7
0?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00
=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?oo
om`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo
00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000
o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o
000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?oooa`0003oR@3o000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000
ohT0o`00=`000?lK0?l001`0003o1`3oool000H0oooo70000?n90?l003L0003o6`3o000L0000o`L0
oooo00060?oooa`0003oR@3o000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000ohT0o`00=`00
0?lK0?l001`0003o1`3oool000H0oooo70000?n90?l003L0003o6`3o000L0000o`L0oooo00060?oo
oa`0003oR@3o000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000ohT0o`00=`000?lK0?l001`0
003o1`3oool000H0oooo70000?n90?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0003oR@3o
000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000ohT0o`00=`000?lK0?l001`0003o1`3oool0
00H0oooo70000?n90?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0003oR@3o000g0000oa/0
o`0070000?l70?ooo`001P3ooolL0000ohT0o`00=`000?lK0?l001`0003o1`3oool000H0oooo7000
0?n90?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0003oR@3o000g0000oa/0o`0070000?l7
0?ooo`001P3ooolL0000ohT0o`00=`000?lK0?l001`0003o1`3oool000H0oooo70000?n90?l003L0
003o6`3o000L0000o`L0oooo00060?oooa`0003oR@3o000g0000oa/0o`0070000?l70?ooo`001P3o
oolL0000ohT0o`00=`000?lK0?l001`0003o1`3oool000H0oooo70000?n90?l003L0003o6`3o000L
0000o`L0oooo00060?oooa`0003oR@3o000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000ohT0
o`00=`000?lK0?l001`0003o1`3oool000H0oooo70000?n90?l003L0003o6`3o000L0000o`L0oooo
00060?oooa`0003oR@3o000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000ohT0o`00=`000?lK
0?l001`0003o1`3oool000H0oooo70000?n90?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0
003oDP3o000K0000ocL0o`00D`000?l70?ooo`001P3ooolL0000oe80o`006`000?lg0?l005<0003o
1`3oool000H0oooo70000?mB0?l001/0003o=`3o001C0000o`L0oooo00060?oooa`0003oDP3o000K
0000ocL0o`00D`000?l70?ooo`001P3ooolL0000oe80o`006`000?lg0?l005<0003o1`3oool000H0
oooo70000?mB0?l001/0003o=`3o001C0000o`L0oooo00060?oooa`0003oDP3o000K0000ocL0o`00
D`000?l70?ooo`001P3ooolL0000oe80o`006`000?lg0?l005<0003o1`3oool000H0oooo70000?mB
0?l001/0003o=`3o001C0000o`L0oooo00060?oooa`0003oDP3o000K0000ocL0o`00D`000?l70?oo
o`001P3ooolL0000oe80o`006`000?lg0?l005<0003o1`3oool000H0oooo70000?mB0?l001/0003o
=`3o001C0000o`L0oooo00060?oooa`0003oDP3o000K0000ocL0o`00D`000?l70?ooo`001P3ooolL
0000oe80o`006`000?lg0?l005<0003o1`3oool000H0oooo70000?mB0?l001/0003o=`3o001C0000
o`L0oooo00060?oooa`0003oDP3o000K0000ocL0o`00D`000?l70?ooo`001P3ooolL0000oe80o`00
6`000?lg0?l005<0003o1`3oool000H0oooo70000?mB0?l001/0003o=`3o001C0000o`L0oooo0006
0?oooa`0003oDP3o000K0000ocL0o`00D`000?l70?ooo`001P3ooolL0000oe80o`006`000?lg0?l0
05<0003o1`3oool000H0oooo70000?mB0?l001/0003o=`3o001C0000o`L0oooo00060?oooa`0003o
DP3o000K0000ocL0o`00D`000?l70?ooo`001P3ooolL0000oe80o`006`000?lg0?l005<0003o1`3o
ool000H0oooo70000?mB0?l001/0003o=`3o001C0000o`L0oooo00060?oooa`0003oDP3o000K0000
ocL0o`00D`000?l70?ooo`001P3ooolL0000oe80o`006`000?lg0?l005<0003o1`3oool000H0oooo
70000?mB0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo0006
0?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0
003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o
001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000
o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo
00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?oo
ocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003o
R@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C
0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0
oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo0006
0?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0
003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o
001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?oooa`0o`00=`000?lf0?l0
03L0003oD`3o00070?ooo`001P3ooolL0?l003L0003o=P3o000g0000oe<0o`001`3oool000H0oooo
703o000g0000ocH0o`00=`000?mC0?l000L0oooo00060?oooa`0o`00=`000?lf0?l003L0003oD`3o
00070?ooo`001P3ooolL0?l003L0003o=P3o000g0000oe<0o`001`3oool000H0oooo703o000g0000
ocH0o`00=`000?mC0?l000L0oooo00060?oooa`0o`00=`000?lf0?l003L0003oD`3o00070?ooo`00
1P3ooolL0?l003L0003o=P3o000g0000oe<0o`001`3oool000H0oooo703o000g0000ocH0o`00=`00
0?mC0?l000L0oooo00060?oooa`0o`00=`000?lf0?l003L0003oD`3o00070?ooo`001P3ooolL0?l0
03L0003o=P3o000g0000oe<0o`001`3oool000H0oooo703o000g0000ocH0o`00=`000?mC0?l000L0
oooo00060?oooa`0o`00=`000?lf0?l003L0003oD`3o00070?ooo`001P3ooolL0?l003L0003o=P3o
000g0000oe<0o`001`3oool000H0oooo703o000g0000ocH0o`00=`000?mC0?l000L0oooo00060?oo
oa`0o`00=`000?lf0?l003L0003oD`3o00070?ooo`001P3ooolL0?l003L0003o=P3o000g0000oe<0
o`001`3oool000H0oooo703o000g0000ocH0o`00=`000?mC0?l000L0oooo00060?oooa`0o`00=`00
0?lf0?l003L0003oD`3o00070?ooo`001P3ooolL0?l003L0003o=P3o000g0000oe<0o`001`3oool0
00H0oooo703o000g0000ocH0o`00=`000?mC0?l000L0oooo00060?oooa`0o`00=`000?lf0?l003L0
003oD`3o00070?ooo`001P3ooolL0?l003L0003o=P3o000g0000oe<0o`001`3oool000H0oooo703o
000g0000ocH0o`00=`000?mC0?l000L0oooo00060?oooa`0o`00=`000?lf0?l003L0003oD`3o0007
0?ooo`001P3ooolL0?l003L0003o=P3o000g0000oe<0o`001`3oool000H0oooo703o000g0000ocH0
o`00=`000?mC0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`00
0?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l0
00L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo
00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?oo
ojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00
=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg
0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0
oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo0006
0?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0
o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`00
0?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l0
00L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo
00060?ooojD0o`00=`000?lg0?l000L0oooo00060?ooojD0o`00=`000?lg0?l000L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo70000?m]0?l008X0
003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3o
ool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0
oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo7000
0?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l0
08X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o
1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool0
00H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo
70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]
0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0
003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3o
ool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0
oooo70000?m]0?l008X0003o1`3oool000H0oooo70000?m]0?l008X0003o1`3oool000H0oooo7000
0?m]0?l008X0003o1`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000
oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`00
1`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool0
00H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0oooo
R@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^
0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0
o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3o
ool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0
ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o
001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000
oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`00
1`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool0
00H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0
oooo00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o
001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oo
oe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0
o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`00
0?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0o`001`3oool0
00H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580
003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o
000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580003o703o0007
0?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0
o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3o
oomC0?l001/0003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL
0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0
003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0oooo
00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o001B
0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oooe<0
o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo
Y@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B
0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0
o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3o
ool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0
ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo
Y@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B
0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0
o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3o
ool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0
oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o
000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000
oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`00
1`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool0
00H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo
`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g
0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0
o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3o
ool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0
oooo`03o000g0000oa`0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l7
0?ooo`001P3ooon90?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0
003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0003o703o
000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0ooooR@3o000g0000
oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00
=`000?lL0?l003L0003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon9
0?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0
ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0003o703o000g0000o`L0oooo
00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l7
0?ooo`001P3ooon90?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0
003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0003o703o
000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0ooooR@3o000g0000
oa`0o`00=`000?l70?ooo`001P3ooon90?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00
=`000?lL0?l003L0003o1`3oool000H0ooooR@3o000g0000oa`0o`00=`000?l70?ooo`001P3ooon9
0?l003L0003o703o000g0000o`L0oooo00060?ooohT0o`00=`000?lL0?l003L0003o1`3oool000H0
ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o
001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000
oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`00
1`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool0
00H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0oooo
R@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^
0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0
o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3o
ool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0
ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o
001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000
oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooR@3o001^0000oa`0o`00
1`3oool000H0ooooR@3o001^0000oa`0o`001`3oool000H0ooooY@3o001^0000o`L0oooo00060?oo
ojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo
00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000
o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o
001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0
ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3o
ool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0
003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU
0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`00
1P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l7
0?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
KP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B
0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0
o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3o
ool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0
ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o
001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000
oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`00
1`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool0
00H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0oooo
KP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B
0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0
o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3oool000H0ooooKP3o001B0000oe<0o`001`3o
ool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0
ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o
001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000
ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`00
1`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool0
00H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0oooo
KP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^
0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0
o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3o
ool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0
ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o
001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000
ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`00
1`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool0
00H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0oooo
KP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^
0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0
o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3o
ool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0
ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o
001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000
ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`00
1`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool0
00H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0oooo
KP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooR@3o001C
0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0
o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3o
ool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0
ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o
001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000
ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`00
1`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool0
00H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0oooo
R@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C
0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0
o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3o
ool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0
ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o
001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000
ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`00
1`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool0
00H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0oooo
R@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C
0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0
o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3o
ool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0
ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o
001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000
ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`001`3oool000H0ooooR@3o001C0000ocL0o`00
1`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool0
00H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K
0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o
000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000
oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`00
1`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool0
00H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K
0000oe<0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
00H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo
703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool0
00H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0oooo
D`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f
0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0
o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3o
ool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0
ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o
000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000
ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`00
1`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool0
00H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0oooo
D`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f
0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0
o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3o
ool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0
ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o
000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000
ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`00
1`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool0
00H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0oooo
D`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f
0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0
o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3o
ool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0
ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o
000f0000ohX0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000
ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`00
1`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool0
00H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0oooo
D`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B
0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0
o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3o
ool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0
ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o
001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000
ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`00
1`3oool000H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooD`3o001B0000ofh0o`001`3oool0
00H0ooooD`3o001B0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0oooo
KP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g
0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o
000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000
ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`00
1`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool0
00H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0oooo
KP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g
0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`00
0?lL0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l0
01`0003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0
oooo00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o
000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo00060?oo
ohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0
o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo00060?ooohT0o`007000
0?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0o`001`3oool0
00H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0
003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o
000L0000ocL0o`006`000?lL0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0003o703o0007
0?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0
o`006`000?lL0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3o
oon90?l001`0003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL
0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0
003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo
00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K
0000oa`0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3o
ool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0
ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o
000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000
oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`00
1`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool0
00H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0oooo
R@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g
0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0
o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3o
ool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0
ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool000H0ooooR@3o
000g0000oe<0o`001`3oool000H0ooooR@3o000g0000oe<0o`001`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF00000000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo70000?mB0?l001/0003o
RP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K
0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80
o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo7000
0?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oo
oa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`00
1P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3o
ool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l0
00L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003o
RP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K
0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80
o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo7000
0?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oo
oa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`00
1P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo=`3o000g0000oa/0o`00D`000?lg0?l000L0oooo00060?ooocL0o`00=`000?lK0?l005<0003o
=`3o00070?ooo`001P3ooolg0?l003L0003o6`3o001C0000ocL0o`001`3oool000H0oooo=`3o000g
0000oa/0o`00D`000?lg0?l000L0oooo00060?ooocL0o`00=`000?lK0?l005<0003o=`3o00070?oo
o`001P3ooolg0?l003L0003o6`3o001C0000ocL0o`001`3oool000H0oooo=`3o000g0000oa/0o`00
D`000?lg0?l000L0oooo00060?ooocL0o`00=`000?lK0?l005<0003o=`3o00070?ooo`001P3ooolg
0?l003L0003o6`3o001C0000ocL0o`001`3oool000H0oooo=`3o000g0000oa/0o`00D`000?lg0?l0
00L0oooo00060?ooocL0o`00=`000?lK0?l005<0003o=`3o00070?ooo`001P3ooolg0?l003L0003o
6`3o001C0000ocL0o`001`3oool000H0oooo=`3o000g0000oa/0o`00D`000?lg0?l000L0oooo0006
0?ooocL0o`00=`000?lK0?l005<0003o=`3o00070?ooo`001P3ooolg0?l003L0003o6`3o001C0000
ocL0o`001`3oool000H0oooo=`3o000g0000oa/0o`00D`000?lg0?l000L0oooo00060?ooocL0o`00
=`000?lK0?l005<0003o=`3o00070?ooo`001P3ooolg0?l003L0003o6`3o001C0000ocL0o`001`3o
ool000H0oooo=`3o000g0000oa/0o`00D`000?lg0?l000L0oooo00060?ooocL0o`00=`000?lK0?l0
05<0003o=`3o00070?ooo`001P3ooolg0?l003L0003o6`3o001C0000ocL0o`001`3oool000H0oooo
=`3o000g0000oa/0o`00D`000?lg0?l000L0oooo00060?ooocL0o`00=`000?lK0?l005<0003o=`3o
00070?ooo`001P3ooolg0?l003L0003o6`3o001C0000ocL0o`001`3oool000H0oooo=`3o000g0000
oa/0o`00D`000?lg0?l000L0oooo00060?ooocL0o`00=`000?lK0?l005<0003o=`3o00070?ooo`00
1P3ooolg0?l003L0003o6`3o001C0000ocL0o`001`3oool000H0oooo=`3o000g0000oa/0o`00D`00
0?lg0?l000L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000
ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00
=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg
0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0
oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo
00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l7
0?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0
003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o
000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000
ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00
=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg
0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0
oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo
00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l7
0?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0
003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o
000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000
ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`00
6`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC
0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0
ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo
00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l7
0?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0
003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o
000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000
ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`00
6`000?n90?l001`0003o1`3oool000H0ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC
0?l001/0003oR@3o000L0000o`L0oooo00060?oooe<0o`006`000?n90?l001`0003o1`3oool000H0
ooooD`3o000K0000ohT0o`0070000?l70?ooo`001P3ooomC0?l001/0003oR@3o000L0000o`L0oooo
00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oo
oe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00
=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:
0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0
oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo0006
0?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0
o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P00
0?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l0
00L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo
00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oo
oe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00
=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:0?l000L0oooo00060?oooe<0o`00=P000?n:
0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0
oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo0006
0?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0
o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y000
0?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l0
00L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo
00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oo
oa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00
Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC
0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0
oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo0006
0?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0o`00Y0000?mC0?l000L0oooo00060?oooa`0
o`00Y0000?mC0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3o
oom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL
0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0
003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo
00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K
0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0
o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`00
1`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg
0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0
ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o
703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g
0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?oo
o`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`00
6`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^
0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l0
00L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o
=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo0006
0?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF0000
0000FF0000FF0000FFFF00000000FF0000FFFF0000FF0000FF00000000FF
FF00000000FF0000FF0000FFFF00000000FFFF0000FF0000FF00000000FF
FF00000000FF0000FF0000FFFF00000000FF0000FF0000FFFF00000000FF
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`00
1`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg
0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0
ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o
703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g
0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?oo
o`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`00
6`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^
0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l0
00L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o
=`3o000K0000oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo0006
0?ooofh0o`00=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000
oa`0o`001`3oool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00
=`000?lg0?l001/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3o
ool000H0ooooKP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l0
01/0003o703o00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0oooo
KP3o000g0000ocL0o`006`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lg0?l001/0003o703o
00070?ooo`001P3ooom^0?l003L0003o=`3o000K0000oa`0o`001`3oool000H0ooooD`000?lK0?l0
03L0003oDP3o000L0000o`L0oooo00060?oooe<0003o6`3o000g0000oe80o`0070000?l70?ooo`00
1P3ooomC0000oa/0o`00=`000?mB0?l001`0003o1`3oool000H0ooooD`000?lK0?l003L0003oDP3o
000L0000o`L0oooo00060?oooe<0003o6`3o000g0000oe80o`0070000?l70?ooo`001P3ooomC0000
oa/0o`00=`000?mB0?l001`0003o1`3oool000H0ooooD`000?lK0?l003L0003oDP3o000L0000o`L0
oooo00060?oooe<0003o6`3o000g0000oe80o`0070000?l70?ooo`001P3ooomC0000oa/0o`00=`00
0?mB0?l001`0003o1`3oool000H0ooooD`000?lK0?l003L0003oDP3o000L0000o`L0oooo00060?oo
oe<0003o6`3o000g0000oe80o`0070000?l70?ooo`001P3ooomC0000oa/0o`00=`000?mB0?l001`0
003o1`3oool000H0ooooD`000?lK0?l003L0003oDP3o000L0000o`L0oooo00060?oooe<0003o6`3o
000g0000oe80o`0070000?l70?ooo`001P3ooomC0000oa/0o`00=`000?mB0?l001`0003o1`3oool0
00H0ooooD`000?lK0?l003L0003oDP3o000L0000o`L0oooo00060?oooe<0003o6`3o000g0000oe80
o`0070000?l70?ooo`001P3ooomC0000oa/0o`00=`000?mB0?l001`0003o1`3oool000H0ooooD`00
0?lK0?l003L0003oDP3o000L0000o`L0oooo00060?oooe<0003o6`3o000g0000oe80o`0070000?l7
0?ooo`001P3ooomC0000oa/0o`00=`000?mB0?l001`0003o1`3oool000H0ooooD`000?lK0?l003L0
003oDP3o000L0000o`L0oooo00060?oooe<0003o6`3o000g0000oe80o`0070000?l70?ooo`001P3o
oomC0000oa/0o`00=`000?mB0?l001`0003o1`3oool000H0ooooD`000?lK0?l003L0003oDP3o000L
0000o`L0oooo00060?oooe<0003o6`3o000g0000oe80o`0070000?l70?ooo`001P3ooomC0000oa/0
o`00=`000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o
1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B
0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l0
01`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo
703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`007000
0?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool0
00H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0
o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o
1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B
0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l0
01`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo
703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`007000
0?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool0
00H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0
o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o
1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B
0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l0
01`0003o1`3oool000H0oooo703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo
703o001B0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`007000
0?mB0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool0
00H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0
o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o
1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B
0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l0
01`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo
703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`00
0?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool0
00H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0
o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o
1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B
0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l0
01`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo
703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`00
0?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool0
00H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0
o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o
1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B
0000oa/0o`00D`000?lK0?l001`0003o1`3oool000H0oooo703o001B0000oa/0o`00D`000?lK0?l0
01`0003o1`3oool000H0oooo703o000g0000oj@0o`0070000?l70?ooo`001P3ooolL0?l003L0003o
Y03o000L0000o`L0oooo00060?oooa`0o`00=`000?nT0?l001`0003o1`3oool000H0oooo703o000g
0000oj@0o`0070000?l70?ooo`001P3ooolL0?l003L0003oY03o000L0000o`L0oooo00060?oooa`0
o`00=`000?nT0?l001`0003o1`3oool000H0oooo703o000g0000oj@0o`0070000?l70?ooo`001P3o
oolL0?l003L0003oY03o000L0000o`L0oooo00060?oooa`0o`00=`000?nT0?l001`0003o1`3oool0
00H0oooo703o000g0000oj@0o`0070000?l70?ooo`001P3ooolL0?l003L0003oY03o000L0000o`L0
oooo00060?oooa`0o`00=`000?nT0?l001`0003o1`3oool000H0oooo703o000g0000oj@0o`007000
0?l70?ooo`001P3ooolL0?l003L0003oY03o000L0000o`L0oooo00060?oooa`0o`00=`000?nT0?l0
01`0003o1`3oool000H0oooo703o000g0000oj@0o`0070000?l70?ooo`001P3ooolL0?l003L0003o
Y03o000L0000o`L0oooo00060?oooa`0o`00=`000?nT0?l001`0003o1`3oool000H0oooo703o000g
0000oj@0o`0070000?l70?ooo`001P3ooolL0?l003L0003oY03o000L0000o`L0oooo00060?oooa`0
o`00=`000?nT0?l001`0003o1`3oool000H0oooo703o000g0000oj@0o`0070000?l70?ooo`001P3o
oolL0?l003L0003oY03o000L0000o`L0oooo00060?oooa`0o`00=`000?nT0?l001`0003o1`3oool0
00H0oooo703o000g0000oj@0o`0070000?l70?ooo`001P3ooolL0?l003L0003oY03o000L0000o`L0
oooo00060?oooa`0o`00=`000?nT0?l001`0003o1`3oool000H0oooo703o000g0000oj@0o`007000
0?l70?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000
ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`00
1P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`00
0?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l0
01/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0
oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o
000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oo
oa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0
o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`00
0?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool0
00H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0
003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o
000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o0007
0?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0
o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3o
oolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:
0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0
003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o
00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?oo
o`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3o
oom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l0
01/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003o
RP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o0007
0?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`00
1P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^
0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0
003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o
00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?oo
o`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3o
oolL0?l00:@0003o=`3o000L0000o`L0oooo00060?oooa`0o`00Y0000?lg0?l001`0003o1`3oool0
00H0oooo703o002T0000ocL0o`0070000?l70?ooo`001P3ooolL0?l00:@0003o=`3o000L0000o`L0
oooo00060?oooa`0o`00Y0000?lg0?l001`0003o1`3oool000H0oooo703o002T0000ocL0o`007000
0?l70?ooo`001P3ooolL0?l00:@0003o=`3o000L0000o`L0oooo00060?oooa`0o`00Y0000?lg0?l0
01`0003o1`3oool000H0oooo703o002T0000ocL0o`0070000?l70?ooo`001P3ooolL0?l00:@0003o
=`3o000L0000o`L0oooo00060?oooa`0o`00Y0000?lg0?l001`0003o1`3oool000H0oooo703o002T
0000ocL0o`0070000?l70?ooo`001P3ooolL0?l00:@0003o=`3o000L0000o`L0oooo00060?oooa`0
o`00Y0000?lg0?l001`0003o1`3oool000H0oooo703o002T0000ocL0o`0070000?l70?ooo`001P3o
oolL0?l00:@0003o=`3o000L0000o`L0oooo00060?oooa`0o`00Y0000?lg0?l001`0003o1`3oool0
00H0oooo703o002T0000ocL0o`0070000?l70?ooo`001P3ooolL0?l00:@0003o=`3o000L0000o`L0
oooo00060?oooa`0o`00Y0000?lg0?l001`0003o1`3oool000H0oooo703o002T0000ocL0o`007000
0?l70?ooo`001P3ooolL0?l00:@0003o=`3o000L0000o`L0oooo00060?oooa`0o`00Y0000?lg0?l0
01`0003o1`3oool000H0oooo703o002T0000ocL0o`0070000?l70?ooo`001P3ooolL0?l00:@0003o
=`3o000L0000o`L0oooo00060?oooa`0o`00Y0000?lg0?l001`0003o1`3oool000H0oooo703o002T
0000ocL0o`0070000?l70?ooo`001P3ooom^0?l003L0003o6`3o001C0000o`L0oooo00060?ooofh0
o`00=`000?lK0?l005<0003o1`3oool000H0ooooKP3o000g0000oa/0o`00D`000?l70?ooo`001P3o
oom^0?l003L0003o6`3o001C0000o`L0oooo00060?ooofh0o`00=`000?lK0?l005<0003o1`3oool0
00H0ooooKP3o000g0000oa/0o`00D`000?l70?ooo`001P3ooom^0?l003L0003o6`3o001C0000o`L0
oooo00060?ooofh0o`00=`000?lK0?l005<0003o1`3oool000H0ooooKP3o000g0000oa/0o`00D`00
0?l70?ooo`001P3ooom^0?l003L0003o6`3o001C0000o`L0oooo00060?ooofh0o`00=`000?lK0?l0
05<0003o1`3oool000H0ooooKP3o000g0000oa/0o`00D`000?l70?ooo`001P3ooom^0?l003L0003o
6`3o001C0000o`L0oooo00060?ooofh0o`00=`000?lK0?l005<0003o1`3oool000H0ooooKP3o000g
0000oa/0o`00D`000?l70?ooo`001P3ooom^0?l003L0003o6`3o001C0000o`L0oooo00060?ooofh0
o`00=`000?lK0?l005<0003o1`3oool000H0ooooKP3o000g0000oa/0o`00D`000?l70?ooo`001P3o
oom^0?l003L0003o6`3o001C0000o`L0oooo00060?ooofh0o`00=`000?lK0?l005<0003o1`3oool0
00H0ooooKP3o000g0000oa/0o`00D`000?l70?ooo`001P3ooom^0?l003L0003o6`3o001C0000o`L0
oooo00060?ooofh0o`00=`000?lK0?l005<0003o1`3oool000H0ooooKP3o000g0000oa/0o`00D`00
0?l70?ooo`001P3ooom^0?l003L0003o6`3o001C0000o`L0oooo00060?ooofh0o`00=`000?lK0?l0
05<0003o1`3oool000H0ooooKP3o000g0000oa/0o`00D`000?l70?ooo`001P3ooom^0?l003L0003o
6`3o000L0000ocL0o`001`3oool000H0ooooKP3o000g0000oa/0o`0070000?lg0?l000L0oooo0006
0?ooofh0o`00=`000?lK0?l001`0003o=`3o00070?ooo`001P3ooom^0?l003L0003o6`3o000L0000
ocL0o`001`3oool000H0ooooKP3o000g0000oa/0o`0070000?lg0?l000L0oooo00060?ooofh0o`00
=`000?lK0?l001`0003o=`3o00070?ooo`001P3ooom^0?l003L0003o6`3o000L0000ocL0o`001`3o
ool000H0ooooKP3o000g0000oa/0o`0070000?lg0?l000L0oooo00060?ooofh0o`00=`000?lK0?l0
01`0003o=`3o00070?ooo`001P3ooom^0?l003L0003o6`3o000L0000ocL0o`001`3oool000H0oooo
KP3o000g0000oa/0o`0070000?lg0?l000L0oooo00060?ooofh0o`00=`000?lK0?l001`0003o=`3o
00070?ooo`001P3ooom^0?l003L0003o6`3o000L0000ocL0o`001`3oool000H0ooooKP3o000g0000
oa/0o`0070000?lg0?l000L0oooo00060?ooofh0o`00=`000?lK0?l001`0003o=`3o00070?ooo`00
1P3ooom^0?l003L0003o6`3o000L0000ocL0o`001`3oool000H0ooooKP3o000g0000oa/0o`007000
0?lg0?l000L0oooo00060?ooofh0o`00=`000?lK0?l001`0003o=`3o00070?ooo`001P3ooom^0?l0
03L0003o6`3o000L0000ocL0o`001`3oool000H0ooooKP3o000g0000oa/0o`0070000?lg0?l000L0
oooo00060?ooofh0o`00=`000?lK0?l001`0003o=`3o00070?ooo`001P3ooom^0?l003L0003o6`3o
000L0000ocL0o`001`3oool000H0ooooKP3o000g0000oa/0o`0070000?lg0?l000L0oooo00060?oo
ofh0o`00=`000?lK0?l001`0003o=`3o00070?ooo`001P3ooom^0?l003L0003o6`3o000L0000ocL0
o`001`3oool000H0ooooKP3o000g0000oa/0o`0070000?lg0?l000L0oooo00060?ooofh0o`00=`00
0?lK0?l001`0003o=`3o00070?ooo`001P3ooom^0?l003L0003o6`3o000L0000ocL0o`001`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00000000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF00000000FF0000FFFF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
FF00000000FF0000FF0000FFFF00000000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0?l006h0003o6`3o000L0000ocL0o`00
1`3oool000H0oooo=`3o001^0000oa/0o`0070000?lg0?l000L0oooo00060?ooocL0o`00KP000?lK
0?l001`0003o=`3o00070?ooo`001P3ooolg0?l006h0003o6`3o000L0000ocL0o`001`3oool000H0
oooo=`3o001^0000oa/0o`0070000?lg0?l000L0oooo00060?ooocL0o`00KP000?lK0?l001`0003o
=`3o00070?ooo`001P3ooolg0?l006h0003o6`3o000L0000ocL0o`001`3oool000H0oooo=`3o001^
0000oa/0o`0070000?lg0?l000L0oooo00060?ooocL0o`00KP000?lK0?l001`0003o=`3o00070?oo
o`001P3ooolg0?l006h0003o6`3o000L0000ocL0o`001`3oool000H0oooo=`3o001^0000oa/0o`00
70000?lg0?l000L0oooo00060?ooocL0o`00KP000?lK0?l001`0003o=`3o00070?ooo`001P3ooolg
0?l006h0003o6`3o000L0000ocL0o`001`3oool000H0oooo=`3o001^0000oa/0o`0070000?lg0?l0
00L0oooo00060?ooocL0o`00KP000?lK0?l001`0003o=`3o00070?ooo`001P3ooolg0?l006h0003o
6`3o000L0000ocL0o`001`3oool000H0oooo=`3o001^0000oa/0o`0070000?lg0?l000L0oooo0006
0?ooocL0o`00KP000?lK0?l001`0003o=`3o00070?ooo`001P3ooolg0?l006h0003o6`3o000L0000
ocL0o`001`3oool000H0oooo=`3o001^0000oa/0o`0070000?lg0?l000L0oooo00060?ooocL0o`00
KP000?lK0?l001`0003o=`3o00070?ooo`001P3ooolg0?l006h0003o6`3o000L0000ocL0o`001`3o
ool000H0oooo=`3o001^0000oa/0o`0070000?lg0?l000L0oooo00060?ooocL0o`00KP000?lK0?l0
01`0003o=`3o00070?ooo`001P3ooolg0?l006h0003o6`3o000L0000ocL0o`001`3oool000H0oooo
=`3o001^0000oa/0o`0070000?lg0?l000L0oooo00060?ooocL0o`00KP000?lK0?l001`0003o=`3o
00070?ooo`001P3ooolg0?l006h0003o6`3o000L0000ocL0o`001`3oool000H0ooooD`3o000K0000
ocL0o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`00
1P3ooomC0?l001/0003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP00
0?lL0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l0
01/0003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0
oooo00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o
001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oo
oe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0
o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`00
0?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0o`001`3oool0
00H0ooooD`3o000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580
003o703o00070?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o
000K0000ocL0o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580003o703o0007
0?ooo`001P3ooomC0?l001/0003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0
o`00DP000?lL0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3o
oomC0?l001/0003o=`3o001B0000oa`0o`001`3oool000H0ooooD`3o000K0000ocL0o`00DP000?lL
0?l000L0oooo00060?oooe<0o`006`000?lg0?l00580003o703o00070?ooo`001P3ooomC0?l001/0
003o=`3o001B0000oa`0o`001`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@00
0?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l0
06h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o
1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool0
00H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0oooo
R@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL
0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0
003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3o
ool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0
ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@00
0?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l0
06h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o
1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g
0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0
o`006`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo
00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC
0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo00060?oooe<0
003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC0?l003L0003o
1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo00060?oooe<0003o6`3o000K
0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC0?l003L0003o1`3oool000H0
ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00
=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK
0?l001/0003oD`3o000g0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?oo
o`001P3ooomC0000oa/0o`006`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003o
D`3o000g0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC
0000oa/0o`006`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000
o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`00
6`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo0006
0?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC0?l0
03L0003o1`3oool000H0oooo=`000?lg0?l003L0003o=`3o000g0000o`L0oooo00060?ooocL0003o
=`3o000g0000ocL0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lg0?l003L0003o1`3o
ool000H0oooo=`000?lg0?l003L0003o=`3o000g0000o`L0oooo00060?ooocL0003o=`3o000g0000
ocL0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lg0?l003L0003o1`3oool000H0oooo
=`000?lg0?l003L0003o=`3o000g0000o`L0oooo00060?ooocL0003o=`3o000g0000ocL0o`00=`00
0?l70?ooo`001P3ooolg0000ocL0o`00=`000?lg0?l003L0003o1`3oool000H0oooo=`000?lg0?l0
03L0003o=`3o000g0000o`L0oooo00060?ooocL0003o=`3o000g0000ocL0o`00=`000?l70?ooo`00
1P3ooolg0000ocL0o`00=`000?lg0?l003L0003o1`3oool000H0oooo=`000?lg0?l003L0003o=`3o
000g0000o`L0oooo00060?ooocL0003o=`3o000g0000ocL0o`00=`000?l70?ooo`001P3ooolg0000
ocL0o`00=`000?lg0?l003L0003o1`3oool000H0oooo=`000?lg0?l003L0003o=`3o000g0000o`L0
oooo00060?ooocL0003o=`3o000g0000ocL0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00=`00
0?lg0?l003L0003o1`3oool000H0oooo=`000?lg0?l003L0003o=`3o000g0000o`L0oooo00060?oo
ocL0003o=`3o000g0000ocL0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lg0?l003L0
003o1`3oool000H0oooo=`000?lg0?l003L0003o=`3o000g0000o`L0oooo00060?ooocL0003o=`3o
000g0000ocL0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lg0?l003L0003o1`3oool0
00H0oooo=`000?lg0?l003L0003o=`3o000g0000o`L0oooo00060?ooocL0003o=`3o000g0000ocL0
o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lg0?l003L0003o1`3oool000H0oooo=`00
0?lg0?l003L0003o=`3o000g0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l7
0?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0
003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3o
oolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L
0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0
o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo
00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB
0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0
003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o
1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L
0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0
oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`00
70000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]
0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?oo
o`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003o
DP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL
0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000
o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00
DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o
000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oo
oa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0
003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo
00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK
0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000
o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00
DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o
000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oo
oa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0
003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo
00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK
0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000
o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00
DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o
000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oo
oa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0
003o=`3o000L0000o`L0oooo00060?oooa`0o`00DP000?lK0?l003L0003o=`3o000L0000o`L0oooo
00060?ooofh0003o6`3o000L0000ocL0o`00=`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lg
0?l003L0003o1`3oool000H0ooooKP000?lK0?l001`0003o=`3o000g0000o`L0oooo00060?ooofh0
003o6`3o000L0000ocL0o`00=`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lg0?l003L0003o
1`3oool000H0ooooKP000?lK0?l001`0003o=`3o000g0000o`L0oooo00060?ooofh0003o6`3o000L
0000ocL0o`00=`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lg0?l003L0003o1`3oool000H0
ooooKP000?lK0?l001`0003o=`3o000g0000o`L0oooo00060?ooofh0003o6`3o000L0000ocL0o`00
=`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lg0?l003L0003o1`3oool000H0ooooKP000?lK
0?l001`0003o=`3o000g0000o`L0oooo00060?ooofh0003o6`3o000L0000ocL0o`00=`000?l70?oo
o`001P3ooom^0000oa/0o`0070000?lg0?l003L0003o1`3oool000H0ooooKP000?lK0?l001`0003o
=`3o000g0000o`L0oooo00060?ooofh0003o6`3o000L0000ocL0o`00=`000?l70?ooo`001P3ooom^
0000oa/0o`0070000?lg0?l003L0003o1`3oool000H0ooooKP000?lK0?l001`0003o=`3o000g0000
o`L0oooo00060?ooofh0003o6`3o000L0000ocL0o`00=`000?l70?ooo`001P3ooom^0000oa/0o`00
70000?lg0?l003L0003o1`3oool000H0ooooKP000?lK0?l001`0003o=`3o000g0000o`L0oooo0006
0?ooofh0003o6`3o000L0000ocL0o`00=`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lg0?l0
03L0003o1`3oool000H0ooooKP000?lK0?l001`0003o=`3o000g0000o`L0oooo00060?ooofh0003o
6`3o000L0000ocL0o`00=`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lg0?l003L0003o1`3o
ool000H0ooooKP000?lK0?l001`0003o=`3o000g0000o`L0oooo00060?oool00003oD`3o00070?oo
o`001P3oooo00000oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo00060?oool00003oD`3o
00070?ooo`001P3oooo00000oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo00060?oool00
003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo0006
0?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool000H0oooo`0000?mC0?l000L0
oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool000H0oooo`0000?mC
0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool000H0oooo
`0000?mC0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool0
00H0oooo`0000?mC0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`00
1`3oool000H0oooo`0000?mC0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000
oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`00
1`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC
0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0
003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o
000K0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000
oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3oool000H0oooo
R@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo0006
0?ooohT0003o703o000K0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?oo
o`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`00
1`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC
0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0
003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o
000K0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000
oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3oool000H0oooo
R@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo0006
0?ooohT0003o703o000K0000oe<0o`001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0o`00
6`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0o`001`3o
ool000H0oooo703o000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l0
01/0003o703o000f0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0
003o703o000K0000oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lL0?l001/0003o
D`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0o`006`000?mC0?l000L0oooo0006
0?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0o`001`3oool000H0oooo703o000K0000
oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0
o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0o`00
1`3oool000H0oooo703o000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL
0?l001/0003o703o000f0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l0
03H0003o703o000K0000oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lL0?l001/0
003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0o`006`000?mC0?l000L0oooo
00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0o`001`3oool000H0oooo703o000K
0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000
oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0
o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3o
oolL0?l001/0003o703o000f0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL
0?l003H0003o703o000K0000oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lL0?l0
01/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0o`006`000?mC0?l000L0
oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0o`001`3oool000H0oooo703o
000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f
0000oa`0o`006`000?mC0?l000L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0
003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o
000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000
o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo
00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?oo
om`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o
6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L
0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0
oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo0006
0?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0
003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o
000L0000o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?ooom`0003o6`3o000L0000
o`L0oooo00060?ooom`0003o6`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo
00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oo
ol00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o
=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L
0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0
oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo0006
0?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00
003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o
000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000
o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo
00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oo
ol00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o
=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oooa`0o`006`000?lL
0?l00:@0003o703o00070?ooo`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0
oooo703o000K0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o
703o00070?ooo`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo703o000K
0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o00070?oo
o`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00
Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL
0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00Y0000?lL0?l0
00L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL0?l001/0003o
703o002T0000oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00Y0000?lL0?l000L0oooo0006
0?oooa`0o`006`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL0?l001/0003o703o002T0000
oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`00
6`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3o
ool000H0oooo703o000K0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l0
0:@0003o703o00070?ooo`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo
703o000K0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o
00070?ooo`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo703o000K0000
oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o
=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o0030
0000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0
oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo0006
0?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0
003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o
00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000
o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo
00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oo
oa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o
=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o0030
0000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0
oooo00060?oooa`0003o=`3o00300000o`L0oooo00060?oooa`0003o=`3o00300000o`L0oooo0006
0?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0
oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g
0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo
703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool0
00H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o
1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l0
0?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3o
oolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?oo
o`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`00
0?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?ooojD0
003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o
000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000
o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo
00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?oo
ojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o
=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g
0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0
oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo0006
0?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0
003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o
000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000
o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo
00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oo
oe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o
6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U
0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0
oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo0006
0?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0
003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o
002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000
o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo
00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oo
oe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o
6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g
0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo
703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool0
00H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o
1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l0
0?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3o
oolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?oo
o`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`00
0?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0
o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo0006
0?oooa`0o`00m`000?l70?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FFFF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo`0000?lL0?l0
03L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o
1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool0
00H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo
`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL
0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0
003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3o
ool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0
oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`000
0?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l0
03L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o
1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool0
00H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo
Y@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg
0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0
003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3o
ool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0
ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@00
0?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l0
03L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o
1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool0
00H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0oooo
Y@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg
0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0
003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3o
ool000H0oooo70000?lK0?l001`0003o6`3o002U0000o`L0oooo00060?oooa`0003o6`3o000L0000
oa/0o`00Y@000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l00:D0003o1`3oool000H0oooo
70000?lK0?l001`0003o6`3o002U0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`00Y@00
0?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l00:D0003o1`3oool000H0oooo70000?lK0?l0
01`0003o6`3o002U0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`00Y@000?l70?ooo`00
1P3ooolL0000oa/0o`0070000?lK0?l00:D0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o
002U0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`00Y@000?l70?ooo`001P3ooolL0000
oa/0o`0070000?lK0?l00:D0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o002U0000o`L0
oooo00060?oooa`0003o6`3o000L0000oa/0o`00Y@000?l70?ooo`001P3ooolL0000oa/0o`007000
0?lK0?l00:D0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o002U0000o`L0oooo00060?oo
oa`0003o6`3o000L0000oa/0o`00Y@000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l00:D0
003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o002U0000o`L0oooo00060?oooa`0003o6`3o
000L0000oa/0o`00Y@000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l00:D0003o1`3oool0
00H0oooo70000?lK0?l001`0003o6`3o002U0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0
o`00Y@000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l00:D0003o1`3oool000H0oooo7000
0?lK0?l001`0003o6`3o002U0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`00Y@000?l7
0?ooo`001P3ooolL0000oa/0o`0070000?lK0?l00:D0003o1`3oool000H0oooo=`3o00300000oa`0
o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3o
ool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0
oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o
00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000
oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`00
1`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool0
00H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo
=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o0030
0000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0
o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3o
ool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0
oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o
00300000oa`0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?oo
o`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o
00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0
003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo0006
0?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0
oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^
0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0oooo
Y@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool0
00H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`00
1`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000
ofh0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3o
ooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?oo
o`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o
00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0
003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo0006
0?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0
oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL
0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooo
m`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool0
00H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`00
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o
1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K
0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0
ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00
=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg
0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?oo
o`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o
703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^
0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000
o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`00
6`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo0006
0?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l0
03L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o
=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3o
ool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000
oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0oooo
KP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`00
0?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0oooo=`000?lL0?l0
01/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0
o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`00
0?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K
0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0
oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003o
KP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3o
ool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l0
01/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0
o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`00
0?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K
0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0
oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003o
KP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3o
ool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l0
01/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0
o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`00
0?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K
0000oa`0o`001`3oool000H0oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0
oooo=`000?lL0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo=`000?m^0?l006h0003o
1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool0
00H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo
=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^
0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0
003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3o
ool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0
oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`00
0?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l0
06h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o
1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool0
00H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo
=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo703o000K
0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o00070?oo
o`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00
Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL
0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00Y0000?lL0?l0
00L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL0?l001/0003o
703o002T0000oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00Y0000?lL0?l000L0oooo0006
0?oooa`0o`006`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL0?l001/0003o703o002T0000
oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`00
6`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3o
ool000H0oooo703o000K0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l0
0:@0003o703o00070?ooo`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo
703o000K0000oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o
00070?ooo`001P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo703o000K0000
oa`0o`00Y0000?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o00070?ooo`00
1P3ooolL0?l001/0003o703o002T0000oa`0o`001`3oool000H0oooo703o000K0000oa`0o`00Y000
0?lL0?l000L0oooo00060?oooa`0o`006`000?lL0?l00:@0003o703o00070?ooo`001P3ooolL0?l0
01/0003o703o002T0000oa`0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o
=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?oo
om`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo
00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l0
00L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog000
0?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0
oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3o
ool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0
o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL
0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`00
1P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooohT0003o703o001^
0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0
oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo0006
0?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0
003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o
001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000
o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo
00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?oo
ohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o
703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^
0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0
oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo0006
0?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oooe<0003o6`3o002U0000
o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo
00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oo
oe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o
6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U
0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0
oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo0006
0?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0
003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o
002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000
o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo
00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oo
oe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o6`3o002U0000o`L0oooo00060?oooe<0003o
DP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3o
ool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000
ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0oooo
D`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`007000
0?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l0
01/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`00
1P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o
000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000
oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0
oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`00
0?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oo
oe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0
003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o
000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool0
00H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0
o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`00
0?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l7
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FFFF0000FF0000FF00000000FF0000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`00
1`3oool000H0oooo703o000g0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]
0?l003L0003o703o00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0
oooo703o000g0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o
703o00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo703o000g
0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o00070?oo
o`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00
=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL
0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00=`000?lL0?l0
00L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL0?l003L0003o
K@3o000g0000oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00=`000?lL0?l000L0oooo0006
0?oooa`0o`00=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000
oa`0o`001`3oool000H0oooo703o000g0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00
=`000?m]0?l003L0003o703o00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3o
ool000H0oooo703o000g0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l0
03L0003o703o00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo
703o000g0000ofd0o`00=`000?lL0?l000L0oooo00060?oooa`0o`00=`000?m]0?l003L0003o703o
00070?ooo`001P3ooolL0?l003L0003oK@3o000g0000oa`0o`001`3oool000H0oooo=`3o000L0000
oe80o`00KP000?l70?ooo`001P3ooolg0?l001`0003oDP3o001^0000o`L0oooo00060?ooocL0o`00
70000?mB0?l006h0003o1`3oool000H0oooo=`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolg
0?l001`0003oDP3o001^0000o`L0oooo00060?ooocL0o`0070000?mB0?l006h0003o1`3oool000H0
oooo=`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolg0?l001`0003oDP3o001^0000o`L0oooo
00060?ooocL0o`0070000?mB0?l006h0003o1`3oool000H0oooo=`3o000L0000oe80o`00KP000?l7
0?ooo`001P3ooolg0?l001`0003oDP3o001^0000o`L0oooo00060?ooocL0o`0070000?mB0?l006h0
003o1`3oool000H0oooo=`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolg0?l001`0003oDP3o
001^0000o`L0oooo00060?ooocL0o`0070000?mB0?l006h0003o1`3oool000H0oooo=`3o000L0000
oe80o`00KP000?l70?ooo`001P3ooolg0?l001`0003oDP3o001^0000o`L0oooo00060?ooocL0o`00
70000?mB0?l006h0003o1`3oool000H0oooo=`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolg
0?l001`0003oDP3o001^0000o`L0oooo00060?ooocL0o`0070000?mB0?l006h0003o1`3oool000H0
oooo=`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolg0?l001`0003oDP3o001^0000o`L0oooo
00060?ooocL0o`0070000?mB0?l006h0003o1`3oool000H0oooo=`3o000L0000oe80o`00KP000?l7
0?ooo`001P3ooolg0?l001`0003oDP3o001^0000o`L0oooo00060?ooocL0o`0070000?mB0?l006h0
003o1`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3o
ool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0
oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o
00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000
oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`00
1`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool0
00H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo
=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o0030
0000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0
o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3o
ool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0
oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o
00300000oa`0o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000
oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo
70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo0006
0?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?oo
o`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`00
1`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg
0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l00:D0
003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o6`3o
002U0000ocL0o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000
oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo
70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo0006
0?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?oo
o`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`00
1`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg
0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0ooooR@000?lL0?l006h0
003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3o
ool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0
ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@00
0?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l0
06h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o
1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool0
00H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0oooo
R@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL
0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0
003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3o
ool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0
ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@000?lL0?l006h0003o1`3oool000H0ooooR@00
0?lL0?l006h0003o1`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?oo
o`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o
00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0
003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo0006
0?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0
oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL
0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooo
m`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool0
00H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`00
1`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000
oa`0o`001`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool0
00H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0oooo
D`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf
0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0
003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3o
ool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0
ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`00
0?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l0
08X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o
1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool0
00H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0oooo
D`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf
0?l008X0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0
003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3o
ool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0
ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP00
0?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l0
06h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o
1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool0
00H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0oooo
KP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg
0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0
003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3o
ool000H0ooooKP000?lg0?l006h0003o1`3oool000H0ooooKP000?lg0?l006h0003o1`3oool000H0
ooooKP000?lg0?l006h0003o1`3oool000H0oooo703o001B0000oe80o`00=`000?lL0?l000L0oooo
00060?oooa`0o`00DP000?mB0?l003L0003o703o00070?ooo`001P3ooolL0?l00580003oDP3o000g
0000oa`0o`001`3oool000H0oooo703o001B0000oe80o`00=`000?lL0?l000L0oooo00060?oooa`0
o`00DP000?mB0?l003L0003o703o00070?ooo`001P3ooolL0?l00580003oDP3o000g0000oa`0o`00
1`3oool000H0oooo703o001B0000oe80o`00=`000?lL0?l000L0oooo00060?oooa`0o`00DP000?mB
0?l003L0003o703o00070?ooo`001P3ooolL0?l00580003oDP3o000g0000oa`0o`001`3oool000H0
oooo703o001B0000oe80o`00=`000?lL0?l000L0oooo00060?oooa`0o`00DP000?mB0?l003L0003o
703o00070?ooo`001P3ooolL0?l00580003oDP3o000g0000oa`0o`001`3oool000H0oooo703o001B
0000oe80o`00=`000?lL0?l000L0oooo00060?oooa`0o`00DP000?mB0?l003L0003o703o00070?oo
o`001P3ooolL0?l00580003oDP3o000g0000oa`0o`001`3oool000H0oooo703o001B0000oe80o`00
=`000?lL0?l000L0oooo00060?oooa`0o`00DP000?mB0?l003L0003o703o00070?ooo`001P3ooolL
0?l00580003oDP3o000g0000oa`0o`001`3oool000H0oooo703o001B0000oe80o`00=`000?lL0?l0
00L0oooo00060?oooa`0o`00DP000?mB0?l003L0003o703o00070?ooo`001P3ooolL0?l00580003o
DP3o000g0000oa`0o`001`3oool000H0oooo703o001B0000oe80o`00=`000?lL0?l000L0oooo0006
0?oooa`0o`00DP000?mB0?l003L0003o703o00070?ooo`001P3ooolL0?l00580003oDP3o000g0000
oa`0o`001`3oool000H0oooo703o001B0000oe80o`00=`000?lL0?l000L0oooo00060?oooa`0o`00
DP000?mB0?l003L0003o703o00070?ooo`001P3ooolL0?l00580003oDP3o000g0000oa`0o`001`3o
ool000H0oooo703o001B0000oe80o`00=`000?lL0?l000L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o
1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K
0000ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0
oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`00
70000?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?n9
0?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`0070000?l70?oo
o`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?n90?l001/0003o
=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL
0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000
o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`00
6`000?lg0?l001`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo0006
0?oooa`0003oR@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l0
01`0003o1`3oool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003o
R@3o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3o
ool000H0oooo70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K0000
ocL0o`0070000?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo
70000?n90?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oR@3o000K0000ocL0o`007000
0?l70?ooo`001P3ooolL0000ohT0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?mB0?l0
08X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o
1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool0
00H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo
=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB
0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0
003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3o
ool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0
oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`00
0?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l0
08X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o
1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool0
00H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo=`000?mB0?l008X0003o1`3oool000H0oooo
g0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK
0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0
003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3o
ool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0
oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog000
0?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l0
01`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o
1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool0
00H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooo
g0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK
0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0
003o1`3oool000H0oooog0000?lK0?l001`0003o1`3oool000H0oooog0000?lK0?l001`0003o1`3o
ool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000
ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0
003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o
000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL
0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0
oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`00
6`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3o
ool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000
ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0
003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o
000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL
0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0
oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`00
6`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3o
ool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000
ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0
003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o
000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL
0?l006h0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0
oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o
003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000
oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`00
1`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool0
00H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo
703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K
0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0
o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3o
ool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0
oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o
003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000
oa`0o`001`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003K0000oa`0o`00
1`3oool000H0oooo703o003K0000oa`0o`001`3oool000H0oooo703o003g0000o`L0oooo00060?oo
oa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo
00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000
o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o
003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0
oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3o
ool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0
003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL
0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`00
1P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l7
0?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00
m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oo
oa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo
00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o003g0000
o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0oooo703o
003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3oool000H0
oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0003o1`3o
ool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL0?l00?L0
003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`001P3ooolL
0?l00?L0003o1`3oool000H0oooo703o003g0000o`L0oooo00060?oooa`0o`00m`000?l70?ooo`00
1P3ooolL0?l00?L0003o1`3oool000H0oooo703o001]0000oe<0o`00=`000?l70?ooo`001P3ooolL
0?l006d0003oD`3o000g0000o`L0oooo00060?oooa`0o`00K@000?mC0?l003L0003o1`3oool000H0
oooo703o001]0000oe<0o`00=`000?l70?ooo`001P3ooolL0?l006d0003oD`3o000g0000o`L0oooo
00060?oooa`0o`00K@000?mC0?l003L0003o1`3oool000H0oooo703o001]0000oe<0o`00=`000?l7
0?ooo`001P3ooolL0?l006d0003oD`3o000g0000o`L0oooo00060?oooa`0o`00K@000?mC0?l003L0
003o1`3oool000H0oooo703o001]0000oe<0o`00=`000?l70?ooo`001P3ooolL0?l006d0003oD`3o
000g0000o`L0oooo00060?oooa`0o`00K@000?mC0?l003L0003o1`3oool000H0oooo703o001]0000
oe<0o`00=`000?l70?ooo`001P3ooolL0?l006d0003oD`3o000g0000o`L0oooo00060?oooa`0o`00
K@000?mC0?l003L0003o1`3oool000H0oooo703o001]0000oe<0o`00=`000?l70?ooo`001P3ooolL
0?l006d0003oD`3o000g0000o`L0oooo00060?oooa`0o`00K@000?mC0?l003L0003o1`3oool000H0
oooo703o001]0000oe<0o`00=`000?l70?ooo`001P3ooolL0?l006d0003oD`3o000g0000o`L0oooo
00060?oooa`0o`00K@000?mC0?l003L0003o1`3oool000H0oooo703o001]0000oe<0o`00=`000?l7
0?ooo`001P3ooolL0?l006d0003oD`3o000g0000o`L0oooo00060?oooa`0o`00K@000?mC0?l003L0
003o1`3oool000H0oooo703o001]0000oe<0o`00=`000?l70?ooo`001P3ooolL0?l006d0003oD`3o
000g0000o`L0oooo00060?oooa`0o`00K@000?mC0?l003L0003o1`3oool000H0oooo703o00290000
ocL0o`006`000?lL0?l000L0oooo00060?oooa`0o`00R@000?lg0?l001/0003o703o00070?ooo`00
1P3ooolL0?l008T0003o=`3o000K0000oa`0o`001`3oool000H0oooo703o00290000ocL0o`006`00
0?lL0?l000L0oooo00060?oooa`0o`00R@000?lg0?l001/0003o703o00070?ooo`001P3ooolL0?l0
08T0003o=`3o000K0000oa`0o`001`3oool000H0oooo703o00290000ocL0o`006`000?lL0?l000L0
oooo00060?oooa`0o`00R@000?lg0?l001/0003o703o00070?ooo`001P3ooolL0?l008T0003o=`3o
000K0000oa`0o`001`3oool000H0oooo703o00290000ocL0o`006`000?lL0?l000L0oooo00060?oo
oa`0o`00R@000?lg0?l001/0003o703o00070?ooo`001P3ooolL0?l008T0003o=`3o000K0000oa`0
o`001`3oool000H0oooo703o00290000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0o`00R@00
0?lg0?l001/0003o703o00070?ooo`001P3ooolL0?l008T0003o=`3o000K0000oa`0o`001`3oool0
00H0oooo703o00290000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0o`00R@000?lg0?l001/0
003o703o00070?ooo`001P3ooolL0?l008T0003o=`3o000K0000oa`0o`001`3oool000H0oooo703o
00290000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0o`00R@000?lg0?l001/0003o703o0007
0?ooo`001P3ooolL0?l008T0003o=`3o000K0000oa`0o`001`3oool000H0oooo703o00290000ocL0
o`006`000?lL0?l000L0oooo00060?oooa`0o`00R@000?lg0?l001/0003o703o00070?ooo`001P3o
oolL0?l008T0003o=`3o000K0000oa`0o`001`3oool000H0oooo703o00290000ocL0o`006`000?lL
0?l000L0oooo00060?oooa`0o`00R@000?lg0?l001/0003o703o00070?ooo`001P3ooolL0?l008T0
003o=`3o000K0000oa`0o`001`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo
00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg
0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0
003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o
1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K
0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0
ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`00
70000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB
0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?oo
o`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o
=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC
0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000
o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`00
6`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo0006
0?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l0
01`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003o
DP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3o
ool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF00000000FF
0000FF0000FF0000FF0000FFFF00000000FFFF00000000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3o
oom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000
oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00
RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l7
0?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`00
1P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^
0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0
o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP00
0?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?oo
o`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3o
oom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000
oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00
RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000
o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooolg0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo=`000?lg0?l001/0003o703o
001^0000o`L0oooo00060?ooocL0003o=`3o000K0000oa`0o`00KP000?l70?ooo`001P3ooolg0000
ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo=`000?lg0?l001/0003o703o001^0000o`L0
oooo00060?ooocL0003o=`3o000K0000oa`0o`00KP000?l70?ooo`001P3ooolg0000ocL0o`006`00
0?lL0?l006h0003o1`3oool000H0oooo=`000?lg0?l001/0003o703o001^0000o`L0oooo00060?oo
ocL0003o=`3o000K0000oa`0o`00KP000?l70?ooo`001P3ooolg0000ocL0o`006`000?lL0?l006h0
003o1`3oool000H0oooo=`000?lg0?l001/0003o703o001^0000o`L0oooo00060?ooocL0003o=`3o
000K0000oa`0o`00KP000?l70?ooo`001P3ooolg0000ocL0o`006`000?lL0?l006h0003o1`3oool0
00H0oooo=`000?lg0?l001/0003o703o001^0000o`L0oooo00060?ooocL0003o=`3o000K0000oa`0
o`00KP000?l70?ooo`001P3ooolg0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo=`00
0?lg0?l001/0003o703o001^0000o`L0oooo00060?ooocL0003o=`3o000K0000oa`0o`00KP000?l7
0?ooo`001P3ooolg0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo=`000?lg0?l001/0
003o703o001^0000o`L0oooo00060?ooocL0003o=`3o000K0000oa`0o`00KP000?l70?ooo`001P3o
oolg0000ocL0o`006`000?lL0?l006h0003o1`3oool000H0oooo=`000?lg0?l001/0003o703o001^
0000o`L0oooo00060?ooocL0003o=`3o000K0000oa`0o`00KP000?l70?ooo`001P3ooolg0000ocL0
o`006`000?lL0?l006h0003o1`3oool000H0oooo=`000?lg0?l001/0003o703o001^0000o`L0oooo
00060?ooocL0003o=`3o000K0000oa`0o`00KP000?l70?ooo`001P3ooooL0000ocL0o`001`3oool0
00H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`00
1`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000
ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3o
oooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?oo
o`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o
00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0
003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo0006
0?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0
oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg
0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`00
1P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL
0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0
o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`007000
0?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?oo
o`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3o
oooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000
oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`00
70000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l7
0?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`00
1P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL
0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0
o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`007000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l7
0?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`00
1P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon9
0000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0
o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`007000
0?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?oo
o`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l7
0?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`00
1P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU
0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0
o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`00
0?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?oo
o`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3o
oonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000
oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00
D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l7
0?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`00
1P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU0000oa/0o`00D`000?l70?ooo`001P3ooonU
0000oa/0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`0070000?lK0?l001`0003o1`3oool000H0
ooooD`000?m]0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0003oK@3o000L0000oa/0o`00
70000?l70?ooo`001P3ooomC0000ofd0o`0070000?lK0?l001`0003o1`3oool000H0ooooD`000?m]
0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0003oK@3o000L0000oa/0o`0070000?l70?oo
o`001P3ooomC0000ofd0o`0070000?lK0?l001`0003o1`3oool000H0ooooD`000?m]0?l001`0003o
6`3o000L0000o`L0oooo00060?oooe<0003oK@3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC
0000ofd0o`0070000?lK0?l001`0003o1`3oool000H0ooooD`000?m]0?l001`0003o6`3o000L0000
o`L0oooo00060?oooe<0003oK@3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC0000ofd0o`00
70000?lK0?l001`0003o1`3oool000H0ooooD`000?m]0?l001`0003o6`3o000L0000o`L0oooo0006
0?oooe<0003oK@3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC0000ofd0o`0070000?lK0?l0
01`0003o1`3oool000H0ooooD`000?m]0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0003o
K@3o000L0000oa/0o`0070000?l70?ooo`001P3ooomC0000ofd0o`0070000?lK0?l001`0003o1`3o
ool000H0ooooD`000?m]0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0003oK@3o000L0000
oa/0o`0070000?l70?ooo`001P3ooomC0000ofd0o`0070000?lK0?l001`0003o1`3oool000H0oooo
D`000?m]0?l001`0003o6`3o000L0000o`L0oooo00060?oooe<0003oK@3o000L0000oa/0o`007000
0?l70?ooo`001P3ooomC0000ofd0o`0070000?lK0?l001`0003o1`3oool000H0ooooD`000?m]0?l0
01`0003o6`3o000L0000o`L0oooo00060?oooe<0003oK@3o000L0000oa/0o`0070000?l70?ooo`00
1P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o
001C0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000
oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0
oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`007000
0?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo00060?oo
ofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0
003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o
000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool0
00H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0
o`00D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP00
0?lK0?l001`0003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0
003o6`3o001C0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3o
oom^0000oa/0o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C
0000o`L0oooo00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0
o`0070000?lK0?l005<0003o1`3oool000H0ooooKP000?lK0?l001`0003o6`3o001C0000o`L0oooo
00060?ooofh0003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooom^0000oa/0o`0070000?lK
0?l005<0003o1`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000
o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo=`3o00300000oa`0o`00
1`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool0
00H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo
=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o0030
0000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0
o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3o
ool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0
oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o
00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000
oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`00
1`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool0
00H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo
=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o003L
0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo
=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool0
00H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o
1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l0
0=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3o
oolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?oo
o`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g000
0?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0
o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo0006
0?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo70000?lK0?l008T0
003o703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3o
oolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o703o000g
0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0
o`00R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000o`L0oooo
00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL
0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000o`L0oooo00060?oooa`0
003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o
1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o6`3o0029
0000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0
oooo70000?lK0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00
=`000?l70?ooo`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK
0?l008T0003o703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?oo
o`001P3ooolL0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o
703o000g0000o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL
0000oa/0o`00R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000
o`L0oooo00060?oooa`0003o6`3o00290000oa`0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00
R@000?lL0?l003L0003o1`3oool000H0oooo70000?lK0?l008T0003o703o000g0000o`L0oooo0006
0?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0
oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:
0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0oooo
R@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool0
00H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`00
1`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000
ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3o
oon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?oo
o`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o
00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooojD0
003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o
000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000
o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo
00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?oo
ojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o
=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g
0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0
oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo0006
0?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0
003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o
000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000
o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo00060?ooojD0003o=`3o000g0000o`L0oooo
00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oo
oe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003o
Y03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L
0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0
oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo0006
0?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0
003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o
000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000
o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo
00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oo
oe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003o
Y03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L
0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0
oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo0006
0?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0
003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o
000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000
o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo
00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?oo
ofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003o
KP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g
0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0
oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo0006
0?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0003oKP3o000g0000o`L0oooo00060?ooofh0
003oKP3o000g0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o
001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000
o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo
00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?oo
ohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o
703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^
0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0
oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo0006
0?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0
003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o
001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000
o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo
00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo=`000?lL0?l0
0:@0003o703o00070?ooo`001P3ooolg0000oa`0o`00Y0000?lL0?l000L0oooo00060?ooocL0003o
703o002T0000oa`0o`001`3oool000H0oooo=`000?lL0?l00:@0003o703o00070?ooo`001P3ooolg
0000oa`0o`00Y0000?lL0?l000L0oooo00060?ooocL0003o703o002T0000oa`0o`001`3oool000H0
oooo=`000?lL0?l00:@0003o703o00070?ooo`001P3ooolg0000oa`0o`00Y0000?lL0?l000L0oooo
00060?ooocL0003o703o002T0000oa`0o`001`3oool000H0oooo=`000?lL0?l00:@0003o703o0007
0?ooo`001P3ooolg0000oa`0o`00Y0000?lL0?l000L0oooo00060?ooocL0003o703o002T0000oa`0
o`001`3oool000H0oooo=`000?lL0?l00:@0003o703o00070?ooo`001P3ooolg0000oa`0o`00Y000
0?lL0?l000L0oooo00060?ooocL0003o703o002T0000oa`0o`001`3oool000H0oooo=`000?lL0?l0
0:@0003o703o00070?ooo`001P3ooolg0000oa`0o`00Y0000?lL0?l000L0oooo00060?ooocL0003o
703o002T0000oa`0o`001`3oool000H0oooo=`000?lL0?l00:@0003o703o00070?ooo`001P3ooolg
0000oa`0o`00Y0000?lL0?l000L0oooo00060?ooocL0003o703o002T0000oa`0o`001`3oool000H0
oooo=`000?lL0?l00:@0003o703o00070?ooo`001P3ooolg0000oa`0o`00Y0000?lL0?l000L0oooo
00060?ooocL0003o703o002T0000oa`0o`001`3oool000H0oooo=`000?lL0?l00:@0003o703o0007
0?ooo`001P3ooolg0000oa`0o`00Y0000?lL0?l000L0oooo00060?ooocL0003o703o002T0000oa`0
o`001`3oool000H0oooo703o000K0000ocL0o`00KP000?lg0?l000L0oooo00060?oooa`0o`006`00
0?lg0?l006h0003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001^0000ocL0o`001`3oool0
00H0oooo703o000K0000ocL0o`00KP000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l006h0
003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001^0000ocL0o`001`3oool000H0oooo703o
000K0000ocL0o`00KP000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l006h0003o=`3o0007
0?ooo`001P3ooolL0?l001/0003o=`3o001^0000ocL0o`001`3oool000H0oooo703o000K0000ocL0
o`00KP000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l006h0003o=`3o00070?ooo`001P3o
oolL0?l001/0003o=`3o001^0000ocL0o`001`3oool000H0oooo703o000K0000ocL0o`00KP000?lg
0?l000L0oooo00060?oooa`0o`006`000?lg0?l006h0003o=`3o00070?ooo`001P3ooolL0?l001/0
003o=`3o001^0000ocL0o`001`3oool000H0oooo703o000K0000ocL0o`00KP000?lg0?l000L0oooo
00060?oooa`0o`006`000?lg0?l006h0003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001^
0000ocL0o`001`3oool000H0oooo703o000K0000ocL0o`00KP000?lg0?l000L0oooo00060?oooa`0
o`006`000?lg0?l006h0003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001^0000ocL0o`00
1`3oool000H0oooo703o000K0000ocL0o`00KP000?lg0?l000L0oooo00060?oooa`0o`006`000?lg
0?l006h0003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001^0000ocL0o`001`3oool000H0
oooo703o000K0000ocL0o`00KP000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l006h0003o
=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o001^0000ocL0o`001`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooR@000?lg0?l001`0
003o=`3o00070?ooo`001P3ooon90000ocL0o`0070000?lg0?l000L0oooo00060?ooohT0003o=`3o
000L0000ocL0o`001`3oool000H0ooooR@000?lg0?l001`0003o=`3o00070?ooo`001P3ooon90000
ocL0o`0070000?lg0?l000L0oooo00060?ooohT0003o=`3o000L0000ocL0o`001`3oool000H0oooo
R@000?lg0?l001`0003o=`3o00070?ooo`001P3ooon90000ocL0o`0070000?lg0?l000L0oooo0006
0?ooohT0003o=`3o000L0000ocL0o`001`3oool000H0ooooR@000?lg0?l001`0003o=`3o00070?oo
o`001P3ooon90000ocL0o`0070000?lg0?l000L0oooo00060?ooohT0003o=`3o000L0000ocL0o`00
1`3oool000H0ooooR@000?lg0?l001`0003o=`3o00070?ooo`001P3ooon90000ocL0o`0070000?lg
0?l000L0oooo00060?ooohT0003o=`3o000L0000ocL0o`001`3oool000H0ooooR@000?lg0?l001`0
003o=`3o00070?ooo`001P3ooon90000ocL0o`0070000?lg0?l000L0oooo00060?ooohT0003o=`3o
000L0000ocL0o`001`3oool000H0ooooR@000?lg0?l001`0003o=`3o00070?ooo`001P3ooon90000
ocL0o`0070000?lg0?l000L0oooo00060?ooohT0003o=`3o000L0000ocL0o`001`3oool000H0oooo
R@000?lg0?l001`0003o=`3o00070?ooo`001P3ooon90000ocL0o`0070000?lg0?l000L0oooo0006
0?ooohT0003o=`3o000L0000ocL0o`001`3oool000H0ooooR@000?lg0?l001`0003o=`3o00070?oo
o`001P3ooon90000ocL0o`0070000?lg0?l000L0oooo00060?ooohT0003o=`3o000L0000ocL0o`00
1`3oool000H0ooooR@000?lg0?l001`0003o=`3o00070?ooo`001P3ooomC0000ohT0o`00=`000?l7
0?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`00
1P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC
0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0
o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`00
0?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?oo
o`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3o
oomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000
ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00
=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l7
0?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`00
1P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC
0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000oj@0
o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000
oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`00
70000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l7
0?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`00
1P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC
0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0
o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g
0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0
o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo
00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL
0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0
003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o
1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K
0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0
ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00
=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg
0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?oo
o`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o
703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^
0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000
o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`00
6`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo0006
0?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?oo
o`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3o
oomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000
oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00
KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l7
0?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`00
1P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC
0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80
o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP00
0?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?oo
o`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3o
oomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000
oe80o`00KP000?l70?ooo`001P3ooomC0000oe80o`00KP000?l70?ooo`001P3ooomC0000ocH0o`00
RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l7
0?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`00
1P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC
0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0
o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP00
0?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?oo
o`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3o
oomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000
ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00
RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l7
0?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`00
1P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC0000ocH0o`00RP000?l70?ooo`001P3ooomC
0000ocH0o`00RP000?l70?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF
0000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF00000000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3o
oomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000
ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00
D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l7
0?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`00
1P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC
0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0
o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`00
0?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?oo
o`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3o
oomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000
ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00
D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l70?ooo`001P3ooomC0000ofd0o`00D`000?l7
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolL0000oa/0o`00=`000?m^0?l003L0003o1`3oool000H0oooo7000
0?lK0?l003L0003oKP3o000g0000o`L0oooo00060?oooa`0003o6`3o000g0000ofh0o`00=`000?l7
0?ooo`001P3ooolL0000oa/0o`00=`000?m^0?l003L0003o1`3oool000H0oooo70000?lK0?l003L0
003oKP3o000g0000o`L0oooo00060?oooa`0003o6`3o000g0000ofh0o`00=`000?l70?ooo`001P3o
oolL0000oa/0o`00=`000?m^0?l003L0003o1`3oool000H0oooo70000?lK0?l003L0003oKP3o000g
0000o`L0oooo00060?oooa`0003o6`3o000g0000ofh0o`00=`000?l70?ooo`001P3ooolL0000oa/0
o`00=`000?m^0?l003L0003o1`3oool000H0oooo70000?lK0?l003L0003oKP3o000g0000o`L0oooo
00060?oooa`0003o6`3o000g0000ofh0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?m^
0?l003L0003o1`3oool000H0oooo70000?lK0?l003L0003oKP3o000g0000o`L0oooo00060?oooa`0
003o6`3o000g0000ofh0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?m^0?l003L0003o
1`3oool000H0oooo70000?lK0?l003L0003oKP3o000g0000o`L0oooo00060?oooa`0003o6`3o000g
0000ofh0o`00=`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?m^0?l003L0003o1`3oool000H0
oooo70000?lK0?l003L0003oKP3o000g0000o`L0oooo00060?oooa`0003o6`3o000g0000ofh0o`00
=`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?m^0?l003L0003o1`3oool000H0oooo70000?lK
0?l003L0003oKP3o000g0000o`L0oooo00060?oooa`0003o6`3o000g0000ofh0o`00=`000?l70?oo
o`001P3ooolL0000oa/0o`00=`000?m^0?l003L0003o1`3oool000H0oooo70000?lK0?l003L0003o
KP3o000g0000o`L0oooo00060?oooa`0003o6`3o000g0000ofh0o`00=`000?l70?ooo`001P3ooon9
0000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`00
1P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o0007
0?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003o
RP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?oo
ohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo
00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l0
00L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@00
0?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0
ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3o
ool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooom^0000ocL0
o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo
00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL
0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0
003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o
1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K
0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0
ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00
=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg
0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?oo
o`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o
703o000g0000o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^
0000ocL0o`006`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000
o`L0oooo00060?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`00
6`000?lL0?l003L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo0006
0?ooofh0003o=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l0
03L0003o1`3oool000H0ooooKP000?lg0?l001/0003o703o000g0000o`L0oooo00060?ooofh0003o
=`3o000K0000oa`0o`00=`000?l70?ooo`001P3ooom^0000ocL0o`006`000?lL0?l003L0003o1`3o
ool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l0
00L0oooo00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003o
RP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?ooocL0003o703o000f
0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0
o`00=P000?n:0?l000L0oooo00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`00
0?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?oo
ocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`00
1P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?ooocL0003o703o000f0000ohX0o`001`3o
ool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l0
00L0oooo00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003o
RP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?ooocL0003o703o000f
0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0
o`00=P000?n:0?l000L0oooo00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`00
0?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?oo
ocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003oD`3o000g0000o`L0
oooo00060?ooocL0003o703o000f0000oe<0o`00=`000?l70?ooo`001P3ooolg0000oa`0o`00=P00
0?mC0?l003L0003o1`3oool000H0oooo=`000?lL0?l003H0003oD`3o000g0000o`L0oooo00060?oo
ocL0003o703o000f0000oe<0o`00=`000?l70?ooo`001P3ooolg0000oa`0o`00=P000?mC0?l003L0
003o1`3oool000H0oooo=`000?lL0?l003H0003oD`3o000g0000o`L0oooo00060?ooocL0003o703o
000f0000oe<0o`00=`000?l70?ooo`001P3ooolg0000oa`0o`00=P000?mC0?l003L0003o1`3oool0
00H0oooo=`000?lL0?l003H0003oD`3o000g0000o`L0oooo00060?ooocL0003o703o000f0000oe<0
o`00=`000?l70?ooo`001P3ooolg0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo=`00
0?lL0?l003H0003oD`3o000g0000o`L0oooo00060?ooocL0003o703o000f0000oe<0o`00=`000?l7
0?ooo`001P3ooolg0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo=`000?lL0?l003H0
003oD`3o000g0000o`L0oooo00060?ooocL0003o703o000f0000oe<0o`00=`000?l70?ooo`001P3o
oolg0000oa`0o`00=P000?mC0?l003L0003o1`3oool000H0oooo=`000?lL0?l003H0003oD`3o000g
0000o`L0oooo00060?ooocL0003o703o000f0000oe<0o`00=`000?l70?ooo`001P3ooolg0000oa`0
o`00=P000?mC0?l003L0003o1`3oool000H0oooo=`000?lL0?l003H0003oD`3o000g0000o`L0oooo
00060?ooocL0003o703o000f0000oe<0o`00=`000?l70?ooo`001P3ooolg0000oa`0o`00=P000?mC
0?l003L0003o1`3oool000H0oooo=`000?lL0?l003H0003oD`3o000g0000o`L0oooo00060?ooocL0
003o703o000f0000oe<0o`00=`000?l70?ooo`001P3ooolg0000oa`0o`00=P000?mC0?l003L0003o
1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool0
00H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0oooo
D`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]
0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0
003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3o
ool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0
ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`00
0?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l0
05<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o
1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool0
00H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0oooo
D`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]
0?l005<0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0
003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3o
ool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0
ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`00
0?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l0
08X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o
1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool0
00H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0oooo
D`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf
0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0
003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3o
ool000H0ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?lf0?l008X0003o1`3oool000H0
ooooD`000?lf0?l008X0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`00
0?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l0
05<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o
1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool0
00H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0oooo
D`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]
0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0
003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3o
ool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0
ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`00
0?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l0
05<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o
1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool000H0ooooD`000?m]0?l005<0003o1`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF0000FF0000FF00000000FF0000FFFF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3o
oonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l0
01/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003o
D`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o0007
0?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`00
1P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU
0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0
003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o
00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?oo
o`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3o
oonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l0
01/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003o
D`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o0007
0?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`00
1P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg
0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00
o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`007000
0?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?oo
o`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3o
oolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000
ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`00
70000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l7
0?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`00
1P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg
0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00
o`0070000?l70?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo0006
0?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0
oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o0
0?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0oooo
D`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool0
00H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`00
1`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000
ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3o
oomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?oo
o`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o
00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?oo
o`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3o
oolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l0
03L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o
`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o0007
0?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`00
1P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL
0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0
003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o
00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?oo
o`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3o
oolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l0
03L0003o`03o00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo
703o000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o
00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo703o000g0000
oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`00
1P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo703o000g0000oa/0o`00=`00
0?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l0
03L0003o6`3o000g0000ofh0o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0
oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o
000g0000ofh0o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oo
oa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0
o`001`3oool000H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`00
0?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool0
00H0oooo703o000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0
003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo703o
000g0000oa/0o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o0007
0?ooo`001P3ooolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo703o000g0000oa/0
o`00=`000?m^0?l000L0oooo00060?oooa`0o`00=`000?lK0?l003L0003oKP3o00070?ooo`001P3o
oolL0?l003L0003o6`3o000g0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool0
00H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo
=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^
0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0
o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3o
ool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0
oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o
001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000
ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`00
1`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool0
00H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo
=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo=`3o001^
0000ofh0o`001`3oool000H0oooo=`3o001^0000ofh0o`001`3oool000H0oooo70000?lK0?l003L0
003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`00
1`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK
0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000
oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo
70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o
000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool0
00H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0
003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`00
1`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK
0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000
oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo
70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o
000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool0
00H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0
003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`00
1`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK
0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000
oa`0o`001`3oool000H0oooo70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo
70000?lK0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0ooooKP000?lg0?l003L0003o=`3o
00070?ooo`001P3ooom^0000ocL0o`00=`000?lg0?l000L0oooo00060?ooofh0003o=`3o000g0000
ocL0o`001`3oool000H0ooooKP000?lg0?l003L0003o=`3o00070?ooo`001P3ooom^0000ocL0o`00
=`000?lg0?l000L0oooo00060?ooofh0003o=`3o000g0000ocL0o`001`3oool000H0ooooKP000?lg
0?l003L0003o=`3o00070?ooo`001P3ooom^0000ocL0o`00=`000?lg0?l000L0oooo00060?ooofh0
003o=`3o000g0000ocL0o`001`3oool000H0ooooKP000?lg0?l003L0003o=`3o00070?ooo`001P3o
oom^0000ocL0o`00=`000?lg0?l000L0oooo00060?ooofh0003o=`3o000g0000ocL0o`001`3oool0
00H0ooooKP000?lg0?l003L0003o=`3o00070?ooo`001P3ooom^0000ocL0o`00=`000?lg0?l000L0
oooo00060?ooofh0003o=`3o000g0000ocL0o`001`3oool000H0ooooKP000?lg0?l003L0003o=`3o
00070?ooo`001P3ooom^0000ocL0o`00=`000?lg0?l000L0oooo00060?ooofh0003o=`3o000g0000
ocL0o`001`3oool000H0ooooKP000?lg0?l003L0003o=`3o00070?ooo`001P3ooom^0000ocL0o`00
=`000?lg0?l000L0oooo00060?ooofh0003o=`3o000g0000ocL0o`001`3oool000H0ooooKP000?lg
0?l003L0003o=`3o00070?ooo`001P3ooom^0000ocL0o`00=`000?lg0?l000L0oooo00060?ooofh0
003o=`3o000g0000ocL0o`001`3oool000H0ooooKP000?lg0?l003L0003o=`3o00070?ooo`001P3o
oom^0000ocL0o`00=`000?lg0?l000L0oooo00060?ooofh0003o=`3o000g0000ocL0o`001`3oool0
00H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo
=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n9
0?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0
003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3o
ool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0
oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`00
0?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l0
05<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o
1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool0
00H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo
=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n9
0?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0
003o1`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`00
0?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l0
03L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003o
KP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg
0000ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0
oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo
00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0003o=`3o0007
0?ooo`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0
o`001`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`00
0?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l0
03L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003o
KP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg
0000ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0
oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo
00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0003o=`3o0007
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000
oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`00
70000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l7
0?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`00
1P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC
0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0
o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000
oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`00
70000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l7
0?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`00
1P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg
0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0
003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o
00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?oo
o`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3o
oolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l0
03L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003o
Y@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o0007
0?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`00
1P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg
0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0
003oY@3o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3o
oomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l0
03H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003o
RP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o0007
0?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`00
1P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC
0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0
003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o
00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?oo
o`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3o
oomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l0
03H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003o
RP3o00070?ooo`001P3ooomC0?l003H0003oRP3o00070?ooo`001P3ooomC0?l003H0003oKP3o000L
0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0
o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P00
0?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l0
03H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0oooo
D`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo0006
0?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?oo
o`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o
1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L
0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0
o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P00
0?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l0
03H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0oooo
D`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo0006
0?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?oo
o`001P3ooolL0?l006d0003o703o000K0000oe<0o`001`3oool000H0oooo703o001]0000oa`0o`00
6`000?mC0?l000L0oooo00060?oooa`0o`00K@000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL
0?l006d0003o703o000K0000oe<0o`001`3oool000H0oooo703o001]0000oa`0o`006`000?mC0?l0
00L0oooo00060?oooa`0o`00K@000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l006d0003o
703o000K0000oe<0o`001`3oool000H0oooo703o001]0000oa`0o`006`000?mC0?l000L0oooo0006
0?oooa`0o`00K@000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l006d0003o703o000K0000
oe<0o`001`3oool000H0oooo703o001]0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00
K@000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l006d0003o703o000K0000oe<0o`001`3o
ool000H0oooo703o001]0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00K@000?lL0?l0
01/0003oD`3o00070?ooo`001P3ooolL0?l006d0003o703o000K0000oe<0o`001`3oool000H0oooo
703o001]0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00K@000?lL0?l001/0003oD`3o
00070?ooo`001P3ooolL0?l006d0003o703o000K0000oe<0o`001`3oool000H0oooo703o001]0000
oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00K@000?lL0?l001/0003oD`3o00070?ooo`00
1P3ooolL0?l006d0003o703o000K0000oe<0o`001`3oool000H0oooo703o001]0000oa`0o`006`00
0?mC0?l000L0oooo00060?oooa`0o`00K@000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l0
06d0003o703o000K0000oe<0o`001`3oool000H0oooo703o001]0000oa`0o`006`000?mC0?l000L0
oooo00060?oooa`0o`00K@000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003og03o
00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?oo
o`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3o
oolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l0
01/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003o
g03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o0007
0?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`00
1P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL
0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0
003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o
00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?oo
o`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3o
oolL0?l001/0003og03o00070?ooo`001P3ooolL0?l001/0003og03o00070?ooo`001P3ooolg0000
ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo
=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo0006
0?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?oo
o`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`00
1`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg
0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0
003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003oKP3o
000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000
ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo
=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo0006
0?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?oo
o`001P3ooolg0000ofh0o`00=`000?lg0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`00
1`3oool000H0oooo=`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolg0000ofh0o`00=`000?lg
0?l000L0oooo00060?ooocL0003oKP3o000g0000ocL0o`001`3oool000H0oooo=`000?m^0?l003L0
003o=`3o00070?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000
oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`00
70000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l7
0?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`00
1P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC
0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0
o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP00
0?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0
ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3o
ool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0
o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^
0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`00
1P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o0007
0?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003o
Y@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?oo
ofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo
00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0oooo703o000g0000
oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`00
1P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3oool000H0oooo703o000g0000oe80o`006`00
0?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l0
03L0003oDP3o000K0000oe<0o`001`3oool000H0oooo703o000g0000oe80o`006`000?mC0?l000L0
oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o
000K0000oe<0o`001`3oool000H0oooo703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oo
oa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0
o`001`3oool000H0oooo703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`00
0?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3oool0
00H0oooo703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0
003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3oool000H0oooo703o
000g0000oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o0007
0?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3oool000H0oooo703o000g0000oe80
o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`001P3o
oolL0?l003L0003oDP3o000K0000oe<0o`001`3oool000H0oooo703o000g0000oe80o`006`000?mC
0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0
003oDP3o000K0000oe<0o`001`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`00
0?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l0
01`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o
1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool0
00H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0oooo
D`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT
0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0
003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3o
ool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0
ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`00
0?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l0
01`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o
1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooocL0o`00=`000?nU
0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0
oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo0006
0?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0
o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`00
0?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l0
00L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo
00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?oo
ocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00
=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU
0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0
oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo0006
0?ooocL0o`00=`000?nU0?l000L0oooo00060?ooocL0o`00=`000?nU0?l000L0oooo00060?ooofh0
003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo0006
0?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0
oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU
0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0oooo
KP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool0
00H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`00
1`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000
ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3o
oom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?oo
o`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oR@3o
000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000
o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo
00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?oo
ofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003o
R@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L
0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0
oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo0006
0?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0
003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o
000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000
o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo
00060?ooofh0003oR@3o000L0000o`L0oooo00060?ooofh0003oR@3o000L0000o`L0oooo00060?oo
ocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`00
1P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3o
ool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000
o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`00
70000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n9
0?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0
003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o
000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?oo
ocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`00
1P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3o
ool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000
o`L0oooo00060?ooocL0o`00=`000?n90?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`00
70000?l70?ooo`001P3ooolg0?l003L0003oR@3o000L0000o`L0oooo00060?ooocL0o`00=`000?n9
0?l001`0003o1`3oool000H0oooo=`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolg0?l003L0
003oR@3o000L0000o`L0oooo00060?oooa`0003o=`3o000f0000oe<0o`00=`000?l70?ooo`001P3o
oolL0000ocL0o`00=P000?mC0?l003L0003o1`3oool000H0oooo70000?lg0?l003H0003oD`3o000g
0000o`L0oooo00060?oooa`0003o=`3o000f0000oe<0o`00=`000?l70?ooo`001P3ooolL0000ocL0
o`00=P000?mC0?l003L0003o1`3oool000H0oooo70000?lg0?l003H0003oD`3o000g0000o`L0oooo
00060?oooa`0003o=`3o000f0000oe<0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`00=P000?mC
0?l003L0003o1`3oool000H0oooo70000?lg0?l003H0003oD`3o000g0000o`L0oooo00060?oooa`0
003o=`3o000f0000oe<0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`00=P000?mC0?l003L0003o
1`3oool000H0oooo70000?lg0?l003H0003oD`3o000g0000o`L0oooo00060?oooa`0003o=`3o000f
0000oe<0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`00=P000?mC0?l003L0003o1`3oool000H0
oooo70000?lg0?l003H0003oD`3o000g0000o`L0oooo00060?oooa`0003o=`3o000f0000oe<0o`00
=`000?l70?ooo`001P3ooolL0000ocL0o`00=P000?mC0?l003L0003o1`3oool000H0oooo70000?lg
0?l003H0003oD`3o000g0000o`L0oooo00060?oooa`0003o=`3o000f0000oe<0o`00=`000?l70?oo
o`001P3ooolL0000ocL0o`00=P000?mC0?l003L0003o1`3oool000H0oooo70000?lg0?l003H0003o
D`3o000g0000o`L0oooo00060?oooa`0003o=`3o000f0000oe<0o`00=`000?l70?ooo`001P3ooolL
0000ocL0o`00=P000?mC0?l003L0003o1`3oool000H0oooo70000?lg0?l003H0003oD`3o000g0000
o`L0oooo00060?oooa`0003o=`3o000f0000oe<0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`00
=P000?mC0?l003L0003o1`3oool000H0oooo70000?lg0?l003H0003oD`3o000g0000o`L0oooo0006
0?oooa`0003o=`3o000f0000oe<0o`00=`000?l70?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3o
oom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l0
01/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003o
RP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o0007
0?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`00
1P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^
0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0
003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o
00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?oo
o`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3o
oom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l0
01/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003o
RP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o0007
0?ooo`001P3ooolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0
003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3o
oolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L
0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oe80
o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L0000o`L0oooo
00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?mB
0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0
003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?mB0?l001`0003o
1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L
0000oe80o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0
oooo=`000?mB0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`00
70000?l70?ooo`001P3ooolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB
0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?oo
o`001P3ooolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003o
DP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg
0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L0000
o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000om`0o`00
1`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000
om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3o
oolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?oo
o`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o
00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0
003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo0006
0?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0
oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL
0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo
=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000oa`0o`006`000?nU
0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0
003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o
000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000
oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo
=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo0006
0?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?oo
o`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`00
1`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU
0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0
003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o
000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000
oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo
=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo0006
0?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?oo
o`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o
00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0
003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo0006
0?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0
oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU
0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0oooo
KP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool0
00H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`00
1`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000
ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3o
oom^0000ojD0o`001`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l0
01`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o
1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool0
00H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0oooo
R@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^
0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0
003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3o
ool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0
ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@00
0?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l0
01`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o
1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool0
00H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0oooo
R@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^
0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0
003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3o
ool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0
ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@00
0?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l0
01`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o
1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool0
00H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0oooo
R@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^
0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0ooooR@000?m^0?l001`0
003o1`3oool000H0ooooR@000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l00580003oKP3o
000L0000o`L0oooo00060?oooa`0003o6`3o001B0000ofh0o`0070000?l70?ooo`001P3ooolL0000
oa/0o`00DP000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l00580003oKP3o000L0000o`L0
oooo00060?oooa`0003o6`3o001B0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00DP00
0?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l00580003oKP3o000L0000o`L0oooo00060?oo
oa`0003o6`3o001B0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00DP000?m^0?l001`0
003o1`3oool000H0oooo70000?lK0?l00580003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o
001B0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00DP000?m^0?l001`0003o1`3oool0
00H0oooo70000?lK0?l00580003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o001B0000ofh0
o`0070000?l70?ooo`001P3ooolL0000oa/0o`00DP000?m^0?l001`0003o1`3oool000H0oooo7000
0?lK0?l00580003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o001B0000ofh0o`0070000?l7
0?ooo`001P3ooolL0000oa/0o`00DP000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l00580
003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o001B0000ofh0o`0070000?l70?ooo`001P3o
oolL0000oa/0o`00DP000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l00580003oKP3o000L
0000o`L0oooo00060?oooa`0003o6`3o001B0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0
o`00DP000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l00580003oKP3o000L0000o`L0oooo
00060?oooa`0003o6`3o001B0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00DP000?m^
0?l001`0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0
003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3o
ool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0
oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`000
0?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l0
03L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o
1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool0
00H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo
`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL
0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0
003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3o
ool000H0oooo`0000?lL0?l003L0003o1`3oool000H0oooo`0000?lL0?l003L0003o1`3oool000H0
oooo`0000?lL0?l003L0003o1`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o
00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000
oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`00
1`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool0
00H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo
=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o0030
0000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0
o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3o
ool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0
oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o
00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000
oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`00
1`3oool000H0oooo=`3o00300000oa`0o`001`3oool000H0oooo=`3o00300000oa`0o`001`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FFFF0000
FF00000000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3o
oom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000
oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00
RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l7
0?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`00
1P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^
0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0
o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP00
0?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?oo
o`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3o
oom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000
oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00
RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l70?ooo`001P3ooom^0000oa/0o`00RP000?l7
0?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`00
1P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL
0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0
003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o
00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?oo
o`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l0
01/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o
703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o0007
0?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`00
1P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL
0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0
003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o
00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?oo
o`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l0
01/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o
703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o0007
0?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`00
1P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL
0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0
003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o
00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?oo
o`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000
ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00
=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo70000?lK
0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0
003o6`3o000g0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3o
oolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool0
00H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0
oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oY@3o
00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000
ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00
=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool000H0oooo70000?lK
0?l003L0003oY@3o00070?ooo`001P3ooolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0
003o6`3o000g0000ojD0o`001`3oool000H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3o
oolL0000oa/0o`00=`000?nU0?l000L0oooo00060?oooa`0003o6`3o000g0000ojD0o`001`3oool0
00H0oooo70000?lK0?l003L0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0
oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o
00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000
ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`00
6`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg
0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0
003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3o
oolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool0
00H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0
oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o
00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000
ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`00
6`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg
0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0
003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3o
oom^0000ocL0o`00DP000?lL0?l000L0oooo00060?ooofh0003o=`3o001B0000oa`0o`001`3oool0
00H0ooooKP000?lg0?l00580003o703o00070?ooo`001P3ooom^0000ocL0o`00DP000?lL0?l000L0
oooo00060?ooofh0003o=`3o001B0000oa`0o`001`3oool000H0ooooKP000?lg0?l00580003o703o
00070?ooo`001P3ooom^0000ocL0o`00DP000?lL0?l000L0oooo00060?ooofh0003o=`3o001B0000
oa`0o`001`3oool000H0ooooKP000?lg0?l00580003o703o00070?ooo`001P3ooom^0000ocL0o`00
DP000?lL0?l000L0oooo00060?ooofh0003o=`3o001B0000oa`0o`001`3oool000H0ooooKP000?lg
0?l00580003o703o00070?ooo`001P3ooom^0000ocL0o`00DP000?lL0?l000L0oooo00060?ooofh0
003o=`3o001B0000oa`0o`001`3oool000H0ooooKP000?lg0?l00580003o703o00070?ooo`001P3o
oom^0000ocL0o`00DP000?lL0?l000L0oooo00060?ooofh0003o=`3o001B0000oa`0o`001`3oool0
00H0ooooKP000?lg0?l00580003o703o00070?ooo`001P3ooom^0000ocL0o`00DP000?lL0?l000L0
oooo00060?ooofh0003o=`3o001B0000oa`0o`001`3oool000H0ooooKP000?lg0?l00580003o703o
00070?ooo`001P3ooom^0000ocL0o`00DP000?lL0?l000L0oooo00060?ooofh0003o=`3o001B0000
oa`0o`001`3oool000H0ooooKP000?lg0?l00580003o703o00070?ooo`001P3ooom^0000ocL0o`00
DP000?lL0?l000L0oooo00060?ooofh0003o=`3o001B0000oa`0o`001`3oool000H0ooooKP000?lg
0?l00580003o703o00070?ooo`001P3ooolg0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0
oooo=`3o000g0000oe80o`00=`000?lL0?l000L0oooo00060?ooocL0o`00=`000?mB0?l003L0003o
703o00070?ooo`001P3ooolg0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo=`3o000g
0000oe80o`00=`000?lL0?l000L0oooo00060?ooocL0o`00=`000?mB0?l003L0003o703o00070?oo
o`001P3ooolg0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo=`3o000g0000oe80o`00
=`000?lL0?l000L0oooo00060?ooocL0o`00=`000?mB0?l003L0003o703o00070?ooo`001P3ooolg
0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo=`3o000g0000oe80o`00=`000?lL0?l0
00L0oooo00060?ooocL0o`00=`000?mB0?l003L0003o703o00070?ooo`001P3ooolg0?l003L0003o
DP3o000g0000oa`0o`001`3oool000H0oooo=`3o000g0000oe80o`00=`000?lL0?l000L0oooo0006
0?ooocL0o`00=`000?mB0?l003L0003o703o00070?ooo`001P3ooolg0?l003L0003oDP3o000g0000
oa`0o`001`3oool000H0oooo=`3o000g0000oe80o`00=`000?lL0?l000L0oooo00060?ooocL0o`00
=`000?mB0?l003L0003o703o00070?ooo`001P3ooolg0?l003L0003oDP3o000g0000oa`0o`001`3o
ool000H0oooo=`3o000g0000oe80o`00=`000?lL0?l000L0oooo00060?ooocL0o`00=`000?mB0?l0
03L0003o703o00070?ooo`001P3ooolg0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo
=`3o000g0000oe80o`00=`000?lL0?l000L0oooo00060?ooocL0o`00=`000?mB0?l003L0003o703o
00070?ooo`001P3ooolg0?l003L0003oDP3o000g0000oa`0o`001`3oool000H0oooo=`3o000g0000
oe80o`00=`000?lL0?l000L0oooo00060?ooocL0o`00=`000?mB0?l003L0003o703o00070?ooo`00
1P3ooolL0?l00580003oDP3o001C0000o`L0oooo00060?oooa`0o`00DP000?mB0?l005<0003o1`3o
ool000H0oooo703o001B0000oe80o`00D`000?l70?ooo`001P3ooolL0?l00580003oDP3o001C0000
o`L0oooo00060?oooa`0o`00DP000?mB0?l005<0003o1`3oool000H0oooo703o001B0000oe80o`00
D`000?l70?ooo`001P3ooolL0?l00580003oDP3o001C0000o`L0oooo00060?oooa`0o`00DP000?mB
0?l005<0003o1`3oool000H0oooo703o001B0000oe80o`00D`000?l70?ooo`001P3ooolL0?l00580
003oDP3o001C0000o`L0oooo00060?oooa`0o`00DP000?mB0?l005<0003o1`3oool000H0oooo703o
001B0000oe80o`00D`000?l70?ooo`001P3ooolL0?l00580003oDP3o001C0000o`L0oooo00060?oo
oa`0o`00DP000?mB0?l005<0003o1`3oool000H0oooo703o001B0000oe80o`00D`000?l70?ooo`00
1P3ooolL0?l00580003oDP3o001C0000o`L0oooo00060?oooa`0o`00DP000?mB0?l005<0003o1`3o
ool000H0oooo703o001B0000oe80o`00D`000?l70?ooo`001P3ooolL0?l00580003oDP3o001C0000
o`L0oooo00060?oooa`0o`00DP000?mB0?l005<0003o1`3oool000H0oooo703o001B0000oe80o`00
D`000?l70?ooo`001P3ooolL0?l00580003oDP3o001C0000o`L0oooo00060?oooa`0o`00DP000?mB
0?l005<0003o1`3oool000H0oooo703o001B0000oe80o`00D`000?l70?ooo`001P3ooolL0?l00580
003oDP3o001C0000o`L0oooo00060?oooa`0o`00DP000?mB0?l005<0003o1`3oool000H0oooo703o
001B0000oe80o`00D`000?l70?ooo`001P3ooolL0?l00580003oDP3o001C0000o`L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l0
01/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o
703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o0007
0?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`00
1P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL
0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0
003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o
00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?oo
o`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l0
01/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o
703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0
003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o
00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0
003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o
00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?oo
o`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3o
oolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l0
0580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003o
Y@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o0007
0?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`00
1P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL
0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580
003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o
00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?oo
o`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3o
oolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l0
0580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003o
Y@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o0007
0?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`00
1P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL
0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580
003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o
00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?oo
o`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3o
oolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l0
0580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003o
Y@3o00070?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l00580003oY@3o0007
0?ooo`001P3ooolL0?l00580003oY@3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`00
1P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL
0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0
003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o
00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?oo
o`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3o
oolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l0
06d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003o
RP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o0007
0?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`00
1P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL
0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0
003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o
00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?oo
o`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3o
oolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l0
06d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003o
RP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o0007
0?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`00
1P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL
0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0
003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o
00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?oo
o`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3o
oolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l0
06d0003oRP3o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o
`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o0007
0?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`00
1P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL
0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0
003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o
00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?oo
o`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3o
oolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l0
03L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o
`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o0007
0?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolL0?l003L0003o`03o00070?ooo`00
1P3ooolL0?l003L0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000
oe<0o`001`3oool000H0oooo703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00
=`000?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3o
ool000H0oooo703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l0
01/0003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3oool000H0oooo
703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o
00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3oool000H0oooo703o000g0000
oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`00
1P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3oool000H0oooo703o000g0000oe80o`006`00
0?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l0
03L0003oDP3o000K0000oe<0o`001`3oool000H0oooo703o000g0000oe80o`006`000?mC0?l000L0
oooo00060?oooa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o
000K0000oe<0o`001`3oool000H0oooo703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oo
oa`0o`00=`000?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0
o`001`3oool000H0oooo703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`00
0?mB0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003oDP3o000K0000oe<0o`001`3oool0
00H0oooo703o000g0000oe80o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?mB0?l001/0
003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o
000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000
ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo
70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo0006
0?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?oo
o`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`00
1`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC
0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0
003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o
000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000
ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo
70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo0006
0?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?oo
o`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`00
1`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC
0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oo
ol00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`00
70000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg
0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0
oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo0006
0?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00
o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`007000
0?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l0
00L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo
00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oo
ol00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`00
70000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg
0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o
00070?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000
ofh0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`00
1P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`006`00
0?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolL0?l0
01/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`006`000?mC0?l000L0
oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003oKP3o
000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`006`000?mC0?l000L0oooo00060?oo
oa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0
o`001`3oool000H0oooo703o000K0000ofh0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`00
0?m^0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool0
00H0oooo703o000K0000ofh0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0
003oD`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o
000K0000ofh0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o0007
0?ooo`001P3ooolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0
o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?m^0?l001/0003oD`3o00070?ooo`001P3o
oolL0?l001/0003oKP3o000K0000oe<0o`001`3oool000H0oooo703o000K0000ofh0o`006`000?mC
0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo
=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool0
00H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`00
1`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000
om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3o
oolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?oo
o`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o
00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0
003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo0006
0?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
00H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo
703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
00H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo
703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?oo
ocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`00
70000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o0
0?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0
oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo0006
0?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0
o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`007000
0?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l0
00L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo
00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?oo
ocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`00
70000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o0
0?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oooa`0003oK@3o000L0000ofh0o`001`3o
ool000H0oooo70000?m]0?l001`0003oKP3o00070?ooo`001P3ooolL0000ofd0o`0070000?m^0?l0
00L0oooo00060?oooa`0003oK@3o000L0000ofh0o`001`3oool000H0oooo70000?m]0?l001`0003o
KP3o00070?ooo`001P3ooolL0000ofd0o`0070000?m^0?l000L0oooo00060?oooa`0003oK@3o000L
0000ofh0o`001`3oool000H0oooo70000?m]0?l001`0003oKP3o00070?ooo`001P3ooolL0000ofd0
o`0070000?m^0?l000L0oooo00060?oooa`0003oK@3o000L0000ofh0o`001`3oool000H0oooo7000
0?m]0?l001`0003oKP3o00070?ooo`001P3ooolL0000ofd0o`0070000?m^0?l000L0oooo00060?oo
oa`0003oK@3o000L0000ofh0o`001`3oool000H0oooo70000?m]0?l001`0003oKP3o00070?ooo`00
1P3ooolL0000ofd0o`0070000?m^0?l000L0oooo00060?oooa`0003oK@3o000L0000ofh0o`001`3o
ool000H0oooo70000?m]0?l001`0003oKP3o00070?ooo`001P3ooolL0000ofd0o`0070000?m^0?l0
00L0oooo00060?oooa`0003oK@3o000L0000ofh0o`001`3oool000H0oooo70000?m]0?l001`0003o
KP3o00070?ooo`001P3ooolL0000ofd0o`0070000?m^0?l000L0oooo00060?oooa`0003oK@3o000L
0000ofh0o`001`3oool000H0oooo70000?m]0?l001`0003oKP3o00070?ooo`001P3ooolL0000ofd0
o`0070000?m^0?l000L0oooo00060?oooa`0003oK@3o000L0000ofh0o`001`3oool000H0oooo7000
0?m]0?l001`0003oKP3o00070?ooo`001P3ooolL0000ofd0o`0070000?m^0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooohT0o`00
70000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^
0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0
oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo0006
0?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0
o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`007000
0?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l0
00L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo
00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?oo
ohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`00
70000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^
0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0
oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo0006
0?ooohT0o`0070000?m^0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`00
1P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon9
0?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0
003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o
00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?oo
o`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooom^0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0ooooKP3o000K0000ocL0
o`0070000?lg0?l000L0oooo00060?ooofh0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3o
oom^0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0ooooKP3o000K0000ocL0o`0070000?lg
0?l000L0oooo00060?ooofh0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooom^0?l001/0
003o=`3o000L0000ocL0o`001`3oool000H0ooooKP3o000K0000ocL0o`0070000?lg0?l000L0oooo
00060?ooofh0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooom^0?l001/0003o=`3o000L
0000ocL0o`001`3oool000H0ooooKP3o000K0000ocL0o`0070000?lg0?l000L0oooo00060?ooofh0
o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooom^0?l001/0003o=`3o000L0000ocL0o`00
1`3oool000H0ooooKP3o000K0000ocL0o`0070000?lg0?l000L0oooo00060?ooofh0o`006`000?lg
0?l001`0003o=`3o00070?ooo`001P3ooom^0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0
ooooKP3o000K0000ocL0o`0070000?lg0?l000L0oooo00060?ooofh0o`006`000?lg0?l001`0003o
=`3o00070?ooo`001P3ooom^0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0ooooKP3o000K
0000ocL0o`0070000?lg0?l000L0oooo00060?ooofh0o`006`000?lg0?l001`0003o=`3o00070?oo
o`001P3ooom^0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0ooooKP3o000K0000ocL0o`00
70000?lg0?l000L0oooo00060?ooofh0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooom^
0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0ooooKP3o000K0000ocL0o`0070000?lg0?l0
00L0oooo00060?ooofh0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooom^0?l003L0003o
KP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o0007
0?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`00
1P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^
0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0
003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o
00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?oo
o`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3o
oom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l0
03L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003o
KP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o0007
0?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`00
1P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooom^0?l003L0003oKP3o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooKP3o
000K0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o0007
0?ooo`001P3ooom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0
o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3o
oom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC
0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooom^0?l001/0
003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC0?l000L0oooo
00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooom^0?l001/0003o703o000K
0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0
o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooom^0?l001/0003o703o000K0000oe<0o`00
1`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL
0?l001/0003oD`3o00070?ooo`001P3ooom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0
ooooKP3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003o
D`3o00070?ooo`001P3ooom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K
0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?oo
o`001P3ooom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`00
6`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooom^
0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l001/0003o=`3o000K0000ocL0o`00
70000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003o=`3o000L0000ocL0o`001`3o
ool000H0oooo703o000K0000ocL0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l0
01/0003o=`3o000K0000ocL0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0
003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l001`0003o
=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ocL0o`0070000?lg0?l000L0oooo0006
0?oooa`0o`006`000?lg0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000
ocL0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ocL0
o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003o=`3o000L0000ocL0o`00
1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL
0?l001/0003o=`3o000K0000ocL0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l0
01/0003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l001`0
003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ocL0o`0070000?lg0?l000L0oooo
00060?oooa`0o`006`000?lg0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K
0000ocL0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000
ocL0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003o=`3o000L0000ocL0
o`001`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3o
oolL0?l001/0003o=`3o000K0000ocL0o`0070000?lg0?l000L0oooo00060?oooa`0o`006`000?lg
0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l0
01`0003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ocL0o`0070000?lg0?l000L0
oooo00060?oooa`0o`006`000?lg0?l001/0003o=`3o000L0000ocL0o`001`3oool000H0oooo703o
000K0000ocL0o`006`000?lg0?l001`0003o=`3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K
0000ocL0o`0070000?lg0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l0
00L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo
00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?oo
ofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00
=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^
0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0
oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo0006
0?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0
o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`00
0?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l0
00L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo
00060?ooofh0o`00=`000?m^0?l000L0oooo00060?ooofh0o`00=`000?m^0?l000L0oooo00060?oo
ofh0o`00=`000?m^0?l000L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o
1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l0
01`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3o
ooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?oo
o`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`007000
0?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0
o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo0006
0?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0
oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L
0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooo
m`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`00
1P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU
0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0
003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o
00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?oo
o`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3o
oonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l0
01/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003o
D`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o0007
0?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`00
1P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU
0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooonU0?l001/0
003oD`3o00070?ooo`001P3ooonU0?l001/0003oD`3o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3o
oom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l0
01/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003o
RP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o0007
0?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`00
1P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^
0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0
003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o
00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?oo
o`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3o
oom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l0
01/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003o
RP3o00070?ooo`001P3ooom^0?l001/0003oRP3o00070?ooo`001P3ooom^0?l001/0003oRP3o0007
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo
00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o0007
0?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0
o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`00
0?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l0
01/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003o
R@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL
0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0
oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo
00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o0007
0?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0
o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`00
0?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l0
01/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003o
R@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL
0000ohT0o`006`000?mC0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l0
00L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo
00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oo
ol00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`00
70000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg
0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0
oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo0006
0?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00
o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`007000
0?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l0
00L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo
00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oo
ol00o`0070000?lg0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`00
6`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL
0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0
oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo0006
0?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0
o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`00
0?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l0
00L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo
00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?oo
om`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`00
6`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL
0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0
oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooocL0o`0070000?o00?l0
00L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo
00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?oo
ocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`00
70000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o0
0?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0
oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo0006
0?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0
o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`007000
0?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l0
00L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo
00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?oo
ocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo=`3o000L0000oe80o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooolg0?l0
01`0003oDP3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?mB0?l001/0
003o703o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000oe80o`006`000?lL0?l001/0003o
703o00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000oa`0o`006`000?lL0?l000L0oooo0006
0?ooocL0o`0070000?mB0?l001/0003o703o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000
oe80o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000oa`0
o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?mB0?l001/0003o703o000K0000oa`0o`00
1`3oool000H0oooo=`3o000L0000oe80o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooolg
0?l001`0003oDP3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?mB0?l0
01/0003o703o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000oe80o`006`000?lL0?l001/0
003o703o00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000oa`0o`006`000?lL0?l000L0oooo
00060?ooocL0o`0070000?mB0?l001/0003o703o000K0000oa`0o`001`3oool000H0oooo=`3o000L
0000oe80o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000
oa`0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?mB0?l001/0003o703o000K0000oa`0
o`001`3oool000H0oooo=`3o000L0000oe80o`006`000?lL0?l001/0003o703o00070?ooo`001P3o
oolg0?l001`0003oDP3o000K0000oa`0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?mB
0?l001/0003o703o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000oe80o`006`000?lL0?l0
01/0003o703o00070?ooo`001P3ooolg0?l001`0003oDP3o000K0000oa`0o`006`000?lL0?l000L0
oooo00060?ooocL0o`0070000?mB0?l001/0003o703o000K0000oa`0o`001`3oool000H0oooo=`3o
000L0000oe80o`006`000?lL0?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003oDP3o000K
0000oa`0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?mB0?l001/0003o703o000K0000
oa`0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?oo
ofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`00
6`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:
0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0
oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo0006
0?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0
o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`00
0?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l0
00L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo
00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?oo
ofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`00
6`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooofh0o`006`000?n:
0?l000L0oooo00060?ooofh0o`006`000?n:0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo0006
0?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0
o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`007000
0?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l0
00L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo
00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?oo
ocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`00
70000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o0
0?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0
oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo0006
0?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0
o`0070000?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooocL0o`007000
0?o00?l000L0oooo00060?ooocL0o`0070000?o00?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0ooooR@000?lL0?l001/0003o
D`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K
0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0
o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3oool000H0ooooR@00
0?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?oo
ohT0003o703o000K0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`00
1P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3o
ool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l0
00L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0003o
D`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K
0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0
o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3oool000H0ooooR@00
0?lL0?l001/0003oD`3o00070?ooo`001P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?oo
ohT0003o703o000K0000oe<0o`001`3oool000H0ooooR@000?lL0?l001/0003oD`3o00070?ooo`00
1P3ooon90000oa`0o`006`000?mC0?l000L0oooo00060?ooohT0003o703o000K0000oe<0o`001`3o
ool000H0oooo703o000K0000ocL0o`00=`000?m^0?l000L0oooo00060?oooa`0o`006`000?lg0?l0
03L0003oKP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000g0000ofh0o`001`3oool000H0oooo
703o000K0000ocL0o`00=`000?m^0?l000L0oooo00060?oooa`0o`006`000?lg0?l003L0003oKP3o
00070?ooo`001P3ooolL0?l001/0003o=`3o000g0000ofh0o`001`3oool000H0oooo703o000K0000
ocL0o`00=`000?m^0?l000L0oooo00060?oooa`0o`006`000?lg0?l003L0003oKP3o00070?ooo`00
1P3ooolL0?l001/0003o=`3o000g0000ofh0o`001`3oool000H0oooo703o000K0000ocL0o`00=`00
0?m^0?l000L0oooo00060?oooa`0o`006`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolL0?l0
01/0003o=`3o000g0000ofh0o`001`3oool000H0oooo703o000K0000ocL0o`00=`000?m^0?l000L0
oooo00060?oooa`0o`006`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolL0?l001/0003o=`3o
000g0000ofh0o`001`3oool000H0oooo703o000K0000ocL0o`00=`000?m^0?l000L0oooo00060?oo
oa`0o`006`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000g0000ofh0
o`001`3oool000H0oooo703o000K0000ocL0o`00=`000?m^0?l000L0oooo00060?oooa`0o`006`00
0?lg0?l003L0003oKP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000g0000ofh0o`001`3oool0
00H0oooo703o000K0000ocL0o`00=`000?m^0?l000L0oooo00060?oooa`0o`006`000?lg0?l003L0
003oKP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000g0000ofh0o`001`3oool000H0oooo703o
000K0000ocL0o`00=`000?m^0?l000L0oooo00060?oooa`0o`006`000?lg0?l003L0003oKP3o0007
0?ooo`001P3ooolL0?l001/0003o=`3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o
000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000
ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`00
1`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool0
00H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0oooo
KP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g
0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o
000g0000ofh0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000
ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`00
1`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool0
00H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo
=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L
0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00
o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3o
ool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0
oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool000H0oooo=`3o
000L0000ol00o`001`3oool000H0oooo=`3o000L0000ol00o`001`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`00
1`3oool000H0oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf
0?l001`0003oKP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0
oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003o
KP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g
0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?oo
o`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g0000ocH0o`00
70000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolL
0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g0000ocH0o`0070000?m^0?l0
00L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolL0?l003L0003o
=P3o000L0000ofh0o`001`3oool000H0oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo0006
0?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000
ofh0o`001`3oool000H0oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00
=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3o
ool000H0oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l0
01`0003oKP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo
703o000g0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o
00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o002T0000
oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`00
1`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool0
00H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo
703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T
0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0
o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3o
ool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0
oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o
002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000
oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`00
1`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool0
00H0oooo703o002T0000oe<0o`001`3oool000H0oooo703o002T0000oe<0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0
oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo7000
0?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l0
01`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o
1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool0
00H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo
70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK
0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0
003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3o
ool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0
oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo7000
0?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l0
01`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3o
ooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?oo
o`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`007000
0?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0
o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo0006
0?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0
oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L
0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooo
m`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool0
00H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o
1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo0006
0?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0
o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`00
0?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l0
00L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo
00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oo
oa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`00
6`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL
0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0
oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo0006
0?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0
o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`00
0?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`00
1`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg
0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0
oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003o
RP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K
0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?oo
o`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`00
6`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL
0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l0
00L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o
=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo0006
0?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000
ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`00
6`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3o
ool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l0
01/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo
703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o
00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo70000?oK0?l001`0003o
1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool0
00H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo
70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK
0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0
003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3o
ool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0
oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo7000
0?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l0
01`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o
1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool0
00H0oooo70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0oooo
70000?oK0?l001`0003o1`3oool000H0oooo70000?oK0?l001`0003o1`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000
oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0
oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`00
0?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oo
oa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0
003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o
000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool0
00H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0
o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo7000
0?mB0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l7
0?ooo`001P3ooolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0
003oKP3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3o
oolL0000oe80o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L
0000o`L0oooo00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80
o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo
00060?oooa`0003oDP3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?m^
0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003oKP3o000L0000o`L0oooo00060?ooojD0
o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`00
0?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l0
00L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo
00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?oo
ojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`00
6`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC
0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0
oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo0006
0?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0
o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`00
0?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l0
00L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo00060?ooojD0o`006`000?mC0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0
003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o
00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000
o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0
ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o
000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000
ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`00
1`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool0
00H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0oooo
R@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L
0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0
o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3oool000H0ooooR@3o000L0000ofh0o`001`3o
ool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000
o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`00
70000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg
0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0
003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o
000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?oo
ohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`00
1P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3o
ool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000
o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`00
70000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg
0?l001`0003o1`3oool000H0ooooR@3o000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0
003o=`3o000L0000o`L0oooo00060?ooohT0o`00=`000?lg0?l001`0003o1`3oool000H0ooooR@3o
000g0000ocL0o`0070000?l70?ooo`001P3ooon90?l003L0003o=`3o000L0000o`L0oooo00060?oo
ohT0o`00=`000?lg0?l001`0003o1`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0
oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o
000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo00060?oo
ocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g0000oe<0
o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo00060?ooocL0o`007000
0?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g0000oe<0o`001`3oool0
00H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0
003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o
000L0000ocH0o`00=`000?mC0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o0007
0?ooo`001P3ooolg0?l001`0003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0
o`00=`000?mC0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3o
oolg0?l001`0003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC
0?l000L0oooo00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0
003o=P3o000g0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo
00060?ooocL0o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g
0000oe<0o`001`3oool000H0oooo=`3o000L0000ocH0o`00=`000?mC0?l000L0oooo00060?ooocL0
o`0070000?lf0?l003L0003oD`3o00070?ooo`001P3ooolg0?l001`0003o=P3o000g0000oe<0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF00000000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo
00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l7
0?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0
003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o
000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000
oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`00
70000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon9
0?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0
ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo
00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l7
0?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0
003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o
000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000
oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`00
70000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon9
0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0
003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o
001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000
o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo
00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?oo
ocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003o
R@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C
0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0
oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo0006
0?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0
003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o
001C0000o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003oR@3o001C0000
o`L0oooo00060?ooocL0003oR@3o001C0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo
00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?oo
ocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o
`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L
0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0
oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo0006
0?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0
003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o
000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000
o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo
00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?oo
ocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o
`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?oooa`0o`006`000?o0
0?l001`0003o1`3oool000H0oooo703o000K0000ol00o`0070000?l70?ooo`001P3ooolL0?l001/0
003o`03o000L0000o`L0oooo00060?oooa`0o`006`000?o00?l001`0003o1`3oool000H0oooo703o
000K0000ol00o`0070000?l70?ooo`001P3ooolL0?l001/0003o`03o000L0000o`L0oooo00060?oo
oa`0o`006`000?o00?l001`0003o1`3oool000H0oooo703o000K0000ol00o`0070000?l70?ooo`00
1P3ooolL0?l001/0003o`03o000L0000o`L0oooo00060?oooa`0o`006`000?o00?l001`0003o1`3o
ool000H0oooo703o000K0000ol00o`0070000?l70?ooo`001P3ooolL0?l001/0003o`03o000L0000
o`L0oooo00060?oooa`0o`006`000?o00?l001`0003o1`3oool000H0oooo703o000K0000ol00o`00
70000?l70?ooo`001P3ooolL0?l001/0003o`03o000L0000o`L0oooo00060?oooa`0o`006`000?o0
0?l001`0003o1`3oool000H0oooo703o000K0000ol00o`0070000?l70?ooo`001P3ooolL0?l001/0
003o`03o000L0000o`L0oooo00060?oooa`0o`006`000?o00?l001`0003o1`3oool000H0oooo703o
000K0000ol00o`0070000?l70?ooo`001P3ooolL0?l001/0003o`03o000L0000o`L0oooo00060?oo
oa`0o`006`000?o00?l001`0003o1`3oool000H0oooo703o000K0000ol00o`0070000?l70?ooo`00
1P3ooolL0?l001/0003o`03o000L0000o`L0oooo00060?oooa`0o`006`000?o00?l001`0003o1`3o
ool000H0oooo703o000K0000ol00o`0070000?l70?ooo`001P3ooolL0?l001/0003o`03o000L0000
o`L0oooo00060?oooa`0o`006`000?nU0?l003L0003o1`3oool000H0oooo703o000K0000ojD0o`00
=`000?l70?ooo`001P3ooolL0?l001/0003oY@3o000g0000o`L0oooo00060?oooa`0o`006`000?nU
0?l003L0003o1`3oool000H0oooo703o000K0000ojD0o`00=`000?l70?ooo`001P3ooolL0?l001/0
003oY@3o000g0000o`L0oooo00060?oooa`0o`006`000?nU0?l003L0003o1`3oool000H0oooo703o
000K0000ojD0o`00=`000?l70?ooo`001P3ooolL0?l001/0003oY@3o000g0000o`L0oooo00060?oo
oa`0o`006`000?nU0?l003L0003o1`3oool000H0oooo703o000K0000ojD0o`00=`000?l70?ooo`00
1P3ooolL0?l001/0003oY@3o000g0000o`L0oooo00060?oooa`0o`006`000?nU0?l003L0003o1`3o
ool000H0oooo703o000K0000ojD0o`00=`000?l70?ooo`001P3ooolL0?l001/0003oY@3o000g0000
o`L0oooo00060?oooa`0o`006`000?nU0?l003L0003o1`3oool000H0oooo703o000K0000ojD0o`00
=`000?l70?ooo`001P3ooolL0?l001/0003oY@3o000g0000o`L0oooo00060?oooa`0o`006`000?nU
0?l003L0003o1`3oool000H0oooo703o000K0000ojD0o`00=`000?l70?ooo`001P3ooolL0?l001/0
003oY@3o000g0000o`L0oooo00060?oooa`0o`006`000?nU0?l003L0003o1`3oool000H0oooo703o
000K0000ojD0o`00=`000?l70?ooo`001P3ooolL0?l001/0003oY@3o000g0000o`L0oooo00060?oo
oa`0o`006`000?nU0?l003L0003o1`3oool000H0oooo703o000K0000ojD0o`00=`000?l70?ooo`00
1P3ooolL0?l001/0003oY@3o000g0000o`L0oooo00060?oooa`0o`006`000?nU0?l003L0003o1`3o
ool000H0oooo=`3o001B0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`00DP000?mC0?l0
01/0003o703o00070?ooo`001P3ooolg0?l00580003oD`3o000K0000oa`0o`001`3oool000H0oooo
=`3o001B0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`00DP000?mC0?l001/0003o703o
00070?ooo`001P3ooolg0?l00580003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o001B0000
oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`00DP000?mC0?l001/0003o703o00070?ooo`00
1P3ooolg0?l00580003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o001B0000oe<0o`006`00
0?lL0?l000L0oooo00060?ooocL0o`00DP000?mC0?l001/0003o703o00070?ooo`001P3ooolg0?l0
0580003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o001B0000oe<0o`006`000?lL0?l000L0
oooo00060?ooocL0o`00DP000?mC0?l001/0003o703o00070?ooo`001P3ooolg0?l00580003oD`3o
000K0000oa`0o`001`3oool000H0oooo=`3o001B0000oe<0o`006`000?lL0?l000L0oooo00060?oo
ocL0o`00DP000?mC0?l001/0003o703o00070?ooo`001P3ooolg0?l00580003oD`3o000K0000oa`0
o`001`3oool000H0oooo=`3o001B0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`00DP00
0?mC0?l001/0003o703o00070?ooo`001P3ooolg0?l00580003oD`3o000K0000oa`0o`001`3oool0
00H0oooo=`3o001B0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`00DP000?mC0?l001/0
003o703o00070?ooo`001P3ooolg0?l00580003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o
001B0000oe<0o`006`000?lL0?l000L0oooo00060?ooocL0o`00DP000?mC0?l001/0003o703o0007
0?ooo`001P3ooolg0?l00580003oD`3o000K0000oa`0o`001`3oool000H0oooo703o000K0000ocL0
o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3o
oolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:
0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0
003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo
00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K
0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0
o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`00
1`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg
0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0
oooo703o000K0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003o
RP3o00070?ooo`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K
0000ocL0o`006`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?oo
o`001P3ooolL0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`00
6`000?n:0?l000L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL
0?l001/0003o=`3o000K0000ohX0o`001`3oool000H0oooo703o000K0000ocL0o`006`000?n:0?l0
00L0oooo00060?oooa`0o`006`000?lg0?l001/0003oRP3o00070?ooo`001P3ooolL0?l001/0003o
=`3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo
00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o0007
0?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000oa`0
o`001`3oool000H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3ooolg0000ojD0o`006`00
0?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l0
01/0003o703o00070?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0003o
Y@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3ooolg
0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0
oooo=`000?nU0?l001/0003o703o00070?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo
00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o0007
0?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000oa`0
o`001`3oool000H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3ooolg0000ojD0o`006`00
0?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l0
01/0003o703o00070?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0003o
Y@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3ooolg
0000ojD0o`006`000?lL0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo7000
0?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oo
oa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`00
1P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3o
ool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l0
00L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003o
RP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K
0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80
o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo7000
0?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oo
oa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`00
1P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3o
ool000H0oooo70000?mB0?l001/0003oRP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l0
00L0oooo00060?oooa`0003oDP3o000K0000ohX0o`001`3oool000H0oooo70000?mB0?l001/0003o
RP3o00070?ooo`001P3ooolL0000oe80o`006`000?n:0?l000L0oooo00060?oooa`0003o`03o000g
0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0
oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo0006
0?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0
003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o
000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000
o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo
00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oo
oa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o
`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g
0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0
oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo0006
0?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0
003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o00070?ooo`001P3o
oolL0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool0
00H0oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0
oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o
00070?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000
oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`00
6`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o0
0?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0
003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o00070?ooo`001P3o
oolL0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool0
00H0oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0
oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o
00070?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000
oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`00
6`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
00H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo
703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo=`000?oL0?l000L0oooo
00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l0
00L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`00
0?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0
oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3o
ool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0
o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg
0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`00
1P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o0007
0?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003o
g03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oo
oa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool0
00H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo
`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g
0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0
o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3o
ool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0
oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o
000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000
oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`00
1`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool0
00H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo
`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g
0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?oo
o`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`007000
0?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0
o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo0006
0?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0
oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L
0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooo
m`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool0
00H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o
1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l0
01`0003o1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g
0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0
o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3o
ool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0
ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o
000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000
ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`00
1`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool0
00H0ooooY@3o000g0000ocL0o`001`3oool000H0ooooY@3o000g0000ocL0o`001`3oool000H0oooo
Y@3o000g0000ocL0o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL
0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0
oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo
00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o0007
0?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0
o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`007000
0?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l0
01`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003o
Y03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL
0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0
oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo
00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o0007
0?ooo`001P3ooolL0000oj@0o`0070000?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0
o`001`3oool000H0oooo70000?nT0?l001`0003o=`3o00070?ooo`001P3ooolL0000oj@0o`007000
0?lg0?l000L0oooo00060?oooa`0003oY03o000L0000ocL0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo=`3o000L0000ohT0o`00
6`000?lL0?l000L0oooo00060?ooocL0o`0070000?n90?l001/0003o703o00070?ooo`001P3ooolg
0?l001`0003oR@3o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000ohT0o`006`000?lL0?l0
00L0oooo00060?ooocL0o`0070000?n90?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003o
R@3o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000ohT0o`006`000?lL0?l000L0oooo0006
0?ooocL0o`0070000?n90?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003oR@3o000K0000
oa`0o`001`3oool000H0oooo=`3o000L0000ohT0o`006`000?lL0?l000L0oooo00060?ooocL0o`00
70000?n90?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003oR@3o000K0000oa`0o`001`3o
ool000H0oooo=`3o000L0000ohT0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?n90?l0
01/0003o703o00070?ooo`001P3ooolg0?l001`0003oR@3o000K0000oa`0o`001`3oool000H0oooo
=`3o000L0000ohT0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?n90?l001/0003o703o
00070?ooo`001P3ooolg0?l001`0003oR@3o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000
ohT0o`006`000?lL0?l000L0oooo00060?ooocL0o`0070000?n90?l001/0003o703o00070?ooo`00
1P3ooolg0?l001`0003oR@3o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000ohT0o`006`00
0?lL0?l000L0oooo00060?ooocL0o`0070000?n90?l001/0003o703o00070?ooo`001P3ooolg0?l0
01`0003oR@3o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000ohT0o`006`000?lL0?l000L0
oooo00060?ooocL0o`0070000?n90?l001/0003o703o00070?ooo`001P3ooolg0?l001`0003oR@3o
000K0000oa`0o`001`3oool000H0oooo=`3o000L0000ohT0o`006`000?lL0?l000L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`00
1P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon9
0?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0
003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o
00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?oo
o`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0
003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o
000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000
oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`00
70000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg
0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0
oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo
00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l7
0?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0
003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o
000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000
oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`00
70000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg
0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0
oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo
00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0
003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o
001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000
oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`00
70000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon9
0?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0
ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo
00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0
003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o
001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000
oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`00
70000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooonU
0?l003L0003o6`3o000L0000o`L0oooo00060?ooojD0o`00=`000?lK0?l001`0003o1`3oool000H0
ooooY@3o000g0000oa/0o`0070000?l70?ooo`001P3ooonU0?l003L0003o6`3o000L0000o`L0oooo
00060?ooojD0o`00=`000?lK0?l001`0003o1`3oool000H0ooooY@3o000g0000oa/0o`0070000?l7
0?ooo`001P3ooonU0?l003L0003o6`3o000L0000o`L0oooo00060?ooojD0o`00=`000?lK0?l001`0
003o1`3oool000H0ooooY@3o000g0000oa/0o`0070000?l70?ooo`001P3ooonU0?l003L0003o6`3o
000L0000o`L0oooo00060?ooojD0o`00=`000?lK0?l001`0003o1`3oool000H0ooooY@3o000g0000
oa/0o`0070000?l70?ooo`001P3ooonU0?l003L0003o6`3o000L0000o`L0oooo00060?ooojD0o`00
=`000?lK0?l001`0003o1`3oool000H0ooooY@3o000g0000oa/0o`0070000?l70?ooo`001P3ooonU
0?l003L0003o6`3o000L0000o`L0oooo00060?ooojD0o`00=`000?lK0?l001`0003o1`3oool000H0
ooooY@3o000g0000oa/0o`0070000?l70?ooo`001P3ooonU0?l003L0003o6`3o000L0000o`L0oooo
00060?ooojD0o`00=`000?lK0?l001`0003o1`3oool000H0ooooY@3o000g0000oa/0o`0070000?l7
0?ooo`001P3ooonU0?l003L0003o6`3o000L0000o`L0oooo00060?ooojD0o`00=`000?lK0?l001`0
003o1`3oool000H0ooooY@3o000g0000oa/0o`0070000?l70?ooo`001P3ooonU0?l003L0003o6`3o
000L0000o`L0oooo00060?ooojD0o`00=`000?lK0?l001`0003o1`3oool000H0ooooY@3o000g0000
oa/0o`0070000?l70?ooo`001P3ooonU0?l001/0003o=`3o000L0000o`L0oooo00060?ooojD0o`00
6`000?lg0?l001`0003o1`3oool000H0ooooY@3o000K0000ocL0o`0070000?l70?ooo`001P3ooonU
0?l001/0003o=`3o000L0000o`L0oooo00060?ooojD0o`006`000?lg0?l001`0003o1`3oool000H0
ooooY@3o000K0000ocL0o`0070000?l70?ooo`001P3ooonU0?l001/0003o=`3o000L0000o`L0oooo
00060?ooojD0o`006`000?lg0?l001`0003o1`3oool000H0ooooY@3o000K0000ocL0o`0070000?l7
0?ooo`001P3ooonU0?l001/0003o=`3o000L0000o`L0oooo00060?ooojD0o`006`000?lg0?l001`0
003o1`3oool000H0ooooY@3o000K0000ocL0o`0070000?l70?ooo`001P3ooonU0?l001/0003o=`3o
000L0000o`L0oooo00060?ooojD0o`006`000?lg0?l001`0003o1`3oool000H0ooooY@3o000K0000
ocL0o`0070000?l70?ooo`001P3ooonU0?l001/0003o=`3o000L0000o`L0oooo00060?ooojD0o`00
6`000?lg0?l001`0003o1`3oool000H0ooooY@3o000K0000ocL0o`0070000?l70?ooo`001P3ooonU
0?l001/0003o=`3o000L0000o`L0oooo00060?ooojD0o`006`000?lg0?l001`0003o1`3oool000H0
ooooY@3o000K0000ocL0o`0070000?l70?ooo`001P3ooonU0?l001/0003o=`3o000L0000o`L0oooo
00060?ooojD0o`006`000?lg0?l001`0003o1`3oool000H0ooooY@3o000K0000ocL0o`0070000?l7
0?ooo`001P3ooonU0?l001/0003o=`3o000L0000o`L0oooo00060?ooojD0o`006`000?lg0?l001`0
003o1`3oool000H0ooooY@3o000K0000ocL0o`0070000?l70?ooo`001P3ooonU0?l001/0003o=`3o
000L0000o`L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l0
00L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo
00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?oo
ojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00
DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL
0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0
oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo0006
0?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0
o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP00
0?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l0
00L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo
00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?oo
ojD0o`00DP000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`00
6`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL
0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0
oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo0006
0?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0
o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`00
0?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l0
00L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo
00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?oo
om`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`00
6`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL
0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`006`000?lL0?l000L0
oooo00060?ooom`0o`006`000?lL0?l000L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL
0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`00
1P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l7
0?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00
=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?oo
om`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo
00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000
o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o
000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0
oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3o
ool000H0oooog03o000g0000o`L0oooo00060?oooe<0o`006`000?m^0?l003L0003o1`3oool000H0
ooooD`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooomC0?l001/0003oKP3o000g0000o`L0oooo
00060?oooe<0o`006`000?m^0?l003L0003o1`3oool000H0ooooD`3o000K0000ofh0o`00=`000?l7
0?ooo`001P3ooomC0?l001/0003oKP3o000g0000o`L0oooo00060?oooe<0o`006`000?m^0?l003L0
003o1`3oool000H0ooooD`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooomC0?l001/0003oKP3o
000g0000o`L0oooo00060?oooe<0o`006`000?m^0?l003L0003o1`3oool000H0ooooD`3o000K0000
ofh0o`00=`000?l70?ooo`001P3ooomC0?l001/0003oKP3o000g0000o`L0oooo00060?oooe<0o`00
6`000?m^0?l003L0003o1`3oool000H0ooooD`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooomC
0?l001/0003oKP3o000g0000o`L0oooo00060?oooe<0o`006`000?m^0?l003L0003o1`3oool000H0
ooooD`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooomC0?l001/0003oKP3o000g0000o`L0oooo
00060?oooe<0o`006`000?m^0?l003L0003o1`3oool000H0ooooD`3o000K0000ofh0o`00=`000?l7
0?ooo`001P3ooomC0?l001/0003oKP3o000g0000o`L0oooo00060?oooe<0o`006`000?m^0?l003L0
003o1`3oool000H0ooooD`3o000K0000ofh0o`00=`000?l70?ooo`001P3ooomC0?l001/0003oKP3o
000g0000o`L0oooo00060?oooe<0o`006`000?m^0?l003L0003o1`3oool000H0ooooD`3o000K0000
ofh0o`00=`000?l70?ooo`001P3ooomC0?l001/0003oKP3o000g0000o`L0oooo00060?ooocL0003o
`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L
0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0
oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo0006
0?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0
003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o
000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000
o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo
00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?oo
ocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o
`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L
0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0
oooo00060?ooocL0003o`03o000L0000o`L0oooo00060?ooocL0003o`03o000L0000o`L0oooo0006
0?ooocL0003o`03o000L0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l7
0?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`00
1P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon9
0000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0
o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`007000
0?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?oo
o`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l7
0?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`00
1P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg
0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0
o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`00
0?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?oo
o`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3o
oolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000
ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00
=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l7
0?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`00
1P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg
0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0
o`00=`000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`00
0?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l7
0?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0
003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3o
oolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L
0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0
o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo
00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg
0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0
003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o
1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K
0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0
oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`00
70000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^
0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?oo
o`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o
=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg
0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000
o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`00
6`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo0006
0?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l0
01`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003o
KP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3o
ool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000
ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo
=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`007000
0?l70?ooo`001P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l0
01/0003o=`3o000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`00
1P3ooolg0000ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o
000L0000o`L0oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000
ofh0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0
oooo00060?ooocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ofh0o`006`00
0?lg0?l001`0003o1`3oool000H0oooo=`000?m^0?l001/0003o=`3o000L0000o`L0oooo00060?oo
ocL0003oKP3o000K0000ocL0o`0070000?l70?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0
oooo00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o
00070?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000
oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3ooolg0000ojD0o`00
6`000?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU
0?l001/0003o703o00070?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0
003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3o
oolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000oa`0o`001`3oool0
00H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0
oooo00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o
00070?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000
oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3ooolg0000ojD0o`00
6`000?lL0?l000L0oooo00060?ooocL0003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU
0?l001/0003o703o00070?ooo`001P3ooolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooocL0
003oY@3o000K0000oa`0o`001`3oool000H0oooo=`000?nU0?l001/0003o703o00070?ooo`001P3o
oolg0000ojD0o`006`000?lL0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?oo
ohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`00
70000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^
0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0
oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo0006
0?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0
o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`007000
0?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l0
00L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo
00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?oo
ohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`00
70000?m^0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?ooohT0o`0070000?m^
0?l000L0oooo00060?ooohT0o`0070000?m^0?l000L0oooo00060?oool00o`0070000?lg0?l000L0
oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo0006
0?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00
o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`007000
0?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l0
00L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo
00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oo
ol00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`00
70000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg
0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0
oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo0006
0?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00
o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?ooojD0o`00DP00
0?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l0
00L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo
00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?oo
ojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00
DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL
0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0
oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo0006
0?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0
o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP00
0?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l0
00L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo
00060?ooojD0o`00DP000?lL0?l000L0oooo00060?ooojD0o`00DP000?lL0?l000L0oooo00060?oo
oe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003o
K@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C
0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0
oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo0006
0?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0
003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o
001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000
o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo
00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oo
oe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003o
K@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C
0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0oooo00060?oooe<0003oK@3o001C0000o`L0
oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo0006
0?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0
003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o
000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000
o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo
00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?oo
ohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003o
D`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g
0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0
oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo0006
0?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0
003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo00060?ooohT0003oD`3o
000g0000o`L0oooo00060?ooohT0003oD`3o000g0000o`L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3o
oolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000
ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00
=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l7
0?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`00
1P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg
0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0
o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`00
0?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?oo
o`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3o
oolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000
ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00
=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l7
0?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003o
g03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?oo
ocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo
00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l0
00L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`00
0?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0
oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3o
ool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0
o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg
0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`00
1P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o0007
0?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003o
g03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?oo
ocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo
00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l0
00L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`00
0?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0
oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3o
ool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0
o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolL
0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0
oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0oooo
00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o0007
0?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0
o`001`3oool000H0oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`006`00
0?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l0
01/0003o703o00070?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o
`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL
0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0
oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0oooo
00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l001/0003o703o0007
0?ooo`001P3ooolL0000ol00o`006`000?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0
o`001`3oool000H0oooo70000?o00?l001/0003o703o00070?ooo`001P3ooolL0000ol00o`006`00
0?lL0?l000L0oooo00060?oooa`0003o`03o000K0000oa`0o`001`3oool000H0oooo70000?o00?l0
01/0003o703o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`00
1P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon9
0?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0
003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o
00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?oo
o`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3o
oon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l0
01`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003o
KP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o0007
0?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`00
1P3ooon90?l001`0003oKP3o00070?ooo`001P3ooon90?l001`0003oKP3o00070?ooo`001P3ooonU
0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0
003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o
00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?oo
o`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3o
oonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l0
03L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o
=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o0007
0?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`00
1P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU
0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0
003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o
00070?ooo`001P3ooonU0?l003L0003o=`3o00070?ooo`001P3ooonU0?l003L0003o=`3o00070?oo
o`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o
=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg
0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000
o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`00
6`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo0006
0?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l0
06h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o
703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3o
ool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000
ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo
=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP00
0?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l0
01/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`00
1P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o
001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000
oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0
oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ohT0o`007000
0?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?oo
o`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3o
oom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000
ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`00
70000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l7
0?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`00
1P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^
0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0
o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`007000
0?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?oo
o`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3o
oom^0000ohT0o`0070000?l70?ooo`001P3ooom^0000ohT0o`0070000?l70?ooo`001P3oooo00000
ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`00
70000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l7
0?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`00
1P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo0
0000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0
o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`007000
0?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?oo
o`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3o
ooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000
ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`00
70000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l7
0?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`001P3oooo00000ocL0o`0070000?l70?ooo`00
1P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^
0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0
o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP00
0?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?oo
o`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3o
oom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000
ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00
KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l7
0?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`00
1P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^
0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0
o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`001P3ooom^0000ocL0o`00KP00
0?l70?ooo`001P3ooom^0000ocL0o`00KP000?l70?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF00000000FF0000FFFF0000FF0000
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FFFF0000FF00000000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3o
oolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000
oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00
D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l7
0?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`00
1P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL
0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0
o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`00
0?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?oo
o`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3o
oolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000
oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00
D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l7
0?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`00
1P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL
0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0
o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`007000
0?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?oo
o`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3o
oolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000
om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`00
70000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l7
0?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`00
1P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL
0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0
o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`007000
0?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?oo
o`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3o
oolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000
om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`00
70000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l7
0?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`00
1P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL
0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0
o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`007000
0?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?oo
o`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3o
oolL0000om/0o`0070000?l70?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooomC0?l003H0003o703o000g0000ocL0o`001`3oool000H0oooo
D`3o000f0000oa`0o`00=`000?lg0?l000L0oooo00060?oooe<0o`00=P000?lL0?l003L0003o=`3o
00070?ooo`001P3ooomC0?l003H0003o703o000g0000ocL0o`001`3oool000H0ooooD`3o000f0000
oa`0o`00=`000?lg0?l000L0oooo00060?oooe<0o`00=P000?lL0?l003L0003o=`3o00070?ooo`00
1P3ooomC0?l003H0003o703o000g0000ocL0o`001`3oool000H0ooooD`3o000f0000oa`0o`00=`00
0?lg0?l000L0oooo00060?oooe<0o`00=P000?lL0?l003L0003o=`3o00070?ooo`001P3ooomC0?l0
03H0003o703o000g0000ocL0o`001`3oool000H0ooooD`3o000f0000oa`0o`00=`000?lg0?l000L0
oooo00060?oooe<0o`00=P000?lL0?l003L0003o=`3o00070?ooo`001P3ooomC0?l003H0003o703o
000g0000ocL0o`001`3oool000H0ooooD`3o000f0000oa`0o`00=`000?lg0?l000L0oooo00060?oo
oe<0o`00=P000?lL0?l003L0003o=`3o00070?ooo`001P3ooomC0?l003H0003o703o000g0000ocL0
o`001`3oool000H0ooooD`3o000f0000oa`0o`00=`000?lg0?l000L0oooo00060?oooe<0o`00=P00
0?lL0?l003L0003o=`3o00070?ooo`001P3ooomC0?l003H0003o703o000g0000ocL0o`001`3oool0
00H0ooooD`3o000f0000oa`0o`00=`000?lg0?l000L0oooo00060?oooe<0o`00=P000?lL0?l003L0
003o=`3o00070?ooo`001P3ooomC0?l003H0003o703o000g0000ocL0o`001`3oool000H0ooooD`3o
000f0000oa`0o`00=`000?lg0?l000L0oooo00060?oooe<0o`00=P000?lL0?l003L0003o=`3o0007
0?ooo`001P3ooomC0?l003H0003o703o000g0000ocL0o`001`3oool000H0ooooD`3o000f0000oa`0
o`00=`000?lg0?l000L0oooo00060?oooe<0o`00=P000?lL0?l003L0003o=`3o00070?ooo`001P3o
oomC0?l003H0003o703o000g0000ocL0o`001`3oool000H0oooo=`000?lL0?l00<00003o1`3oool0
00H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo
=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL
0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00
003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3o
ool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0
oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`00
0?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l0
0<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o
1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool0
00H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo
=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL
0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo`0000?lg0?l001`0
003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3o
ool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0
oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`000
0?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l0
01`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o
1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool0
00H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo
`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg
0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0
003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3o
ool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0
oooo`0000?lg0?l001`0003o1`3oool000H0oooo`0000?lg0?l001`0003o1`3oool000H0oooo=`00
0?lg0?l00580003o=`3o000L0000o`L0oooo00060?ooocL0003o=`3o001B0000ocL0o`0070000?l7
0?ooo`001P3ooolg0000ocL0o`00DP000?lg0?l001`0003o1`3oool000H0oooo=`000?lg0?l00580
003o=`3o000L0000o`L0oooo00060?ooocL0003o=`3o001B0000ocL0o`0070000?l70?ooo`001P3o
oolg0000ocL0o`00DP000?lg0?l001`0003o1`3oool000H0oooo=`000?lg0?l00580003o=`3o000L
0000o`L0oooo00060?ooocL0003o=`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolg0000ocL0
o`00DP000?lg0?l001`0003o1`3oool000H0oooo=`000?lg0?l00580003o=`3o000L0000o`L0oooo
00060?ooocL0003o=`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolg0000ocL0o`00DP000?lg
0?l001`0003o1`3oool000H0oooo=`000?lg0?l00580003o=`3o000L0000o`L0oooo00060?ooocL0
003o=`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolg0000ocL0o`00DP000?lg0?l001`0003o
1`3oool000H0oooo=`000?lg0?l00580003o=`3o000L0000o`L0oooo00060?ooocL0003o=`3o001B
0000ocL0o`0070000?l70?ooo`001P3ooolg0000ocL0o`00DP000?lg0?l001`0003o1`3oool000H0
oooo=`000?lg0?l00580003o=`3o000L0000o`L0oooo00060?ooocL0003o=`3o001B0000ocL0o`00
70000?l70?ooo`001P3ooolg0000ocL0o`00DP000?lg0?l001`0003o1`3oool000H0oooo=`000?lg
0?l00580003o=`3o000L0000o`L0oooo00060?ooocL0003o=`3o001B0000ocL0o`0070000?l70?oo
o`001P3ooolg0000ocL0o`00DP000?lg0?l001`0003o1`3oool000H0oooo=`000?lg0?l00580003o
=`3o000L0000o`L0oooo00060?ooocL0003o=`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolg
0000ocL0o`00DP000?lg0?l001`0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooD`000?lf0?l001`0003o6`3o001C0000o`L0oooo
00060?oooe<0003o=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooomC0000ocH0o`0070000?lK
0?l005<0003o1`3oool000H0ooooD`000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooe<0
003o=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooomC0000ocH0o`0070000?lK0?l005<0003o
1`3oool000H0ooooD`000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooe<0003o=P3o000L
0000oa/0o`00D`000?l70?ooo`001P3ooomC0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0
ooooD`000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooe<0003o=P3o000L0000oa/0o`00
D`000?l70?ooo`001P3ooomC0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0ooooD`000?lf
0?l001`0003o6`3o001C0000o`L0oooo00060?oooe<0003o=P3o000L0000oa/0o`00D`000?l70?oo
o`001P3ooomC0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0ooooD`000?lf0?l001`0003o
6`3o001C0000o`L0oooo00060?oooe<0003o=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooomC
0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0ooooD`000?lf0?l001`0003o6`3o001C0000
o`L0oooo00060?oooe<0003o=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooomC0000ocH0o`00
70000?lK0?l005<0003o1`3oool000H0ooooD`000?lf0?l001`0003o6`3o001C0000o`L0oooo0006
0?oooe<0003o=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooomC0000ocH0o`0070000?lK0?l0
05<0003o1`3oool000H0ooooD`000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooe<0003o
=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooomC0000ocH0o`0070000?lK0?l005<0003o1`3o
ool000H0ooooD`000?lf0?l001`0003o6`3o001C0000o`L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FFFF0000FF00000000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o
00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0
ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3o
ool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00
003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC
0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`00
1P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l7
0?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00
`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oo
oe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo
00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000
o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o
00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0
ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3o
ool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00
003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC
0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`00
1P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l7
0?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00
`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oo
oe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0oooog03o000K0000oa`0o`00
1`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool0
00H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooo
g03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K
0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0
o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3o
ool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0
oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o
000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000
oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`00
1`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool0
00H0oooog03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0oooo
g03o000K0000oa`0o`001`3oool000H0oooog03o000K0000oa`0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooKP000?lK0?l003L0
003o=`3o000L0000o`L0oooo00060?ooofh0003o6`3o000g0000ocL0o`0070000?l70?ooo`001P3o
oom^0000oa/0o`00=`000?lg0?l001`0003o1`3oool000H0ooooKP000?lK0?l003L0003o=`3o000L
0000o`L0oooo00060?ooofh0003o6`3o000g0000ocL0o`0070000?l70?ooo`001P3ooom^0000oa/0
o`00=`000?lg0?l001`0003o1`3oool000H0ooooKP000?lK0?l003L0003o=`3o000L0000o`L0oooo
00060?ooofh0003o6`3o000g0000ocL0o`0070000?l70?ooo`001P3ooom^0000oa/0o`00=`000?lg
0?l001`0003o1`3oool000H0ooooKP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?ooofh0
003o6`3o000g0000ocL0o`0070000?l70?ooo`001P3ooom^0000oa/0o`00=`000?lg0?l001`0003o
1`3oool000H0ooooKP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?ooofh0003o6`3o000g
0000ocL0o`0070000?l70?ooo`001P3ooom^0000oa/0o`00=`000?lg0?l001`0003o1`3oool000H0
ooooKP000?lK0?l003L0003o=`3o000L0000o`L0oooo00060?ooofh0003o6`3o000g0000ocL0o`00
70000?l70?ooo`001P3ooom^0000oa/0o`00=`000?lg0?l001`0003o1`3oool000H0ooooKP000?lK
0?l003L0003o=`3o000L0000o`L0oooo00060?ooofh0003o6`3o000g0000ocL0o`0070000?l70?oo
o`001P3ooom^0000oa/0o`00=`000?lg0?l001`0003o1`3oool000H0ooooKP000?lK0?l003L0003o
=`3o000L0000o`L0oooo00060?ooofh0003o6`3o000g0000ocL0o`0070000?l70?ooo`001P3ooom^
0000oa/0o`00=`000?lg0?l001`0003o1`3oool000H0ooooKP000?lK0?l003L0003o=`3o000L0000
o`L0oooo00060?ooofh0003o6`3o000g0000ocL0o`0070000?l70?ooo`001P3ooom^0000oa/0o`00
=`000?lg0?l001`0003o1`3oool000H0ooooKP000?lK0?l003L0003o=`3o000L0000o`L0oooo0006
0?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0
003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o
000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000
o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo
00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?oo
ojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003o
DP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L
0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0
oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo0006
0?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0
003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o
000L0000o`L0oooo00060?ooojD0003oDP3o000L0000o`L0oooo00060?ooojD0003oDP3o000L0000
o`L0oooo00060?ooocL0003o=`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooolg0000ocL0o`00
=`000?lK0?l005<0003o1`3oool000H0oooo=`000?lg0?l003L0003o6`3o001C0000o`L0oooo0006
0?ooocL0003o=`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lK0?l0
05<0003o1`3oool000H0oooo=`000?lg0?l003L0003o6`3o001C0000o`L0oooo00060?ooocL0003o
=`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lK0?l005<0003o1`3o
ool000H0oooo=`000?lg0?l003L0003o6`3o001C0000o`L0oooo00060?ooocL0003o=`3o000g0000
oa/0o`00D`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lK0?l005<0003o1`3oool000H0oooo
=`000?lg0?l003L0003o6`3o001C0000o`L0oooo00060?ooocL0003o=`3o000g0000oa/0o`00D`00
0?l70?ooo`001P3ooolg0000ocL0o`00=`000?lK0?l005<0003o1`3oool000H0oooo=`000?lg0?l0
03L0003o6`3o001C0000o`L0oooo00060?ooocL0003o=`3o000g0000oa/0o`00D`000?l70?ooo`00
1P3ooolg0000ocL0o`00=`000?lK0?l005<0003o1`3oool000H0oooo=`000?lg0?l003L0003o6`3o
001C0000o`L0oooo00060?ooocL0003o=`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooolg0000
ocL0o`00=`000?lK0?l005<0003o1`3oool000H0oooo=`000?lg0?l003L0003o6`3o001C0000o`L0
oooo00060?ooocL0003o=`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooolg0000ocL0o`00=`00
0?lK0?l005<0003o1`3oool000H0oooo=`000?lg0?l003L0003o6`3o001C0000o`L0oooo00060?oo
ocL0003o=`3o000g0000oa/0o`00D`000?l70?ooo`001P3ooolg0000ocL0o`00=`000?lK0?l005<0
003o1`3oool000H0oooo=`000?lg0?l003L0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o
001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000
o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo
00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?oo
ojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o
6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C
0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0
oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo0006
0?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0
003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o
001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000
o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo
00060?ooojD0003o6`3o001C0000o`L0oooo00060?ooojD0003o6`3o001C0000o`L0oooo00060?oo
oa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`00
1P3ooolL0?l008T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3o
ool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000
o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00
=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@000?lg
0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0
003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo703o
00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000o`L0oooo00060?oo
oa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`00
1P3ooolL0?l008T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3o
ool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000
o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00
=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@000?lg
0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0
003o=`3o000g0000o`L0oooo00060?oooe<0o`00K@000?lL0?l003L0003o1`3oool000H0ooooD`3o
001]0000oa`0o`00=`000?l70?ooo`001P3ooomC0?l006d0003o703o000g0000o`L0oooo00060?oo
oe<0o`00K@000?lL0?l003L0003o1`3oool000H0ooooD`3o001]0000oa`0o`00=`000?l70?ooo`00
1P3ooomC0?l006d0003o703o000g0000o`L0oooo00060?oooe<0o`00K@000?lL0?l003L0003o1`3o
ool000H0ooooD`3o001]0000oa`0o`00=`000?l70?ooo`001P3ooomC0?l006d0003o703o000g0000
o`L0oooo00060?oooe<0o`00K@000?lL0?l003L0003o1`3oool000H0ooooD`3o001]0000oa`0o`00
=`000?l70?ooo`001P3ooomC0?l006d0003o703o000g0000o`L0oooo00060?oooe<0o`00K@000?lL
0?l003L0003o1`3oool000H0ooooD`3o001]0000oa`0o`00=`000?l70?ooo`001P3ooomC0?l006d0
003o703o000g0000o`L0oooo00060?oooe<0o`00K@000?lL0?l003L0003o1`3oool000H0ooooD`3o
001]0000oa`0o`00=`000?l70?ooo`001P3ooomC0?l006d0003o703o000g0000o`L0oooo00060?oo
oe<0o`00K@000?lL0?l003L0003o1`3oool000H0ooooD`3o001]0000oa`0o`00=`000?l70?ooo`00
1P3ooomC0?l006d0003o703o000g0000o`L0oooo00060?oooe<0o`00K@000?lL0?l003L0003o1`3o
ool000H0ooooD`3o001]0000oa`0o`00=`000?l70?ooo`001P3ooomC0?l006d0003o703o000g0000
o`L0oooo00060?oooe<0o`00K@000?lL0?l003L0003o1`3oool000H0ooooD`3o001]0000oa`0o`00
=`000?l70?ooo`001P3ooomC0?l006d0003o703o000g0000o`L0oooo00060?oooe<0o`00K@000?lL
0?l003L0003o1`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooomC0?l006d0003o703o000K0000oa`0o`00
1`3oool000H0ooooD`3o001]0000oa`0o`006`000?lL0?l000L0oooo00060?oooe<0o`00K@000?lL
0?l001/0003o703o00070?ooo`001P3ooomC0?l006d0003o703o000K0000oa`0o`001`3oool000H0
ooooD`3o001]0000oa`0o`006`000?lL0?l000L0oooo00060?oooe<0o`00K@000?lL0?l001/0003o
703o00070?ooo`001P3ooomC0?l006d0003o703o000K0000oa`0o`001`3oool000H0ooooD`3o001]
0000oa`0o`006`000?lL0?l000L0oooo00060?oooe<0o`00K@000?lL0?l001/0003o703o00070?oo
o`001P3ooomC0?l006d0003o703o000K0000oa`0o`001`3oool000H0ooooD`3o001]0000oa`0o`00
6`000?lL0?l000L0oooo00060?oooe<0o`00K@000?lL0?l001/0003o703o00070?ooo`001P3ooomC
0?l006d0003o703o000K0000oa`0o`001`3oool000H0ooooD`3o001]0000oa`0o`006`000?lL0?l0
00L0oooo00060?oooe<0o`00K@000?lL0?l001/0003o703o00070?ooo`001P3ooomC0?l006d0003o
703o000K0000oa`0o`001`3oool000H0ooooD`3o001]0000oa`0o`006`000?lL0?l000L0oooo0006
0?oooe<0o`00K@000?lL0?l001/0003o703o00070?ooo`001P3ooomC0?l006d0003o703o000K0000
oa`0o`001`3oool000H0ooooD`3o001]0000oa`0o`006`000?lL0?l000L0oooo00060?oooe<0o`00
K@000?lL0?l001/0003o703o00070?ooo`001P3ooomC0?l006d0003o703o000K0000oa`0o`001`3o
ool000H0ooooD`3o001]0000oa`0o`006`000?lL0?l000L0oooo00060?oooe<0o`00K@000?lL0?l0
01/0003o703o00070?ooo`001P3ooomC0?l006d0003o703o000K0000oa`0o`001`3oool000H0oooo
D`3o001]0000oa`0o`006`000?lL0?l000L0oooo00060?oooe<0o`00K@000?lL0?l001/0003o703o
00070?ooo`001P3ooomC0?l006d0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?mC0?l0
01/0003o703o00070?ooo`001P3ooon90000oe<0o`006`000?lL0?l000L0oooo00060?ooohT0003o
D`3o000K0000oa`0o`001`3oool000H0ooooR@000?mC0?l001/0003o703o00070?ooo`001P3ooon9
0000oe<0o`006`000?lL0?l000L0oooo00060?ooohT0003oD`3o000K0000oa`0o`001`3oool000H0
ooooR@000?mC0?l001/0003o703o00070?ooo`001P3ooon90000oe<0o`006`000?lL0?l000L0oooo
00060?ooohT0003oD`3o000K0000oa`0o`001`3oool000H0ooooR@000?mC0?l001/0003o703o0007
0?ooo`001P3ooon90000oe<0o`006`000?lL0?l000L0oooo00060?ooohT0003oD`3o000K0000oa`0
o`001`3oool000H0ooooR@000?mC0?l001/0003o703o00070?ooo`001P3ooon90000oe<0o`006`00
0?lL0?l000L0oooo00060?ooohT0003oD`3o000K0000oa`0o`001`3oool000H0ooooR@000?mC0?l0
01/0003o703o00070?ooo`001P3ooon90000oe<0o`006`000?lL0?l000L0oooo00060?ooohT0003o
D`3o000K0000oa`0o`001`3oool000H0ooooR@000?mC0?l001/0003o703o00070?ooo`001P3ooon9
0000oe<0o`006`000?lL0?l000L0oooo00060?ooohT0003oD`3o000K0000oa`0o`001`3oool000H0
ooooR@000?mC0?l001/0003o703o00070?ooo`001P3ooon90000oe<0o`006`000?lL0?l000L0oooo
00060?ooohT0003oD`3o000K0000oa`0o`001`3oool000H0ooooR@000?mC0?l001/0003o703o0007
0?ooo`001P3ooon90000oe<0o`006`000?lL0?l000L0oooo00060?ooohT0003oD`3o000K0000oa`0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
oooo=`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolg0000ocL0o`00=`000?m^0?l000L0oooo
00060?ooocL0003o=`3o000g0000ofh0o`001`3oool000H0oooo=`000?lg0?l003L0003oKP3o0007
0?ooo`001P3ooolg0000ocL0o`00=`000?m^0?l000L0oooo00060?ooocL0003o=`3o000g0000ofh0
o`001`3oool000H0oooo=`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolg0000ocL0o`00=`00
0?m^0?l000L0oooo00060?ooocL0003o=`3o000g0000ofh0o`001`3oool000H0oooo=`000?lg0?l0
03L0003oKP3o00070?ooo`001P3ooolg0000ocL0o`00=`000?m^0?l000L0oooo00060?ooocL0003o
=`3o000g0000ofh0o`001`3oool000H0oooo=`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolg
0000ocL0o`00=`000?m^0?l000L0oooo00060?ooocL0003o=`3o000g0000ofh0o`001`3oool000H0
oooo=`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolg0000ocL0o`00=`000?m^0?l000L0oooo
00060?ooocL0003o=`3o000g0000ofh0o`001`3oool000H0oooo=`000?lg0?l003L0003oKP3o0007
0?ooo`001P3ooolg0000ocL0o`00=`000?m^0?l000L0oooo00060?ooocL0003o=`3o000g0000ofh0
o`001`3oool000H0oooo=`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolg0000ocL0o`00=`00
0?m^0?l000L0oooo00060?ooocL0003o=`3o000g0000ofh0o`001`3oool000H0oooo=`000?lg0?l0
03L0003oKP3o00070?ooo`001P3ooolg0000ocL0o`00=`000?m^0?l000L0oooo00060?ooocL0003o
=`3o000g0000ofh0o`001`3oool000H0oooo=`000?lg0?l003L0003oKP3o00070?ooo`001P3ooolg
0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0
o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@00
0?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?oo
o`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3o
oolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000
ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00
Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l7
0?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`00
1P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg
0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0
o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@00
0?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?ooo`001P3ooolg0000ocL0o`00Y@000?l70?oo
o`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o
00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0
003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo0006
0?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg0?l000L0
oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooog0000?lg
0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool000H0oooo
g0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`001`3oool0
00H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000ocL0o`00
1`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3ooooL0000
ocL0o`001`3oool000H0oooog0000?lg0?l000L0oooo00060?ooom`0003o=`3o00070?ooo`001P3o
oon90000oa`0o`00DP000?lL0?l000L0oooo00060?ooohT0003o703o001B0000oa`0o`001`3oool0
00H0ooooR@000?lL0?l00580003o703o00070?ooo`001P3ooon90000oa`0o`00DP000?lL0?l000L0
oooo00060?ooohT0003o703o001B0000oa`0o`001`3oool000H0ooooR@000?lL0?l00580003o703o
00070?ooo`001P3ooon90000oa`0o`00DP000?lL0?l000L0oooo00060?ooohT0003o703o001B0000
oa`0o`001`3oool000H0ooooR@000?lL0?l00580003o703o00070?ooo`001P3ooon90000oa`0o`00
DP000?lL0?l000L0oooo00060?ooohT0003o703o001B0000oa`0o`001`3oool000H0ooooR@000?lL
0?l00580003o703o00070?ooo`001P3ooon90000oa`0o`00DP000?lL0?l000L0oooo00060?ooohT0
003o703o001B0000oa`0o`001`3oool000H0ooooR@000?lL0?l00580003o703o00070?ooo`001P3o
oon90000oa`0o`00DP000?lL0?l000L0oooo00060?ooohT0003o703o001B0000oa`0o`001`3oool0
00H0ooooR@000?lL0?l00580003o703o00070?ooo`001P3ooon90000oa`0o`00DP000?lL0?l000L0
oooo00060?ooohT0003o703o001B0000oa`0o`001`3oool000H0ooooR@000?lL0?l00580003o703o
00070?ooo`001P3ooon90000oa`0o`00DP000?lL0?l000L0oooo00060?ooohT0003o703o001B0000
oa`0o`001`3oool000H0ooooR@000?lL0?l00580003o703o00070?ooo`001P3ooon90000oa`0o`00
DP000?lL0?l000L0oooo00060?ooohT0003o703o001B0000oa`0o`001`3oool000H0ooooR@000?lL
0?l00580003o703o00070?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0
o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP00
0?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?oo
o`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3o
oon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000
oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00
KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l7
0?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`00
1P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon9
0000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0
o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP00
0?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?oo
o`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooonU0000oa/0o`00=`000?lL0?l000L0oooo
00060?ooojD0003o6`3o000g0000oa`0o`001`3oool000H0ooooY@000?lK0?l003L0003o703o0007
0?ooo`001P3ooonU0000oa/0o`00=`000?lL0?l000L0oooo00060?ooojD0003o6`3o000g0000oa`0
o`001`3oool000H0ooooY@000?lK0?l003L0003o703o00070?ooo`001P3ooonU0000oa/0o`00=`00
0?lL0?l000L0oooo00060?ooojD0003o6`3o000g0000oa`0o`001`3oool000H0ooooY@000?lK0?l0
03L0003o703o00070?ooo`001P3ooonU0000oa/0o`00=`000?lL0?l000L0oooo00060?ooojD0003o
6`3o000g0000oa`0o`001`3oool000H0ooooY@000?lK0?l003L0003o703o00070?ooo`001P3ooonU
0000oa/0o`00=`000?lL0?l000L0oooo00060?ooojD0003o6`3o000g0000oa`0o`001`3oool000H0
ooooY@000?lK0?l003L0003o703o00070?ooo`001P3ooonU0000oa/0o`00=`000?lL0?l000L0oooo
00060?ooojD0003o6`3o000g0000oa`0o`001`3oool000H0ooooY@000?lK0?l003L0003o703o0007
0?ooo`001P3ooonU0000oa/0o`00=`000?lL0?l000L0oooo00060?ooojD0003o6`3o000g0000oa`0
o`001`3oool000H0ooooY@000?lK0?l003L0003o703o00070?ooo`001P3ooonU0000oa/0o`00=`00
0?lL0?l000L0oooo00060?ooojD0003o6`3o000g0000oa`0o`001`3oool000H0ooooY@000?lK0?l0
03L0003o703o00070?ooo`001P3ooonU0000oa/0o`00=`000?lL0?l000L0oooo00060?ooojD0003o
6`3o000g0000oa`0o`001`3oool000H0ooooY@000?lK0?l003L0003o703o00070?ooo`001P3ooonU
0000oa/0o`00=`000?lL0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FF0000FFFF00000000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3o
oom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000
oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00
D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l7
0?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`00
1P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^
0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80
o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`00
0?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?oo
o`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3o
oom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000
oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00
D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l70?ooo`001P3ooom^0000oe80o`00D`000?l7
0?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`00
1P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo0
0?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0
003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o
00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?oo
o`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3o
ooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l0
01`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o
=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o0007
0?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`00
1P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo0
0?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0003o=`3o00070?ooo`001P3oooo00?l001`0
003o=`3o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo70000?lg
0?l008T0003o=`3o00070?ooo`001P3ooolL0000ocL0o`00R@000?lg0?l000L0oooo00060?oooa`0
003o=`3o00290000ocL0o`001`3oool000H0oooo70000?lg0?l008T0003o=`3o00070?ooo`001P3o
oolL0000ocL0o`00R@000?lg0?l000L0oooo00060?oooa`0003o=`3o00290000ocL0o`001`3oool0
00H0oooo70000?lg0?l008T0003o=`3o00070?ooo`001P3ooolL0000ocL0o`00R@000?lg0?l000L0
oooo00060?oooa`0003o=`3o00290000ocL0o`001`3oool000H0oooo70000?lg0?l008T0003o=`3o
00070?ooo`001P3ooolL0000ocL0o`00R@000?lg0?l000L0oooo00060?oooa`0003o=`3o00290000
ocL0o`001`3oool000H0oooo70000?lg0?l008T0003o=`3o00070?ooo`001P3ooolL0000ocL0o`00
R@000?lg0?l000L0oooo00060?oooa`0003o=`3o00290000ocL0o`001`3oool000H0oooo70000?lg
0?l008T0003o=`3o00070?ooo`001P3ooolL0000ocL0o`00R@000?lg0?l000L0oooo00060?oooa`0
003o=`3o00290000ocL0o`001`3oool000H0oooo70000?lg0?l008T0003o=`3o00070?ooo`001P3o
oolL0000ocL0o`00R@000?lg0?l000L0oooo00060?oooa`0003o=`3o00290000ocL0o`001`3oool0
00H0oooo70000?lg0?l008T0003o=`3o00070?ooo`001P3ooolL0000ocL0o`00R@000?lg0?l000L0
oooo00060?oooa`0003o=`3o00290000ocL0o`001`3oool000H0oooo70000?lg0?l008T0003o=`3o
00070?ooo`001P3ooolL0000ocL0o`00R@000?lg0?l000L0oooo00060?oooa`0003o=`3o00290000
ocL0o`001`3oool000H0ooooD`3o000f0000oa`0o`00KP000?l70?ooo`001P3ooomC0?l003H0003o
703o001^0000o`L0oooo00060?oooe<0o`00=P000?lL0?l006h0003o1`3oool000H0ooooD`3o000f
0000oa`0o`00KP000?l70?ooo`001P3ooomC0?l003H0003o703o001^0000o`L0oooo00060?oooe<0
o`00=P000?lL0?l006h0003o1`3oool000H0ooooD`3o000f0000oa`0o`00KP000?l70?ooo`001P3o
oomC0?l003H0003o703o001^0000o`L0oooo00060?oooe<0o`00=P000?lL0?l006h0003o1`3oool0
00H0ooooD`3o000f0000oa`0o`00KP000?l70?ooo`001P3ooomC0?l003H0003o703o001^0000o`L0
oooo00060?oooe<0o`00=P000?lL0?l006h0003o1`3oool000H0ooooD`3o000f0000oa`0o`00KP00
0?l70?ooo`001P3ooomC0?l003H0003o703o001^0000o`L0oooo00060?oooe<0o`00=P000?lL0?l0
06h0003o1`3oool000H0ooooD`3o000f0000oa`0o`00KP000?l70?ooo`001P3ooomC0?l003H0003o
703o001^0000o`L0oooo00060?oooe<0o`00=P000?lL0?l006h0003o1`3oool000H0ooooD`3o000f
0000oa`0o`00KP000?l70?ooo`001P3ooomC0?l003H0003o703o001^0000o`L0oooo00060?oooe<0
o`00=P000?lL0?l006h0003o1`3oool000H0ooooD`3o000f0000oa`0o`00KP000?l70?ooo`001P3o
oomC0?l003H0003o703o001^0000o`L0oooo00060?oooe<0o`00=P000?lL0?l006h0003o1`3oool0
00H0ooooD`3o000f0000oa`0o`00KP000?l70?ooo`001P3ooomC0?l003H0003o703o001^0000o`L0
oooo00060?oooe<0o`00=P000?lL0?l006h0003o1`3oool000H0ooooD`3o00300000o`L0oooo0006
0?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0
oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o0030
0000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0oooo
D`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool0
00H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o
1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l0
0<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3o
oomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?oo
o`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`000
0?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0oooo70000?lK0?l00580003o703o001^0000o`L0oooo
00060?oooa`0003o6`3o001B0000oa`0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00DP000?lL
0?l006h0003o1`3oool000H0oooo70000?lK0?l00580003o703o001^0000o`L0oooo00060?oooa`0
003o6`3o001B0000oa`0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00DP000?lL0?l006h0003o
1`3oool000H0oooo70000?lK0?l00580003o703o001^0000o`L0oooo00060?oooa`0003o6`3o001B
0000oa`0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00DP000?lL0?l006h0003o1`3oool000H0
oooo70000?lK0?l00580003o703o001^0000o`L0oooo00060?oooa`0003o6`3o001B0000oa`0o`00
KP000?l70?ooo`001P3ooolL0000oa/0o`00DP000?lL0?l006h0003o1`3oool000H0oooo70000?lK
0?l00580003o703o001^0000o`L0oooo00060?oooa`0003o6`3o001B0000oa`0o`00KP000?l70?oo
o`001P3ooolL0000oa/0o`00DP000?lL0?l006h0003o1`3oool000H0oooo70000?lK0?l00580003o
703o001^0000o`L0oooo00060?oooa`0003o6`3o001B0000oa`0o`00KP000?l70?ooo`001P3ooolL
0000oa/0o`00DP000?lL0?l006h0003o1`3oool000H0oooo70000?lK0?l00580003o703o001^0000
o`L0oooo00060?oooa`0003o6`3o001B0000oa`0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00
DP000?lL0?l006h0003o1`3oool000H0oooo70000?lK0?l00580003o703o001^0000o`L0oooo0006
0?oooa`0003o6`3o001B0000oa`0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00DP000?lL0?l0
06h0003o1`3oool000H0oooo70000?lK0?l00580003o703o001^0000o`L0oooo00060?oooa`0003o
6`3o001B0000oa`0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00DP000?lL0?l006h0003o1`3o
ool000H0oooo70000?lK0?l00580003o703o001^0000o`L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo
00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l00580003o703o0007
0?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0
o`001`3oool000H0oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP00
0?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l0
0580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003o
R@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL
0000ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0
oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo
00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l00580003o703o0007
0?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0
o`001`3oool000H0oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP00
0?lL0?l000L0oooo00060?oooa`0003oR@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l0
0580003o703o00070?ooo`001P3ooolL0000ohT0o`00DP000?lL0?l000L0oooo00060?oooa`0003o
R@3o001B0000oa`0o`001`3oool000H0oooo70000?n90?l00580003o703o00070?ooo`001P3ooolL
0000ohT0o`00DP000?lL0?l000L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?oo
o`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o
=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC
0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000
o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`00
6`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo0006
0?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l0
01`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003o
DP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3o
ool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000
ocL0o`0070000?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0oooo
D`000?mB0?l001/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`007000
0?l70?ooo`001P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l0
01/0003o=`3o000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`00
1P3ooomC0000oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o
000L0000o`L0oooo00060?oooe<0003oDP3o000K0000ocL0o`0070000?l70?ooo`001P3ooomC0000
oe80o`006`000?lg0?l001`0003o1`3oool000H0ooooD`000?mB0?l001/0003o=`3o000L0000o`L0
oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo0006
0?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0
003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o
000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000
o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo
00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oo
oe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003o
Y03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L
0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0
oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo0006
0?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0
003oY03o000L0000o`L0oooo00060?oooe<0003oY03o000L0000o`L0oooo00060?oooe<0003oY03o
000L0000o`L0oooo00060?ooocL0003o703o000K0000ohT0o`0070000?l70?ooo`001P3ooolg0000
oa`0o`006`000?n90?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0003oR@3o000L0000o`L0
oooo00060?ooocL0003o703o000K0000ohT0o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`00
0?n90?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0003oR@3o000L0000o`L0oooo00060?oo
ocL0003o703o000K0000ohT0o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`000?n90?l001`0
003o1`3oool000H0oooo=`000?lL0?l001/0003oR@3o000L0000o`L0oooo00060?ooocL0003o703o
000K0000ohT0o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`000?n90?l001`0003o1`3oool0
00H0oooo=`000?lL0?l001/0003oR@3o000L0000o`L0oooo00060?ooocL0003o703o000K0000ohT0
o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`000?n90?l001`0003o1`3oool000H0oooo=`00
0?lL0?l001/0003oR@3o000L0000o`L0oooo00060?ooocL0003o703o000K0000ohT0o`0070000?l7
0?ooo`001P3ooolg0000oa`0o`006`000?n90?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0
003oR@3o000L0000o`L0oooo00060?ooocL0003o703o000K0000ohT0o`0070000?l70?ooo`001P3o
oolg0000oa`0o`006`000?n90?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0003oR@3o000L
0000o`L0oooo00060?ooocL0003o703o000K0000ohT0o`0070000?l70?ooo`001P3ooolg0000oa`0
o`006`000?n90?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0003oR@3o000L0000o`L0oooo
00060?ooocL0003o703o000K0000ohT0o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`000?n9
0?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0003oR@3o000L0000o`L0oooo00060?ooocL0
003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o
00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000
o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo
00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?oo
ocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o
703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o0030
0000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0
oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo0006
0?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0
003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o
00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000
o`L0oooo00060?ooocL0003o703o00300000o`L0oooo00060?ooocL0003o703o00300000o`L0oooo
00060?ooocL0003o703o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l0
0<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3o
oomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?oo
o`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0o`00`000
0?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo00060?oooe<0
o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0oooo0006
0?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o00300000o`L0
oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0ooooD`3o0030
0000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool000H0oooo
D`3o00300000o`L0oooo00060?oooe<0o`00`0000?l70?ooo`001P3ooomC0?l00<00003o1`3oool0
00H0ooooD`3o00300000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o
1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l0
0=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3o
oolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?oo
o`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g000
0?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0
o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo0006
0?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0
oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L
0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo
=`3o003L0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3o
oooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo0006
0?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0
003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o
002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000
o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo
00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?oo
ocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003o
DP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:
0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0
oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo0006
0?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0
003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo00060?ooocL0003oDP3o
002:0000o`L0oooo00060?ooocL0003oDP3o002:0000o`L0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FFFF0000FF00000000FF0000FF0000FFFF00000000FF
FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`00
70000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL
0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000
oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`00
1P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o
001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l7
0?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0
003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`00
70000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL
0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000
oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`00
1P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o
001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l7
0?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0
003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`00
70000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL
0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000
oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`00
1P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o
001C0000oa/0o`0070000?l70?ooo`001P3ooolL0?l003L0003o=P3o001C0000oa/0o`0070000?l7
0?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g0000ocH0
o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3o
oolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g0000ocH0o`0070000?m^
0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolL0?l003L0
003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo
00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L
0000ofh0o`001`3oool000H0oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0
o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`00
1`3oool000H0oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf
0?l001`0003oKP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0
oooo703o000g0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003o
KP3o00070?ooo`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g
0000ocH0o`0070000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?oo
o`001P3ooolL0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g0000ocH0o`00
70000?m^0?l000L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolL
0?l003L0003o=P3o000L0000ofh0o`001`3oool000H0oooo703o000g0000ocH0o`0070000?m^0?l0
00L0oooo00060?oooa`0o`00=`000?lf0?l001`0003oKP3o00070?ooo`001P3ooolg0000om`0o`00
1`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000
om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3o
oolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?oo
o`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0003og03o
00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo00060?ooocL0
003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0oooo0006
0?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL0?l000L0
oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo=`000?oL
0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooolg0000om`0o`001`3oool000H0oooo
=`000?oL0?l000L0oooo00060?ooocL0003og03o00070?ooo`001P3ooomC0000ohT0o`00=`000?l7
0?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`00
1P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC
0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0
o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`00
0?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?oo
o`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3o
oomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000
ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00
=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l7
0?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`00
1P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooomC
0000ohT0o`00=`000?l70?ooo`001P3ooomC0000ohT0o`00=`000?l70?ooo`001P3ooolL0000oa/0
o`00=`000?n90?l001`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo
00060?oooa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n9
0?l001`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0
003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o
1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0003o6`3o000g
0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3oool000H0
oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0003o6`3o000g0000ohT0o`00
70000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3oool000H0oooo70000?lK
0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0003o6`3o000g0000ohT0o`0070000?l70?oo
o`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3oool000H0oooo70000?lK0?l003L0003o
R@3o000L0000o`L0oooo00060?oooa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL
0000oa/0o`00=`000?n90?l001`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000
o`L0oooo00060?oooa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00
=`000?n90?l001`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo0006
0?oooa`0003o6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l0
01`0003o1`3oool000H0oooo70000?lK0?l003L0003oR@3o000L0000o`L0oooo00060?oooa`0003o
6`3o000g0000ohT0o`0070000?l70?ooo`001P3ooolL0000oa/0o`00=`000?n90?l001`0003o1`3o
ool000H0oooo70000?lK0?l001`0003oY03o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000
oj@0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?nT0?l001`0003o1`3oool000H0oooo
70000?lK0?l001`0003oY03o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oj@0o`007000
0?l70?ooo`001P3ooolL0000oa/0o`0070000?nT0?l001`0003o1`3oool000H0oooo70000?lK0?l0
01`0003oY03o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oj@0o`0070000?l70?ooo`00
1P3ooolL0000oa/0o`0070000?nT0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003oY03o
000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolL0000
oa/0o`0070000?nT0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003oY03o000L0000o`L0
oooo00060?oooa`0003o6`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolL0000oa/0o`007000
0?nT0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003oY03o000L0000o`L0oooo00060?oo
oa`0003o6`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?nT0?l001`0
003o1`3oool000H0oooo70000?lK0?l001`0003oY03o000L0000o`L0oooo00060?oooa`0003o6`3o
000L0000oj@0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?nT0?l001`0003o1`3oool0
00H0oooo70000?lK0?l001`0003oY03o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oj@0
o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?nT0?l001`0003o1`3oool000H0oooo7000
0?lK0?l001`0003oY03o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oj@0o`0070000?l7
0?ooo`001P3ooolL0000oa/0o`0070000?nT0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0
003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3o
ool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0
ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@00
0?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l0
01`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o
1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool0
00H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0oooo
Y@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB
0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0
003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3o
ool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0
ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooKP00
0?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l7
0?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0
003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3o
oom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L
0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0
o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo
00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB
0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0
003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o
1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L
0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0
ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`00
70000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK
0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?oo
o`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003o
DP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^
0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000
o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`00
70000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo0006
0?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l0
01`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003o
K@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3o
ool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000
oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo
70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`007000
0?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l0
01`0003oDP3o000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`00
1P3ooolL0000ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o
000L0000o`L0oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000
ofd0o`0070000?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0
oooo00060?oooa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`007000
0?mB0?l001`0003o1`3oool000H0oooo70000?m]0?l001`0003oDP3o000L0000o`L0oooo00060?oo
oa`0003oK@3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000ofd0o`0070000?mB0?l001`0
003o1`3oool000H0oooo70000?m]0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003oK@3o
001C0000oa/0o`0070000?l70?ooo`001P3ooolL0000ofd0o`00D`000?lK0?l001`0003o1`3oool0
00H0oooo70000?m]0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003oK@3o001C0000oa/0
o`0070000?l70?ooo`001P3ooolL0000ofd0o`00D`000?lK0?l001`0003o1`3oool000H0oooo7000
0?m]0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003oK@3o001C0000oa/0o`0070000?l7
0?ooo`001P3ooolL0000ofd0o`00D`000?lK0?l001`0003o1`3oool000H0oooo70000?m]0?l005<0
003o6`3o000L0000o`L0oooo00060?oooa`0003oK@3o001C0000oa/0o`0070000?l70?ooo`001P3o
oolL0000ofd0o`00D`000?lK0?l001`0003o1`3oool000H0oooo70000?m]0?l005<0003o6`3o000L
0000o`L0oooo00060?oooa`0003oK@3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0000ofd0
o`00D`000?lK0?l001`0003o1`3oool000H0oooo70000?m]0?l005<0003o6`3o000L0000o`L0oooo
00060?oooa`0003oK@3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0000ofd0o`00D`000?lK
0?l001`0003o1`3oool000H0oooo70000?m]0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0
003oK@3o001C0000oa/0o`0070000?l70?ooo`001P3ooolL0000ofd0o`00D`000?lK0?l001`0003o
1`3oool000H0oooo70000?m]0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003oK@3o001C
0000oa/0o`0070000?l70?ooo`001P3ooolL0000ofd0o`00D`000?lK0?l001`0003o1`3oool000H0
oooo70000?m]0?l005<0003o6`3o000L0000o`L0oooo00060?oooa`0003oK@3o001C0000oa/0o`00
70000?l70?ooo`001P3ooolL0000ofd0o`00D`000?lK0?l001`0003o1`3oool000H0oooo70000?m]
0?l005<0003o6`3o000L0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF0000FF00000000FF0000FFFF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF00000000FF0000FF0000FFFF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0000oe80o`00=`000?lL0?l003L0003o
1`3oool000H0oooo=`000?mB0?l003L0003o703o000g0000o`L0oooo00060?ooocL0003oDP3o000g
0000oa`0o`00=`000?l70?ooo`001P3ooolg0000oe80o`00=`000?lL0?l003L0003o1`3oool000H0
oooo=`000?mB0?l003L0003o703o000g0000o`L0oooo00060?ooocL0003oDP3o000g0000oa`0o`00
=`000?l70?ooo`001P3ooolg0000oe80o`00=`000?lL0?l003L0003o1`3oool000H0oooo=`000?mB
0?l003L0003o703o000g0000o`L0oooo00060?ooocL0003oDP3o000g0000oa`0o`00=`000?l70?oo
o`001P3ooolg0000oe80o`00=`000?lL0?l003L0003o1`3oool000H0oooo=`000?mB0?l003L0003o
703o000g0000o`L0oooo00060?ooocL0003oDP3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolg
0000oe80o`00=`000?lL0?l003L0003o1`3oool000H0oooo=`000?mB0?l003L0003o703o000g0000
o`L0oooo00060?ooocL0003oDP3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolg0000oe80o`00
=`000?lL0?l003L0003o1`3oool000H0oooo=`000?mB0?l003L0003o703o000g0000o`L0oooo0006
0?ooocL0003oDP3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolg0000oe80o`00=`000?lL0?l0
03L0003o1`3oool000H0oooo=`000?mB0?l003L0003o703o000g0000o`L0oooo00060?ooocL0003o
DP3o000g0000oa`0o`00=`000?l70?ooo`001P3ooolg0000oe80o`00=`000?lL0?l003L0003o1`3o
ool000H0oooo=`000?mB0?l003L0003o703o000g0000o`L0oooo00060?ooocL0003oDP3o000g0000
oa`0o`00=`000?l70?ooo`001P3ooolg0000oe80o`00=`000?lL0?l003L0003o1`3oool000H0oooo
=`000?mB0?l003L0003o703o000g0000o`L0oooo00060?ooocL0003oDP3o000g0000oa`0o`00=`00
0?l70?ooo`001P3ooolg0000oe80o`00=`000?lL0?l003L0003o1`3oool000H0oooo=`000?o00?l0
01`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o
1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool0
00H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo
=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o0
0?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0
003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3o
ool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0
oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`00
0?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l0
01`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o
1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool0
00H0oooo=`000?o00?l001`0003o1`3oool000H0oooo=`000?o00?l001`0003o1`3oool000H0oooo
D`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n9
0?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0
003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3o
ool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0
ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`00
0?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l0
03L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o
1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool0
00H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0oooo
D`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n9
0?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0
003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3o
ool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0
o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^
0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`00
1P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o0007
0?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003o
Y@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?oo
ofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo
00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l0
00L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP00
0?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0
ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3o
ool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00
o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC
0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`00
1P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o0007
0?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o
`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oo
oe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo
00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l0
00L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`00
0?o00?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0
ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3o
ool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0
o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU
0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`00
1P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o0007
0?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003o
KP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?oo
ojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo
00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l0
00L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o
6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`00
0?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oo
oa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0
o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo
00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^
0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l0
00L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o
6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`00
0?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oo
oa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0
o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo
00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^
0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l0
00L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o
6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`00
0?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oo
oa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0
o`006`000?lL0?l000L0oooo00060?oooa`0003o6`3o001^0000ocL0o`006`000?lL0?l000L0oooo
00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC
0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0
003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o
1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K
0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0
oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00
=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB
0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?oo
o`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003o
D`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL
0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000
o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`00
6`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo0006
0?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l0
03L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003o
DP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3o
ool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000
oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo
70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`00
0?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l0
01/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`00
1P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o
000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000
oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0
oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`00
0?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oo
oa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0
003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o
000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool0
00H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0
o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo7000
0?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l7
0?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0
003oD`3o000g0000o`L0oooo00060?ooocL0003o=`3o001B0000oa`0o`00=`000?l70?ooo`001P3o
oolg0000ocL0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`000?lg0?l00580003o703o000g
0000o`L0oooo00060?ooocL0003o=`3o001B0000oa`0o`00=`000?l70?ooo`001P3ooolg0000ocL0
o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`000?lg0?l00580003o703o000g0000o`L0oooo
00060?ooocL0003o=`3o001B0000oa`0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00DP000?lL
0?l003L0003o1`3oool000H0oooo=`000?lg0?l00580003o703o000g0000o`L0oooo00060?ooocL0
003o=`3o001B0000oa`0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00DP000?lL0?l003L0003o
1`3oool000H0oooo=`000?lg0?l00580003o703o000g0000o`L0oooo00060?ooocL0003o=`3o001B
0000oa`0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00DP000?lL0?l003L0003o1`3oool000H0
oooo=`000?lg0?l00580003o703o000g0000o`L0oooo00060?ooocL0003o=`3o001B0000oa`0o`00
=`000?l70?ooo`001P3ooolg0000ocL0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`000?lg
0?l00580003o703o000g0000o`L0oooo00060?ooocL0003o=`3o001B0000oa`0o`00=`000?l70?oo
o`001P3ooolg0000ocL0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`000?lg0?l00580003o
703o000g0000o`L0oooo00060?ooocL0003o=`3o001B0000oa`0o`00=`000?l70?ooo`001P3ooolg
0000ocL0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`000?lg0?l00580003o703o000g0000
o`L0oooo00060?ooocL0003o=`3o001B0000oa`0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00
DP000?lL0?l003L0003o1`3oool000H0oooo=`000?lg0?l00580003o703o000g0000o`L0oooo0006
0?ooocL0003o=`3o001B0000oa`0o`00=`000?l70?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0000ocL0o`00=`000?mB0?l001`0003o
1`3oool000H0oooo=`000?lg0?l003L0003oDP3o000L0000o`L0oooo00060?ooocL0003o=`3o000g
0000oe80o`0070000?l70?ooo`001P3ooolg0000ocL0o`00=`000?mB0?l001`0003o1`3oool000H0
oooo=`000?lg0?l003L0003oDP3o000L0000o`L0oooo00060?ooocL0003o=`3o000g0000oe80o`00
70000?l70?ooo`001P3ooolg0000ocL0o`00=`000?mB0?l001`0003o1`3oool000H0oooo=`000?lg
0?l003L0003oDP3o000L0000o`L0oooo00060?ooocL0003o=`3o000g0000oe80o`0070000?l70?oo
o`001P3ooolg0000ocL0o`00=`000?mB0?l001`0003o1`3oool000H0oooo=`000?lg0?l003L0003o
DP3o000L0000o`L0oooo00060?ooocL0003o=`3o000g0000oe80o`0070000?l70?ooo`001P3ooolg
0000ocL0o`00=`000?mB0?l001`0003o1`3oool000H0oooo=`000?lg0?l003L0003oDP3o000L0000
o`L0oooo00060?ooocL0003o=`3o000g0000oe80o`0070000?l70?ooo`001P3ooolg0000ocL0o`00
=`000?mB0?l001`0003o1`3oool000H0oooo=`000?lg0?l003L0003oDP3o000L0000o`L0oooo0006
0?ooocL0003o=`3o000g0000oe80o`0070000?l70?ooo`001P3ooolg0000ocL0o`00=`000?mB0?l0
01`0003o1`3oool000H0oooo=`000?lg0?l003L0003oDP3o000L0000o`L0oooo00060?ooocL0003o
=`3o000g0000oe80o`0070000?l70?ooo`001P3ooolg0000ocL0o`00=`000?mB0?l001`0003o1`3o
ool000H0oooo=`000?lg0?l003L0003oDP3o000L0000o`L0oooo00060?ooocL0003o=`3o000g0000
oe80o`0070000?l70?ooo`001P3ooolg0000ocL0o`00=`000?mB0?l001`0003o1`3oool000H0oooo
=`000?lg0?l003L0003oDP3o000L0000o`L0oooo00060?ooocL0003o=`3o000g0000oe80o`007000
0?l70?ooo`001P3ooolg0000ocL0o`00=`000?mB0?l001`0003o1`3oool000H0ooooD`000?n90?l0
03L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o
1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool0
00H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0oooo
D`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n9
0?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0
003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3o
ool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0
ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`00
0?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l0
03L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o
1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool0
00H0ooooD`000?n90?l003L0003o1`3oool000H0ooooD`000?n90?l003L0003o1`3oool000H0oooo
R@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg
0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0
003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3o
ool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0
ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@00
0?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l0
05<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o
1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool0
00H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0oooo
R@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg
0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0
003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3oool000H0ooooR@000?lg0?l005<0003o1`3o
ool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0
ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`00
0?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l0
01`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o
1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool0
00H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0oooo
D`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT
0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0
003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3o
ool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0
ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`00
0?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l001`0003o1`3oool000H0ooooD`000?nT0?l0
01`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o
1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool0
00H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0oooo
Y@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB
0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0
003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3o
ool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0
ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@00
0?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l0
01`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o
1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool0
00H0ooooY@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0oooo
Y@000?mB0?l001`0003o1`3oool000H0ooooY@000?mB0?l001`0003o1`3oool000H0oooo=`3o000g
0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0
o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3o
ool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0
oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o
000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000
ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`00
1`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool0
00H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo
=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g
0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0
o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3o
ool000H0oooo=`3o000g0000ojD0o`001`3oool000H0oooo=`3o000g0000ojD0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo70000?og0?l000L0oooo
00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l0
00L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo7000
0?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0
oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0o`001`3o
ool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL0000ooL0
o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`001P3ooolL
0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o00070?ooo`00
1P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003om`3o0007
0?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo00060?oooa`0003o
m`3o00070?ooo`001P3ooolL0000ooL0o`001`3oool000H0oooo70000?og0?l000L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3o
oolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000
ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00
=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l7
0?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`00
1P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL
0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00
o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`00
0?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?oo
o`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3o
oolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000
ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00
=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l7
0?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`00
1P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg
0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0
o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`00
0?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?oo
o`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3o
oolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000
ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00
D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l7
0?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`00
1P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg
0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0
o`00D`000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000
oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`00
70000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l7
0?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`00
1P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC
0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0
o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l0
00L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@00
0?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0
ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3o
ool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0
o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU
0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`00
1P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o0007
0?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003o
KP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?oo
ojD0003oKP3o00070?ooo`001P3ooolL0000oa/0o`0070000?o00?l000L0oooo00060?oooa`0003o
6`3o000L0000ol00o`001`3oool000H0oooo70000?lK0?l001`0003o`03o00070?ooo`001P3ooolL
0000oa/0o`0070000?o00?l000L0oooo00060?oooa`0003o6`3o000L0000ol00o`001`3oool000H0
oooo70000?lK0?l001`0003o`03o00070?ooo`001P3ooolL0000oa/0o`0070000?o00?l000L0oooo
00060?oooa`0003o6`3o000L0000ol00o`001`3oool000H0oooo70000?lK0?l001`0003o`03o0007
0?ooo`001P3ooolL0000oa/0o`0070000?o00?l000L0oooo00060?oooa`0003o6`3o000L0000ol00
o`001`3oool000H0oooo70000?lK0?l001`0003o`03o00070?ooo`001P3ooolL0000oa/0o`007000
0?o00?l000L0oooo00060?oooa`0003o6`3o000L0000ol00o`001`3oool000H0oooo70000?lK0?l0
01`0003o`03o00070?ooo`001P3ooolL0000oa/0o`0070000?o00?l000L0oooo00060?oooa`0003o
6`3o000L0000ol00o`001`3oool000H0oooo70000?lK0?l001`0003o`03o00070?ooo`001P3ooolL
0000oa/0o`0070000?o00?l000L0oooo00060?oooa`0003o6`3o000L0000ol00o`001`3oool000H0
oooo70000?lK0?l001`0003o`03o00070?ooo`001P3ooolL0000oa/0o`0070000?o00?l000L0oooo
00060?oooa`0003o6`3o000L0000ol00o`001`3oool000H0oooo70000?lK0?l001`0003o`03o0007
0?ooo`001P3ooolL0000oa/0o`0070000?o00?l000L0oooo00060?oooa`0003o6`3o000L0000ol00
o`001`3oool000H0oooo70000?lK0?l001`0003o`03o00070?ooo`001P3ooolL0000oa/0o`007000
0?o00?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o
000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0
oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3o
ool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog0?l001`0
003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`001P3oooog
0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l70?ooo`00
1P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`0070000?l7
0?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?ooooL0o`00
70000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo00060?oo
ooL0o`0070000?l70?ooo`001P3oooog0?l001`0003o1`3oool000H0oooom`3o000L0000o`L0oooo
00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oo
ol00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`00
70000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg
0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0
oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo0006
0?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00
o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`007000
0?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l0
00L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo
00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oo
ol00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`00
70000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`007000
0?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l0
01`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003o
DP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L
0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0
o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3o
oon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool0
00H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0
oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`007000
0?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l0
01`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003o
DP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L
0000oe80o`0070000?l70?ooo`001P3ooon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0
o`0070000?mB0?l001`0003o1`3oool000H0ooooR@3o000L0000oe80o`0070000?l70?ooo`001P3o
oon90?l001`0003oDP3o000L0000o`L0oooo00060?ooohT0o`0070000?mB0?l001`0003o1`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo
00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0
003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o
001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000
oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`00
70000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon9
0?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0
ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo
00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0
003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o
001C0000o`L0oooo00060?ooohT0o`0070000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000
oa/0o`00D`000?l70?ooo`001P3ooon90?l001`0003o6`3o001C0000o`L0oooo00060?ooohT0o`00
70000?lK0?l005<0003o1`3oool000H0ooooR@3o000L0000oa/0o`00D`000?l70?ooo`001P3ooon9
0?l001`0003o6`3o001C0000o`L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo7000
0?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oo
oa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`00
1P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3o
ool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l0
00L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003o
D`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K
0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0
o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo7000
0?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oo
oa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`00
1P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3o
ool000H0oooo70000?n90?l001/0003oD`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l0
00L0oooo00060?oooa`0003oR@3o000K0000oe<0o`001`3oool000H0oooo70000?n90?l001/0003o
D`3o00070?ooo`001P3ooolL0000ohT0o`006`000?mC0?l000L0oooo00060?oool00o`0070000?lg
0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0
oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo0006
0?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00
o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`007000
0?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l0
00L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo
00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oo
ol00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`00
70000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg
0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0
oooo00060?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo0006
0?oool00o`0070000?lg0?l000L0oooo00060?oool00o`0070000?lg0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l0
01/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o
703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o0007
0?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`00
1P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL
0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0
003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o
00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?oo
o`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3o
oooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l0
01/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o
703o00070?ooo`001P3ooooL0?l001/0003o703o00070?ooo`001P3ooooL0?l001/0003o703o0007
0?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00
Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?oo
ofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo
00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o002U0000
o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0ooooKP3o
002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3oool000H0
ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0003o1`3o
ool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^0?l00:D0
003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`001P3ooom^
0?l00:D0003o1`3oool000H0ooooKP3o002U0000o`L0oooo00060?ooofh0o`00Y@000?l70?ooo`00
1P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL
0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80
o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@00
0?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?oo
o`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3o
oolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000
oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00
Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l7
0?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`00
1P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL
0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80
o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`001P3ooolL0000oe80o`00Y@00
0?l70?ooo`001P3ooolL0000oe80o`00Y@000?l70?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o
=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL
0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l0
03L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`00
1P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`00
0?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o0007
0?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80
o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o
=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL
0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l0
03L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`00
1P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`00
0?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o0007
0?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80
o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o
=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL
0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l0
03L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`00
1P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`00
0?lL0?l003L0003o=`3o00070?ooo`001P3ooolL0000oe80o`006`000?lL0?l003L0003o=`3o0007
0?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0
003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3o
oolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^
0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0
o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo
00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB
0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0
003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o
1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L
0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0
oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00
KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK
0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?oo
o`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003o
DP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL
0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000
o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3oooo00?l005<0003o
1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l0
05<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3o
ooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?oo
o`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`00
0?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00
o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo0006
0?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0
oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C
0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo
`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3o
ool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0
ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o
001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000
ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`00
1`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool0
00H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0oooo
KP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^
0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0
o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3o
ool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0
ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o
001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l0
06h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003o
DP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL
0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0
oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo
00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0003o=`3o0007
0?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0
o`001`3oool000H0oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP00
0?lg0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l0
06h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003o
DP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL
0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0
oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo
00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0003o=`3o0007
0?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0
o`001`3oool000H0ooooD`3o000K0000ocL0o`00=`000?lg0?l000L0oooo00060?oooe<0o`006`00
0?lg0?l003L0003o=`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000g0000ocL0o`001`3oool0
00H0ooooD`3o000K0000ocL0o`00=`000?lg0?l000L0oooo00060?oooe<0o`006`000?lg0?l003L0
003o=`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000g0000ocL0o`001`3oool000H0ooooD`3o
000K0000ocL0o`00=`000?lg0?l000L0oooo00060?oooe<0o`006`000?lg0?l003L0003o=`3o0007
0?ooo`001P3ooomC0?l001/0003o=`3o000g0000ocL0o`001`3oool000H0ooooD`3o000K0000ocL0
o`00=`000?lg0?l000L0oooo00060?oooe<0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3o
oomC0?l001/0003o=`3o000g0000ocL0o`001`3oool000H0ooooD`3o000K0000ocL0o`00=`000?lg
0?l000L0oooo00060?oooe<0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooomC0?l001/0
003o=`3o000g0000ocL0o`001`3oool000H0ooooD`3o000K0000ocL0o`00=`000?lg0?l000L0oooo
00060?oooe<0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000g
0000ocL0o`001`3oool000H0ooooD`3o000K0000ocL0o`00=`000?lg0?l000L0oooo00060?oooe<0
o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000g0000ocL0o`00
1`3oool000H0ooooD`3o000K0000ocL0o`00=`000?lg0?l000L0oooo00060?oooe<0o`006`000?lg
0?l003L0003o=`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000g0000ocL0o`001`3oool000H0
ooooD`3o000K0000ocL0o`00=`000?lg0?l000L0oooo00060?oooe<0o`006`000?lg0?l003L0003o
=`3o00070?ooo`001P3ooomC0?l001/0003o=`3o000g0000ocL0o`001`3oool000H0ooooD`3o000K
0000ocL0o`00=`000?lg0?l000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3o
oolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l0
03L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003o
Y@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o0007
0?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`00
1P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg
0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0
003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o
00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?oo
o`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3o
oolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l0
03L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003o
Y@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o0007
0?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oe80
o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3o
oolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oe80o`0070000?m^
0?l000L0oooo00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0
003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oe80o`0070000?m^0?l000L0oooo
00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L
0000ofh0o`001`3oool000H0oooo703o000K0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0
o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`00
1`3oool000H0oooo703o000K0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?mB
0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0
oooo703o000K0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?mB0?l001`0003o
KP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K
0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?oo
o`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oe80o`00
70000?m^0?l000L0oooo00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL
0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oe80o`0070000?m^0?l0
00L0oooo00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o
000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000
ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`00
1`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool0
00H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo
`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L
0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0
o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3o
ool000H0oooo`03o000L0000ocL0o`001`3oool000H0oooo`03o000L0000ocL0o`001`3oool000H0
ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o
001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000
ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`00
1`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool0
00H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0oooo
KP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^
0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0
o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3o
ool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0
ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o
001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000
ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`001`3oool000H0ooooKP3o001^0000ocL0o`00
1`3oool000H0oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg
0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0
003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o
001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000
oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0oooo
70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo0006
0?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0003o=`3o00070?oo
o`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0o`00
1`3oool000H0oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg
0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0
003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o
001^0000ocL0o`001`3oool000H0oooo70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000
oe80o`00KP000?lg0?l000L0oooo00060?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0oooo
70000?mB0?l006h0003o=`3o00070?ooo`001P3ooolL0000oe80o`00KP000?lg0?l000L0oooo0006
0?oooa`0003oDP3o001^0000ocL0o`001`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?oo
o`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o
1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L
0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0
o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P00
0?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l0
03H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0oooo
D`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo0006
0?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?oo
o`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o
1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L
0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0
o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P00
0?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l0
03H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0oooo
=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo0006
0?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?oo
o`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o
1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L
0000o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80
o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP00
0?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l0
06h0003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo
=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo0006
0?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?oo
o`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o
1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L
0000o`L0oooo00060?ooocL0o`00KP000?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80
o`0070000?l70?ooo`001P3ooolg0?l006h0003oDP3o000L0000o`L0oooo00060?ooocL0o`00KP00
0?mB0?l001`0003o1`3oool000H0oooo=`3o001^0000oe80o`0070000?l70?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FFFF00000000FF0000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`00
70000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL
0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000
ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`00
1P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o
001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l7
0?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0
003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`00
70000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL
0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000
ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`00
1P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o
001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l7
0?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0
003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`00
70000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL
0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000
ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`00
1P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o
001B0000ocL0o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o001B0000ocL0o`0070000?l7
0?ooo`001P3ooom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0
o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3o
oom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC
0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooom^0?l001/0
003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC0?l000L0oooo
00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooom^0?l001/0003o703o000K
0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0
o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooom^0?l001/0003o703o000K0000oe<0o`00
1`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL
0?l001/0003oD`3o00070?ooo`001P3ooom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0
ooooKP3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003o
D`3o00070?ooo`001P3ooom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K
0000oa`0o`006`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?oo
o`001P3ooom^0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`00
6`000?mC0?l000L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooom^
0?l001/0003o703o000K0000oe<0o`001`3oool000H0ooooKP3o000K0000oa`0o`006`000?mC0?l0
00L0oooo00060?ooofh0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0
003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o
00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?oo
o`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3o
oomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l0
01/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003o
Y@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o0007
0?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`00
1P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooomC
0?l001/0003oY@3o00070?ooo`001P3ooomC0?l001/0003oY@3o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o
000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000
oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`00
1`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool0
00H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K
0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o
000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000
oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`00
1`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool0
00H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K
0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0
o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3o
ool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0
ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o
000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000
oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`00
1`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool0
00H0ooooY@3o000K0000oe<0o`001`3oool000H0ooooY@3o000K0000oe<0o`001`3oool000H0oooo
Y@3o000K0000oe<0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0
ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o
000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000
ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`00
1`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool0
00H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo
D`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K
0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0
o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3oool000H0ooooD`3o000K0000ojD0o`001`3o
ool000H0ooooD`3o000K0000ojD0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l0
00L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o
6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0oooo0006
0?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000
ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0oooo00060?ooocL0o`00
=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000ofh0o`001`3o
ool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l0
01`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000ofh0o`001`3oool000H0oooo
=`3o000g0000oa/0o`0070000?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o
00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000
oa/0o`0070000?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`00
1P3ooolg0?l003L0003o6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`007000
0?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l0
03L0003o6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0
oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o
000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0oooo00060?oo
ocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000ofh0
o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3o
ool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0
oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o
001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000
ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`00
1`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool0
00H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo
703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]
0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0
o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3o
ool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0
oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o
001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FFFF00000000FFFF00000000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo
00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o0007
0?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?ooocL0003o703o000f0000ohX0
o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P00
0?n:0?l000L0oooo00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l0
03H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?ooocL0003o
703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg
0000oa`0o`00=P000?n:0?l000L0oooo00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0
oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo
00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o0007
0?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?ooocL0003o703o000f0000ohX0
o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P00
0?n:0?l000L0oooo00060?ooocL0003o703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l0
03H0003oRP3o00070?ooo`001P3ooolg0000oa`0o`00=P000?n:0?l000L0oooo00060?ooocL0003o
703o000f0000ohX0o`001`3oool000H0oooo=`000?lL0?l003H0003oRP3o00070?ooo`001P3ooolg
0000oa`0o`00=P000?n:0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0
o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`00
0?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l0
00L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo
00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oo
oe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`00
6`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU
0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0
oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo0006
0?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0
o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`00
0?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l0
00L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo
00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oo
oe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`00
6`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU
0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0
oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo0006
0?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0
o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`00
0?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l0
00L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo
00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oo
oe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`00
6`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooa`0o`00=`000?o0
0?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0
oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo0006
0?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0
o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`00
0?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l0
00L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo
00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oo
oa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00
=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o0
0?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0
oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo0006
0?oooa`0o`00=`000?o00?l000L0oooo00060?oooa`0o`00=`000?o00?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oolg0?l001`0003o6`3o000g0000ofh0o`001`3oool000H0oooo=`3o000L0000oa/0o`00=`000?m^
0?l000L0oooo00060?ooocL0o`0070000?lK0?l003L0003oKP3o00070?ooo`001P3ooolg0?l001`0
003o6`3o000g0000ofh0o`001`3oool000H0oooo=`3o000L0000oa/0o`00=`000?m^0?l000L0oooo
00060?ooocL0o`0070000?lK0?l003L0003oKP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000g
0000ofh0o`001`3oool000H0oooo=`3o000L0000oa/0o`00=`000?m^0?l000L0oooo00060?ooocL0
o`0070000?lK0?l003L0003oKP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000g0000ofh0o`00
1`3oool000H0oooo=`3o000L0000oa/0o`00=`000?m^0?l000L0oooo00060?ooocL0o`0070000?lK
0?l003L0003oKP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000g0000ofh0o`001`3oool000H0
oooo=`3o000L0000oa/0o`00=`000?m^0?l000L0oooo00060?ooocL0o`0070000?lK0?l003L0003o
KP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000g0000ofh0o`001`3oool000H0oooo=`3o000L
0000oa/0o`00=`000?m^0?l000L0oooo00060?ooocL0o`0070000?lK0?l003L0003oKP3o00070?oo
o`001P3ooolg0?l001`0003o6`3o000g0000ofh0o`001`3oool000H0oooo=`3o000L0000oa/0o`00
=`000?m^0?l000L0oooo00060?ooocL0o`0070000?lK0?l003L0003oKP3o00070?ooo`001P3ooolg
0?l001`0003o6`3o000g0000ofh0o`001`3oool000H0oooo=`3o000L0000oa/0o`00=`000?m^0?l0
00L0oooo00060?ooocL0o`0070000?lK0?l003L0003oKP3o00070?ooo`001P3ooolg0?l001`0003o
6`3o000g0000ofh0o`001`3oool000H0oooo=`3o000L0000oa/0o`00=`000?m^0?l000L0oooo0006
0?ooocL0o`0070000?lK0?l003L0003oKP3o00070?ooo`001P3ooolL0?l003L0003o6`3o000K0000
oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?lK0?l001/0003o703o000K0000oe<0
o`001`3oool000H0oooo703o000g0000oa/0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3o
oolL0?l003L0003o6`3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?lK
0?l001/0003o703o000K0000oe<0o`001`3oool000H0oooo703o000g0000oa/0o`006`000?lL0?l0
01/0003oD`3o00070?ooo`001P3ooolL0?l003L0003o6`3o000K0000oa`0o`006`000?mC0?l000L0
oooo00060?oooa`0o`00=`000?lK0?l001/0003o703o000K0000oe<0o`001`3oool000H0oooo703o
000g0000oa/0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003o6`3o000K
0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?lK0?l001/0003o703o000K0000
oe<0o`001`3oool000H0oooo703o000g0000oa/0o`006`000?lL0?l001/0003oD`3o00070?ooo`00
1P3ooolL0?l003L0003o6`3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`00
0?lK0?l001/0003o703o000K0000oe<0o`001`3oool000H0oooo703o000g0000oa/0o`006`000?lL
0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003o6`3o000K0000oa`0o`006`000?mC0?l0
00L0oooo00060?oooa`0o`00=`000?lK0?l001/0003o703o000K0000oe<0o`001`3oool000H0oooo
703o000g0000oa/0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003o6`3o
000K0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00=`000?lK0?l001/0003o703o000K
0000oe<0o`001`3oool000H0oooo703o000g0000oa/0o`006`000?lL0?l001/0003oD`3o00070?oo
o`001P3ooolL0?l003L0003o6`3o000K0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00
=`000?lK0?l001/0003o703o000K0000oe<0o`001`3oool000H0oooo703o000g0000oa/0o`006`00
0?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l003L0003o6`3o000K0000oa`0o`006`000?mC
0?l000L0oooo00060?oooa`0o`00=`000?lK0?l001/0003o703o000K0000oe<0o`001`3oool000H0
oooo703o000g0000oa/0o`006`000?lL0?l001/0003oD`3o00070?ooo`001P3ooolg0000ol00o`00
70000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l7
0?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`00
1P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg
0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00
o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`007000
0?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?oo
o`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3o
oolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000
ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`00
70000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l7
0?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`00
1P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg0000ol00o`0070000?l70?ooo`001P3ooolg
0000ol00o`0070000?l70?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF0000FF0000
0000FF0000FFFF00000000FFFF00000000FFFF0000FF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3o
oolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l0
03L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003o
Y@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o0007
0?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`00
1P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg
0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0
003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o
00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?oo
o`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3o
oolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l0
03L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003o
Y@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0
o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3o
ool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0
ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o
000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000
ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`00
1`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool0
00H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0oooo
KP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000K
0000ohX0o`001`3oool000H0ooooKP3o000K0000ohX0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o
000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000
ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`00
1`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool0
00H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0oooo
KP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g
0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0
o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3o
ool000H0ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0
ooooKP3o000g0000ofh0o`001`3oool000H0ooooKP3o000g0000ofh0o`001`3oool000H0oooo703o
000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f
0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000
oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`00
1P3ooolL0?l001/0003o703o000f0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`00
0?lL0?l003H0003o703o000K0000oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lL
0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0o`006`000?mC0?l0
00L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0o`001`3oool000H0oooo
703o000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o
000f0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K
0000oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?oo
o`001P3ooolL0?l001/0003o703o000f0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`00
6`000?lL0?l003H0003o703o000K0000oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00=P00
0?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0o`006`000?mC
0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0o`001`3oool000H0
oooo703o000K0000oa`0o`00=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o
703o000f0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o
000K0000oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00=P000?lL0?l001/0003oD`3o0007
0?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0o`006`000?mC0?l000L0oooo00060?oooa`0
o`006`000?lL0?l003H0003o703o000K0000oe<0o`001`3oool000H0oooo703o000K0000oa`0o`00
=P000?lL0?l001/0003oD`3o00070?ooo`001P3ooolL0?l001/0003o703o000f0000oa`0o`006`00
0?mC0?l000L0oooo00060?oooa`0o`006`000?lL0?l003H0003o703o000K0000oe<0o`001`3oool0
00H0oooo=`000?lL0?l001/0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oa`0
o`006`000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003o703o000K0000oa/0o`00
70000?mB0?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0003o6`3o000L0000oe80o`007000
0?l70?ooo`001P3ooolg0000oa`0o`006`000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?oo
ocL0003o703o000K0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0
003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`000?lK0?l001`0003o
DP3o000L0000o`L0oooo00060?ooocL0003o703o000K0000oa/0o`0070000?mB0?l001`0003o1`3o
ool000H0oooo=`000?lL0?l001/0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000
oa`0o`006`000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003o703o000K0000oa/0
o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0003o6`3o000L0000oe80o`00
70000?l70?ooo`001P3ooolg0000oa`0o`006`000?lK0?l001`0003oDP3o000L0000o`L0oooo0006
0?ooocL0003o703o000K0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?lL0?l0
01/0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`000?lK0?l001`0
003oDP3o000L0000o`L0oooo00060?ooocL0003o703o000K0000oa/0o`0070000?mB0?l001`0003o
1`3oool000H0oooo=`000?lL0?l001/0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooolg
0000oa`0o`006`000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003o703o000K0000
oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?lL0?l001/0003o6`3o000L0000oe80
o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`000?lK0?l001`0003oDP3o000L0000o`L0oooo
00060?ooocL0003o703o000K0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?lL
0?l001/0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oa`0o`006`000?lK0?l0
01`0003oDP3o000L0000o`L0oooo00060?ooocL0003o703o000K0000oa/0o`0070000?mB0?l001`0
003o1`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`00
0?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l0
01/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o
=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL
0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0
oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo
00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o0007
0?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0
o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`00
0?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l0
01/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o
=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL
0000ocL0o`006`000?nU0?l000L0oooo00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0
oooo70000?lg0?l001/0003oY@3o00070?ooo`001P3ooolL0000ocL0o`006`000?nU0?l000L0oooo
00060?oooa`0003o=`3o000K0000ojD0o`001`3oool000H0oooo70000?lg0?l001/0003oY@3o0007
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF00000000FF
0000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00
503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo=`000?mB0?l0
01`0003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`00
1P3ooolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o
000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000
oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L0000o`L0
oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oe80o`007000
0?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L0000o`L0oooo00060?oo
ocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?mB0?l001`0
003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o
000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?mB0?l001`0003o1`3oool0
00H0oooo=`000?mB0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80
o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`00
0?mB0?l001`0003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l7
0?ooo`001P3ooolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0
003oDP3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3o
oolg0000oe80o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003oDP3o000L
0000o`L0oooo00060?ooocL0003oDP3o000L0000oe80o`0070000?l70?ooo`001P3ooolg0000oe80
o`0070000?mB0?l001`0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`00
0?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l0
05<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o
1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool0
00H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo
=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n9
0?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0
003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3o
ool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0
oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`00
0?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l0
05<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o
1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l7
0?ooo`001P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0
003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o
000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0oooo703o001B0000
ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00
DP000?m^0?l003L0003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL
0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0
oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o000g0000o`L0oooo
00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l7
0?ooo`001P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0
003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o
000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0oooo703o001B0000
ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00
DP000?m^0?l003L0003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL
0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0
ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo
00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l7
0?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0
003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o
000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000
ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00
=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC
0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0
ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo
00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l7
0?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0
003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o
000L0000o`L0oooo00060?oooe<0o`00=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000
ofh0o`0070000?l70?ooo`001P3ooomC0?l003H0003oKP3o000L0000o`L0oooo00060?oooe<0o`00
=P000?m^0?l001`0003o1`3oool000H0ooooD`3o000f0000ofh0o`0070000?l70?ooo`001P3ooomC
0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580
003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o
00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?oo
o`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3o
oomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l0
0580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003o
KP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o0007
0?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`00
1P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC
0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580
003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o
00070?ooo`001P3ooomC0?l00580003oKP3o00070?ooo`001P3ooomC0?l00580003oKP3o00070?oo
o`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3o
oolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l0
06d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003o
RP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o0007
0?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`00
1P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL
0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0
003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o
00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?oo
o`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3o
oolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l0
06d0003oRP3o00070?ooo`001P3ooolL0?l006d0003oRP3o00070?ooo`001P3ooolL0?l006d0003o
RP3o00070?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK
0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?oo
o`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003o
DP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^
0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000
o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`00
70000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo0006
0?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l0
01`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o
6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3o
ool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000
oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo
KP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`007000
0?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l0
01`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`00
1P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o
000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooolL0000
oa/0o`00DP000?n:0?l000L0oooo00060?oooa`0003o6`3o001B0000ohX0o`001`3oool000H0oooo
70000?lK0?l00580003oRP3o00070?ooo`001P3ooolL0000oa/0o`00DP000?n:0?l000L0oooo0006
0?oooa`0003o6`3o001B0000ohX0o`001`3oool000H0oooo70000?lK0?l00580003oRP3o00070?oo
o`001P3ooolL0000oa/0o`00DP000?n:0?l000L0oooo00060?oooa`0003o6`3o001B0000ohX0o`00
1`3oool000H0oooo70000?lK0?l00580003oRP3o00070?ooo`001P3ooolL0000oa/0o`00DP000?n:
0?l000L0oooo00060?oooa`0003o6`3o001B0000ohX0o`001`3oool000H0oooo70000?lK0?l00580
003oRP3o00070?ooo`001P3ooolL0000oa/0o`00DP000?n:0?l000L0oooo00060?oooa`0003o6`3o
001B0000ohX0o`001`3oool000H0oooo70000?lK0?l00580003oRP3o00070?ooo`001P3ooolL0000
oa/0o`00DP000?n:0?l000L0oooo00060?oooa`0003o6`3o001B0000ohX0o`001`3oool000H0oooo
70000?lK0?l00580003oRP3o00070?ooo`001P3ooolL0000oa/0o`00DP000?n:0?l000L0oooo0006
0?oooa`0003o6`3o001B0000ohX0o`001`3oool000H0oooo70000?lK0?l00580003oRP3o00070?oo
o`001P3ooolL0000oa/0o`00DP000?n:0?l000L0oooo00060?oooa`0003o6`3o001B0000ohX0o`00
1`3oool000H0oooo70000?lK0?l00580003oRP3o00070?ooo`001P3ooolL0000oa/0o`00DP000?n:
0?l000L0oooo00060?oooa`0003o6`3o001B0000ohX0o`001`3oool000H0oooo70000?lK0?l00580
003oRP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000ohX0o`001`3oool000H0oooo=`3o
000L0000oa/0o`006`000?n:0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oRP3o0007
0?ooo`001P3ooolg0?l001`0003o6`3o000K0000ohX0o`001`3oool000H0oooo=`3o000L0000oa/0
o`006`000?n:0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oRP3o00070?ooo`001P3o
oolg0?l001`0003o6`3o000K0000ohX0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?n:
0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oRP3o00070?ooo`001P3ooolg0?l001`0
003o6`3o000K0000ohX0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?n:0?l000L0oooo
00060?ooocL0o`0070000?lK0?l001/0003oRP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000K
0000ohX0o`001`3oool000H0oooo=`3o000L0000oa/0o`006`000?n:0?l000L0oooo00060?ooocL0
o`0070000?lK0?l001/0003oRP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000ohX0o`00
1`3oool000H0oooo=`3o000L0000oa/0o`006`000?n:0?l000L0oooo00060?ooocL0o`0070000?lK
0?l001/0003oRP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000ohX0o`001`3oool000H0
oooo=`3o000L0000oa/0o`006`000?n:0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003o
RP3o00070?ooo`001P3ooolg0?l001`0003o6`3o000K0000ohX0o`001`3oool000H0oooo=`3o000L
0000oa/0o`006`000?n:0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oRP3o00070?oo
o`001P3ooolg0?l001`0003o6`3o000K0000ohX0o`001`3oool000H0oooo=`3o000L0000oa/0o`00
6`000?n:0?l000L0oooo00060?ooocL0o`0070000?lK0?l001/0003oRP3o00070?ooo`001P3ooolg
0?l001`0003o6`3o000K0000ohX0o`001`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FFFF00000000FFFF00000000FF0000FF0000FFFF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000
oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`00
70000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l7
0?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`00
1P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC
0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0
o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000
oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`00
70000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l7
0?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0
003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3o
oolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g
0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80
o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo
00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC
0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0
003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o
1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K
0000oe<0o`00=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0
oooo70000?mB0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00
=`000?l70?ooo`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB
0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?oo
o`001P3ooolL0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003o
D`3o000g0000o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL
0000oe80o`006`000?mC0?l003L0003o1`3oool000H0oooo70000?mB0?l001/0003oD`3o000g0000
o`L0oooo00060?oooa`0003oDP3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolL0000ol00o`00
=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l7
0?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`00
1P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL
0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00
o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`00
0?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?oo
o`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3o
oolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000
ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00
=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l7
0?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`00
1P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL0000ol00o`00=`000?l70?ooo`001P3ooolL
0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0
o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`007000
0?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?oo
o`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3o
oolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000
om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`00
70000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l7
0?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`00
1P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL
0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0
o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`007000
0?l70?ooo`001P3ooolL0000om/0o`0070000?l70?ooo`001P3ooolL0000om/0o`0070000?l70?oo
o`001P3ooolL0000ohT0o`006`000?lL0?l003L0003o1`3oool000H0oooo70000?n90?l001/0003o
703o000g0000o`L0oooo00060?oooa`0003oR@3o000K0000oa`0o`00=`000?l70?ooo`001P3ooolL
0000ohT0o`006`000?lL0?l003L0003o1`3oool000H0oooo70000?n90?l001/0003o703o000g0000
o`L0oooo00060?oooa`0003oR@3o000K0000oa`0o`00=`000?l70?ooo`001P3ooolL0000ohT0o`00
6`000?lL0?l003L0003o1`3oool000H0oooo70000?n90?l001/0003o703o000g0000o`L0oooo0006
0?oooa`0003oR@3o000K0000oa`0o`00=`000?l70?ooo`001P3ooolL0000ohT0o`006`000?lL0?l0
03L0003o1`3oool000H0oooo70000?n90?l001/0003o703o000g0000o`L0oooo00060?oooa`0003o
R@3o000K0000oa`0o`00=`000?l70?ooo`001P3ooolL0000ohT0o`006`000?lL0?l003L0003o1`3o
ool000H0oooo70000?n90?l001/0003o703o000g0000o`L0oooo00060?oooa`0003oR@3o000K0000
oa`0o`00=`000?l70?ooo`001P3ooolL0000ohT0o`006`000?lL0?l003L0003o1`3oool000H0oooo
70000?n90?l001/0003o703o000g0000o`L0oooo00060?oooa`0003oR@3o000K0000oa`0o`00=`00
0?l70?ooo`001P3ooolL0000ohT0o`006`000?lL0?l003L0003o1`3oool000H0oooo70000?n90?l0
01/0003o703o000g0000o`L0oooo00060?oooa`0003oR@3o000K0000oa`0o`00=`000?l70?ooo`00
1P3ooolL0000ohT0o`006`000?lL0?l003L0003o1`3oool000H0oooo70000?n90?l001/0003o703o
000g0000o`L0oooo00060?oooa`0003oR@3o000K0000oa`0o`00=`000?l70?ooo`001P3ooolL0000
ohT0o`006`000?lL0?l003L0003o1`3oool000H0oooo70000?n90?l001/0003o703o000g0000o`L0
oooo00060?oooa`0003oR@3o000K0000oa`0o`00=`000?l70?ooo`001P3ooolL0000ohT0o`006`00
0?lL0?l003L0003o1`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000
ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`00
1`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool0
00H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo
703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]
0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0
o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3o
ool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0
oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o
001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000
ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`00
1`3oool000H0oooo703o001]0000ohX0o`001`3oool000H0oooo703o001]0000ohX0o`001`3oool0
00H0oooo703o001]0000ohX0o`001`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0oooo
KP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n9
0?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0
003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3o
ool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0
ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP00
0?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l0
01`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o
1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool0
00H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0oooo
KP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n9
0?l001`0003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0ooooKP000?n90?l001`0
003o1`3oool000H0ooooKP000?n90?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o
000K0000oa`0o`00DP000?lL0?l000L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?lL
0?l00580003o703o00070?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003o703o001B0000
oa`0o`001`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l000L0
oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?lL0?l00580003o703o00070?ooo`001P3o
oolL0000oa/0o`0070000?lK0?l001/0003o703o001B0000oa`0o`001`3oool000H0oooo70000?lK
0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l000L0oooo00060?oooa`0003o6`3o000L0000
oa/0o`006`000?lL0?l00580003o703o00070?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0
003o703o001B0000oa`0o`001`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000oa`0o`00
DP000?lL0?l000L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?lL0?l00580003o703o
00070?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003o703o001B0000oa`0o`001`3oool0
00H0oooo70000?lK0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l000L0oooo00060?oooa`0
003o6`3o000L0000oa/0o`006`000?lL0?l00580003o703o00070?ooo`001P3ooolL0000oa/0o`00
70000?lK0?l001/0003o703o001B0000oa`0o`001`3oool000H0oooo70000?lK0?l001`0003o6`3o
000K0000oa`0o`00DP000?lL0?l000L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?lL
0?l00580003o703o00070?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003o703o001B0000
oa`0o`001`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l000L0
oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?lL0?l00580003o703o00070?ooo`001P3o
oolL0000oa/0o`0070000?lK0?l001/0003o703o001B0000oa`0o`001`3oool000H0oooo70000?lK
0?l001`0003o6`3o000K0000oa`0o`00DP000?lL0?l000L0oooo00060?oooa`0003o6`3o000L0000
oa/0o`006`000?lL0?l00580003o703o00070?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0
003o703o001B0000oa`0o`001`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000oa`0o`00
DP000?lL0?l000L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?lL0?l00580003o703o
00070?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003o703o001B0000oa`0o`001`3oool0
00H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo
703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g
0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00
o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3o
ool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0
oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o
000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000
ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`00
1`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool0
00H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo
703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g
0000ol00o`001`3oool000H0oooo703o000g0000ol00o`001`3oool000H0oooo703o000g0000ol00
o`001`3oool000H0oooo703o001B0000ohT0o`0070000?l70?ooo`001P3ooolL0?l00580003oR@3o
000L0000o`L0oooo00060?oooa`0o`00DP000?n90?l001`0003o1`3oool000H0oooo703o001B0000
ohT0o`0070000?l70?ooo`001P3ooolL0?l00580003oR@3o000L0000o`L0oooo00060?oooa`0o`00
DP000?n90?l001`0003o1`3oool000H0oooo703o001B0000ohT0o`0070000?l70?ooo`001P3ooolL
0?l00580003oR@3o000L0000o`L0oooo00060?oooa`0o`00DP000?n90?l001`0003o1`3oool000H0
oooo703o001B0000ohT0o`0070000?l70?ooo`001P3ooolL0?l00580003oR@3o000L0000o`L0oooo
00060?oooa`0o`00DP000?n90?l001`0003o1`3oool000H0oooo703o001B0000ohT0o`0070000?l7
0?ooo`001P3ooolL0?l00580003oR@3o000L0000o`L0oooo00060?oooa`0o`00DP000?n90?l001`0
003o1`3oool000H0oooo703o001B0000ohT0o`0070000?l70?ooo`001P3ooolL0?l00580003oR@3o
000L0000o`L0oooo00060?oooa`0o`00DP000?n90?l001`0003o1`3oool000H0oooo703o001B0000
ohT0o`0070000?l70?ooo`001P3ooolL0?l00580003oR@3o000L0000o`L0oooo00060?oooa`0o`00
DP000?n90?l001`0003o1`3oool000H0oooo703o001B0000ohT0o`0070000?l70?ooo`001P3ooolL
0?l00580003oR@3o000L0000o`L0oooo00060?oooa`0o`00DP000?n90?l001`0003o1`3oool000H0
oooo703o001B0000ohT0o`0070000?l70?ooo`001P3ooolL0?l00580003oR@3o000L0000o`L0oooo
00060?oooa`0o`00DP000?n90?l001`0003o1`3oool000H0oooo703o001B0000ohT0o`0070000?l7
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FFFF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000
0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3o
oolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000
ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00
=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l7
0?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`00
1P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg
0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0
o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`00
0?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?oo
o`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3o
oolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000
ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00
=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l70?ooo`001P3ooolg0000ojD0o`00=`000?l7
0?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0
003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3o
oolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^
0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0
o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo
00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg
0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0
003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o
1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K
0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0
oooo=`000?lL0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00
KP000?l70?ooo`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL
0?l001/0003o=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?oo
o`001P3ooolg0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o
=`3o001^0000o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg
0000oa`0o`006`000?lg0?l006h0003o1`3oool000H0oooo=`000?lL0?l001/0003o=`3o001^0000
o`L0oooo00060?ooocL0003o703o000K0000ocL0o`00KP000?l70?ooo`001P3ooolg0000oa`0o`00
6`000?mB0?l005<0003o1`3oool000H0oooo=`000?lL0?l001/0003oDP3o001C0000o`L0oooo0006
0?ooocL0003o703o000K0000oe80o`00D`000?l70?ooo`001P3ooolg0000oa`0o`006`000?mB0?l0
05<0003o1`3oool000H0oooo=`000?lL0?l001/0003oDP3o001C0000o`L0oooo00060?ooocL0003o
703o000K0000oe80o`00D`000?l70?ooo`001P3ooolg0000oa`0o`006`000?mB0?l005<0003o1`3o
ool000H0oooo=`000?lL0?l001/0003oDP3o001C0000o`L0oooo00060?ooocL0003o703o000K0000
oe80o`00D`000?l70?ooo`001P3ooolg0000oa`0o`006`000?mB0?l005<0003o1`3oool000H0oooo
=`000?lL0?l001/0003oDP3o001C0000o`L0oooo00060?ooocL0003o703o000K0000oe80o`00D`00
0?l70?ooo`001P3ooolg0000oa`0o`006`000?mB0?l005<0003o1`3oool000H0oooo=`000?lL0?l0
01/0003oDP3o001C0000o`L0oooo00060?ooocL0003o703o000K0000oe80o`00D`000?l70?ooo`00
1P3ooolg0000oa`0o`006`000?mB0?l005<0003o1`3oool000H0oooo=`000?lL0?l001/0003oDP3o
001C0000o`L0oooo00060?ooocL0003o703o000K0000oe80o`00D`000?l70?ooo`001P3ooolg0000
oa`0o`006`000?mB0?l005<0003o1`3oool000H0oooo=`000?lL0?l001/0003oDP3o001C0000o`L0
oooo00060?ooocL0003o703o000K0000oe80o`00D`000?l70?ooo`001P3ooolg0000oa`0o`006`00
0?mB0?l005<0003o1`3oool000H0oooo=`000?lL0?l001/0003oDP3o001C0000o`L0oooo00060?oo
ocL0003o703o000K0000oe80o`00D`000?l70?ooo`001P3ooolg0000oa`0o`006`000?mB0?l005<0
003o1`3oool000H0oooo=`000?lL0?l001/0003oDP3o001C0000o`L0oooo00060?ooocL0003o703o
000K0000oe80o`00D`000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000
ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00
KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l7
0?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`00
1P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg
0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0
o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP00
0?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?oo
o`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3o
oolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000
ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00
KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolg0000ofh0o`00KP000?l7
0?ooo`001P3ooolg0000ofh0o`00KP000?l70?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0
o`001`3oool000H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@00
0?lK0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool0
00H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0
003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0oooo703o
00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o=`3o0007
0?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0oooo703o00290000oa/0
o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o=`3o00070?ooo`001P3o
oolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0oooo703o00290000oa/0o`0070000?lg
0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0
003o6`3o000L0000ocL0o`001`3oool000H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo
00060?oooa`0o`00R@000?lK0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L
0000ocL0o`001`3oool000H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0
o`00R@000?lK0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`00
1`3oool000H0oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK
0?l001`0003o=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0
oooo703o00290000oa/0o`0070000?lg0?l000L0oooo00060?oooa`0o`00R@000?lK0?l001`0003o
=`3o00070?ooo`001P3ooolL0?l008T0003o6`3o000L0000ocL0o`001`3oool000H0ooooKP000?lK
0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?oo
o`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003o
DP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^
0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000
o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`00
70000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo0006
0?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l0
01`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o
6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3o
ool000H0ooooKP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000
oe80o`0070000?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0oooo
KP000?lK0?l001`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`007000
0?l70?ooo`001P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l0
01`0003oDP3o000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`00
1P3ooom^0000oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooKP000?lK0?l001`0003oDP3o
000L0000o`L0oooo00060?ooofh0003o6`3o000L0000oe80o`0070000?l70?ooo`001P3ooom^0000
oa/0o`0070000?mB0?l001`0003o1`3oool000H0ooooD`000?n90?l001/0003o703o00070?ooo`00
1P3ooomC0000ohT0o`006`000?lL0?l000L0oooo00060?oooe<0003oR@3o000K0000oa`0o`001`3o
ool000H0ooooD`000?n90?l001/0003o703o00070?ooo`001P3ooomC0000ohT0o`006`000?lL0?l0
00L0oooo00060?oooe<0003oR@3o000K0000oa`0o`001`3oool000H0ooooD`000?n90?l001/0003o
703o00070?ooo`001P3ooomC0000ohT0o`006`000?lL0?l000L0oooo00060?oooe<0003oR@3o000K
0000oa`0o`001`3oool000H0ooooD`000?n90?l001/0003o703o00070?ooo`001P3ooomC0000ohT0
o`006`000?lL0?l000L0oooo00060?oooe<0003oR@3o000K0000oa`0o`001`3oool000H0ooooD`00
0?n90?l001/0003o703o00070?ooo`001P3ooomC0000ohT0o`006`000?lL0?l000L0oooo00060?oo
oe<0003oR@3o000K0000oa`0o`001`3oool000H0ooooD`000?n90?l001/0003o703o00070?ooo`00
1P3ooomC0000ohT0o`006`000?lL0?l000L0oooo00060?oooe<0003oR@3o000K0000oa`0o`001`3o
ool000H0ooooD`000?n90?l001/0003o703o00070?ooo`001P3ooomC0000ohT0o`006`000?lL0?l0
00L0oooo00060?oooe<0003oR@3o000K0000oa`0o`001`3oool000H0ooooD`000?n90?l001/0003o
703o00070?ooo`001P3ooomC0000ohT0o`006`000?lL0?l000L0oooo00060?oooe<0003oR@3o000K
0000oa`0o`001`3oool000H0ooooD`000?n90?l001/0003o703o00070?ooo`001P3ooomC0000ohT0
o`006`000?lL0?l000L0oooo00060?oooe<0003oR@3o000K0000oa`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
00H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo
703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K
0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0
o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3o
ool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0
oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o
000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000
om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`00
1`3oool000H0oooo703o000K0000om`0o`001`3oool000H0oooo703o000K0000om`0o`001`3oool0
00H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU
0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0
003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3o
ool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0
oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`00
0?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l0
03L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o
1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool0
00H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo
=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU
0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0
003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3o
ool000H0oooo=`000?nU0?l003L0003o1`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FF
0000FFFF00000000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FFFF00000000FFFF0000FF0000FF00000000FF0000FF
FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo
00060?oooa`0003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o0007
0?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003oY03o000g0000oa`0
o`001`3oool000H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`00
0?lL0?l000L0oooo00060?oooa`0003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l0
03L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003o
Y03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3ooolL
0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003oY03o000g0000oa`0o`001`3oool000H0
oooo70000?nT0?l003L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo
00060?oooa`0003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o0007
0?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003oY03o000g0000oa`0
o`001`3oool000H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`00
0?lL0?l000L0oooo00060?oooa`0003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l0
03L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003o
Y03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3ooolL
0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003o6`3o000L0000ocH0o`0070000?lK0?l0
05<0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o000L0000oa/0o`00D`000?l70?ooo`00
1P3ooolL0000oa/0o`0070000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooa`0003o6`3o
000L0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o000L
0000oa/0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?lf0?l001`0003o6`3o001C0000
o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0oooo
70000?lK0?l001`0003o=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`007000
0?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`0070000?lK
0?l005<0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o000L0000oa/0o`00D`000?l70?oo
o`001P3ooolL0000oa/0o`0070000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooa`0003o
6`3o000L0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o
000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?lf0?l001`0003o6`3o001C
0000o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0
oooo70000?lK0?l001`0003o=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`00
70000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`007000
0?lK0?l005<0003o1`3oool000H0oooo70000?lK0?l001`0003o=P3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooolL0000oa/0o`0070000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooa`0
003o6`3o000L0000ocH0o`0070000?lK0?l005<0003o1`3oool000H0oooo70000?lK0?l001`0003o
=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0000oa/0o`0070000?lf0?l001`0003o6`3o
001C0000o`L0oooo00060?oooa`0003o6`3o000L0000ocH0o`0070000?lK0?l005<0003o1`3oool0
00H0oooo70000?lK0?l001`0003o=P3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0000oa/0
o`0070000?lf0?l001`0003o6`3o001C0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00
KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK
0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?oo
o`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003o
DP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL
0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000
o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00
70000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo0006
0?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l0
06h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o
6`3o000L0000oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3o
ool000H0oooo70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000
oe80o`00KP000?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo
70000?lK0?l001`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP00
0?l70?ooo`001P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l0
01`0003oDP3o001^0000o`L0oooo00060?oooa`0003o6`3o000L0000oe80o`00KP000?l70?ooo`00
1P3ooolL0000oa/0o`0070000?mB0?l006h0003o1`3oool000H0oooo70000?lK0?l001`0003oDP3o
001^0000o`L0oooo00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l0
0:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o
6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL
0000oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0
oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo
00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o0007
0?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0
o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@00
0?lg0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l0
0:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o
6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL
0000oa/0o`00Y@000?lg0?l000L0oooo00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0
oooo70000?lK0?l00:D0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo
00060?oooa`0003o6`3o002U0000ocL0o`001`3oool000H0oooo70000?lK0?l00:D0003o=`3o0007
0?ooo`001P3ooolL0000oa/0o`00Y@000?lg0?l000L0oooo00060?oool00003o=`3o000L0000o`L0
oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo0006
0?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00
003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o
000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000
o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo
00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oo
ol00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o
=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L
0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0
oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo0006
0?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00
003o=`3o000L0000o`L0oooo00060?oool00003o=`3o000L0000o`L0oooo00060?oool00003o=`3o
000L0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000
oa/0o`006`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0
oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`00
0?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo00060?oo
oe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC0?l003L0
003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo00060?oooe<0003o6`3o
000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC0?l003L0003o1`3oool0
00H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0
o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC0?l003L0003o1`3oool000H0ooooD`00
0?lK0?l001/0003oD`3o000g0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l7
0?ooo`001P3ooomC0000oa/0o`006`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0
003oD`3o000g0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3o
oomC0000oa/0o`006`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g
0000o`L0oooo00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0
o`006`000?mC0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo
00060?oooe<0003o6`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooomC0000oa/0o`006`000?mC
0?l003L0003o1`3oool000H0ooooD`000?lK0?l001/0003oD`3o000g0000o`L0oooo00060?oooa`0
o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`00
1`3oool000H0oooo703o000K0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?mB
0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0
oooo703o000K0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?mB0?l001`0003o
KP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K
0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?oo
o`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oe80o`00
70000?m^0?l000L0oooo00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL
0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oe80o`0070000?m^0?l0
00L0oooo00060?oooa`0o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003o
DP3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oe80o`0070000?m^0?l000L0oooo0006
0?oooa`0o`006`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000
ofh0o`001`3oool000H0oooo703o000K0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0o`00
6`000?mB0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3o
ool000H0oooo703o000K0000oe80o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?mB0?l0
01`0003oKP3o00070?ooo`001P3ooolL0?l001/0003oDP3o000L0000ofh0o`001`3oool000H0oooo
703o000K0000oe80o`0070000?m^0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo0006
0?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0
o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`00
0?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l0
00L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo
00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oo
oe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`00
6`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU
0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0
oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo0006
0?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0
o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`00
0?nU0?l000L0oooo00060?oooe<0o`006`000?nU0?l000L0oooo00060?oooe<0o`006`000?lK0?l0
01`0003oKP3o00070?ooo`001P3ooomC0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0oooo
D`3o000K0000oa/0o`0070000?m^0?l000L0oooo00060?oooe<0o`006`000?lK0?l001`0003oKP3o
00070?ooo`001P3ooomC0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0ooooD`3o000K0000
oa/0o`0070000?m^0?l000L0oooo00060?oooe<0o`006`000?lK0?l001`0003oKP3o00070?ooo`00
1P3ooomC0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0ooooD`3o000K0000oa/0o`007000
0?m^0?l000L0oooo00060?oooe<0o`006`000?lK0?l001`0003oKP3o00070?ooo`001P3ooomC0?l0
01/0003o6`3o000L0000ofh0o`001`3oool000H0ooooD`3o000K0000oa/0o`0070000?m^0?l000L0
oooo00060?oooe<0o`006`000?lK0?l001`0003oKP3o00070?ooo`001P3ooomC0?l001/0003o6`3o
000L0000ofh0o`001`3oool000H0ooooD`3o000K0000oa/0o`0070000?m^0?l000L0oooo00060?oo
oe<0o`006`000?lK0?l001`0003oKP3o00070?ooo`001P3ooomC0?l001/0003o6`3o000L0000ofh0
o`001`3oool000H0ooooD`3o000K0000oa/0o`0070000?m^0?l000L0oooo00060?oooe<0o`006`00
0?lK0?l001`0003oKP3o00070?ooo`001P3ooomC0?l001/0003o6`3o000L0000ofh0o`001`3oool0
00H0ooooD`3o000K0000oa/0o`0070000?m^0?l000L0oooo00060?oooe<0o`006`000?lK0?l001`0
003oKP3o00070?ooo`001P3ooomC0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0ooooD`3o
000K0000oa/0o`0070000?m^0?l000L0oooo00060?oooe<0o`006`000?lK0?l001`0003oKP3o0007
0?ooo`001P3ooomC0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0ooooD`3o000K0000oa/0
o`0070000?m^0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`00
0?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l0
00L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo
00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oo
ol00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00
=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL
0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0
oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo0006
0?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00
o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`00
0?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l0
00L0oooo00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo
00060?oool00o`00=`000?lL0?l000L0oooo00060?oool00o`00=`000?lL0?l000L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
FF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF00000000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o
001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0
oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3o
ool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0
003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`001P3oooo0
0?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l70?ooo`00
1P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00D`000?l7
0?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oool00o`00
D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo00060?oo
ol00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0oooo`03o001C0000o`L0oooo
00060?oool00o`00D`000?l70?ooo`001P3oooo00?l005<0003o1`3oool000H0ooooY@3o001^0000
o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o
001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0
ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3o
ool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0
003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU
0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`00
1P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l7
0?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00
KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?oo
ojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooD`3o002T0000oa`0o`00
1`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool0
00H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0oooo
D`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T
0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0
o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3o
ool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0
ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o
002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000
oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`00
1`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool0
00H0ooooD`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0oooo
D`3o002T0000oa`0o`001`3oool000H0ooooD`3o002T0000oa`0o`001`3oool000H0oooo703o002T
0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l00:@0003o703o000g0000o`L0oooo00060?oooa`0
o`00Y0000?lL0?l003L0003o1`3oool000H0oooo703o002T0000oa`0o`00=`000?l70?ooo`001P3o
oolL0?l00:@0003o703o000g0000o`L0oooo00060?oooa`0o`00Y0000?lL0?l003L0003o1`3oool0
00H0oooo703o002T0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l00:@0003o703o000g0000o`L0
oooo00060?oooa`0o`00Y0000?lL0?l003L0003o1`3oool000H0oooo703o002T0000oa`0o`00=`00
0?l70?ooo`001P3ooolL0?l00:@0003o703o000g0000o`L0oooo00060?oooa`0o`00Y0000?lL0?l0
03L0003o1`3oool000H0oooo703o002T0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l00:@0003o
703o000g0000o`L0oooo00060?oooa`0o`00Y0000?lL0?l003L0003o1`3oool000H0oooo703o002T
0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l00:@0003o703o000g0000o`L0oooo00060?oooa`0
o`00Y0000?lL0?l003L0003o1`3oool000H0oooo703o002T0000oa`0o`00=`000?l70?ooo`001P3o
oolL0?l00:@0003o703o000g0000o`L0oooo00060?oooa`0o`00Y0000?lL0?l003L0003o1`3oool0
00H0oooo703o002T0000oa`0o`00=`000?l70?ooo`001P3ooolL0?l00:@0003o703o000g0000o`L0
oooo00060?oooa`0o`00Y0000?lL0?l003L0003o1`3oool000H0oooo703o002T0000oa`0o`00=`00
0?l70?ooo`001P3ooolL0?l00:@0003o703o000g0000o`L0oooo00060?oooa`0o`00Y0000?lL0?l0
03L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o
1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool0
00H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0oooo
Y@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg
0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0
003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3o
ool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0
ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@00
0?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l0
03L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o
1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool0
00H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0oooo
Y@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0oooo703o000K
0000oa`0o`006`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003o703o000K0000
oa/0o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?lL0?l001/0003o6`3o000L0000ofh0
o`001`3oool000H0oooo703o000K0000oa`0o`006`000?lK0?l001`0003oKP3o00070?ooo`001P3o
oolL0?l001/0003o703o000K0000oa/0o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?lL
0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oa`0o`006`000?lK0?l0
01`0003oKP3o00070?ooo`001P3ooolL0?l001/0003o703o000K0000oa/0o`0070000?m^0?l000L0
oooo00060?oooa`0o`006`000?lL0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0oooo703o
000K0000oa`0o`006`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003o703o000K
0000oa/0o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?lL0?l001/0003o6`3o000L0000
ofh0o`001`3oool000H0oooo703o000K0000oa`0o`006`000?lK0?l001`0003oKP3o00070?ooo`00
1P3ooolL0?l001/0003o703o000K0000oa/0o`0070000?m^0?l000L0oooo00060?oooa`0o`006`00
0?lL0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oa`0o`006`000?lK
0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003o703o000K0000oa/0o`0070000?m^0?l0
00L0oooo00060?oooa`0o`006`000?lL0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0oooo
703o000K0000oa`0o`006`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003o703o
000K0000oa/0o`0070000?m^0?l000L0oooo00060?oooa`0o`006`000?lL0?l001/0003o6`3o000L
0000ofh0o`001`3oool000H0oooo703o000K0000oa`0o`006`000?lK0?l001`0003oKP3o00070?oo
o`001P3ooolL0?l001/0003o703o000K0000oa/0o`0070000?m^0?l000L0oooo00060?oooa`0o`00
6`000?lL0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0oooo703o000K0000oa`0o`006`00
0?lK0?l001`0003oKP3o00070?ooo`001P3ooolL0?l001/0003o703o000K0000oa/0o`0070000?m^
0?l000L0oooo00060?oooa`0o`006`000?lL0?l001/0003o6`3o000L0000ofh0o`001`3oool000H0
ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o
000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000
ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`00
1`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool0
00H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0oooo
D`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f
0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0
o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3o
ool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0
ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o
000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000
ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`001`3oool000H0ooooD`3o000f0000ohX0o`00
1`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l0
01@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3o
oooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?oo
o`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o
00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0
o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo0006
0?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0
oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D
0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0oooo
o`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool0
00H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo
`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g
0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0
o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3o
ool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0
oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o
000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000
oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`00
1`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool0
00H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo
`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g
0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0o`001`3oool000H0oooo`03o000g0000oa`0
o`001`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o
000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg
0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0
oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`00
6`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3o
ool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000
ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0
003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o
000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg
0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0
oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`00
6`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3o
ool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000
ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0
003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o
000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg
0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0
oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`00
6`000?lg0?l005<0003o1`3oool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3o
ool000H0oooo703o000K0000ocL0o`006`000?lg0?l005<0003o1`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
0000FFFF00000000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l001/0003oKP3o001^0000o`L0oooo
00060?oooa`0o`006`000?m^0?l006h0003o1`3oool000H0oooo703o000K0000ofh0o`00KP000?l7
0?ooo`001P3ooolL0?l001/0003oKP3o001^0000o`L0oooo00060?oooa`0o`006`000?m^0?l006h0
003o1`3oool000H0oooo703o000K0000ofh0o`00KP000?l70?ooo`001P3ooolL0?l001/0003oKP3o
001^0000o`L0oooo00060?oooa`0o`006`000?m^0?l006h0003o1`3oool000H0oooo703o000K0000
ofh0o`00KP000?l70?ooo`001P3ooolL0?l001/0003oKP3o001^0000o`L0oooo00060?oooa`0o`00
6`000?m^0?l006h0003o1`3oool000H0oooo703o000K0000ofh0o`00KP000?l70?ooo`001P3ooolL
0?l001/0003oKP3o001^0000o`L0oooo00060?oooa`0o`006`000?m^0?l006h0003o1`3oool000H0
oooo703o000K0000ofh0o`00KP000?l70?ooo`001P3ooolL0?l001/0003oKP3o001^0000o`L0oooo
00060?oooa`0o`006`000?m^0?l006h0003o1`3oool000H0oooo703o000K0000ofh0o`00KP000?l7
0?ooo`001P3ooolL0?l001/0003oKP3o001^0000o`L0oooo00060?oooa`0o`006`000?m^0?l006h0
003o1`3oool000H0oooo703o000K0000ofh0o`00KP000?l70?ooo`001P3ooolL0?l001/0003oKP3o
001^0000o`L0oooo00060?oooa`0o`006`000?m^0?l006h0003o1`3oool000H0oooo703o000K0000
ofh0o`00KP000?l70?ooo`001P3ooolL0?l001/0003oKP3o001^0000o`L0oooo00060?oooa`0o`00
6`000?m^0?l006h0003o1`3oool000H0oooo703o000K0000ofh0o`00KP000?l70?ooo`001P3ooolL
0?l001/0003oKP3o001^0000o`L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0
o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP00
0?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l0
00L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo
00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?oo
ohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00
KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL
0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0
oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo0006
0?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0
o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP00
0?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooohT0o`00KP000?lL0?l0
00L0oooo00060?ooohT0o`00KP000?lL0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo
00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?oo
ocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00
R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC
0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0
oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo0006
0?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0
o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@00
0?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l0
00L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo
00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?oo
ocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooocL0o`00
R@000?mC0?l000L0oooo00060?ooocL0o`00R@000?mC0?l000L0oooo00060?ooojD0003oKP3o0007
0?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003o
KP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?oo
ojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo
00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l0
00L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@00
0?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0
ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3o
ool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0
o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU
0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`00
1P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o0007
0?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003o
KP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?oo
ojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo
00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l0
00L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@00
0?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0
ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3o
ool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0
o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooolL
0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000
oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0
o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo
00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK
0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l0
01/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0
003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3o
oolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L
0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000
ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0
oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo7000
0?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK
0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l0
01`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`00
1P3ooolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o
000L0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K
0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`0070000?lK0?l001/0003oKP3o000L0000
o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0oooo
70000?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooolL0000oa/0o`007000
0?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooa`0003o6`3o000L0000oa/0o`006`000?m^
0?l001`0003o1`3oool000H0oooo70000?lK0?l001`0003o6`3o000K0000ofh0o`0070000?l70?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o0007
0?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`00
1P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg
0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0
003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o
00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?oo
o`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3o
oolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l0
01`0003o`03o00070?ooo`001P3ooolg0?l001`0003o`03o00070?ooo`001P3ooolg0?l001`0003o
`03o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?oo
ool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo
00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l0
00L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0ooooo`3o
000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3oool000H0
ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0o`001`3o
ool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo0?l001@0
o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`001P3ooooo
0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o00070?ooo`00
1P3ooooo0?l001@0o`001`3oool000H0ooooo`3o000D0?l000L0oooo00060?ooool0o`00503o0007
0?ooo`001P3ooolL0?l001/0003oKP3o000g0000ocL0o`001`3oool000H0oooo703o000K0000ofh0
o`00=`000?lg0?l000L0oooo00060?oooa`0o`006`000?m^0?l003L0003o=`3o00070?ooo`001P3o
oolL0?l001/0003oKP3o000g0000ocL0o`001`3oool000H0oooo703o000K0000ofh0o`00=`000?lg
0?l000L0oooo00060?oooa`0o`006`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolL0?l001/0
003oKP3o000g0000ocL0o`001`3oool000H0oooo703o000K0000ofh0o`00=`000?lg0?l000L0oooo
00060?oooa`0o`006`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000g
0000ocL0o`001`3oool000H0oooo703o000K0000ofh0o`00=`000?lg0?l000L0oooo00060?oooa`0
o`006`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000g0000ocL0o`00
1`3oool000H0oooo703o000K0000ofh0o`00=`000?lg0?l000L0oooo00060?oooa`0o`006`000?m^
0?l003L0003o=`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000g0000ocL0o`001`3oool000H0
oooo703o000K0000ofh0o`00=`000?lg0?l000L0oooo00060?oooa`0o`006`000?m^0?l003L0003o
=`3o00070?ooo`001P3ooolL0?l001/0003oKP3o000g0000ocL0o`001`3oool000H0oooo703o000K
0000ofh0o`00=`000?lg0?l000L0oooo00060?oooa`0o`006`000?m^0?l003L0003o=`3o00070?oo
o`001P3ooolL0?l001/0003oKP3o000g0000ocL0o`001`3oool000H0oooo703o000K0000ofh0o`00
=`000?lg0?l000L0oooo00060?oooa`0o`006`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolL
0?l001/0003oKP3o000g0000ocL0o`001`3oool000H0oooo703o000K0000ofh0o`00=`000?lg0?l0
00L0oooo00060?oooa`0o`006`000?m^0?l003L0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00
=`000?lg0?l006h0003o1`3oool000H0oooo70000?lK0?l003L0003o=`3o001^0000o`L0oooo0006
0?oooa`0003o6`3o000g0000ocL0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00=`000?lg0?l0
06h0003o1`3oool000H0oooo70000?lK0?l003L0003o=`3o001^0000o`L0oooo00060?oooa`0003o
6`3o000g0000ocL0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00=`000?lg0?l006h0003o1`3o
ool000H0oooo70000?lK0?l003L0003o=`3o001^0000o`L0oooo00060?oooa`0003o6`3o000g0000
ocL0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00=`000?lg0?l006h0003o1`3oool000H0oooo
70000?lK0?l003L0003o=`3o001^0000o`L0oooo00060?oooa`0003o6`3o000g0000ocL0o`00KP00
0?l70?ooo`001P3ooolL0000oa/0o`00=`000?lg0?l006h0003o1`3oool000H0oooo70000?lK0?l0
03L0003o=`3o001^0000o`L0oooo00060?oooa`0003o6`3o000g0000ocL0o`00KP000?l70?ooo`00
1P3ooolL0000oa/0o`00=`000?lg0?l006h0003o1`3oool000H0oooo70000?lK0?l003L0003o=`3o
001^0000o`L0oooo00060?oooa`0003o6`3o000g0000ocL0o`00KP000?l70?ooo`001P3ooolL0000
oa/0o`00=`000?lg0?l006h0003o1`3oool000H0oooo70000?lK0?l003L0003o=`3o001^0000o`L0
oooo00060?oooa`0003o6`3o000g0000ocL0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00=`00
0?lg0?l006h0003o1`3oool000H0oooo70000?lK0?l003L0003o=`3o001^0000o`L0oooo00060?oo
oa`0003o6`3o000g0000ocL0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00=`000?lg0?l006h0
003o1`3oool000H0oooo70000?lK0?l003L0003o=`3o001^0000o`L0oooo00060?oooa`0003o6`3o
000g0000ocL0o`00KP000?l70?ooo`001P3ooolL0000oa/0o`00=`000?lg0?l006h0003o1`3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF00000000FF0000FF0000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0000oe80o`00R@000?lL0?l000L0oooo
00060?oooa`0003oDP3o00290000oa`0o`001`3oool000H0oooo70000?mB0?l008T0003o703o0007
0?ooo`001P3ooolL0000oe80o`00R@000?lL0?l000L0oooo00060?oooa`0003oDP3o00290000oa`0
o`001`3oool000H0oooo70000?mB0?l008T0003o703o00070?ooo`001P3ooolL0000oe80o`00R@00
0?lL0?l000L0oooo00060?oooa`0003oDP3o00290000oa`0o`001`3oool000H0oooo70000?mB0?l0
08T0003o703o00070?ooo`001P3ooolL0000oe80o`00R@000?lL0?l000L0oooo00060?oooa`0003o
DP3o00290000oa`0o`001`3oool000H0oooo70000?mB0?l008T0003o703o00070?ooo`001P3ooolL
0000oe80o`00R@000?lL0?l000L0oooo00060?oooa`0003oDP3o00290000oa`0o`001`3oool000H0
oooo70000?mB0?l008T0003o703o00070?ooo`001P3ooolL0000oe80o`00R@000?lL0?l000L0oooo
00060?oooa`0003oDP3o00290000oa`0o`001`3oool000H0oooo70000?mB0?l008T0003o703o0007
0?ooo`001P3ooolL0000oe80o`00R@000?lL0?l000L0oooo00060?oooa`0003oDP3o00290000oa`0
o`001`3oool000H0oooo70000?mB0?l008T0003o703o00070?ooo`001P3ooolL0000oe80o`00R@00
0?lL0?l000L0oooo00060?oooa`0003oDP3o00290000oa`0o`001`3oool000H0oooo70000?mB0?l0
08T0003o703o00070?ooo`001P3ooolL0000oe80o`00R@000?lL0?l000L0oooo00060?oooa`0003o
DP3o00290000oa`0o`001`3oool000H0oooo70000?mB0?l008T0003o703o00070?ooo`001P3ooolL
0000oe80o`00R@000?lL0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0
o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@00
0?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l0
00L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo
00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?oo
ocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00
Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg
0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0
oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo0006
0?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0
o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@00
0?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?ooocL0o`00Y@000?lg0?l0
00L0oooo00060?ooocL0o`00Y@000?lg0?l000L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o
1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g
0000o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0
o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@00
0?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l0
08T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo
703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000o`L0oooo0006
0?oooa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?oo
o`001P3ooolL0?l008T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o
1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g
0000o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0
o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@00
0?lg0?l003L0003o1`3oool000H0oooo703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l0
08T0003o=`3o000g0000o`L0oooo00060?oooa`0o`00R@000?lg0?l003L0003o1`3oool000H0oooo
703o00290000ocL0o`00=`000?l70?ooo`001P3ooolL0?l008T0003o=`3o000g0000o`L0oooo0006
0?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0
o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@00
0?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l0
00L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo
00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oo
oa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00
R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^
0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0
oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo0006
0?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0
o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@00
0?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l000L0oooo00060?oooa`0o`00R@000?m^0?l0
00L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`00
70000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o
001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?oo
ocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0
003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo
00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK
0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000
o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`00
70000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o
001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?oo
ocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0
003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo
00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK
0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000
o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`00
70000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o
001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?oo
ocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0
003o=`3o001C0000o`L0oooo00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo
00060?ooocL0o`0070000?lK0?l001/0003o=`3o001C0000o`L0oooo00060?oooe<0o`006`000?m^
0?l001/0003o703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0
ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l001/0003o
703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K
0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l001/0003o703o00070?oo
o`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K0000ofh0o`00
6`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l001/0003o703o00070?ooo`001P3ooomC
0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l0
00L0oooo00060?oooe<0o`006`000?m^0?l001/0003o703o00070?ooo`001P3ooomC0?l001/0003o
KP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo0006
0?oooe<0o`006`000?m^0?l001/0003o703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000
oa`0o`001`3oool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`00
6`000?m^0?l001/0003o703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3o
ool000H0ooooD`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l0
01/0003o703o00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0oooo
D`3o000K0000ofh0o`006`000?lL0?l000L0oooo00060?oooe<0o`006`000?m^0?l001/0003o703o
00070?ooo`001P3ooomC0?l001/0003oKP3o000K0000oa`0o`001`3oool000H0ooooD`3o000K0000
ofh0o`006`000?lL0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo
=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo0006
0?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?oo
o`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`00
1`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU
0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0
003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o
000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000
oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo
=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo0006
0?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?oo
o`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`00
1`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU
0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0
003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?oooa`0o`006`00
0?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l0
00L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo
00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oo
oa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`00
6`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL
0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0
oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo0006
0?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0
o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`00
0?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l0
00L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo
00060?oooa`0o`006`000?oL0?l000L0oooo00060?oooa`0o`006`000?oL0?l000L0oooo00060?oo
oa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o
`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g
0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0
oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo0006
0?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0
003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o
000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000
o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo
00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oo
oa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o
`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g
0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0oooo00060?oooa`0003o`03o000g0000o`L0
oooo00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o
000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo00060?oo
ohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0
o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo00060?ooohT0o`007000
0?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0o`001`3oool0
00H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0
003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o
000L0000ocL0o`006`000?lL0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0003o703o0007
0?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0
o`006`000?lL0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3o
oon90?l001`0003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL
0?l000L0oooo00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0
003o=`3o000K0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo
00060?ooohT0o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K
0000oa`0o`001`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo00060?ooohT0
o`0070000?lg0?l001/0003o703o00070?ooo`001P3ooon90?l001`0003o=`3o000K0000oa`0o`00
1`3oool000H0ooooR@3o000L0000ocL0o`006`000?lL0?l000L0oooo00060?ooohT0o`0070000?lg
0?l001/0003o703o00070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000
0000FFFF00000000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3o
oomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l0
08T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o
=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o0007
0?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`00
1P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC
0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0
003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o
00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?oo
o`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3o
oomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l0
08T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o
=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o0007
0?ooo`001P3ooolL0?l008T0003oDP3o000L0000o`L0oooo00060?oooa`0o`00R@000?mB0?l001`0
003o1`3oool000H0oooo703o00290000oe80o`0070000?l70?ooo`001P3ooolL0?l008T0003oDP3o
000L0000o`L0oooo00060?oooa`0o`00R@000?mB0?l001`0003o1`3oool000H0oooo703o00290000
oe80o`0070000?l70?ooo`001P3ooolL0?l008T0003oDP3o000L0000o`L0oooo00060?oooa`0o`00
R@000?mB0?l001`0003o1`3oool000H0oooo703o00290000oe80o`0070000?l70?ooo`001P3ooolL
0?l008T0003oDP3o000L0000o`L0oooo00060?oooa`0o`00R@000?mB0?l001`0003o1`3oool000H0
oooo703o00290000oe80o`0070000?l70?ooo`001P3ooolL0?l008T0003oDP3o000L0000o`L0oooo
00060?oooa`0o`00R@000?mB0?l001`0003o1`3oool000H0oooo703o00290000oe80o`0070000?l7
0?ooo`001P3ooolL0?l008T0003oDP3o000L0000o`L0oooo00060?oooa`0o`00R@000?mB0?l001`0
003o1`3oool000H0oooo703o00290000oe80o`0070000?l70?ooo`001P3ooolL0?l008T0003oDP3o
000L0000o`L0oooo00060?oooa`0o`00R@000?mB0?l001`0003o1`3oool000H0oooo703o00290000
oe80o`0070000?l70?ooo`001P3ooolL0?l008T0003oDP3o000L0000o`L0oooo00060?oooa`0o`00
R@000?mB0?l001`0003o1`3oool000H0oooo703o00290000oe80o`0070000?l70?ooo`001P3ooolL
0?l008T0003oDP3o000L0000o`L0oooo00060?oooa`0o`00R@000?mB0?l001`0003o1`3oool000H0
oooo703o00290000oe80o`0070000?l70?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@00
0?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0
ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3o
ool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU0000ofh0
o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`001P3ooonU
0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o00070?ooo`00
1P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003oKP3o0007
0?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?ooojD0003o
KP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo00060?oo
ojD0003oKP3o00070?ooo`001P3ooonU0000ofh0o`001`3oool000H0ooooY@000?m^0?l000L0oooo
00060?ooojD0003oKP3o00070?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool0
00H0ooooD`000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0
o`0070000?l70?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`00
0?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l7
0?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0
003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3o
oomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0003oKP3o000L
0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooomC0000oa/0
o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0003oKP3o000L0000o`L0oooo
00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooomC0000oa/0o`006`000?m^
0?l001`0003o1`3oool000H0ooooD`000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0
003o6`3o000K0000ofh0o`0070000?l70?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o
1`3oool000H0ooooD`000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K
0000ofh0o`0070000?l70?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0
ooooD`000?lK0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`00
70000?l70?ooo`001P3ooomC0000oa/0o`006`000?m^0?l001`0003o1`3oool000H0ooooD`000?lK
0?l001/0003oKP3o000L0000o`L0oooo00060?oooe<0003o6`3o000K0000ofh0o`0070000?l70?oo
o`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`00
6`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o
00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000
oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0
003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3o
oolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK
0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?oo
o`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`00
6`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o
00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000
oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0
003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3o
oolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK
0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?oo
o`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`00
6`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o
00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000
oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0
003oD`3o00070?ooo`001P3ooolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3o
oolg0000oa`0o`006`000?lK0?l003L0003oD`3o00070?ooo`001P3ooom^0000oa/0o`00D`000?lg
0?l000L0oooo00060?ooofh0003o6`3o001C0000ocL0o`001`3oool000H0ooooKP000?lK0?l005<0
003o=`3o00070?ooo`001P3ooom^0000oa/0o`00D`000?lg0?l000L0oooo00060?ooofh0003o6`3o
001C0000ocL0o`001`3oool000H0ooooKP000?lK0?l005<0003o=`3o00070?ooo`001P3ooom^0000
oa/0o`00D`000?lg0?l000L0oooo00060?ooofh0003o6`3o001C0000ocL0o`001`3oool000H0oooo
KP000?lK0?l005<0003o=`3o00070?ooo`001P3ooom^0000oa/0o`00D`000?lg0?l000L0oooo0006
0?ooofh0003o6`3o001C0000ocL0o`001`3oool000H0ooooKP000?lK0?l005<0003o=`3o00070?oo
o`001P3ooom^0000oa/0o`00D`000?lg0?l000L0oooo00060?ooofh0003o6`3o001C0000ocL0o`00
1`3oool000H0ooooKP000?lK0?l005<0003o=`3o00070?ooo`001P3ooom^0000oa/0o`00D`000?lg
0?l000L0oooo00060?ooofh0003o6`3o001C0000ocL0o`001`3oool000H0ooooKP000?lK0?l005<0
003o=`3o00070?ooo`001P3ooom^0000oa/0o`00D`000?lg0?l000L0oooo00060?ooofh0003o6`3o
001C0000ocL0o`001`3oool000H0ooooKP000?lK0?l005<0003o=`3o00070?ooo`001P3ooom^0000
oa/0o`00D`000?lg0?l000L0oooo00060?ooofh0003o6`3o001C0000ocL0o`001`3oool000H0oooo
KP000?lK0?l005<0003o=`3o00070?ooo`001P3ooom^0000oa/0o`00D`000?lg0?l000L0oooo0006
0?ooofh0003o6`3o001C0000ocL0o`001`3oool000H0ooooKP000?lK0?l005<0003o=`3o00070?oo
o`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00
=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg
0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l0
00L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg0?l001`0003o
DP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l000L0oooo0006
0?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000
ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`00
70000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3o
ool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l0
03L0003o=`3o00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo
=`3o000L0000oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o
00070?ooo`001P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000
oe80o`00=`000?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`00
1P3ooolg0?l001`0003oDP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00=`00
0?lg0?l000L0oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`001P3ooolg0?l0
01`0003oDP3o000g0000ocL0o`001`3oool000H0oooo=`3o000L0000oe80o`00=`000?lg0?l000L0
oooo00060?ooocL0o`0070000?mB0?l003L0003o=`3o00070?ooo`001P3ooolL0000oa/0o`00=`00
0?mB0?l005<0003o1`3oool000H0oooo70000?lK0?l003L0003oDP3o001C0000o`L0oooo00060?oo
oa`0003o6`3o000g0000oe80o`00D`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?mB0?l005<0
003o1`3oool000H0oooo70000?lK0?l003L0003oDP3o001C0000o`L0oooo00060?oooa`0003o6`3o
000g0000oe80o`00D`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?mB0?l005<0003o1`3oool0
00H0oooo70000?lK0?l003L0003oDP3o001C0000o`L0oooo00060?oooa`0003o6`3o000g0000oe80
o`00D`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?mB0?l005<0003o1`3oool000H0oooo7000
0?lK0?l003L0003oDP3o001C0000o`L0oooo00060?oooa`0003o6`3o000g0000oe80o`00D`000?l7
0?ooo`001P3ooolL0000oa/0o`00=`000?mB0?l005<0003o1`3oool000H0oooo70000?lK0?l003L0
003oDP3o001C0000o`L0oooo00060?oooa`0003o6`3o000g0000oe80o`00D`000?l70?ooo`001P3o
oolL0000oa/0o`00=`000?mB0?l005<0003o1`3oool000H0oooo70000?lK0?l003L0003oDP3o001C
0000o`L0oooo00060?oooa`0003o6`3o000g0000oe80o`00D`000?l70?ooo`001P3ooolL0000oa/0
o`00=`000?mB0?l005<0003o1`3oool000H0oooo70000?lK0?l003L0003oDP3o001C0000o`L0oooo
00060?oooa`0003o6`3o000g0000oe80o`00D`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?mB
0?l005<0003o1`3oool000H0oooo70000?lK0?l003L0003oDP3o001C0000o`L0oooo00060?oooa`0
003o6`3o000g0000oe80o`00D`000?l70?ooo`001P3ooolL0000oa/0o`00=`000?mB0?l005<0003o
1`3oool000H0oooo70000?lK0?l003L0003oDP3o001C0000o`L0oooo00060?oooa`0003o6`3o000g
0000oe80o`00D`000?l70?ooo`001P3ooom^0?l003L0003o6`3o000g0000oa`0o`001`3oool000H0
ooooKP3o000g0000oa/0o`00=`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lK0?l003L0003o
703o00070?ooo`001P3ooom^0?l003L0003o6`3o000g0000oa`0o`001`3oool000H0ooooKP3o000g
0000oa/0o`00=`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lK0?l003L0003o703o00070?oo
o`001P3ooom^0?l003L0003o6`3o000g0000oa`0o`001`3oool000H0ooooKP3o000g0000oa/0o`00
=`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lK0?l003L0003o703o00070?ooo`001P3ooom^
0?l003L0003o6`3o000g0000oa`0o`001`3oool000H0ooooKP3o000g0000oa/0o`00=`000?lL0?l0
00L0oooo00060?ooofh0o`00=`000?lK0?l003L0003o703o00070?ooo`001P3ooom^0?l003L0003o
6`3o000g0000oa`0o`001`3oool000H0ooooKP3o000g0000oa/0o`00=`000?lL0?l000L0oooo0006
0?ooofh0o`00=`000?lK0?l003L0003o703o00070?ooo`001P3ooom^0?l003L0003o6`3o000g0000
oa`0o`001`3oool000H0ooooKP3o000g0000oa/0o`00=`000?lL0?l000L0oooo00060?ooofh0o`00
=`000?lK0?l003L0003o703o00070?ooo`001P3ooom^0?l003L0003o6`3o000g0000oa`0o`001`3o
ool000H0ooooKP3o000g0000oa/0o`00=`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lK0?l0
03L0003o703o00070?ooo`001P3ooom^0?l003L0003o6`3o000g0000oa`0o`001`3oool000H0oooo
KP3o000g0000oa/0o`00=`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lK0?l003L0003o703o
00070?ooo`001P3ooom^0?l003L0003o6`3o000g0000oa`0o`001`3oool000H0ooooKP3o000g0000
oa/0o`00=`000?lL0?l000L0oooo00060?ooofh0o`00=`000?lK0?l003L0003o703o00070?ooo`00
1P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC
0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0
003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o
00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?oo
o`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3o
oomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l0
08T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o
=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o0007
0?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`00
1P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC
0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0
003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`001P3ooomC0?l008T0003o=`3o
00070?ooo`001P3ooomC0?l008T0003o=`3o00070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
FF00000000FF0000FFFF00000000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3o
oolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l0
03L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003o
Y@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o0007
0?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`00
1P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg
0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0
003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o
00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?oo
o`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3o
oolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l0
03L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003o
Y@3o00070?ooo`001P3ooolg0?l003L0003oY@3o00070?ooo`001P3ooolg0?l003L0003oY@3o0007
0?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003o
RP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?oo
ohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo
00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@000?n:0?l0
00L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0ooooR@00
0?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3oool000H0
ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0o`001`3o
ool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon90000ohX0
o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`001P3ooon9
0000ohX0o`001`3oool000H0ooooR@000?n:0?l000L0oooo00060?ooohT0003oRP3o00070?ooo`00
1P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon9
0000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0
o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`007000
0?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?oo
o`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l7
0?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`00
1P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon9
0000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0
o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`007000
0?l70?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000
ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`00
6`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL
0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0
003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3o
oolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool0
00H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0
oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o
00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000
ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`00
6`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL
0?l001/0003oY@3o00070?ooo`001P3ooolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0
003o703o000K0000ojD0o`001`3oool000H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3o
oolg0000oa`0o`006`000?nU0?l000L0oooo00060?ooocL0003o703o000K0000ojD0o`001`3oool0
00H0oooo=`000?lL0?l001/0003oY@3o00070?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`00
1P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC
0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0
o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?oo
o`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3o
oomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000
oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`00
70000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l7
0?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`00
1P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC
0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0
o`0070000?l70?ooo`001P3ooomC0000oj@0o`0070000?l70?ooo`001P3ooomC0000oj@0o`007000
0?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l0
01`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003o
Y03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L
0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0
o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3o
oolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool0
00H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0
oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`007000
0?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l0
01`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003o
Y03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L
0000oj@0o`0070000?l70?ooo`001P3ooolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0
o`0070000?nT0?l001`0003o1`3oool000H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3o
oolg0?l001`0003oY03o000L0000o`L0oooo00060?ooocL0o`0070000?nT0?l001`0003o1`3oool0
00H0oooo=`3o000L0000oj@0o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`00
1P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU
0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80
o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`007000
0?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?oo
o`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3o
oonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000
oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`00
70000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l7
0?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`00
1P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU
0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooonU0000oe80
o`0070000?l70?ooo`001P3ooonU0000oe80o`0070000?l70?ooo`001P3ooolL0?l003L0003o6`3o
001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oo
oa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o001^0000ocL0
o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0o`00=`00
0?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o001^0000ocL0o`001`3oool0
00H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0o`00=`000?lK0?l006h0
003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o001^0000ocL0o`001`3oool000H0oooo703o
000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o0007
0?ooo`001P3ooolL0?l003L0003o6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0
o`00KP000?lg0?l000L0oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3o
oolL0?l003L0003o6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg
0?l000L0oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0
003o6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo
00060?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o001^
0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0
o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o001^0000ocL0o`00
1`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0o`00=`000?lK
0?l006h0003o=`3o00070?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0
o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`007000
0?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?oo
o`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3o
oooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000
oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`00
70000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l7
0?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`00
1P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL
0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0
o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`007000
0?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooooL0000oa/0o`0070000?l70?oo
o`001P3ooooL0000oa/0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l7
0?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`00
1P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon9
0000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0
o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`007000
0?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?oo
o`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l7
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF00000000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l7
0?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`00
1P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon9
0000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0
o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`007000
0?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?oo
o`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3o
oon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000
ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`00
70000?l70?ooo`001P3ooon90000ofh0o`0070000?l70?ooo`001P3ooon90000ofh0o`0070000?l7
0?ooo`001P3ooonU0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooY@000?lK0?l001`0
003o6`3o000L0000o`L0oooo00060?ooojD0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3o
oonU0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooY@000?lK0?l001`0003o6`3o000L
0000o`L0oooo00060?ooojD0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooonU0000oa/0
o`0070000?lK0?l001`0003o1`3oool000H0ooooY@000?lK0?l001`0003o6`3o000L0000o`L0oooo
00060?ooojD0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooonU0000oa/0o`0070000?lK
0?l001`0003o1`3oool000H0ooooY@000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?ooojD0
003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooonU0000oa/0o`0070000?lK0?l001`0003o
1`3oool000H0ooooY@000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?ooojD0003o6`3o000L
0000oa/0o`0070000?l70?ooo`001P3ooonU0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0
ooooY@000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?ooojD0003o6`3o000L0000oa/0o`00
70000?l70?ooo`001P3ooonU0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooY@000?lK
0?l001`0003o6`3o000L0000o`L0oooo00060?ooojD0003o6`3o000L0000oa/0o`0070000?l70?oo
o`001P3ooonU0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooY@000?lK0?l001`0003o
6`3o000L0000o`L0oooo00060?ooojD0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooonU
0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooY@000?lK0?l001`0003o6`3o000L0000
o`L0oooo00060?ooojD0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooom^0000ojD0o`00
1`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000
ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3o
oom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?oo
o`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0003oY@3o
00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo00060?ooofh0
003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0oooo0006
0?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU0?l000L0
oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0ooooKP000?nU
0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooom^0000ojD0o`001`3oool000H0oooo
KP000?nU0?l000L0oooo00060?ooofh0003oY@3o00070?ooo`001P3ooolg0?l001`0003o=P3o000L
0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?oo
o`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o
=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`00
0?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l0
01`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0
o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3o
oolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L
0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?oo
o`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o
=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`00
0?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l0
01`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0
o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3o
oolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L
0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?oo
o`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o
=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`00
0?l70?ooo`001P3ooolg0?l001`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooolg0?l0
01`0003o=P3o000L0000ocL0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooo
g03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool0
00H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o
1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l0
03L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3o
oooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?oo
o`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`00
0?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0
o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo0006
0?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0
oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooo=`000?nU
0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0
003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3o
ool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0
oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`00
0?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l0
03L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o
1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool0
00H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo
=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU
0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0
003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3o
ool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0
ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool0
00H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0oooo
Y@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B
0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0
o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3o
ool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0
ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o
001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000
oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`001`3oool000H0ooooY@3o001B0000oa`0o`00
1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool0
00H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo
=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL
0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00
003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3o
ool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0
oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`00
0?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l0
0<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o
1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool0
00H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo
=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL
0?l00<00003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0
003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3o
ool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0
ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@00
0?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l0
03L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o
1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool0
00H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0oooo
Y@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg
0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0
003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3o
ool000H0ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l003L0003o1`3oool000H0
ooooY@000?lg0?l003L0003o1`3oool000H0ooooY@000?lg0?l001/0003o703o00070?ooo`001P3o
oonU0000ocL0o`006`000?lL0?l000L0oooo00060?ooojD0003o=`3o000K0000oa`0o`001`3oool0
00H0ooooY@000?lg0?l001/0003o703o00070?ooo`001P3ooonU0000ocL0o`006`000?lL0?l000L0
oooo00060?ooojD0003o=`3o000K0000oa`0o`001`3oool000H0ooooY@000?lg0?l001/0003o703o
00070?ooo`001P3ooonU0000ocL0o`006`000?lL0?l000L0oooo00060?ooojD0003o=`3o000K0000
oa`0o`001`3oool000H0ooooY@000?lg0?l001/0003o703o00070?ooo`001P3ooonU0000ocL0o`00
6`000?lL0?l000L0oooo00060?ooojD0003o=`3o000K0000oa`0o`001`3oool000H0ooooY@000?lg
0?l001/0003o703o00070?ooo`001P3ooonU0000ocL0o`006`000?lL0?l000L0oooo00060?ooojD0
003o=`3o000K0000oa`0o`001`3oool000H0ooooY@000?lg0?l001/0003o703o00070?ooo`001P3o
oonU0000ocL0o`006`000?lL0?l000L0oooo00060?ooojD0003o=`3o000K0000oa`0o`001`3oool0
00H0ooooY@000?lg0?l001/0003o703o00070?ooo`001P3ooonU0000ocL0o`006`000?lL0?l000L0
oooo00060?ooojD0003o=`3o000K0000oa`0o`001`3oool000H0ooooY@000?lg0?l001/0003o703o
00070?ooo`001P3ooonU0000ocL0o`006`000?lL0?l000L0oooo00060?ooojD0003o=`3o000K0000
oa`0o`001`3oool000H0ooooY@000?lg0?l001/0003o703o00070?ooo`001P3ooonU0000ocL0o`00
6`000?lL0?l000L0oooo00060?ooojD0003o=`3o000K0000oa`0o`001`3oool000H0ooooY@000?lg
0?l001/0003o703o00070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FFFF00000000FFFF0000
FF0000FF00000000FFFF00000000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FFFF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooR@000?lL0?l0
01/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0
o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@00
0?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K
0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0
ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o
703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3o
ool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l0
01/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0
o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@00
0?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K
0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0
ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o
703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3o
ool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l0
01/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0
o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@00
0?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K
0000oa`0o`001`3oool000H0ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0
ooooR@000?lL0?l001/0003o703o000K0000oa`0o`001`3oool000H0oooo=`3o000L0000oa/0o`00
DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3o
ool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000
oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0
003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o
000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL
0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0
oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00
DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3o
ool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000
oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0
003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o
000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL
0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0
oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00
DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3o
ool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000
oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0
003o1`3oool000H0oooo=`3o000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`3o
000L0000oa/0o`00DP000?lL0?l003L0003o1`3oool000H0oooo=`000?lg0?l001/0003oD`3o000g
0000o`L0oooo00060?ooocL0003o=`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolg0000ocL0
o`006`000?mC0?l003L0003o1`3oool000H0oooo=`000?lg0?l001/0003oD`3o000g0000o`L0oooo
00060?ooocL0003o=`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`006`000?mC
0?l003L0003o1`3oool000H0oooo=`000?lg0?l001/0003oD`3o000g0000o`L0oooo00060?ooocL0
003o=`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`006`000?mC0?l003L0003o
1`3oool000H0oooo=`000?lg0?l001/0003oD`3o000g0000o`L0oooo00060?ooocL0003o=`3o000K
0000oe<0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`006`000?mC0?l003L0003o1`3oool000H0
oooo=`000?lg0?l001/0003oD`3o000g0000o`L0oooo00060?ooocL0003o=`3o000K0000oe<0o`00
=`000?l70?ooo`001P3ooolg0000ocL0o`006`000?mC0?l003L0003o1`3oool000H0oooo=`000?lg
0?l001/0003oD`3o000g0000o`L0oooo00060?ooocL0003o=`3o000K0000oe<0o`00=`000?l70?oo
o`001P3ooolg0000ocL0o`006`000?mC0?l003L0003o1`3oool000H0oooo=`000?lg0?l001/0003o
D`3o000g0000o`L0oooo00060?ooocL0003o=`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolg
0000ocL0o`006`000?mC0?l003L0003o1`3oool000H0oooo=`000?lg0?l001/0003oD`3o000g0000
o`L0oooo00060?ooocL0003o=`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`00
6`000?mC0?l003L0003o1`3oool000H0oooo=`000?lg0?l001/0003oD`3o000g0000o`L0oooo0006
0?ooocL0003o=`3o000K0000oe<0o`00=`000?l70?ooo`001P3ooolg0000ocL0o`006`000?mC0?l0
03L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o
1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool0
00H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo
=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU
0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0
003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3o
ool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0
oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`00
0?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l0
03L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o
1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool0
00H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo
=`000?nU0?l003L0003o1`3oool000H0oooo=`000?nU0?l003L0003o1`3oool000H0oooo70000?nT
0?l003L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0
003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3o
oolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003oY03o000g0000oa`0o`001`3oool0
00H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0
oooo00060?oooa`0003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o
00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003oY03o000g0000
oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3ooolL0000oj@0o`00
=`000?lL0?l000L0oooo00060?oooa`0003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT
0?l003L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0
003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3o
oolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003oY03o000g0000oa`0o`001`3oool0
00H0oooo70000?nT0?l003L0003o703o00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0
oooo00060?oooa`0003oY03o000g0000oa`0o`001`3oool000H0oooo70000?nT0?l003L0003o703o
00070?ooo`001P3ooolL0000oj@0o`00=`000?lL0?l000L0oooo00060?oooa`0003oY03o000g0000
oa`0o`001`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o
1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool0
00H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo
=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL
0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00
003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3o
ool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0
oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`00
0?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l0
0<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o
1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool0
00H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo=`000?lL0?l00<00003o1`3oool000H0oooo
=`000?lL0?l00<00003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000
o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000
o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000
o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3o
oon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000
oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00
KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l7
0?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`00
1P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon9
0000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0
o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP00
0?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?oo
o`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3o
oon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000
oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00
KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l70?ooo`001P3ooon90000oa`0o`00KP000?l7
0?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00
RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?oo
ohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo
00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000
o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o
002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0
ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3o
ool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0
003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon9
0?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`00
1P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg
0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0
o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`00
0?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?oo
o`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3o
oolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000
ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00
D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l7
0?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`00
1P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg
0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0
o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`00
0?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?oo
o`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3o
oolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000
ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00
D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l7
0?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`00
1P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg
0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0
o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`00
0?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?oo
o`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3o
oolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000
ohT0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00
D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l7
0?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`00
1P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL
0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0
o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`00
0?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?oo
o`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3o
oolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000
oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00
D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l7
0?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`00
1P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL0000oj@0o`00D`000?l70?ooo`001P3ooolL
0?l001/0003o703o00300000o`L0oooo00060?oooa`0o`006`000?lL0?l00<00003o1`3oool000H0
oooo703o000K0000oa`0o`00`0000?l70?ooo`001P3ooolL0?l001/0003o703o00300000o`L0oooo
00060?oooa`0o`006`000?lL0?l00<00003o1`3oool000H0oooo703o000K0000oa`0o`00`0000?l7
0?ooo`001P3ooolL0?l001/0003o703o00300000o`L0oooo00060?oooa`0o`006`000?lL0?l00<00
003o1`3oool000H0oooo703o000K0000oa`0o`00`0000?l70?ooo`001P3ooolL0?l001/0003o703o
00300000o`L0oooo00060?oooa`0o`006`000?lL0?l00<00003o1`3oool000H0oooo703o000K0000
oa`0o`00`0000?l70?ooo`001P3ooolL0?l001/0003o703o00300000o`L0oooo00060?oooa`0o`00
6`000?lL0?l00<00003o1`3oool000H0oooo703o000K0000oa`0o`00`0000?l70?ooo`001P3ooolL
0?l001/0003o703o00300000o`L0oooo00060?oooa`0o`006`000?lL0?l00<00003o1`3oool000H0
oooo703o000K0000oa`0o`00`0000?l70?ooo`001P3ooolL0?l001/0003o703o00300000o`L0oooo
00060?oooa`0o`006`000?lL0?l00<00003o1`3oool000H0oooo703o000K0000oa`0o`00`0000?l7
0?ooo`001P3ooolL0?l001/0003o703o00300000o`L0oooo00060?oooa`0o`006`000?lL0?l00<00
003o1`3oool000H0oooo703o000K0000oa`0o`00`0000?l70?ooo`001P3ooolL0?l001/0003o703o
00300000o`L0oooo00060?oooa`0o`006`000?lL0?l00<00003o1`3oool000H0oooo703o000K0000
oa`0o`00`0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo
00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000
o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o
003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3oool000H0
oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0003o1`3o
ool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg0?l00=`0
003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`001P3ooolg
0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l70?ooo`00
1P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00g0000?l7
0?ooo`001P3ooolg0?l00=`0003o1`3oool000H0oooo=`3o003L0000o`L0oooo00060?ooocL0o`00
g0000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000
o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000
o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`00
1P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l7
0?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o
50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?oo
ool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo
00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000
o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`00
0?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0
ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3o
ool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0
003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo
0000oa@0003o1`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o
002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0
ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3o
ool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0
003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`001P3ooon9
0?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l70?ooo`00
1P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00RP000?l7
0?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?ooohT0o`00
RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo00060?oo
ohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0ooooR@3o002:0000o`L0oooo
00060?ooohT0o`00RP000?l70?ooo`001P3ooon90?l008X0003o1`3oool000H0oooo=`000?n90?l0
05<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o
1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool0
00H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo
=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n9
0?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0
003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3o
ool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0
oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`00
0?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l0
05<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o
1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool0
00H0oooo=`000?n90?l005<0003o1`3oool000H0oooo=`000?n90?l005<0003o1`3oool000H0oooo
=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^
0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0
003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3o
ool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0
oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`00
0?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l0
06h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o
1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool0
00H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo
=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^
0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0
003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3oool000H0oooo=`000?m^0?l006h0003o1`3o
ool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0
oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo7000
0?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l0
06h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o
1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool0
00H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo
70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n9
0?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0
003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3o
ool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0
oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo7000
0?n90?l006h0003o1`3oool000H0oooo70000?n90?l006h0003o1`3oool000H0oooo70000?n90?l0
06h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3o
oonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?oo
o`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP00
0?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo00060?ooojD0
o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0oooo0006
0?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^0000o`L0
oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0ooooY@3o001^
0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool000H0oooo
Y@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o1`3oool0
00H0ooooY@3o001^0000o`L0oooo00060?ooojD0o`00KP000?l70?ooo`001P3ooonU0?l006h0003o
1`3oool000H0ooooY@3o001^0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oo
oa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o
6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L
0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0
oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo0006
0?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0
003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o
003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000
o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo
00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oo
oa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o
6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?oooa`0003o6`3o003L
0000o`L0oooo00060?oooa`0003o6`3o003L0000o`L0oooo00060?ooohT0003o703o001^0000o`L0
oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo0006
0?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0
003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o
001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000
o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo
00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?oo
ohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o
703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^
0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0
oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo0006
0?ooohT0003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooohT0
003o703o001^0000o`L0oooo00060?ooohT0003o703o001^0000o`L0oooo00060?ooooL0003o703o
00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0
003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo0006
0?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0
oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooom`000?lL
0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool000H0oooo
m`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`001`3oool0
00H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000oa`0o`00
1`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3oooog0000
oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooooL0003o703o00070?ooo`001P3o
ooog0000oa`0o`001`3oool000H0oooom`000?lL0?l000L0oooo00060?ooool0003o50000?l70?oo
o`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o5000
0?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0
003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo0006
0?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD0000o`L0
oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0ooooo`000?lD
0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool000H0oooo
o`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o1`3oool0
00H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000oa@0003o
1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooool0003o50000?l70?ooo`001P3ooooo0000
oa@0003o1`3oool000H0ooooo`000?lD0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo
00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?oo
ocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003o
KP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^
0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0
oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo0006
0?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0
003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o
001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000
o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo
00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?oo
ocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003o
KP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^0000o`L0oooo00060?ooocL0003oKP3o001^
0000o`L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF00000000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3o
oolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000
ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00
D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l7
0?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`00
1P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg
0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0
o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`00
0?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?oo
o`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3o
oolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000
ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00
D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l70?ooo`001P3ooolg0000ohT0o`00D`000?l7
0?ooo`001P3ooolg0000ofh0o`00DP000?lL0?l000L0oooo00060?ooocL0003oKP3o001B0000oa`0
o`001`3oool000H0oooo=`000?m^0?l00580003o703o00070?ooo`001P3ooolg0000ofh0o`00DP00
0?lL0?l000L0oooo00060?ooocL0003oKP3o001B0000oa`0o`001`3oool000H0oooo=`000?m^0?l0
0580003o703o00070?ooo`001P3ooolg0000ofh0o`00DP000?lL0?l000L0oooo00060?ooocL0003o
KP3o001B0000oa`0o`001`3oool000H0oooo=`000?m^0?l00580003o703o00070?ooo`001P3ooolg
0000ofh0o`00DP000?lL0?l000L0oooo00060?ooocL0003oKP3o001B0000oa`0o`001`3oool000H0
oooo=`000?m^0?l00580003o703o00070?ooo`001P3ooolg0000ofh0o`00DP000?lL0?l000L0oooo
00060?ooocL0003oKP3o001B0000oa`0o`001`3oool000H0oooo=`000?m^0?l00580003o703o0007
0?ooo`001P3ooolg0000ofh0o`00DP000?lL0?l000L0oooo00060?ooocL0003oKP3o001B0000oa`0
o`001`3oool000H0oooo=`000?m^0?l00580003o703o00070?ooo`001P3ooolg0000ofh0o`00DP00
0?lL0?l000L0oooo00060?ooocL0003oKP3o001B0000oa`0o`001`3oool000H0oooo=`000?m^0?l0
0580003o703o00070?ooo`001P3ooolg0000ofh0o`00DP000?lL0?l000L0oooo00060?ooocL0003o
KP3o001B0000oa`0o`001`3oool000H0oooo=`000?m^0?l00580003o703o00070?ooo`001P3ooolg
0000ofh0o`00DP000?lL0?l000L0oooo00060?ooocL0003oKP3o001B0000oa`0o`001`3oool000H0
oooo=`000?m^0?l00580003o703o00070?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3o
oolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000
ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00
KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l7
0?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`00
1P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL
0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0
o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP00
0?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?oo
o`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3o
oolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000
ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooolL0000ohT0o`00
KP000?l70?ooo`001P3ooolL0000ohT0o`00KP000?l70?ooo`001P3ooooL0?l003L0003o1`3oool0
00H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o
1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l0
03L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3o
oooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`000?l70?oo
o`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0o`00=`00
0?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo00060?ooom`0
o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0oooo0006
0?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g0000o`L0
oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooooL0?l003L0003o1`3oool000H0oooog03o000g
0000o`L0oooo00060?ooom`0o`00=`000?l70?ooo`001P3ooolL0000ocL0o`00DP000?mB0?l001`0
003o1`3oool000H0oooo70000?lg0?l00580003oDP3o000L0000o`L0oooo00060?oooa`0003o=`3o
001B0000oe80o`0070000?l70?ooo`001P3ooolL0000ocL0o`00DP000?mB0?l001`0003o1`3oool0
00H0oooo70000?lg0?l00580003oDP3o000L0000o`L0oooo00060?oooa`0003o=`3o001B0000oe80
o`0070000?l70?ooo`001P3ooolL0000ocL0o`00DP000?mB0?l001`0003o1`3oool000H0oooo7000
0?lg0?l00580003oDP3o000L0000o`L0oooo00060?oooa`0003o=`3o001B0000oe80o`0070000?l7
0?ooo`001P3ooolL0000ocL0o`00DP000?mB0?l001`0003o1`3oool000H0oooo70000?lg0?l00580
003oDP3o000L0000o`L0oooo00060?oooa`0003o=`3o001B0000oe80o`0070000?l70?ooo`001P3o
oolL0000ocL0o`00DP000?mB0?l001`0003o1`3oool000H0oooo70000?lg0?l00580003oDP3o000L
0000o`L0oooo00060?oooa`0003o=`3o001B0000oe80o`0070000?l70?ooo`001P3ooolL0000ocL0
o`00DP000?mB0?l001`0003o1`3oool000H0oooo70000?lg0?l00580003oDP3o000L0000o`L0oooo
00060?oooa`0003o=`3o001B0000oe80o`0070000?l70?ooo`001P3ooolL0000ocL0o`00DP000?mB
0?l001`0003o1`3oool000H0oooo70000?lg0?l00580003oDP3o000L0000o`L0oooo00060?oooa`0
003o=`3o001B0000oe80o`0070000?l70?ooo`001P3ooolL0000ocL0o`00DP000?mB0?l001`0003o
1`3oool000H0oooo70000?lg0?l00580003oDP3o000L0000o`L0oooo00060?oooa`0003o=`3o001B
0000oe80o`0070000?l70?ooo`001P3ooolL0000ocL0o`00DP000?mB0?l001`0003o1`3oool000H0
oooo70000?lg0?l00580003oDP3o000L0000o`L0oooo00060?oooa`0003o=`3o001B0000oe80o`00
70000?l70?ooo`001P3ooolL0000ocL0o`00DP000?mB0?l001`0003o1`3oool000H0oooo`0000?mC
0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool000H0oooo
`0000?mC0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool0
00H0oooo`0000?mC0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`00
1`3oool000H0oooo`0000?mC0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3oooo00000
oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo00060?oool00003oD`3o00070?ooo`001P3o
ooo00000oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo00060?oool00003oD`3o00070?oo
o`001P3oooo00000oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo00060?oool00003oD`3o
00070?ooo`001P3oooo00000oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo00060?oool00
003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool000H0oooo`0000?mC0?l000L0oooo0006
0?oool00003oD`3o00070?ooo`001P3oooo00000oe<0o`001`3oool000H0ooooD`000?lf0?l006h0
003o703o00070?ooo`001P3ooomC0000ocH0o`00KP000?lL0?l000L0oooo00060?oooe<0003o=P3o
001^0000oa`0o`001`3oool000H0ooooD`000?lf0?l006h0003o703o00070?ooo`001P3ooomC0000
ocH0o`00KP000?lL0?l000L0oooo00060?oooe<0003o=P3o001^0000oa`0o`001`3oool000H0oooo
D`000?lf0?l006h0003o703o00070?ooo`001P3ooomC0000ocH0o`00KP000?lL0?l000L0oooo0006
0?oooe<0003o=P3o001^0000oa`0o`001`3oool000H0ooooD`000?lf0?l006h0003o703o00070?oo
o`001P3ooomC0000ocH0o`00KP000?lL0?l000L0oooo00060?oooe<0003o=P3o001^0000oa`0o`00
1`3oool000H0ooooD`000?lf0?l006h0003o703o00070?ooo`001P3ooomC0000ocH0o`00KP000?lL
0?l000L0oooo00060?oooe<0003o=P3o001^0000oa`0o`001`3oool000H0ooooD`000?lf0?l006h0
003o703o00070?ooo`001P3ooomC0000ocH0o`00KP000?lL0?l000L0oooo00060?oooe<0003o=P3o
001^0000oa`0o`001`3oool000H0ooooD`000?lf0?l006h0003o703o00070?ooo`001P3ooomC0000
ocH0o`00KP000?lL0?l000L0oooo00060?oooe<0003o=P3o001^0000oa`0o`001`3oool000H0oooo
D`000?lf0?l006h0003o703o00070?ooo`001P3ooomC0000ocH0o`00KP000?lL0?l000L0oooo0006
0?oooe<0003o=P3o001^0000oa`0o`001`3oool000H0ooooD`000?lf0?l006h0003o703o00070?oo
o`001P3ooomC0000ocH0o`00KP000?lL0?l000L0oooo00060?oooe<0003o=P3o001^0000oa`0o`00
1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool0
00H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0oooo
KP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK
0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0
003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3o
ool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0
ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP00
0?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l0
08X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o
1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool0
00H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0oooo
KP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK0?l008X0003o1`3oool000H0ooooKP000?lK
0?l008X0003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580
003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0oooo703o
001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oo
oa`0o`00DP000?m^0?l003L0003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`00
1P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3o
ool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o000g0000
o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0oooo703o001B0000ofh0o`00
=`000?l70?ooo`001P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^
0?l003L0003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580
003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0oooo703o
001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oo
oa`0o`00DP000?m^0?l003L0003o1`3oool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`00
1P3ooolL0?l00580003oKP3o000g0000o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3o
ool000H0oooo703o001B0000ofh0o`00=`000?l70?ooo`001P3ooolL0?l00580003oKP3o000g0000
o`L0oooo00060?oooa`0o`00DP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o
1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool0
00H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0oooo
KP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^
0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0
003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3o
ool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0
ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP00
0?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l0
03L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o
1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool0
00H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0oooo
KP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^0?l003L0003o1`3oool000H0ooooKP000?m^
0?l003L0003o1`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{879, 878},
WindowMargins->{{5, Automatic}, {Automatic, 4}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 66, 1, 58, "Subtitle"],
Cell[1845, 56, 114, 2, 33, "Subsubtitle"],
Cell[1962, 60, 184, 6, 102, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2171, 70, 32, 0, 76, "Section"],
Cell[2206, 72, 95, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2338, 79, 40, 0, 76, "Section"],
Cell[2381, 81, 54, 1, 29, "Input"],
Cell[2438, 84, 233, 8, 81, "Text"],

Cell[CellGroupData[{
Cell[2696, 96, 94, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[2815, 103, 138, 3, 44, "Input"],
Cell[2956, 108, 962, 13, 139, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3967, 127, 48, 0, 38, "Subsection"],
Cell[4018, 129, 1581, 27, 251, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5648, 162, 34, 0, 76, "Section"],

Cell[CellGroupData[{
Cell[5707, 166, 230, 5, 59, "Input"],
Cell[5940, 173, 1035, 20, 202, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7012, 198, 657, 17, 27, "Input"],
Cell[7672, 217, 15412, 238, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[23099, 458, 62, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23198, 464, 29, 0, 76, "Section"],
Cell[23230, 466, 53, 1, 27, "Input"],
Cell[23286, 469, 102, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[23413, 476, 2035, 40, 192, "Input"],

Cell[CellGroupData[{
Cell[25473, 520, 13022, 208, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[38498, 730, 13196, 210, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[51697, 942, 13573, 215, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[65273, 1159, 12273, 199, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[77549, 1360, 12091, 197, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[89643, 1559, 12091, 197, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[101737, 1758, 10787, 181, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[112527, 1941, 11710, 192, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[124240, 2135, 13371, 213, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[137614, 2350, 11516, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[149133, 2542, 14257, 223, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[163393, 2767, 13204, 210, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[176600, 2979, 11900, 194, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[188503, 3175, 10787, 181, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[199293, 3358, 11341, 187, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[210637, 3547, 10799, 181, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[221439, 3730, 10989, 183, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[232431, 3915, 11929, 195, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[244363, 4112, 11718, 192, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[256084, 4306, 11908, 194, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[267995, 4502, 12265, 199, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[280263, 4703, 12820, 206, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[293086, 4911, 13002, 208, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[306091, 5121, 12804, 206, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[318898, 5329, 11706, 192, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[330607, 5523, 10977, 183, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[341587, 5708, 11151, 185, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[352741, 5895, 11900, 194, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[364644, 6091, 12629, 203, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[377276, 6296, 11921, 195, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[389200, 6493, 11933, 195, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[401136, 6690, 12427, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[413566, 6893, 11706, 192, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[425275, 7087, 11159, 185, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[436437, 7274, 11516, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[447956, 7466, 11524, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[459483, 7658, 12642, 204, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[472128, 7864, 15027, 233, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[487158, 8099, 14662, 228, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[501823, 8329, 12459, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[514285, 8532, 11151, 185, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[525439, 8719, 13006, 208, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[538448, 8929, 12650, 204, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[551101, 9135, 13379, 213, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[564483, 9350, 12455, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[576941, 9553, 11536, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[588480, 9745, 12621, 203, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[601104, 9950, 13002, 208, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[614109, 10160, 13006, 208, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[627118, 10370, 12257, 199, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[639378, 10571, 12075, 197, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[651456, 10770, 12435, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[663894, 10973, 12994, 208, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[676891, 11183, 12447, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[689341, 11386, 11325, 187, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[700669, 11575, 11333, 187, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[712005, 11764, 11706, 192, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[723714, 11958, 11548, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[735265, 12150, 10981, 183, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[746249, 12335, 11690, 192, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[757942, 12529, 11524, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[769469, 12721, 11354, 188, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[780826, 12911, 11710, 192, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[792539, 13105, 10604, 178, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[803146, 13285, 11333, 187, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[814482, 13474, 12812, 206, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[827297, 13682, 11536, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[838836, 13874, 11536, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[850375, 14066, 12629, 203, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[863007, 14271, 12812, 206, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[875822, 14479, 12075, 197, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[887900, 14678, 12650, 204, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[900553, 14884, 12455, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[913011, 15087, 12467, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[925481, 15290, 12083, 197, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[937567, 15489, 12083, 197, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[949653, 15688, 14492, 226, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[964148, 15916, 13371, 213, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[977522, 16131, 11536, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[989061, 16323, 11544, 190, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1000608, 16515, 11346, 188, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1011957, 16705, 12467, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1024427, 16908, 12257, 199, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1036687, 17109, 12820, 206, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1049510, 17317, 12621, 203, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1062134, 17522, 13168, 210, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1075305, 17734, 13366, 212, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1088674, 17948, 13735, 217, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1102412, 18167, 13366, 212, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1115781, 18381, 14452, 226, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1130236, 18609, 12820, 206, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1143059, 18817, 13002, 208, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1156064, 19027, 13755, 217, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1169822, 19246, 14100, 222, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1183925, 19470, 12439, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1196367, 19673, 12621, 203, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1208991, 19878, 12791, 205, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1221785, 20085, 11159, 185, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1232947, 20272, 11151, 185, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1244101, 20459, 12455, 201, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

