(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     58473,       1409]*)
(*NotebookOutlinePosition[     59101,       1431]*)
(*  CellTagsIndexPosition[     59057,       1427]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Zweidimensionales Ising-Modell", "Subtitle",
  FontSize->26],

Cell["\[Copyright] Apl. Prof. Dr. J\[UDoubleDot]rgen Schnack, Probestudium \
2005", "Subsubtitle",
  FontSize->16],

Cell["\<\
Ising-Modell auf einem Quadratgitter der Gr\[ODoubleDot]\[SZ]e NMax \
* NMax.
Das Programm durchl\[ADoubleDot]uft mehrere Temperaturen und berechnet die \
Magnetisierung.
Die Wechselwirkung der Spins ist 1.\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Wechselwirkungsmatrix", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(NMax = 10;\)\), "\[IndentingNewLine]", 
    \(\(NMaxSq = NMax\^2;\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(NMax\\)\\\" is similar to existing symbol \\\
\"\\!\\(Max\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[TextData[{
  "Spins sind wie folgt abgez\[ADoubleDot]hlt:\n",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"1", "2", "3"},
            {"4", "5", "6"},
            {"7", "8", "9"}
            }], ")"}]]]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Hilfsfeld, in dem die Spinnummer in den Platz umgerechnet \
wird\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Platz = 
      Table[{IntegerPart[\(k - 1\)\/NMax] + 1, Mod[k - 1, NMax] + 1}, {k, 1, 
          NMaxSq}]\)], "Input"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 
        9}, {1, 10}, {2, 1}, {2, 2}, {2, 3}, {2, 4}, {2, 5}, {2, 6}, {2, 
        7}, {2, 8}, {2, 9}, {2, 10}, {3, 1}, {3, 2}, {3, 3}, {3, 4}, {3, 
        5}, {3, 6}, {3, 7}, {3, 8}, {3, 9}, {3, 10}, {4, 1}, {4, 2}, {4, 
        3}, {4, 4}, {4, 5}, {4, 6}, {4, 7}, {4, 8}, {4, 9}, {4, 10}, {5, 
        1}, {5, 2}, {5, 3}, {5, 4}, {5, 5}, {5, 6}, {5, 7}, {5, 8}, {5, 
        9}, {5, 10}, {6, 1}, {6, 2}, {6, 3}, {6, 4}, {6, 5}, {6, 6}, {6, 
        7}, {6, 8}, {6, 9}, {6, 10}, {7, 1}, {7, 2}, {7, 3}, {7, 4}, {7, 
        5}, {7, 6}, {7, 7}, {7, 8}, {7, 9}, {7, 10}, {8, 1}, {8, 2}, {8, 
        3}, {8, 4}, {8, 5}, {8, 6}, {8, 7}, {8, 8}, {8, 9}, {8, 10}, {9, 
        1}, {9, 2}, {9, 3}, {9, 4}, {9, 5}, {9, 6}, {9, 7}, {9, 8}, {9, 
        9}, {9, 10}, {10, 1}, {10, 2}, {10, 3}, {10, 4}, {10, 5}, {10, 
        6}, {10, 7}, {10, 8}, {10, 9}, {10, 10}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wechselwirkungsmatrix JMat", "Subsection"],

Cell[BoxData[{
    \(\(JMat = 
        Table[0, {i, 1, NMaxSq}, {j, 1, 
            NMaxSq}];\)\), "\[IndentingNewLine]", 
    \(\(For[i1 = 1, 
        i1 < NMax + 1, \(i1++\), \[IndentingNewLine]For[j1 = 1, 
          j1 < NMax + 1, \(j1++\), \[IndentingNewLine]For[i2 = 1, 
            i2 < NMax + 1, \(i2++\), \[IndentingNewLine]For[j2 = 1, 
              j2 < NMax + 
                  1, \(j2++\), \[IndentingNewLine] (*\ \(Print[i1, "\< \>", 
                    i2, "\< \>", j1, "\< \>", 
                    j2, "\< \>", \((i1 - 1)\)*NMax + 
                      j1, "\< \>", \((i2 - 1)\)*NMax + 
                      j2];\)\ *) \[IndentingNewLine]If[
                Mod[Abs[i1 - i2], NMax] \[Equal] 1 && j1 \[Equal] j2, 
                JMat[\([\((i1 - 1)\)*NMax + j1, \((i2 - 1)\)*NMax + j2]\)] = 
                  1]; \[IndentingNewLine]If[
                Mod[Abs[i1 - i2], NMax] \[Equal] NMax - 1 && j1 \[Equal] j2, 
                JMat[\([\((i1 - 1)\)*NMax + j1, \((i2 - 1)\)*NMax + j2]\)] = 
                  1]; \[IndentingNewLine]If[
                Mod[Abs[j1 - j2], NMax] \[Equal] 1 && i1 \[Equal] i2, 
                JMat[\([\((i1 - 1)\)*NMax + j1, \((i2 - 1)\)*NMax + j2]\)] = 
                  1]; \[IndentingNewLine]If[
                Mod[Abs[j1 - j2], NMax] \[Equal] NMax - 1 && i1 \[Equal] i2, 
                JMat[\([\((i1 - 1)\)*NMax + j1, \((i2 - 1)\)*NMax + j2]\)] = 
                  1]\[IndentingNewLine]]\[IndentingNewLine]]\
\[IndentingNewLine]]\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(MatrixForm[JMat];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ausgangszustand", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Spins = 
        Table[2*Random[Integer] - 1, {i, 1, NMax}, {j, 1, 
            NMax}];\)\), "\[IndentingNewLine]", 
    \(\(Spins0 = Spins;\)\), "\[IndentingNewLine]", 
    \(MatrixForm[Spins]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(-1\), \(-1\), \(-1\), "1", \(-1\), 
              "1", \(-1\), \(-1\), \(-1\)},
            {\(-1\), "1", "1", \(-1\), "1", "1", \(-1\), \(-1\), "1", "1"},
            {\(-1\), \(-1\), \(-1\), "1", "1", "1", "1", "1", "1", "1"},
            {\(-1\), "1", "1", \(-1\), "1", "1", \(-1\), \(-1\), 
              "1", \(-1\)},
            {"1", \(-1\), \(-1\), "1", \(-1\), \(-1\), \(-1\), \(-1\), "1", 
              "1"},
            {\(-1\), "1", "1", "1", \(-1\), "1", \(-1\), "1", "1", \(-1\)},
            {\(-1\), \(-1\), "1", "1", "1", \(-1\), "1", \(-1\), 
              "1", \(-1\)},
            {"1", "1", "1", "1", \(-1\), \(-1\), \(-1\), \(-1\), 
              "1", \(-1\)},
            {"1", "1", "1", "1", \(-1\), "1", "1", "1", \(-1\), "1"},
            {"1", "1", \(-1\), \(-1\), "1", \(-1\), "1", "1", "1", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"Graphics", "[", 
          RowBox[{
            
            StyleBox[\(RasterArray[
                  Spins] /. {1 -> RGBColor[1, 0, 0], \(-1\) -> 
                    RGBColor[0, 0, 1]}\),
              PageBreakAbove->False,
              AspectRatioFixed->True,
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False}], ",", \(AspectRatio -> 1\)}], "]"}], "]"}], 
      ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0238095 0.0952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
30 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FF0000FFFF00000000FFFF00000000FF0000FF0000FF
0000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FF
FF00000000FF0000FFFF00000000FF0000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF00000000FFFF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00
D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL
0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000
oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`00
1P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o
000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580
003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00
D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL
0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000
oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`00
1P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o
000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580
003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00
D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL
0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000
oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`00
1P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o
000L0000oa/0o`00D`000?l70?ooo`001P3ooolL0?l00580003o6`3o000L0000oa/0o`00D`000?l7
0?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0
o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o
=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL
0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l0
03L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`00
1P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`00
0?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o0007
0?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0
o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o
=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL
0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l0
03L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`00
1P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`00
0?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o0007
0?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0
o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o
=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL
0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l0
03L0003o=`3o00070?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o=`3o00070?ooo`00
1P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o0007
0?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o
`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oo
oe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l000L0oooo
00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`000?o00?l0
00L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0ooooD`00
0?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3oool000H0
ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00o`001`3o
ool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooomC0000ol00
o`001`3oool000H0ooooD`000?o00?l000L0oooo00060?oooe<0003o`03o00070?ooo`001P3ooolL
0000ocL0o`006`000?lg0?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0003o=`3o000K0000
ocL0o`00=`000?lK0?l001`0003o1`3oool000H0oooo70000?lg0?l001/0003o=`3o000g0000oa/0
o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o6`3o000L0000o`L0oooo
00060?oooa`0003o=`3o000K0000ocL0o`00=`000?lK0?l001`0003o1`3oool000H0oooo70000?lg
0?l001/0003o=`3o000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`000?lg0?l0
03L0003o6`3o000L0000o`L0oooo00060?oooa`0003o=`3o000K0000ocL0o`00=`000?lK0?l001`0
003o1`3oool000H0oooo70000?lg0?l001/0003o=`3o000g0000oa/0o`0070000?l70?ooo`001P3o
oolL0000ocL0o`006`000?lg0?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0003o=`3o000K
0000ocL0o`00=`000?lK0?l001`0003o1`3oool000H0oooo70000?lg0?l001/0003o=`3o000g0000
oa/0o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o6`3o000L0000o`L0
oooo00060?oooa`0003o=`3o000K0000ocL0o`00=`000?lK0?l001`0003o1`3oool000H0oooo7000
0?lg0?l001/0003o=`3o000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`000?lg
0?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0003o=`3o000K0000ocL0o`00=`000?lK0?l0
01`0003o1`3oool000H0oooo70000?lg0?l001/0003o=`3o000g0000oa/0o`0070000?l70?ooo`00
1P3ooolL0000ocL0o`006`000?lg0?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0003o=`3o
000K0000ocL0o`00=`000?lK0?l001`0003o1`3oool000H0oooo70000?lg0?l001/0003o=`3o000g
0000oa/0o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`000?lg0?l003L0003o6`3o000L0000
o`L0oooo00060?oooa`0003o=`3o000K0000ocL0o`00=`000?lK0?l001`0003o1`3oool000H0oooo
70000?lg0?l001/0003o=`3o000g0000oa/0o`0070000?l70?ooo`001P3ooolL0000ocL0o`006`00
0?lg0?l003L0003o6`3o000L0000o`L0oooo00060?oooa`0003o=`3o000K0000ocL0o`00=`000?lK
0?l001`0003o1`3oool000H0oooo70000?lg0?l001/0003o=`3o000g0000oa/0o`0070000?l70?oo
o`001P3ooolL0?l003L0003o6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00
KP000?lg0?l000L0oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL
0?l003L0003o6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l0
00L0oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o
6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo0006
0?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o001^0000
ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0o`00
=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o001^0000ocL0o`001`3o
ool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0o`00=`000?lK0?l0
06h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o001^0000ocL0o`001`3oool000H0oooo
703o000g0000oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o
00070?ooo`001P3ooolL0?l003L0003o6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000
oa/0o`00KP000?lg0?l000L0oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`00
1P3ooolL0?l003L0003o6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP00
0?lg0?l000L0oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l0
03L0003o6`3o001^0000ocL0o`001`3oool000H0oooo703o000g0000oa/0o`00KP000?lg0?l000L0
oooo00060?oooa`0o`00=`000?lK0?l006h0003o=`3o00070?ooo`001P3ooolL0?l003L0003o6`3o
001^0000ocL0o`001`3oool000H0oooo70000?mB0?l001/0003o703o000K0000ocL0o`0070000?l7
0?ooo`001P3ooolL0000oe80o`006`000?lL0?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0
003oDP3o000K0000oa`0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003o
703o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?lL0?l001/0003o=`3o
000L0000o`L0oooo00060?oooa`0003oDP3o000K0000oa`0o`006`000?lg0?l001`0003o1`3oool0
00H0oooo70000?mB0?l001/0003o703o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000oe80
o`006`000?lL0?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000oa`0o`00
6`000?lg0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003o703o000K0000ocL0o`007000
0?l70?ooo`001P3ooolL0000oe80o`006`000?lL0?l001/0003o=`3o000L0000o`L0oooo00060?oo
oa`0003oDP3o000K0000oa`0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0
003o703o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?lL0?l001/0003o
=`3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000oa`0o`006`000?lg0?l001`0003o1`3o
ool000H0oooo70000?mB0?l001/0003o703o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000
oe80o`006`000?lL0?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000oa`0
o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?mB0?l001/0003o703o000K0000ocL0o`00
70000?l70?ooo`001P3ooolL0000oe80o`006`000?lL0?l001/0003o=`3o000L0000o`L0oooo0006
0?oooa`0003oDP3o000K0000oa`0o`006`000?lg0?l001`0003o1`3oool000H0oooo70000?mB0?l0
01/0003o703o000K0000ocL0o`0070000?l70?ooo`001P3ooolL0000oe80o`006`000?lL0?l001/0
003o=`3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000oa`0o`006`000?lg0?l001`0003o
1`3oool000H0oooo70000?mB0?l001/0003o703o000K0000ocL0o`0070000?l70?ooo`001P3ooolL
0000oe80o`006`000?lL0?l001/0003o=`3o000L0000o`L0oooo00060?oooa`0003oDP3o000K0000
oa`0o`006`000?lg0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003o6`3o000L0000oa/0
o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo
00060?ooocL0003oDP3o000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`000?mB
0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?lK0?l0
01`0003o6`3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oa/0o`0070000?lK0?l001`0
003o1`3oool000H0oooo=`000?mB0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3o
oolg0000oe80o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?ooocL0003oDP3o000L
0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003o6`3o000L0000
oa/0o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?lK0?l001`0003o6`3o000L0000o`L0
oooo00060?ooocL0003oDP3o000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`00
0?mB0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?lK
0?l001`0003o6`3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oa/0o`0070000?lK0?l0
01`0003o1`3oool000H0oooo=`000?mB0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`00
1P3ooolg0000oe80o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?ooocL0003oDP3o
000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003o6`3o000L
0000oa/0o`0070000?l70?ooo`001P3ooolg0000oe80o`0070000?lK0?l001`0003o6`3o000L0000
o`L0oooo00060?ooocL0003oDP3o000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0oooo
=`000?mB0?l001`0003o6`3o000L0000oa/0o`0070000?l70?ooo`001P3ooolg0000oe80o`007000
0?lK0?l001`0003o6`3o000L0000o`L0oooo00060?ooocL0003oDP3o000L0000oa/0o`0070000?lK
0?l001`0003o1`3oool000H0oooo=`000?mB0?l001`0003o6`3o000L0000oa/0o`0070000?l70?oo
o`001P3ooolg0000oe80o`0070000?lK0?l001`0003o6`3o000L0000o`L0oooo00060?ooocL0003o
DP3o000L0000oa/0o`0070000?lK0?l001`0003o1`3oool000H0ooooKP3o001^0000oa/0o`007000
0?l70?ooo`001P3ooom^0?l006h0003o6`3o000L0000o`L0oooo00060?ooofh0o`00KP000?lK0?l0
01`0003o1`3oool000H0ooooKP3o001^0000oa/0o`0070000?l70?ooo`001P3ooom^0?l006h0003o
6`3o000L0000o`L0oooo00060?ooofh0o`00KP000?lK0?l001`0003o1`3oool000H0ooooKP3o001^
0000oa/0o`0070000?l70?ooo`001P3ooom^0?l006h0003o6`3o000L0000o`L0oooo00060?ooofh0
o`00KP000?lK0?l001`0003o1`3oool000H0ooooKP3o001^0000oa/0o`0070000?l70?ooo`001P3o
oom^0?l006h0003o6`3o000L0000o`L0oooo00060?ooofh0o`00KP000?lK0?l001`0003o1`3oool0
00H0ooooKP3o001^0000oa/0o`0070000?l70?ooo`001P3ooom^0?l006h0003o6`3o000L0000o`L0
oooo00060?ooofh0o`00KP000?lK0?l001`0003o1`3oool000H0ooooKP3o001^0000oa/0o`007000
0?l70?ooo`001P3ooom^0?l006h0003o6`3o000L0000o`L0oooo00060?ooofh0o`00KP000?lK0?l0
01`0003o1`3oool000H0ooooKP3o001^0000oa/0o`0070000?l70?ooo`001P3ooom^0?l006h0003o
6`3o000L0000o`L0oooo00060?ooofh0o`00KP000?lK0?l001`0003o1`3oool000H0ooooKP3o001^
0000oa/0o`0070000?l70?ooo`001P3ooom^0?l006h0003o6`3o000L0000o`L0oooo00060?ooofh0
o`00KP000?lK0?l001`0003o1`3oool000H0ooooKP3o001^0000oa/0o`0070000?l70?ooo`001P3o
oom^0?l006h0003o6`3o000L0000o`L0oooo00060?ooofh0o`00KP000?lK0?l001`0003o1`3oool0
00H0ooooKP3o000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooofh0o`006`000?mC0?l001/0
003o703o00070?ooo`001P3ooom^0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0ooooKP3o
000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooofh0o`006`000?mC0?l001/0003o703o0007
0?ooo`001P3ooom^0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0ooooKP3o000K0000oe<0
o`006`000?lL0?l000L0oooo00060?ooofh0o`006`000?mC0?l001/0003o703o00070?ooo`001P3o
oom^0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0ooooKP3o000K0000oe<0o`006`000?lL
0?l000L0oooo00060?ooofh0o`006`000?mC0?l001/0003o703o00070?ooo`001P3ooom^0?l001/0
003oD`3o000K0000oa`0o`001`3oool000H0ooooKP3o000K0000oe<0o`006`000?lL0?l000L0oooo
00060?ooofh0o`006`000?mC0?l001/0003o703o00070?ooo`001P3ooom^0?l001/0003oD`3o000K
0000oa`0o`001`3oool000H0ooooKP3o000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooofh0
o`006`000?mC0?l001/0003o703o00070?ooo`001P3ooom^0?l001/0003oD`3o000K0000oa`0o`00
1`3oool000H0ooooKP3o000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooofh0o`006`000?mC
0?l001/0003o703o00070?ooo`001P3ooom^0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0
ooooKP3o000K0000oe<0o`006`000?lL0?l000L0oooo00060?ooofh0o`006`000?mC0?l001/0003o
703o00070?ooo`001P3ooom^0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0ooooKP3o000K
0000oe<0o`006`000?lL0?l000L0oooo00060?ooofh0o`006`000?mC0?l001/0003o703o00070?oo
o`001P3ooom^0?l001/0003oD`3o000K0000oa`0o`001`3oool000H0oooo=`3o000g0000oa/0o`00
70000?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg
0?l003L0003o6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l0
00L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o
6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0oooo0006
0?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000
ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0oooo00060?ooocL0o`00
=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000ofh0o`001`3o
ool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l0
01`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000ofh0o`001`3oool000H0oooo
=`3o000g0000oa/0o`0070000?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o
00070?ooo`001P3ooolg0?l003L0003o6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000
oa/0o`0070000?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`00
1P3ooolg0?l003L0003o6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`007000
0?m^0?l000L0oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l0
03L0003o6`3o000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0
oooo00060?ooocL0o`00=`000?lK0?l001`0003oKP3o00070?ooo`001P3ooolg0?l003L0003o6`3o
000L0000ofh0o`001`3oool000H0oooo=`3o000g0000oa/0o`0070000?m^0?l000L0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.250052, -0.250052, 0.0365857, \
0.0365857}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Metropolis", "Section"],

Cell[BoxData[{
    \(\(MaxSweeps = 100;\)\), "\[IndentingNewLine]", 
    \(\(TSteps = 20;\)\), "\[IndentingNewLine]", 
    \(\(Magnetisierung = Table[{0.0, 0.0}, {k, 1, TSteps}];\)\)}], "Input"],

Cell["\<\
DeltaE=(ENeu-EAlt) ist zweimal die Summe, weil man \
-s_i*Summe-s_i*Summe hat.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(For[iT = 1, 
        iT < 21, \(iT++\), \ \  (*\ Temperaturschleife, \ 
          T\ in\ Einheiten\ von\ J\ *) \[IndentingNewLine]T = 
          0.5*iT; \[IndentingNewLine]Spins = 
          Spins0; \[IndentingNewLine]Magnetisierung[\([iT, 1]\)] = 
          T; \[IndentingNewLine]For[Sweeps = 1, 
          Sweeps < MaxSweeps + 1, \(Sweeps++\), \[IndentingNewLine]For[i = 1, 
            i < NMaxSq + 1, \(i++\), \ \ \  (*\ 
              Spinnummer\ *) \[IndentingNewLine]DeltaE\  = \ \ 2*
                Spins[\([Platz[\([i, 1]\)], 
                    Platz[\([i, 2]\)]]\)]*\[IndentingNewLine]Sum[
                  JMat[\([i, k]\)]*
                    Spins[\([Platz[\([k, 1]\)], Platz[\([k, 2]\)]]\)], {k, 1, 
                    NMaxSq}]; \[IndentingNewLine]If[DeltaE \[LessEqual] 0\ , 
              Spins[\([Platz[\([i, 1]\)], 
                    Platz[\([i, 2]\)]]\)] = \(-Spins[\([Platz[\([i, 1]\)], 
                      Platz[\([i, 2]\)]]\)]\), \[IndentingNewLine]If[
                Random[] \[LessEqual] \[ExponentialE]\^\(\(-DeltaE\)/T\), 
                Spins[\([Platz[\([i, 1]\)], 
                      Platz[\([i, 2]\)]]\)] = \(-Spins[\([Platz[\([i, 1]\)], 
                        Platz[\([i, 
                            2]\)]]\)]\)]]; \[IndentingNewLine]Magnetisierung[\
\([iT, 2]\)] = 
              Magnetisierung[\([iT, 2]\)] + \[IndentingNewLine]Abs[
                  Sum[Spins[\([Platz[\([k, 1]\)], Platz[\([k, 2]\)]]\)], {k, 
                      1, NMaxSq}]]\[IndentingNewLine]]\[IndentingNewLine]]; \
\[IndentingNewLine]Magnetisierung[\([iT, 2]\)] = 
          Magnetisierung[\([iT, 2]\)]/\((Sweeps*NMaxSq*
                NMaxSq)\); \[IndentingNewLine]Print[
          Magnetisierung[\([iT, 1]\)], "\<  \>", 
          Magnetisierung[\([iT, 2]\)]]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(0.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.9707564356435644`\),
      SequenceForm[ 0.5, "  ", 0.9707564356435644],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(1.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.9707564356435644`\),
      SequenceForm[ 1.0, "  ", 0.9707564356435644],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(1.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.9527900990099011`\),
      SequenceForm[ 1.5, "  ", 0.95279009900990108],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(2.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.8986178217821783`\),
      SequenceForm[ 2.0, "  ", 0.89861782178217831],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(2.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.42157821782178223`\),
      SequenceForm[ 2.5, "  ", 0.42157821782178223],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.2772811881188119`\),
      SequenceForm[ 3.0, "  ", 0.27728118811881192],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.22304752475247527`\),
      SequenceForm[ 3.5, "  ", 0.22304752475247527],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.1784851485148515`\),
      SequenceForm[ 4.0, "  ", 0.1784851485148515],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.1493980198019802`\),
      SequenceForm[ 4.5, "  ", 0.1493980198019802],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(5.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.13502178217821784`\),
      SequenceForm[ 5.0, "  ", 0.13502178217821784],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(5.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.12412475247524754`\),
      SequenceForm[ 5.5, "  ", 0.12412475247524754],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.13403762376237624`\),
      SequenceForm[ 6.0, "  ", 0.13403762376237624],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.09850891089108911`\),
      SequenceForm[ 6.5, "  ", 0.09850891089108911],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.11741584158415842`\),
      SequenceForm[ 7.0, "  ", 0.11741584158415842],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.10167722772277228`\),
      SequenceForm[ 7.5, "  ", 0.10167722772277228],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(8.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.1035861386138614`\),
      SequenceForm[ 8.0, "  ", 0.1035861386138614],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(8.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.11361386138613862`\),
      SequenceForm[ 8.5, "  ", 0.11361386138613862],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(9.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.10176435643564358`\),
      SequenceForm[ 9.0, "  ", 0.10176435643564358],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(9.5`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.11707920792079209`\),
      SequenceForm[ 9.5, "  ", 0.11707920792079209],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(10.`\[InvisibleSpace]"  \
"\[InvisibleSpace]0.09597425742574259`\),
      SequenceForm[ 10.0, "  ", 0.095974257425742587],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Magnetisierung, PlotRange -> {0.0, 1.1}, 
        PlotStyle \[Rule] {Hue[0], PointSize[0.03]}, 
        TextStyle \[Rule] {FontFamily \[Rule] Helvetica, 
            FontSize \[Rule] 18}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 1.94614e-17 0.561849 [
[.21429 -0.0125 -7 -18.5625 ]
[.21429 -0.0125 7 0 ]
[.40476 -0.0125 -7 -18.5625 ]
[.40476 -0.0125 7 0 ]
[.59524 -0.0125 -7 -18.5625 ]
[.59524 -0.0125 7 0 ]
[.78571 -0.0125 -7 -18.5625 ]
[.78571 -0.0125 7 0 ]
[.97619 -0.0125 -12 -18.5625 ]
[.97619 -0.0125 12 0 ]
[.01131 .11237 -29 -9.28125 ]
[.01131 .11237 0 9.28125 ]
[.01131 .22474 -29 -9.28125 ]
[.01131 .22474 0 9.28125 ]
[.01131 .33711 -29 -9.28125 ]
[.01131 .33711 0 9.28125 ]
[.01131 .44948 -29 -9.28125 ]
[.01131 .44948 0 9.28125 ]
[.01131 .56185 -14 -9.28125 ]
[.01131 .56185 0 9.28125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -68 -22.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -68 -22.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -68 -22.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -68 -22.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -73 -22.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .11237 m
.03006 .11237 L
s
gsave
.01131 .11237 -90 -13.2812 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .22474 m
.03006 .22474 L
s
gsave
.01131 .22474 -90 -13.2812 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .33711 m
.03006 .33711 L
s
gsave
.01131 .33711 -90 -13.2812 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .44948 m
.03006 .44948 L
s
gsave
.01131 .44948 -90 -13.2812 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .56185 m
.03006 .56185 L
s
gsave
.01131 .56185 -75 -13.2812 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .02809 m
.02756 .02809 L
s
.02381 .05618 m
.02756 .05618 L
s
.02381 .08428 m
.02756 .08428 L
s
.02381 .14046 m
.02756 .14046 L
s
.02381 .16855 m
.02756 .16855 L
s
.02381 .19665 m
.02756 .19665 L
s
.02381 .25283 m
.02756 .25283 L
s
.02381 .28092 m
.02756 .28092 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .3652 m
.02756 .3652 L
s
.02381 .39329 m
.02756 .39329 L
s
.02381 .42139 m
.02756 .42139 L
s
.02381 .47757 m
.02756 .47757 L
s
.02381 .50566 m
.02756 .50566 L
s
.02381 .53376 m
.02756 .53376 L
s
.02381 .58994 m
.02756 .58994 L
s
.02381 .61803 m
.02756 .61803 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03 w
.07143 .54542 Mdot
.11905 .54542 Mdot
.16667 .53532 Mdot
.21429 .50489 Mdot
.2619 .23686 Mdot
.30952 .15579 Mdot
.35714 .12532 Mdot
.40476 .10028 Mdot
.45238 .08394 Mdot
.5 .07586 Mdot
.54762 .06974 Mdot
.59524 .07531 Mdot
.64286 .05535 Mdot
.69048 .06597 Mdot
.7381 .05713 Mdot
.78571 .0582 Mdot
.83333 .06383 Mdot
.88095 .05718 Mdot
.92857 .06578 Mdot
.97619 .05392 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{367.188, 226.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005_0000hR000`400?l00000o`00003oo`3ooom`
0?ooo`00o`3ooom`0?ooo`00o`3ooom`0?ooo`00o`3ooom`0?ooo`00o`3ooom`0?ooo`00G`3oool8
000003d0oooo0P00000h0?ooo`@00000>`3oool4000003P0oooo0P0000060?ooo`@000002P3oool0
05l0oooo2000000m0?ooo`800000=`3oool6000003T0oooo1P00000g0?ooo`8000001@3oool60000
00T0oooo001O0?ooo`800000@`3oool2000003H0oooo0`0000030?ooo`800000=`3oool300000080
oooo0`00000f0?ooo`8000001@3oool200000080oooo0P0000090?ooo`00G`3oool3000003`0oooo
2@00000e0?ooo`800000103oool2000003L0oooo0P0000040?ooo`800000=P3oool2000000@0oooo
0P0000040?ooo`800000203oool00600oooo0`00000k0?ooo`T00000=@3oool2000000@0oooo0P00
000g0?ooo`800000103oool2000003H0oooo0P0000040?ooo`800000103oool2000000P0oooo001Q
0?ooo`<00000>P3oool2000000@0oooo0P00000f0?ooo`800000103oool2000003P0oooo0P000002
0?ooo`800000=`3oool2000000@0oooo0P0000040?ooo`800000203oool00680oooo0`00000j0?oo
o`8000000`3oool2000003H0oooo1`00000i0?ooo`H00000=`3oool2000000@0oooo0P0000040?oo
o`800000203oool006<0oooo0`00000j0?ooo`8000000P3oool2000003H0oooo0P000000103oool0
000000000000000j0?ooo`8000000P3oool2000003L0oooo0P0000040?ooo`800000103oool20000
00P0oooo001T0?ooo`<00000>@3oool200000080oooo0P00000f0?ooo`800000?@3oool2000000@0
oooo0P00000f0?ooo`800000103oool2000000@0oooo0P0000080?ooo`00I@3oool2000003X0oooo
0P0000000`3oool000000000000f0?ooo`800000?@3oool2000000@0oooo0P00000f0?ooo`800000
103oool2000000@0oooo0P0000080?ooo`00G`3oool2000000@0oooo0P00000k0?ooo`@00000=`3o
ool2000000<0oooo0P00000g0?ooo`<000000P3oool3000003<0oooo1@0000050?ooo`8000000P3o
ool2000000T0oooo001O0?ooo`L00000?@3oool3000003L0oooo1`00000h0?ooo`H00000=03oool5
000000D0oooo1P0000090?ooo`00H@3oool4000003l0oooo0P00000h0?ooo`@00000>`3oool40000
03P0oooo0P0000060?ooo`@000002P3oool00?l0ooooL03oool00?l0ooooL03oool00?l0ooooL03o
ool00?l0ooooL03oool001d0ooooo`00001;000000P0oooo000U0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03P3oool002D0oooo00<0
00000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?oo
o`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00
9@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03o
ool002D0oooo0P00003o0?ooodT0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0
oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooold
0?ooo`H0o`003P3oool002D0oooo00<000000?ooo`3oool0aP3oool60?l001T0oooo1P3o000Y0?oo
o`H0o`00603oool80?l000d0oooo000U0?ooo`030000003oool0oooo0<D0oooo203o000G0?ooo`P0
o`002@3oool60?l001P0oooo203o000G0?ooo`P0o`003@3oool002D0oooo00<000000?ooo`3oool0
a@3oool80?l001L0oooo203o00080?ooo`P0o`005`3oool80?l001L0oooo203o000=0?ooo`009@3o
ool00`000000oooo0?ooo`350?ooo`P0o`00203oool60?l000T0oooo203o00080?ooo`P0o`00203o
ool60?l000T0oooo203o00090?ooo`H0o`00203oool80?l000d0oooo000U0?ooo`800000aP3oool8
0?l000L0oooo203o00080?ooo`P0o`00203oool80?l000L0oooo203o00080?ooo`P0o`00203oool8
0?l000L0oooo203o000=0?ooo`009@3oool00`000000oooo0?ooo`2V0?ooo`H0o`006@3oool80?l0
00L0oooo203o00080?ooo`P0o`00203oool80?l000L0oooo203o00080?ooo`P0o`00203oool80?l0
00L0oooo203o000=0?ooo`009@3oool00`000000oooo0?ooo`2U0?ooo`P0o`002@3oool60?l000T0
oooo203o00070?ooo`P0o`00203oool80?l000P0oooo203o00070?ooo`P0o`00203oool80?l000P0
oooo203o00080?ooo`H0o`003P3oool002D0oooo00<000000?ooo`3oool0U`3oool60?l000P0oooo
203o00080?ooo`P0o`002@3oool60?l000P0oooo203o00090?ooo`H0o`002@3oool80?l000L0oooo
203o00090?ooo`H0o`002@3oool80?l001`0oooo000U0?ooo`030000003oool0oooo09H0oooo203o
00070?ooo`P0o`00203oool80?l001L0oooo203o000I0?ooo`H0o`00203oool80?l001P0oooo203o
000L0?ooo`009@3oool00`000000oooo0?ooo`270?ooo`H0o`002@3oool80?l000L0oooo203o0008
0?ooo`P0o`005`3oool80?l002L0oooo203o000H0?ooo`P0o`00703oool002D0oooo00<000000?oo
o`3oool0QP3oool80?l000P0oooo203o00070?ooo`P0o`00203oool80?l001P0oooo1P3o000Y0?oo
o`H0o`006P3oool60?l001d0oooo000U0?ooo`030000003oool0oooo08H0oooo203o00080?ooo`P0
o`001`3oool80?l000P0oooo203o002:0?ooo`009@3oool00`000000oooo0?ooo`260?ooo`P0o`00
203oool80?l000P0oooo1P3o00090?ooo`P0o`00RP3oool002D0oooo0P0000270?ooo`P0o`00203o
ool80?l001P0oooo1P3o002;0?ooo`009@3oool00`000000oooo0?ooo`260?ooo`P0o`002@3oool6
0?l00:X0oooo000U0?ooo`030000003oool0oooo07L0oooo1P3o00090?ooo`P0o`00^@3oool002D0
oooo00<000000?ooo`3oool0MP3oool80?l000T0oooo1P3o002j0?ooo`009@3oool00`000000oooo
0?ooo`1f0?ooo`P0o`00b@3oool002D0oooo00<000000?ooo`3oool0MP3oool80?l00<T0oooo0008
0?ooo`@00000103oool2000000<0oooo200000080?ooo`030000003oool0oooo07H0oooo203o0039
0?ooo`001`3oool6000000<0oooo0P0000030?ooo`P00000203oool00`000000oooo0?ooo`1f0?oo
o`P0o`00b@3oool000L0oooo0P0000020?ooo`800000203oool2000000h0oooo00<000000?ooo`3o
ool0MP3oool80?l00<T0oooo00060?ooo`800000103oool2000000L0oooo0`00000=0?ooo`<00000
M`3oool60?l00<X0oooo00060?ooo`800000103oool2000000P0oooo0`00000<0?ooo`030000003o
ool0oooo06P0oooo1P3o003I0?ooo`001P3oool2000000@0oooo0P0000090?ooo`<000002`3oool0
0`000000oooo0?ooo`1W0?ooo`P0o`00f03oool000H0oooo0P0000040?ooo`8000002P3oool30000
00X0oooo00<000000?ooo`3oool0I`3oool80?l00=P0oooo00060?ooo`800000103oool2000000/0
oooo0`0000090?ooo`030000003oool0oooo06L0oooo203o003H0?ooo`001P3oool2000000@0oooo
0P00000<0?ooo`<00000203oool00`000000oooo0?ooo`1W0?ooo`P0o`00f03oool000H0oooo0P00
00040?ooo`8000003@3oool2000000P0oooo00<000000?ooo`3oool0I`3oool80?l00=P0oooo0007
0?ooo`8000000P3oool2000000P0oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`1W
0?ooo`P0o`00f03oool000L0oooo1P0000080?ooo`L000002@3oool00`000000oooo0?ooo`1X0?oo
o`H0o`00f@3oool000P0oooo1000000;0?ooo`@000002P3oool200000?l0ooooB@3oool002D0oooo
00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`1H0?ooo`H0o`00j@3o
ool002D0oooo00<000000?ooo`3oool0E`3oool80?l00>P0oooo000U0?ooo`030000003oool0oooo
05L0oooo203o003X0?ooo`009@3oool00`000000oooo0?ooo`1G0?ooo`P0o`00j03oool002D0oooo
00<000000?ooo`3oool0E`3oool80?l00>P0oooo000U0?ooo`030000003oool0oooo05L0oooo203o
003X0?ooo`009@3oool00`000000oooo0?ooo`1G0?ooo`P0o`00j03oool002D0oooo00<000000?oo
o`3oool0F03oool60?l00>T0oooo000U0?ooo`800000o`3ooom90?ooo`009@3oool00`000000oooo
0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo00<00000
0?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`03
0000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3o
ool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool0
02D0oooo0P00003o0?ooodT0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo
00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U
0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?oo
o`00203oool4000000@0oooo0P0000090?ooo`800000203oool00`000000oooo0?ooo`3o0?ooodP0
oooo00070?ooo`H000000`3oool2000000T0oooo0P0000080?ooo`030000003oool0oooo0?l0oooo
B03oool000L0oooo0P0000020?ooo`8000003P3oool2000000P0oooo00<000000?ooo`3oool0o`3o
oom80?ooo`001P3oool2000000@0oooo0P0000070?ooo`T000001`3oool300000?l0ooooB03oool0
00H0oooo0P0000040?ooo`8000001`3oool9000000L0oooo00<000000?ooo`3oool0B03oool60?l0
0?T0oooo00060?ooo`800000103oool2000000L0oooo0P0000040?ooo`800000203oool00`000000
oooo0?ooo`170?ooo`P0o`00n03oool000H0oooo0P0000040?ooo`800000203oool2000000<0oooo
0P0000080?ooo`030000003oool0oooo04L0oooo203o003h0?ooo`001P3oool2000000@0oooo0P00
00090?ooo`8000000P3oool2000000P0oooo00<000000?ooo`3oool0A`3oool80?l00?P0oooo0006
0?ooo`800000103oool2000000T0oooo0P0000020?ooo`800000203oool00`000000oooo0?ooo`17
0?ooo`P0o`00n03oool000H0oooo0P0000040?ooo`8000002P3oool2000000030?ooo`0000000000
00P0oooo00<000000?ooo`3oool0A`3oool80?l00?P0oooo00070?ooo`8000000P3oool2000000`0
oooo100000080?ooo`030000003oool0oooo04L0oooo203o003h0?ooo`001`3oool6000000d0oooo
0`0000080?ooo`030000003oool0oooo04P0oooo1P3o003i0?ooo`00203oool4000000l0oooo0P00
00080?ooo`800000o`3ooom90?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?oo
o`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00
9@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03o
ool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?oo
odP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`009@3oool200000?l0ooooB@3oool002D0oooo00<000000?ooo`3oool0o`3ooom8
0?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0
ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?oo
o`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`800000
o`3ooom90?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0
oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool000P0oooo1000
00040?ooo`8000001@3oool4000000X0oooo00<000000?ooo`3oool0o`3ooom80?ooo`001`3oool6
000000<0oooo0P0000040?ooo`H000002@3oool00`000000oooo0?ooo`3o0?ooodP0oooo00070?oo
o`8000000P3oool2000000P0oooo0`0000030?ooo`800000203oool00`000000oooo0?ooo`3o0?oo
odP0oooo00060?ooo`800000103oool2000000L0oooo0P0000040?ooo`800000203oool300000?l0
ooooB03oool000H0oooo0P0000040?ooo`8000001`3oool2000000@0oooo0P0000080?ooo`030000
003oool0oooo0?l0ooooB03oool000H0oooo0P0000040?ooo`8000001`3oool2000000@0oooo0P00
00080?ooo`030000003oool0oooo0?l0ooooB03oool000H0oooo0P0000040?ooo`8000001`3oool7
000000T0oooo00<000000?ooo`3oool0o`3ooom80?ooo`001P3oool2000000@0oooo0P0000070?oo
o`80000000@0oooo00000000000000002P3oool00`000000oooo0?ooo`3o0?ooodP0oooo00060?oo
o`800000103oool2000000L0oooo0P00000>0?ooo`030000003oool0oooo0?l0ooooB03oool000H0
oooo0P0000040?ooo`8000001`3oool2000000h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00
1`3oool200000080oooo0P0000090?ooo`8000000`3oool2000000P0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`001`3oool6000000T0oooo1`0000080?ooo`030000003oool0oooo0?l0ooooB03o
ool000P0oooo1000000;0?ooo`@000002P3oool200000?l0ooooB@3oool002D0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000
003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0
oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo0P00003o0?ooodT0oooo000U0?oo
o`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00
9@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03o
ool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?oo
odP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`009@3oool200000?l0ooooB@3oool002D0oooo00<000000?ooo`3oool0o`3ooom8
0?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0
ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00203oool4000000@0oooo0P00
00050?ooo`@000002P3oool00`000000oooo0?ooo`3o0?ooodP0oooo00070?ooo`H000000`3oool2
000000@0oooo1P0000090?ooo`030000003oool0oooo0?l0ooooB03oool000L0oooo0P0000020?oo
o`800000203oool300000080oooo0`0000080?ooo`030000003oool0oooo0?l0ooooB03oool000H0
oooo0P0000040?ooo`8000001`3oool2000000@0oooo0P0000080?ooo`030000003oool0oooo0?l0
ooooB03oool000H0oooo0P0000040?ooo`8000001`3oool2000000@0oooo0P0000080?ooo`<00000
o`3ooom80?ooo`001P3oool2000000@0oooo0P0000080?ooo`8000000P3oool2000000T0oooo00<0
00000?ooo`3oool0o`3ooom80?ooo`001P3oool2000000@0oooo0P0000080?ooo`H000002@3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo00060?ooo`800000103oool2000000P0oooo0P0000020?oo
o`8000002@3oool00`000000oooo0?ooo`3o0?ooodP0oooo00060?ooo`800000103oool2000000L0
oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`3o0?ooodP0oooo00060?ooo`800000
103oool2000000L0oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`3o0?ooodP0oooo
00070?ooo`8000000P3oool2000000P0oooo0`0000020?ooo`<00000203oool00`000000oooo0?oo
o`3o0?ooodP0oooo00070?ooo`H000002@3oool6000000T0oooo00<000000?ooo`3oool0o`3ooom8
0?ooo`00203oool4000000/0oooo1000000:0?ooo`030000003oool0oooo0?l0ooooB03oool002D0
oooo0P00003o0?ooodT0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo00<0
00000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?oo
o`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00
9@3oool00`000000oooo0?ooo`0i0?ooo`H0o`00o`3oool90?ooo`009@3oool00`000000oooo0?oo
o`0h0?ooo`P0o`00o`3oool80?ooo`009@3oool00`000000oooo0?ooo`0h0?ooo`P0o`00o`3oool8
0?ooo`009@3oool00`000000oooo0?ooo`0h0?ooo`P0o`00o`3oool80?ooo`009@3oool2000003T0
oooo203o003o0?ooo`P0oooo000U0?ooo`030000003oool0oooo03P0oooo203o003o0?ooo`P0oooo
000U0?ooo`030000003oool0oooo03P0oooo203o003o0?ooo`P0oooo000U0?ooo`030000003oool0
oooo03T0oooo1P3o003o0?ooo`T0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0
oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`0Y0?ooo`H0o`00
o`3ooolI0?ooo`009@3oool00`000000oooo0?ooo`0X0?ooo`P0o`00o`3ooolH0?ooo`009@3oool0
0`000000oooo0?ooo`0X0?ooo`P0o`00o`3ooolH0?ooo`009@3oool2000000/0oooo1P3o00090?oo
o`H0o`002@3oool80?l00?l0oooo603oool002D0oooo00<000000?ooo`3oool02@3oool80?l000L0
oooo203o00080?ooo`P0o`00o`3ooolH0?ooo`009@3oool00`000000oooo0?ooo`090?ooo`P0o`00
1`3oool80?l000P0oooo203o003o0?oooaP0oooo000U0?ooo`030000003oool0oooo00T0oooo203o
00070?ooo`P0o`00203oool80?l00?l0oooo603oool002D0oooo00<000000?ooo`3oool02@3oool8
0?l000L0oooo203o00090?ooo`H0o`00o`3ooolI0?ooo`006@3oool2000000X0oooo00<000000?oo
o`3oool02@3oool80?l000L0oooo203o003o0?ooobP0oooo000I0?ooo`8000002P3oool00`000000
oooo0?ooo`090?ooo`P0o`001`3oool80?l00?l0oooo:03oool001T0oooo0P00000:0?ooo`030000
003oool0oooo00X0oooo1P3o00090?ooo`H0o`00o`3ooolY0?ooo`006@3oool2000000X0oooo00<0
00000?ooo`3oool0o`3ooom80?ooo`006@3oool2000000X0oooo0`00003o0?ooodP0oooo000I0?oo
o`8000002P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000I0?ooo`8000002P3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000I0?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000I0?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000I0?ooo`8000002P3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo000F0?ooo`D000002P3oool00`000000oooo0?ooo`3o0?oo
odP0oooo000F0?ooo`D000002P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000I0?ooo`800000
2P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`800000o`3ooom90?ooo`009@3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0
oooo00<000000?ooo`3oool0o`3ooom80?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000U0?ooo`030000003oool0oooo0?l0ooooB03oool002D0oooo00<000000?ooo`3oool0o`3ooom8
0?ooo`009@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000U0?ooo`030000003oool0oooo0?l0
ooooB03oool002D0oooo0P00003o0?ooodT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 366.188}, {225.938, 0}} -> {-1.18243, -0.122708, \
0.0319259, 0.0054117}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{879, 878},
WindowMargins->{{3, Automatic}, {Automatic, 1}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 66, 1, 58, "Subtitle"],
Cell[1845, 56, 114, 2, 33, "Subsubtitle"],
Cell[1962, 60, 237, 6, 79, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2224, 70, 40, 0, 76, "Section"],

Cell[CellGroupData[{
Cell[2289, 74, 104, 2, 45, "Input"],
Cell[2396, 78, 355, 5, 20, "Message"]
}, Open  ]],
Cell[2766, 86, 233, 8, 81, "Text"],

Cell[CellGroupData[{
Cell[3024, 98, 94, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[3143, 105, 138, 3, 44, "Input"],
Cell[3284, 110, 962, 13, 139, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4295, 129, 48, 0, 38, "Subsection"],
Cell[4346, 131, 1581, 27, 251, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5976, 164, 34, 0, 76, "Section"],

Cell[CellGroupData[{
Cell[6035, 168, 230, 5, 59, "Input"],
Cell[6268, 175, 1026, 20, 202, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7331, 200, 662, 18, 27, "Input"],
Cell[7996, 220, 16315, 249, 296, 1390, 60, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24360, 475, 29, 0, 76, "Section"],
Cell[24392, 477, 194, 3, 59, "Input"],
Cell[24589, 482, 102, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[24716, 489, 1844, 31, 311, "Input"],
Cell[26563, 522, 190, 4, 23, "Print"],
Cell[26756, 528, 189, 4, 23, "Print"],
Cell[26948, 534, 191, 4, 23, "Print"],
Cell[27142, 540, 190, 4, 23, "Print"],
Cell[27335, 546, 192, 4, 23, "Print"],
Cell[27530, 552, 190, 4, 23, "Print"],
Cell[27723, 558, 192, 4, 23, "Print"],
Cell[27918, 564, 189, 4, 23, "Print"],
Cell[28110, 570, 190, 4, 23, "Print"],
Cell[28303, 576, 191, 4, 23, "Print"],
Cell[28497, 582, 192, 4, 23, "Print"],
Cell[28692, 588, 191, 4, 23, "Print"],
Cell[28886, 594, 192, 4, 23, "Print"],
Cell[29081, 600, 191, 4, 23, "Print"],
Cell[29275, 606, 192, 4, 23, "Print"],
Cell[29470, 612, 189, 4, 23, "Print"],
Cell[29662, 618, 192, 4, 23, "Print"],
Cell[29857, 624, 191, 4, 23, "Print"],
Cell[30051, 630, 192, 4, 23, "Print"],
Cell[30246, 636, 194, 4, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30477, 645, 234, 4, 43, "Input"],
Cell[30714, 651, 27719, 753, 235, 12196, 557, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

